# vi: ts=8 sw=8

package Tongues::Cymraeg;

use strict;
use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $charset $grammar %dictionary);

use Exporter   ();
# set the version for version checking
@ISA         = qw(Exporter);
@EXPORT      = qw(charset grammar dictionary);
@EXPORT_OK   = qw();
$VERSION     = 0.00;

# Character set ISO 8859-14 / Latin-8

# Alphabetical order
# A B C CH D DD E F FF G NG H I (J K) L LL M N O P PH (Q) R S T TH U (V) W (X) Y (Z)
# a b c ch d dd e f ff g ng h i (j k) l ll m n o p ph (q) r s t th u (v) w (x) y (z)

# Extra characters (ISO)
#                        
#                        

sub new {
	my $class = shift;
	my $self = bless {}, $class;
	return $self;
}

sub charset {
	return $charset;
}

sub grammar {
	return $grammar;
}

sub dictionary {
	return \%dictionary;
}

sub BEGIN {

require Charsets::Latin8;

$charset = new Charsets::Latin8;

# Table for converting words to root form
$grammar = [
 # Soft mutation
 [ 'g-',	'c-',	'',		'',	'n' ],
 [ 'b-',	'p-',	'',		'',	'n' ],
 [ 'd-',	't-',	'',		'',	'n' ],
 [ '',		'g-',	'',		'',	'n' ],
 [ 'f-',	'b-',	'',		'',	'n' ],
 [ 'dd-',	'd-',	'',		'',	'n' ],
 [ 'f-',	'm-',	'',		'',	'n' ],
 [ 'l-',	'll-',	'',		'',	'n' ],
 [ 'r-',	'rh-',	'',		'',	'n' ],
 # Noun case
 # Noun gender
 # Noun plural
 # Adjectives
 # Verb past participle
 # Verb gerund
 # Verb present participle
 # Verb present
 # Verb present subjunctive
 # Verb imperitive
 # Verb preterite
 # Verb imperfect
 # Verb future
 # Verb conditional
 # Adverb
 # Higher level transformations
];

#Fields:
# x -> translatioin		all words
# r -> root			irregular declensions
# t -> type:			all words
#	n -> noun
#	v -> verb
#	a -> adjective
#	p -> preposition
#	art -> article
#	pro -> pronoun
#	conj -> conjugation
#	adv -> adverb
# g -> gender:			nouns, pronouns, adjectives
#	m -> masculine		default
#	f -> feminine
# n -> number:			articles, pronouns, verbs, adjectives
#	s -> singular		default
#	d -> dual
#	t -> trial
#	p -> plural
# p -> person:			pronouns, verbs
#	1 -> 1st person
#	2 -> 2nd person
#	3 -> 3rd person		default
# c -> conjugation:
#	p -> present
#	i -> imperfect
#	f -> future
#	c -> conditional
#	t -> preterite
#	ps -> present subjunctive
#	is -> imperfect subjunctive
#	inf -> infinitive		default
#	pp -> past participle
#	g -> gerund
#	imp -> imperative
# c -> case:
#	n -> nominative 		default
#	a -> accusative 

# Cymraeg to English dictionary
%dictionary = (
 # Functional words
 #  Articles
 #   Definite articles
 #    Masculine
 #     Singular
 #     Plural
 #    Feminine
 #     Singular
 #     Plural
 #   Indefinite articles
 #  Pronouns & possessive adjectives
 #   1st person
 #   2nd person
 #   3rd person
 #   Other pronouns
 #  Interrogatives
 #  Other functional words
 'a'		=> { 'x' => 'and' },
 'ac'		=> { 'x' => 'and' },
 'achos'	=> { 'x' => 'as',
		     '#' => ', because, for, since' },
 'at'		=> { 'x' => 'at',
		     '#' => ', to, toward, towards' },
 'gan'		=> { 'x' => 'with' },
 'ger'		=> { 'x' => 'at',
		     '#' => ', beside, by, near, nearby, near to, next to' },
 'gyda'		=> { 'x' => 'with' },
 'heb'		=> { 'x' => 'without' },
 'i'		=> { 'x' => 'a',
		     '#' => ', in, inside, into, on, per, within, for, to, in order to, per' },
 'mewn'		=> { 'x' => 'a',
		     '#' => ', in, inside, into, on, per, within' },
 'yn'		=> { 'x' => 'a',
		     '#' => ', in, inside, into, on, per, within' },
 ''		=> { 'x' => 'by',
		     '#' => ', by means of, on, through, with' },
 #   Partitive / Contractions
 # Numbers: cardinal and ordinal
 'dwy'		=> { 'x' => 'two' },
 'dwy waith'	=> { 'x' => 'twice' },
 'pedair'	=> { 'x' => 'four' },
 'pedwar'	=> { 'x' => 'four' },
 'pedwaredd'	=> { 'x' => 'fourth' },
 'pedwerydd'	=> { 'x' => 'fourth' },
 'pedair ar ddeg'	=> { 'x' => 'fourteen' },
 'pedair ar bymtheg'	=> { 'x' => 'nineteen' },
 'pedwar ar ddeg'	=> { 'x' => 'fourteen' },
 'pedwaredd ar ddeg'	=> { 'x' => 'fourteenth' },
 'pedwerydd ar ddeg'	=> { 'x' => 'fourteenth' },
 'dwy ar bymtheg'	=> { 'x' => 'seventeen' },
 'pedwar ar bymtheg'	=> { 'x' => 'nineteen' },
 'pedwaredd ar bymtheg'	=> { 'x' => 'nineteenth' },
 'pedwerydd ar bymtheg'	=> { 'x' => 'nineteenth' },
 'pedwar ugain'	=> { 'x' => 'eighty' },
 'pedwar ugain a deg'	=> { 'x' => 'ninety' },
 'mil'		=> { 'x' => 'thousand',
		     '#' => ', one thousand' },
 'miliwn'	=> { 'x' => 'million' },
 # Days and months
 # Key verbs
 # Vocabulary
 'abad'		=> { 'x' => 'abbot' },
 'abades'	=> { 'x' => 'abbess' },
 'abaty'	=> { 'x' => 'abbey' },
 'aber'		=> { 'x' => 'mouth' },
 'achosi'	=> { 'x' => 'cause',
		     '#' => ', reason' },
 'adda'		=> { 'x' => 'adam',
		     't' => 'n',
		     '#' => 'capitalize' },
 'adeg'		=> { 'x' => 'time',
		     '#' => ', while' },
 'adeiladu'	=> { 'x' => 'build',
		     '#' => ', construct' },
 'aderyn'	=> { 'x' => 'bird' },
 'adnabod'	=> { 'x' => 'be acquainted with',
		     '#' => ', know' },
 'adref'	=> { 'x' => 'home' },
 'afal'		=> { 'x' => 'apple' },
 'afon'		=> { 'x' => 'river' },
 'agor'		=> { 'x' => 'open',
		     '#' => ', open up' },
 'ail'		=> { 'x' => 'second' },
 'ail ar bymtheg'	=> { 'x' => 'seventeenth' },
 'albanwr'	=> { 'x' => 'scot',
		     't' => 'n',
		     '#' => 'capitalize',
		     '#' => ', scotsman' },
 'algebra'	=> { 'x' => 'algebra' },
 'almaeneg'	=> { 'x' => 'german',
		     't' => 'n',
		     '#' => 'capitalize',
		     '#' => ', german woman' },
 'almaenwr'	=> { 'x' => 'german',
		     't' => 'n',
		     '#' => 'capitalize' },
 'alpau'	=> { 'x' => 'alps',
		     't' => 'n',
		     '#' => 'capitalize' },
 'am'		=> { 'x' => 'at',
		     '#' => ', by, on, upon, about, concerning, on, upon' },
 'amser'	=> { 'x' => 'time',
		     '#' => ', while' },
 'anadl'	=> { 'x' => 'breath' },
 'anfon'	=> { 'x' => 'send',
		     '#' => ', transmit' },
 'anghofio'	=> { 'x' => 'forget' },
 'anhawdd'	=> { 'x' => 'difficult',
		     '#' => ', hard, inconvenient' },
 'annwyd'	=> { 'x' => 'cold',
		     '#' => ', cold' },
 'anodd'	=> { 'x' => 'difficult',
		     '#' => ', hard, inconvenient' },
 'anrheg'	=> { 'x' => 'gift',
		     '#' => ', present' },
 'anthem'	=> { 'x' => 'corn chamomile' },
 'ar'		=> { 'x' => 'on',
		     '#' => ', upon' },
 'ar agor'	=> { 'x' => 'open' },
 'ar gau'	=> { 'x' => 'closed',
		     '#' => ', shut' },
 'ar hyd'	=> { 'x' => 'along' },
 'ar unwaith'	=> { 'x' => 'at once',
		     '#' => ', immediately, just, right away, right now' },
 'ar l'	=> { 'x' => 'behind',
		     '#' => ', after, after, behind' },
 'araf'		=> { 'x' => 'slow',
		     '#' => ', slow' },
 'arall'	=> { 'x' => 'other',
		     '#' => ', another, else' },
 'arglwydd'	=> { 'x' => 'god',
		     't' => 'n',
		     '#' => 'capitalize' },
 'arholiad'	=> { 'x' => 'investigation',
		     '#' => ', examination, test' },
 'arian'	=> { 'x' => 'money' },
 'aros'		=> { 'x' => 'halt',
		     '#' => ', come to a halt, stop, remain, stay, stay over' },
 'arth'		=> { 'x' => 'bear' },
 'arthes'	=> { 'x' => 'bear' },
 'arwain'	=> { 'x' => 'conduct',
		     '#' => ', direct, guide, head, lead' },
 'asyn'		=> { 'x' => 'ass',
		     '#' => ', donkey' },
 'ateb'		=> { 'x' => 'answer',
		     '#' => ', reply, respond, answer, reply' },
 'athen'	=> { 'x' => 'athens',
		     't' => 'n',
		     '#' => 'capitalize' },
 'athro'	=> { 'x' => 'instructor',
		     '#' => ', teacher' },
 'aur'		=> { 'x' => 'gold' },
 'awel'		=> { 'x' => 'breeze' },
 'awr'		=> { 'x' => 'hour',
		     '#' => ', o\'clock, time' },
 'awst'		=> { 'x' => 'august',
		     't' => 'n',
		     '#' => 'capitalize' },
 'awstralia'	=> { 'x' => 'australia',
		     't' => 'n',
		     '#' => 'capitalize' },
 'awstria'	=> { 'x' => 'austria',
		     't' => 'n',
		     '#' => 'capitalize' },
 'awyren'	=> { 'x' => 'aeroplane',
		     '#' => ', airplane, plane, aircraft' },
 'baban'	=> { 'x' => 'baby' },
 'bach'		=> { 'x' => 'diminutive',
		     '#' => ', little, small' },
 'bachgen'	=> { 'x' => 'boy',
		     '#' => ', lad, laddie' },
 'balch'	=> { 'x' => 'proud' },
 'banc'		=> { 'x' => 'bank' },
 'baner'	=> { 'x' => 'flag',
		     '#' => ', standard' },
 'bara'		=> { 'x' => 'bread',
		     '#' => ', loaf' },
 'bardd'	=> { 'x' => 'bard',
		     '#' => ', poet' },
 'basged'	=> { 'x' => 'basket' },
 'bedwen'	=> { 'x' => 'birch' },
 'beibl'	=> { 'x' => 'bible',
		     't' => 'n',
		     '#' => 'capitalize' },
 'beisicl'	=> { 'x' => 'bike',
		     '#' => ', cycle, bicycle, bike, bicycle' },
 'berwi'	=> { 'x' => 'boil' },
 'bisged'	=> { 'x' => 'biscuit',
		     '#' => ', cookie' },
 'blaidd'	=> { 'x' => 'wolf' },
 'blino'	=> { 'x' => 'get tired' },
 'blodeuyn'	=> { 'x' => 'bloom',
		     '#' => ', flower' },
 'blwyddyn'	=> { 'x' => 'year' },
 'bore'		=> { 'x' => 'morning' },
 'braidd'	=> { 'x' => 'barely',
		     '#' => ', hardly, only just, scarcely' },
 'brawd'	=> { 'x' => 'brother' },
 'brecwast'	=> { 'x' => 'breakfast' },
 'brenhines'	=> { 'x' => 'queen' },
 'brithwr'	=> { 'x' => 'pict',
		     't' => 'n',
		     '#' => 'capitalize' },
 'bro morgannwg'	=> { 'x' => 'vale of glamorgan',
		     't' => 'n',
		     '#' => 'capitalize' },
 'brown'	=> { 'x' => 'brown' },
 'brwnt'	=> { 'x' => 'dirty',
		     '#' => ', filthy, nasty, soiled, unclean' },
 'bryn'		=> { 'x' => 'hill' },
 'brython'	=> { 'x' => 'briton',
		     't' => 'n',
		     '#' => 'capitalize',
		     '#' => ', welshman' },
 'brythoneg'	=> { 'x' => 'welsh',
		     't' => 'n',
		     '#' => 'capitalize',
		     '#' => ', welsh language' },
 'buan'		=> { 'x' => 'fast',
		     '#' => ', quick, rapid, speedy, swift' },
 'bugail'	=> { 'x' => 'shepherd' },
 'bus'		=> { 'x' => 'bus',
		     '#' => ', autobus, omnibus' },
 'busnes'	=> { 'x' => 'affair',
		     '#' => ', business, business deal, case, matter' },
 'buwch'	=> { 'x' => 'calf' },
 'bwced'	=> { 'x' => 'bucket',
		     '#' => ', pail' },
 'bwrdd'	=> { 'x' => 'table' },
 'bwrw glaw'	=> { 'x' => 'rain' },
 'bwyd'		=> { 'x' => 'food' },
 'bychan'	=> { 'x' => 'diminutive',
		     '#' => ', little, small' },
 'byd'		=> { 'x' => 'world' },
 'byr'		=> { 'x' => 'short',
		     '#' => ', brief, short' },
 'byth'		=> { 'x' => 'at some time',
		     '#' => ', ever, sometime' },
 'byw'		=> { 'x' => 'be alive',
		     '#' => ', live' },
 'cadair'	=> { 'x' => 'chair' },
 'cadnawes'	=> { 'x' => 'vixen' },
 'cadno'	=> { 'x' => 'fox' },
 'cadw'		=> { 'x' => 'hang onto',
		     '#' => ', hold' },
 'cael'		=> { 'x' => 'get',
		     '#' => ', have, receive' },
 'caerdydd'	=> { 'x' => 'cardiff',
		     't' => 'n',
		     '#' => 'capitalize' },
 'caeredin'	=> { 'x' => 'edinburgh',
		     't' => 'n',
		     '#' => 'capitalize' },
 'caerefrog'	=> { 'x' => 'york',
		     't' => 'n',
		     '#' => 'capitalize' },
 'caerludd'	=> { 'x' => 'london',
		     't' => 'n',
		     '#' => 'capitalize' },
 'caint'	=> { 'x' => 'kent',
		     't' => 'n',
		     '#' => 'capitalize' },
 'caled'	=> { 'x' => 'hard',
		     '#' => ', hard' },
 'calon'	=> { 'x' => 'heart' },
 'canol'	=> { 'x' => 'average',
		     '#' => ', mean, middle' },
 'cant'		=> { 'x' => 'hundred',
		     '#' => ', one hundred' },
 'canu'		=> { 'x' => 'sing',
		     '#' => ', play, play' },
 'cap'		=> { 'x' => 'cap' },
 'capel'	=> { 'x' => 'chapel' },
 'car'		=> { 'x' => 'car' },
 'caredig'	=> { 'x' => 'affable',
		     '#' => ', friendly, good-natured, kind' },
 'cario'	=> { 'x' => 'carry',
		     '#' => ', wear' },
 'carreg'	=> { 'x' => 'stone' },
 'cartref'	=> { 'x' => 'home' },
 'caru'		=> { 'x' => 'love',
		     '#' => ', appreciate, like' },
 'carw'		=> { 'x' => 'deer' },
 'castell'	=> { 'x' => 'castle' },
 'cath'		=> { 'x' => 'cat' },
 'cau'		=> { 'x' => 'close',
		     '#' => ', shut' },
 'cawrfil'	=> { 'x' => 'elephant' },
 'caws'		=> { 'x' => 'cheese' },
 'ceffyl'	=> { 'x' => 'horse' },
 'cegin'	=> { 'x' => 'kitchen' },
 'ceinach'	=> { 'x' => 'hare' },
 'ceiniog'	=> { 'x' => 'penny' },
 'cerdded'	=> { 'x' => 'march',
		     '#' => ', walk' },
 'chwaer'	=> { 'x' => 'sister' },
 'chwant'	=> { 'x' => 'desire',
		     '#' => ', want, wish' },
 'chwarae'	=> { 'x' => 'play',
		     '#' => ', play' },
 'chwe'		=> { 'x' => 'six' },
 'chwech'	=> { 'x' => 'six' },
 'chweched'	=> { 'x' => 'sixth' },
 'chwefror'	=> { 'x' => 'february',
		     't' => 'n',
		     '#' => 'capitalize' },
 'chwerthin'	=> { 'x' => 'laugh' },
 'chwith'	=> { 'x' => 'left' },
 'ci'		=> { 'x' => 'dog' },
 'cledd'	=> { 'x' => 'sword' },
 'cleddau'	=> { 'x' => 'sword' },
 'cleddyf'	=> { 'x' => 'sword' },
 'clir'		=> { 'x' => 'clear',
		     '#' => ', distinct, plain' },
 'cloc'		=> { 'x' => 'clock',
		     '#' => ', watch' },
 'cloch'	=> { 'x' => 'bell' },
 'clywed'	=> { 'x' => 'hear' },
 'cneuen ffrengig'	=> { 'x' => 'walnut' },
 'coch'		=> { 'x' => 'red' },
 'codi'		=> { 'x' => 'get up' },
 'coeden'	=> { 'x' => 'tree' },
 'coffi'	=> { 'x' => 'coffee' },
 'cofio'	=> { 'x' => 'recall',
		     '#' => ', recollect, remember' },
 'colli'	=> { 'x' => 'lose' },
 'cordyn'	=> { 'x' => 'cord',
		     '#' => ', rope, string' },
 'cornel'	=> { 'x' => 'corner' },
 'cot'		=> { 'x' => 'coat',
		     '#' => ', overcoat' },
 'craig'	=> { 'x' => 'boulder' },
 'credu'	=> { 'x' => 'account',
		     '#' => ', accredit, believe, deem' },
 'creulon'	=> { 'x' => 'cruel' },
 'crist'	=> { 'x' => 'christ',
		     't' => 'n',
		     '#' => 'capitalize' },
 'cristion'	=> { 'x' => 'christian',
		     't' => 'n',
		     '#' => 'capitalize' },
 'cristionogol'	=> { 'x' => 'christian',
		     't' => 'n',
		     '#' => 'capitalize' },
 'croesi'	=> { 'x' => 'cross' },
 'crwn'		=> { 'x' => 'round' },
 'crwtyn'	=> { 'x' => 'boy',
		     '#' => ', lad, laddie' },
 'cryf'		=> { 'x' => 'strong' },
 'cuddio'	=> { 'x' => 'conceal',
		     '#' => ', hide' },
 'cudyll'	=> { 'x' => 'hawk' },
 'curyll'	=> { 'x' => 'hawk' },
 'cwch'		=> { 'x' => 'boat' },
 'cwcw'		=> { 'x' => 'cuckoo' },
 'cwestiwn'	=> { 'x' => 'question' },
 'cwm'		=> { 'x' => 'valley' },
 'cwningen'	=> { 'x' => 'rabbit' },
 'cwpan'	=> { 'x' => 'cup' },
 'cwpwrdd'	=> { 'x' => 'cabinet',
		     '#' => ', closet, cupboard, sideboard' },
 'cwrdd'	=> { 'x' => 'come across',
		     '#' => ', encounter, meet, see' },
 'cwt'		=> { 'x' => 'tail' },
 'cwympo'	=> { 'x' => 'drop',
		     '#' => ', fall' },
 'cyfaill'	=> { 'x' => 'friend' },
 'cyfarfod'	=> { 'x' => 'come across',
		     '#' => ', encounter, meet, see' },
 'cyflym'	=> { 'x' => 'fast',
		     '#' => ', quick, rapid, speedy, swift' },
 'cyllell'	=> { 'x' => 'knife' },
 'cymraeg'	=> { 'x' => 'welsh',
		     't' => 'n',
		     '#' => 'capitalize',
		     '#' => ', welsh language' },
 'cymreig'	=> { 'x' => 'welsh',
		     't' => 'n',
		     '#' => 'capitalize' },
 'cymru'	=> { 'x' => 'wales',
		     't' => 'n',
		     '#' => 'capitalize' },
 'cymryd'	=> { 'x' => 'get',
		     '#' => ', lay hold of, pick up, take' },
 'cyn'		=> { 'x' => 'before',
		     '#' => ', in front of' },
 'cyngerdd'	=> { 'x' => 'concert' },
 'cynnes'	=> { 'x' => 'warm' },
 'cyntaf'	=> { 'x' => 'first' },
 'cyrraedd'	=> { 'x' => 'accomplish',
		     '#' => ', achieve, attain, get, reach' },
 'cysgu'	=> { 'x' => 'be asleep',
		     '#' => ', sleep' },
 'cywir'	=> { 'x' => 'falcon' },
 'cn'		=> { 'x' => 'song' },
 'cr'		=> { 'x' => 'chorus',
		     '#' => ', coir' },
 'da'		=> { 'x' => 'good',
		     '#' => ', nice, okay' },
 'dafad'	=> { 'x' => 'sheep' },
 'dafydd'	=> { 'x' => 'david',
		     't' => 'n',
		     '#' => 'capitalize' },
 'dal'		=> { 'x' => 'capture',
		     '#' => ', catch, grapple' },
 'damwain'	=> { 'x' => 'accident' },
 'dan'		=> { 'x' => 'below',
		     '#' => ', beneath, under, underneath' },
 'dangos'	=> { 'x' => 'indicate',
		     '#' => ', point out, show' },
 'dannoedd'	=> { 'x' => 'toothache' },
 'dant'		=> { 'x' => 'tooth' },
 'darfod'	=> { 'x' => 'become',
		     '#' => ', come about, grow, happen, come about, happen, occur' },
 'darllen'	=> { 'x' => 'read' },
 'darlun'	=> { 'x' => 'painting',
		     '#' => ', picture' },
 'darn'		=> { 'x' => 'bit',
		     '#' => ', lump, piece' },
 'dau'		=> { 'x' => 'two' },
 'dau ar bymtheg'	=> { 'x' => 'seventeen' },
 'dau gant'	=> { 'x' => 'two hundred' },
 'dawns'	=> { 'x' => 'dance' },
 'dawnsio'	=> { 'x' => 'dance' },
 'ddoe'		=> { 'x' => 'yesterday' },
 'deall'	=> { 'x' => 'understand',
		     '#' => ', realize' },
 'dechrau'	=> { 'x' => 'begin',
		     '#' => ', commence, start' },
 'deffro'	=> { 'x' => 'wake',
		     '#' => ', wake up' },
 'deg'		=> { 'x' => 'ten' },
 'deg a deugain'	=> { 'x' => 'fifty' },
 'deg a phedwar ugain'	=> { 'x' => 'ninety' },
 'deg a thrigain'	=> { 'x' => 'seventy' },
 'deg ar hugain'	=> { 'x' => 'thirty' },
 'degfed'	=> { 'x' => 'tenth' },
 'deintydd'	=> { 'x' => 'dentist' },
 'desg'		=> { 'x' => 'desk',
		     '#' => ', writing desk, writing-desk' },
 'deuddeg'	=> { 'x' => 'twelve' },
 'deuddegfed'	=> { 'x' => 'twelfth' },
 'deugain'	=> { 'x' => 'forty' },
 'deunaw'	=> { 'x' => 'eighteen' },
 'deunawfed'	=> { 'x' => 'eighteenth' },
 'dewi'		=> { 'x' => 'david',
		     't' => 'n',
		     '#' => 'capitalize' },
 'dewin'	=> { 'x' => 'enchanter',
		     '#' => ', magician, sorcerer, warlock, wizard' },
 'diddorol'	=> { 'x' => 'interesting' },
 'digon'	=> { 'x' => 'enough',
		     '#' => ', sufficient' },
 'dim'		=> { 'x' => 'anything',
		     '#' => ', something' },
 'dinas'	=> { 'x' => 'city',
		     '#' => ', metropolis' },
 'diolch'	=> { 'x' => 'thank you',
		     '#' => ', thanks' },
 'dod'		=> { 'x' => 'come' },
 'dod '	=> { 'x' => 'bring',
		     '#' => ', fetch' },
 'doe'		=> { 'x' => 'yesterday' },
 'doenitheb'	=> { 'x' => 'wisdom' },
 'dofydd'	=> { 'x' => 'god',
		     't' => 'n',
		     '#' => 'capitalize' },
 'dolgelly'	=> { 'x' => 'dolgelly',
		     't' => 'n',
		     '#' => 'capitalize' },
 'draig'	=> { 'x' => 'dragon' },
 'dringo'	=> { 'x' => 'climb' },
 'drwg'		=> { 'x' => 'bad',
		     '#' => ', miserable, nasty, poor, airy-fairy, frolic, frolicsome, petulant' },
 'drws'		=> { 'x' => 'door' },
 'drwy'		=> { 'x' => 'through' },
 'du'		=> { 'x' => 'black' },
 'dulyn'	=> { 'x' => 'dublin',
		     't' => 'n',
		     '#' => 'capitalize' },
 'duw'		=> { 'x' => 'god',
		     't' => 'n',
		     '#' => 'capitalize' },
 'dweud'	=> { 'x' => 'say',
		     '#' => ', tell, narrate, relate, tell' },
 'dwr'		=> { 'x' => 'water' },
 'dwsin'	=> { 'x' => 'dozen' },
 'dydd'		=> { 'x' => 'day' },
 'dydd gwener y groglith'	=> { 'x' => 'good friday',
		     't' => 'n',
		     '#' => 'capitalize' },
 'dydd llun'	=> { 'x' => 'monday' },
 'dydd sadwrn'	=> { 'x' => 'sabbath' },
 'dydd sul'	=> { 'x' => 'sunday' },
 'dyfod'	=> { 'x' => 'come' },
 'dyfod '	=> { 'x' => 'bring',
		     '#' => ', fetch' },
 'dyma'		=> { 'x' => 'behold',
		     '#' => ', here is, here are, look, there' },
 'dyn'		=> { 'x' => 'fellow',
		     '#' => ', man' },
 'dyna'		=> { 'x' => 'there is',
		     '#' => ', there are' },
 'dynes'	=> { 'x' => 'woman' },
 'dysgu'	=> { 'x' => 'teach',
		     '#' => ', learn' },
 'dywalgi'	=> { 'x' => 'tiger' },
 'dywedyd'	=> { 'x' => 'say',
		     '#' => ', tell, narrate, relate, tell' },
 'ebrill'	=> { 'x' => 'april',
		     't' => 'n',
		     '#' => 'capitalize' },
 'ef'		=> { 'x' => 'he',
		     '#' => ', him, it' },
 'efa'		=> { 'x' => 'eva',
		     't' => 'n',
		     '#' => 'capitalize' },
 'efrog'	=> { 'x' => 'york',
		     't' => 'n',
		     '#' => 'capitalize' },
 'eglwys'	=> { 'x' => 'church',
		     '#' => ', church-building, house of worship, place of worship' },
 'ei'		=> { 'x' => 'his',
		     '#' => ', her, his, its, their, her' },
 'eifftaidd'	=> { 'x' => 'egyptian',
		     't' => 'n',
		     '#' => 'capitalize' },
 'ein'		=> { 'x' => 'our' },
 'eira'		=> { 'x' => 'snow' },
 'eisiau'	=> { 'x' => 'need',
		     '#' => ', want' },
 'eistedd'	=> { 'x' => 'sit' },
 'eliffant'	=> { 'x' => 'elephant' },
 'enw'		=> { 'x' => 'appellation',
		     '#' => ', name' },
 'er'		=> { 'x' => 'since',
		     '#' => ', from, since, though, although' },
 'erioed'	=> { 'x' => 'at some time',
		     '#' => ', ever, sometime' },
 'eropln'	=> { 'x' => 'aeroplane',
		     '#' => ', airplane, plane, aircraft' },
 'ers'		=> { 'x' => 'from',
		     '#' => ', since' },
 'erthygl'	=> { 'x' => 'article',
		     't' => 'n' },
 'eryr'		=> { 'x' => 'eagle' },
 'eto'		=> { 'x' => 'still',
		     '#' => ', yet, afresh, again, all over again, anew, afresh, again, once more' },
 'ewrob'	=> { 'x' => 'europe',
		     't' => 'n',
		     '#' => 'capitalize' },
 'fe'		=> { 'x' => 'he',
		     '#' => ', him, it' },
 'felly'	=> { 'x' => 'so',
		     '#' => ', such, thus' },
 'ffatri'	=> { 'x' => 'factory',
		     '#' => ', factory' },
 'ffedog'	=> { 'x' => 'apron' },
 'ffenestr'	=> { 'x' => 'window' },
 'fferm'	=> { 'x' => 'estate',
		     '#' => ', farm, property, ranch' },
 'ffermwr'	=> { 'x' => 'farmer' },
 'ffilm'	=> { 'x' => 'film',
		     '#' => ', motion picture, movie' },
 'fflandrys'	=> { 'x' => 'flanders',
		     't' => 'n',
		     '#' => 'capitalize' },
 'fforc'	=> { 'x' => 'fork' },
 'ffordd'	=> { 'x' => 'road',
		     '#' => ', route, way' },
 'ffrainc'	=> { 'x' => 'france',
		     't' => 'n',
		     '#' => 'capitalize' },
 'ffrind'	=> { 'x' => 'friend' },
 'ffydd'	=> { 'x' => 'confidence',
		     '#' => ', faith, trust' },
 'ffyddlon'	=> { 'x' => 'falcon' },
 'ffynnon'	=> { 'x' => 'fountain',
		     '#' => ', source, spring' },
 'fwltur'	=> { 'x' => 'vulture' },
 'gadael'	=> { 'x' => 'absent onself',
		     '#' => ', depart, go away, leave, accord, admit, afford, allow, permit' },
 'gaeaf'	=> { 'x' => 'winter' },
 'gafr'		=> { 'x' => 'goat' },
 'gair'		=> { 'x' => 'word' },
 'gallu'	=> { 'x' => 'can',
		     '#' => 'be able to' },
 'galw'		=> { 'x' => 'call',
		     '#' => ', summon' },
 'gardd'	=> { 'x' => 'garden' },
 'gartref'	=> { 'x' => 'at home' },
 'geneth'	=> { 'x' => 'girl',
		     '#' => ', lass, wench' },
 'geni'		=> { 'x' => 'arise',
		     '#' => ', be born' },
 'glas'		=> { 'x' => 'blue' },
 'glyn'		=> { 'x' => 'valley' },
 'gof'		=> { 'x' => 'smith' },
 'gofalus'	=> { 'x' => 'careful',
		     '#' => ', cautious' },
 'gofyn'	=> { 'x' => 'ask' },
 'golchi'	=> { 'x' => 'wash',
		     '#' => ', wash' },
 'golff'	=> { 'x' => 'golf' },
 'gorffennaf'	=> { 'x' => 'july',
		     't' => 'n',
		     '#' => 'capitalize' },
 'gorwedd'	=> { 'x' => 'lie',
		     '#' => ', recline' },
 'grisiau'	=> { 'x' => 'staircase',
		     '#' => ', stairs' },
 'groeg'	=> { 'x' => 'greece',
		     't' => 'n',
		     '#' => 'capitalize' },
 'groegaidd'	=> { 'x' => 'greek',
		     't' => 'n',
		     '#' => 'capitalize' },
 'groeges'	=> { 'x' => 'greek woman',
		     't' => 'n',
		     '#' => 'capitalize' },
 'groegwr'	=> { 'x' => 'greek',
		     't' => 'n',
		     '#' => 'capitalize' },
 'gwaith'	=> { 'x' => 'job',
		     '#' => ', work' },
 'gwal'		=> { 'x' => 'wall' },
 'gwallt'	=> { 'x' => 'hair' },
 'gwas'		=> { 'x' => 'boy',
		     '#' => ', servant' },
 'gwawr'	=> { 'x' => 'dawn',
		     '#' => ', daybreak' },
 'gwdih'	=> { 'x' => 'owl' },
 'gweithio'	=> { 'x' => 'work' },
 'gweld'	=> { 'x' => 'see' },
 'gwell'	=> { 'x' => 'best',
		     '#' => ', better' },
 'gwely'	=> { 'x' => 'bed' },
 'gwers'	=> { 'x' => 'lesson' },
 'gwerthu'	=> { 'x' => 'dispose of',
		     '#' => ', sell, vend' },
 'gwiber'	=> { 'x' => 'adder',
		     '#' => ', viper' },
 'gwir'		=> { 'x' => 'true' },
 'gwisgo'	=> { 'x' => 'wear' },
 'gwlad'	=> { 'x' => 'country',
		     '#' => ', land' },
 'gwlad yr haf'	=> { 'x' => 'somerset',
		     't' => 'n',
		     '#' => 'capitalize' },
 'gwlyb'	=> { 'x' => 'wet' },
 'gwln'	=> { 'x' => 'wool' },
 'gwneud'	=> { 'x' => 'achieve',
		     '#' => ', act, do, make, perform' },
 'gwraig'	=> { 'x' => 'wife',
		     '#' => ', woman' },
 'gwrando'	=> { 'x' => 'listen' },
 'gwybod'	=> { 'x' => 'know',
		     '#' => ', know how' },
 'gwyddel'	=> { 'x' => 'irishman',
		     't' => 'n',
		     '#' => 'capitalize' },
 'gwyddeles'	=> { 'x' => 'iriswoman',
		     't' => 'n',
		     '#' => 'capitalize' },
 'gwyddelig'	=> { 'x' => 'irish',
		     't' => 'n',
		     '#' => 'capitalize' },
 'gwyliau'	=> { 'x' => 'vacation' },
 'gwynt'	=> { 'x' => 'wind' },
 'gwyrdd'	=> { 'x' => 'green' },
 'gynt'		=> { 'x' => 'ahead',
		     '#' => ', formerly, previously' },
 'gr'		=> { 'x' => 'fellow',
		     '#' => ', man' },
 'haf'		=> { 'x' => 'summer' },
 'hallt'	=> { 'x' => 'salty' },
 'hanes'	=> { 'x' => 'story',
		     '#' => ', history' },
 'hanner'	=> { 'x' => 'half' },
 'hanner dydd'	=> { 'x' => 'midday',
		     '#' => ', noon' },
 'hanner nos'	=> { 'x' => 'midnight' },
 'hapus'	=> { 'x' => 'fortunate',
		     '#' => ', happy' },
 'hardd'	=> { 'x' => 'beautiful',
		     '#' => ', fine, handsome, lovely' },
 'haul'		=> { 'x' => 'sun' },
 'hawdd'	=> { 'x' => 'easy',
		     '#' => ', facile' },
 'heblaw'	=> { 'x' => 'apart from',
		     '#' => ', but, except, other than' },
 'hebog'	=> { 'x' => 'hawk' },
 'heddiw'	=> { 'x' => 'today' },
 'heddwch'	=> { 'x' => 'peace' },
 'hefyd'	=> { 'x' => 'also',
		     '#' => ', likewise, too' },
 'help'		=> { 'x' => 'aid',
		     '#' => ', help, aid, help' },
 'hen'		=> { 'x' => 'old',
		     '#' => ', old' },
 'heol'		=> { 'x' => 'street',
		     '#' => ', road, route, way' },
 'het'		=> { 'x' => 'hat' },
 'hi'		=> { 'x' => 'it',
		     '#' => ', her, she' },
 'hir'		=> { 'x' => 'long' },
 'hisbaen'	=> { 'x' => 'spain',
		     't' => 'n',
		     '#' => 'capitalize' },
 'hoffi'	=> { 'x' => 'appreciate',
		     '#' => ', like' },
 'hogyn'	=> { 'x' => 'boy',
		     '#' => ', lad, laddie' },
 'hon'		=> { 'x' => 'this',
		     '#' => ', this' },
 'hwn'		=> { 'x' => 'this',
		     '#' => ', this' },
 'hwylio'	=> { 'x' => 'sail' },
 'hydref'	=> { 'x' => 'october',
		     't' => 'n',
		     '#' => 'capitalize' },
 'hyfryd'	=> { 'x' => 'agreeable',
		     '#' => ', pleasant' },
 'iaith'	=> { 'x' => 'language',
		     '#' => ', tongue' },
 'iar'		=> { 'x' => 'chicken',
		     '#' => ', fowl' },
 'iau'		=> { 'x' => 'jupiter',
		     't' => 'n',
		     '#' => 'capitalize' },
 'iawn'		=> { 'x' => 'quite',
		     '#' => ', very, very much' },
 'iechyd'	=> { 'x' => 'health' },
 'ieuanc'	=> { 'x' => 'young' },
 'ifanc'	=> { 'x' => 'young' },
 'ionawr'	=> { 'x' => 'january',
		     't' => 'n',
		     '#' => 'capitalize' },
 'isalmaen'	=> { 'x' => 'holland',
		     't' => 'n',
		     '#' => 'capitalize',
		     '#' => ', holland, the netherlands' },
 'isel'		=> { 'x' => 'low' },
 'iwerddon'	=> { 'x' => 'ireland',
		     't' => 'n',
		     '#' => 'capitalize' },
 'iwerydd'	=> { 'x' => 'atlantic',
		     't' => 'n',
		     '#' => 'capitalize',
		     '#' => ', atlantic ocean' },
 'lawer gwaith'	=> { 'x' => 'frequently',
		     '#' => ', often, regularly' },
 'lerpwl'	=> { 'x' => 'liverpool',
		     't' => 'n',
		     '#' => 'capitalize' },
 'lladd'	=> { 'x' => 'kill',
		     '#' => ', liquidate, slay' },
 'lladin'	=> { 'x' => 'latin',
		     't' => 'n',
		     '#' => 'capitalize' },
 'llaeth'	=> { 'x' => 'milk' },
 'llafariad'	=> { 'x' => 'vowel' },
 'llanelli'	=> { 'x' => 'llanelly',
		     't' => 'n',
		     '#' => 'capitalize' },
 'llaw'		=> { 'x' => 'hand' },
 'llawen'	=> { 'x' => 'cheerful',
		     '#' => ', gay, merry' },
 'llawr'	=> { 'x' => 'floor' },
 'lle'		=> { 'x' => 'place',
		     '#' => ', location, place, spot, room, space' },
 'lleuad'	=> { 'x' => 'moon' },
 'llew'		=> { 'x' => 'lion' },
 'lliw'		=> { 'x' => 'colour',
		     '#' => ', dye' },
 'lloegr'	=> { 'x' => 'england',
		     't' => 'n',
		     '#' => 'capitalize',
		     '#' => ', england' },
 'llong'	=> { 'x' => 'ship',
		     '#' => ', vessel' },
 'llongwr'	=> { 'x' => 'sailor' },
 'llosgi'	=> { 'x' => 'burn' },
 'llundain'	=> { 'x' => 'london',
		     't' => 'n',
		     '#' => 'capitalize' },
 'llwyd'	=> { 'x' => 'grey' },
 'llwyddiant'	=> { 'x' => 'achievement',
		     '#' => ', success' },
 'llwynog'	=> { 'x' => 'fox' },
 'llwynoges'	=> { 'x' => 'vixen' },
 'llydaw'	=> { 'x' => 'bretagne',
		     't' => 'n',
		     '#' => 'capitalize',
		     '#' => ', brittany' },
 'llyfr'	=> { 'x' => 'book' },
 'llyfrgell'	=> { 'x' => 'library' },
 'llygoden'	=> { 'x' => 'mouse' },
 'llygoden fawr'	=> { 'x' => 'rat' },
 'llygota'	=> { 'x' => 'mouse',
		     '#' => ', rat' },
 'llyn'		=> { 'x' => 'lake',
		     '#' => ', loch' },
 'llythyr'	=> { 'x' => 'letter' },
 'llythyrdy'	=> { 'x' => 'post office' },
 'mab'		=> { 'x' => 'son' },
 'mai'		=> { 'x' => 'may',
		     't' => 'n',
		     '#' => 'capitalize' },
 'mam'		=> { 'x' => 'mother' },
 'manceinion'	=> { 'x' => 'manchester',
		     't' => 'n',
		     '#' => 'capitalize' },
 'map'		=> { 'x' => 'map',
		     '#' => ', map' },
 'marw'		=> { 'x' => 'die',
		     '#' => ', expire, pass away, dead' },
 'mat'		=> { 'x' => 'mat' },
 'math'		=> { 'x' => 'kind',
		     '#' => ', sort' },
 'mawr'		=> { 'x' => 'big',
		     '#' => ', great, large' },
 'mawrth'	=> { 'x' => 'mars',
		     't' => 'n',
		     '#' => 'capitalize',
		     '#' => ', march' },
 'meddyg'	=> { 'x' => 'doctor',
		     '#' => ', physician' },
 'medi'		=> { 'x' => 'september',
		     't' => 'n',
		     '#' => 'capitalize' },
 'medru'	=> { 'x' => 'can',
		     '#' => 'be able to' },
 'mehefin'	=> { 'x' => 'june',
		     't' => 'n',
		     '#' => 'capitalize' },
 'melys'	=> { 'x' => 'gentle',
		     '#' => ', soft, sweet, tender' },
 'menyn'	=> { 'x' => 'butter' },
 'merch'	=> { 'x' => 'daughter',
		     '#' => ', woman' },
 'milwr'	=> { 'x' => 'pawn',
		     '#' => ', soldier' },
 'mis'		=> { 'x' => 'month' },
 'mochyn'	=> { 'x' => 'hog',
		     '#' => ', pig, swine' },
 'modryb'	=> { 'x' => 'aunt' },
 'molecwl'	=> { 'x' => 'molecule' },
 'morgannwg'	=> { 'x' => 'glamorgan',
		     't' => 'n',
		     '#' => 'capitalize' },
 'morwr'	=> { 'x' => 'sailor' },
 'mur'		=> { 'x' => 'wall' },
 'mynd'		=> { 'x' => 'go' },
 'mynydd'	=> { 'x' => 'mountain' },
 'mr'		=> { 'x' => 'sea' },
 'mr coch'	=> { 'x' => 'red sea',
		     't' => 'n',
		     '#' => 'capitalize' },
 'mr tawel'	=> { 'x' => 'pacific',
		     't' => 'n',
		     '#' => 'capitalize',
		     '#' => ', pacific ocean' },
 'mr y canoldir'	=> { 'x' => 'mediterranean',
		     't' => 'n',
		     '#' => 'capitalize' },
 'na'		=> { 'x' => 'than' },
 'nadolig'	=> { 'x' => 'christmas',
		     't' => 'n',
		     '#' => 'capitalize',
		     '#' => ', yule' },
 'nant'		=> { 'x' => 'stream' },
 'naw'		=> { 'x' => 'nine' },
 'nawfed'	=> { 'x' => 'ninth' },
 'neb'		=> { 'x' => 'a',
		     '#' => ', any, anybody, some, somebody, one, someone, some one' },
 'neidr'	=> { 'x' => 'serpent',
		     '#' => ', snake' },
 'neifion'	=> { 'x' => 'neptune',
		     't' => 'n',
		     '#' => 'capitalize' },
 'neis'		=> { 'x' => 'pretty' },
 'nes'		=> { 'x' => 'until',
		     '#' => ', till' },
 'nesaf'	=> { 'x' => 'following',
		     '#' => ', next' },
 'neuadd'	=> { 'x' => 'hall' },
 'newydd'	=> { 'x' => 'new',
		     '#' => ', novel' },
 'newyddion'	=> { 'x' => 'news',
		     '#' => ', novelty, something new' },
 'ni'		=> { 'x' => 'us',
		     '#' => ', we' },
 'nofel'	=> { 'x' => 'novel' },
 'nofio'	=> { 'x' => 'float',
		     '#' => ', swim' },
 'nos'		=> { 'x' => 'night' },
 'noson'	=> { 'x' => 'evening' },
 'o'		=> { 'x' => 'from',
		     '#' => ', out of' },
 'o amgylch'	=> { 'x' => 'about',
		     '#' => ', round, around, towards' },
 'o flaen'	=> { 'x' => 'before',
		     '#' => ', in front of' },
 'ochr'		=> { 'x' => 'side' },
 'oedrannus'	=> { 'x' => 'old' },
 'oer'		=> { 'x' => 'bleak',
		     '#' => ', chilly, cold' },
 'ofn'		=> { 'x' => 'fear' },
 'ogof'		=> { 'x' => 'cave',
		     '#' => ', grotto, cave, cavern, den' },
 'ond'		=> { 'x' => 'but' },
 'os'		=> { 'x' => 'if',
		     '#' => ', provided that' },
 'os gwelwch yn dda'	=> { 'x' => 'please' },
 'paham'	=> { 'x' => 'what for',
		     '#' => ', wherefore, why' },
 'paladr'	=> { 'x' => 'beam',
		     '#' => ', ray' },
 'pam'		=> { 'x' => 'what for',
		     '#' => ', wherefore, why' },
 'papur'	=> { 'x' => 'paper' },
 'paratoi'	=> { 'x' => 'prepare' },
 'parc'		=> { 'x' => 'park' },
 'parod'	=> { 'x' => 'finished',
		     '#' => ', ready, through' },
 'pe'		=> { 'x' => 'if',
		     '#' => ', provided that' },
 'pelydryn'	=> { 'x' => 'beam',
		     '#' => ', ray' },
 'pen'		=> { 'x' => 'summit',
		     '#' => ', surface, top' },
 'pensil'	=> { 'x' => 'pencil' },
 'pentref'	=> { 'x' => 'village' },
 'penybont'	=> { 'x' => 'bridgend',
		     't' => 'n',
		     '#' => 'capitalize' },
 'perllan'	=> { 'x' => 'orchard' },
 'peswch'	=> { 'x' => 'cough' },
 'piano'	=> { 'x' => 'piano' },
 'pib'		=> { 'x' => 'pipe' },
 'plismon'	=> { 'x' => 'policeman',
		     '#' => ', policeman' },
 'pobl'		=> { 'x' => 'folk',
		     '#' => ', nation, people' },
 'poced'	=> { 'x' => 'pocket' },
 'poeth'	=> { 'x' => 'hot' },
 'pont'		=> { 'x' => 'bridge' },
 'popeth'	=> { 'x' => 'all',
		     '#' => ', altogether, everything' },
 'pori'		=> { 'x' => 'graze' },
 'potel'	=> { 'x' => 'bottle' },
 'prif'		=> { 'x' => 'chief',
		     '#' => ', boss' },
 'prifathro'	=> { 'x' => 'headmaster',
		     '#' => ', head of a school' },
 'prifysgol'	=> { 'x' => 'university' },
 'prin'		=> { 'x' => 'barely',
		     '#' => ', hardly, only just, scarcely' },
 'priodi'	=> { 'x' => 'marry',
		     '#' => ', be married, get married, marry, be married, get married' },
 'pris'		=> { 'x' => 'price' },
 'prwsia'	=> { 'x' => 'prussia',
		     't' => 'n',
		     '#' => 'capitalize' },
 'prydain'	=> { 'x' => 'britain',
		     't' => 'n',
		     '#' => 'capitalize',
		     '#' => ', great britain' },
 'prydeinig'	=> { 'x' => 'british',
		     't' => 'n',
		     '#' => 'capitalize' },
 'prydeiniwr'	=> { 'x' => 'briton',
		     't' => 'n',
		     '#' => 'capitalize' },
 'prydferth'	=> { 'x' => 'beautiful',
		     '#' => ', fine, handsome, lovely' },
 'pum'		=> { 'x' => 'five' },
 'pumed'	=> { 'x' => 'fifth' },
 'pump'		=> { 'x' => 'five' },
 'punt'		=> { 'x' => 'pound' },
 'pwll'		=> { 'x' => 'pond' },
 'pwy'		=> { 'x' => 'of which',
		     '#' => ', which one\'s, whose' },
 'pwyl'		=> { 'x' => 'poland',
		     't' => 'n',
		     '#' => 'capitalize' },
 'pymtheg'	=> { 'x' => 'fifteen' },
 'pymthegfed'	=> { 'x' => 'fifteenth' },
 'pl'		=> { 'x' => 'ball' },
 'rabbi'	=> { 'x' => 'rabbi' },
 'radio'	=> { 'x' => 'radio',
		     '#' => ', wireless' },
 'ras'		=> { 'x' => 'breed',
		     '#' => ', race' },
 'reis'		=> { 'x' => 'rice' },
 'rhad'		=> { 'x' => 'cheap',
		     '#' => ', inexpensive, cheap, inexpensive' },
 'rhaff'	=> { 'x' => 'cord',
		     '#' => ', rope, string' },
 'rhag'		=> { 'x' => 'from',
		     '#' => ', out of' },
 'rhagfyr'	=> { 'x' => 'december',
		     't' => 'n',
		     '#' => 'capitalize' },
 'rhaid'	=> { 'x' => 'necessity' },
 'rhedeg'	=> { 'x' => 'run' },
 'rheol'	=> { 'x' => 'regulation',
		     '#' => ', rule' },
 'rheolwr'	=> { 'x' => 'manager' },
 'rhoi'		=> { 'x' => 'give' },
 'rhosyn'	=> { 'x' => 'rose' },
 'rhufain'	=> { 'x' => 'rome',
		     't' => 'n',
		     '#' => 'capitalize' },
 'rhufeinaidd'	=> { 'x' => 'roman',
		     't' => 'n',
		     '#' => 'capitalize',
		     '#' => ', roman' },
 'rhufeiniad'	=> { 'x' => 'roman',
		     't' => 'n',
		     '#' => 'capitalize',
		     '#' => ', roman' },
 'rhufeinig'	=> { 'x' => 'roman',
		     't' => 'n',
		     '#' => 'capitalize',
		     '#' => ', roman' },
 'rhufeiniwr'	=> { 'x' => 'roman',
		     't' => 'n',
		     '#' => 'capitalize',
		     '#' => ', roman' },
 'rhwng'	=> { 'x' => 'among',
		     '#' => ', between' },
 'rhwyfo'	=> { 'x' => 'row' },
 'rhydychen'	=> { 'x' => 'oxford',
		     't' => 'n',
		     '#' => 'capitalize' },
 'rhyfedd'	=> { 'x' => 'wonderful' },
 'rhyfel'	=> { 'x' => 'war' },
 'rwber'	=> { 'x' => 'rubber' },
 'rwsia'	=> { 'x' => 'russia',
		     't' => 'n',
		     '#' => 'capitalize' },
 'sabath'	=> { 'x' => 'saturday',
		     't' => 'n',
		     '#' => 'capitalize' },
 'saboth'	=> { 'x' => 'saturday',
		     't' => 'n',
		     '#' => 'capitalize' },
 'sadwrn'	=> { 'x' => 'saturn',
		     't' => 'n',
		     '#' => 'capitalize' },
 'saesneg'	=> { 'x' => 'english',
		     't' => 'n',
		     '#' => 'capitalize',
		     '#' => ', english, english language' },
 'saesnes'	=> { 'x' => 'english',
		     't' => 'n',
		     '#' => 'capitalize',
		     '#' => ', englishwoman' },
 'sais'		=> { 'x' => 'englishman',
		     't' => 'n',
		     '#' => 'capitalize',
		     '#' => ', sassenach, saxon' },
 'saith'	=> { 'x' => 'seven' },
 'sefyll'	=> { 'x' => 'stand' },
 'seithfed'	=> { 'x' => 'seventh' },
 'sgwar'	=> { 'x' => 'plaza',
		     '#' => ', square, public square' },
 'siarad'	=> { 'x' => 'speak',
		     '#' => ', talk' },
 'sicr'		=> { 'x' => 'certain',
		     '#' => ', sure' },
 'sigar'	=> { 'x' => 'cigar' },
 'sigaret'	=> { 'x' => 'cigarette' },
 'silff'	=> { 'x' => 'shelf' },
 'sinema'	=> { 'x' => 'cinema',
		     '#' => ', movie theatre' },
 'siop'		=> { 'x' => 'boutique',
		     '#' => ', shop, store' },
 'siwgr'	=> { 'x' => 'sugar' },
 'siwr'		=> { 'x' => 'certain',
		     '#' => ', sure' },
 'smocio'	=> { 'x' => 'smoke' },
 'stori'	=> { 'x' => 'account',
		     '#' => ', narrative, story, tale' },
 'storm'	=> { 'x' => 'storm' },
 'stryd'	=> { 'x' => 'street' },
 'swansea'	=> { 'x' => 'swansea',
		     't' => 'n',
		     '#' => 'capitalize' },
 'swllt'	=> { 'x' => 'shilling' },
 'swyddfa'	=> { 'x' => 'office',
		     '#' => ', bureau, office' },
 'swynwr'	=> { 'x' => 'enchanter',
		     '#' => ', magician, sorcerer, warlock, wizard' },
 'syched'	=> { 'x' => 'thirst' },
 'symud'	=> { 'x' => 'move' },
 'syrthio'	=> { 'x' => 'drop',
		     '#' => ', fall' },
 'tachwedd'	=> { 'x' => 'november',
		     't' => 'n',
		     '#' => 'capitalize' },
 'tacsi'	=> { 'x' => 'taxi' },
 'tafod'	=> { 'x' => 'tongue' },
 'tafwys'	=> { 'x' => 'thames',
		     't' => 'n',
		     '#' => 'capitalize' },
 'tair'		=> { 'x' => 'three' },
 'tair ar ddeg'	=> { 'x' => 'thirteen' },
 'taith'	=> { 'x' => 'journey',
		     '#' => ', trip, voyage' },
 'tal'		=> { 'x' => 'tall' },
 'talu'		=> { 'x' => 'pay' },
 'taro'		=> { 'x' => 'beat',
		     '#' => ', hit, strike' },
 'tarw'		=> { 'x' => 'bull' },
 'tebot'	=> { 'x' => 'tea-pot' },
 'tegell'	=> { 'x' => 'kettle' },
 'teigr'	=> { 'x' => 'tiger' },
 'teisen'	=> { 'x' => 'cake' },
 'teledu'	=> { 'x' => 'television',
		     '#' => ', tv' },
 'telyn'	=> { 'x' => 'harp' },
 'thermomedr'	=> { 'x' => 'thermometer' },
 'tiddewi'	=> { 'x' => 'saint david\'s',
		     't' => 'n',
		     '#' => 'capitalize' },
 'tir'		=> { 'x' => 'country',
		     '#' => ', land' },
 'tlawd'	=> { 'x' => 'miserable',
		     '#' => ', poor, poor' },
 'tlws'		=> { 'x' => 'pretty' },
 'torri'	=> { 'x' => 'break',
		     '#' => ', cut, slice' },
 'tost'		=> { 'x' => 'ill',
		     '#' => ', sick' },
 'traeth'	=> { 'x' => 'beach' },
 'tref'		=> { 'x' => 'city',
		     '#' => ', town' },
 'treulio'	=> { 'x' => 'transact money' },
 'tri'		=> { 'x' => 'three' },
 'tri ar ddeg'	=> { 'x' => 'thirteen' },
 'trigain'	=> { 'x' => 'sixty' },
 'trigain a deg'	=> { 'x' => 'seventy' },
 'trwm'		=> { 'x' => 'burdensome',
		     '#' => ', heavy, onerous' },
 'trwy'		=> { 'x' => 'through' },
 'trydan'	=> { 'x' => 'electricity' },
 'trydedd'	=> { 'x' => 'third' },
 'trydedd ar ddeg'	=> { 'x' => 'thirteenth' },
 'trydydd'	=> { 'x' => 'third' },
 'trydydd ar ddeg'	=> { 'x' => 'thirteenth' },
 'trysor'	=> { 'x' => 'treasure' },
 'trn'		=> { 'x' => 'train',
		     '#' => ', train' },
 'twrc'		=> { 'x' => 'turk',
		     't' => 'n',
		     '#' => 'capitalize' },
 'twrci'	=> { 'x' => 'turkey' },
 'twrci'	=> { 'x' => 'turkey',
		     't' => 'n',
		     '#' => 'capitalize' },
 'tyfu'		=> { 'x' => 'accrue',
		     '#' => ', grow' },
 'tylluan'	=> { 'x' => 'owl' },
 'tywydd'	=> { 'x' => 'weather' },
 'tn'		=> { 'x' => 'fire' },
 't'		=> { 'x' => 'tea' },
 'tr'		=> { 'x' => 'castle',
		     '#' => ', tower' },
 'uchel'	=> { 'x' => 'high',
		     '#' => ', lofty, tall' },
 'ugain'	=> { 'x' => 'twenty' },
 'ugeinfed'	=> { 'x' => 'twentieth' },
 'un'		=> { 'x' => 'one' },
 'un ar bymtheg'	=> { 'x' => 'sixteen' },
 'un ar ddeg'	=> { 'x' => 'eleven' },
 'un ar hugain'	=> { 'x' => 'twenty-one' },
 'unfed ar bymtheg'	=> { 'x' => 'sixteenth' },
 'unfed ar ddeg'	=> { 'x' => 'eleventh' },
 'unwaith'	=> { 'x' => 'once',
		     '#' => ', one time' },
 'wedi'		=> { 'x' => 'behind',
		     '#' => ', after, after, behind' },
 'wedi blino'	=> { 'x' => 'tired' },
 'wedyn'	=> { 'x' => 'afterwards',
		     '#' => ', next, subsequently' },
 'weithiau'	=> { 'x' => 'several times',
		     '#' => ', sometimes' },
 'wrth'		=> { 'x' => 'at',
		     '#' => ', beside, by, near, nearby, near to, next to, for, during, whereas, while, whilst' },
 'wyth'		=> { 'x' => 'eight' },
 'wythfed'	=> { 'x' => 'eighth' },
 'wythnos'	=> { 'x' => 'week' },
 'ychydig'	=> { 'x' => 'a little',
		     '#' => ', rather, some, somewhat, to some extent, little' },
 'yfed'		=> { 'x' => 'drink' },
 'yfory'	=> { 'x' => 'tomorrow' },
 'ymenyn'	=> { 'x' => 'butter' },
 'ymhlith'	=> { 'x' => 'among',
		     '#' => ', between' },
 'ymlaen'	=> { 'x' => 'ahead',
		     '#' => ', foreward, on' },
 'yn awr'	=> { 'x' => 'at present',
		     '#' => ', now' },
 'yn dda'	=> { 'x' => 'okay',
		     '#' => ', well' },
 'yn erbyn'	=> { 'x' => 'across from',
		     '#' => ', against, in exchange for, opposed to, opposite, upon' },
 'yn gynnar'	=> { 'x' => 'early' },
 'yn gyntaf'	=> { 'x' => 'first',
		     '#' => ', firstly, first of all' },
 'yn hwyr'	=> { 'x' => 'late' },
 'yn lle'	=> { 'x' => 'instead' },
 'yn ofalus'	=> { 'x' => 'carefully',
		     '#' => ', gently, lightly' },
 'yn rhad'	=> { 'x' => 'cheaply',
		     '#' => ', cheaply, cheaply' },
 'ynys'		=> { 'x' => 'island' },
 'yr aifft'	=> { 'x' => 'egypt',
		     't' => 'n',
		     '#' => 'capitalize' },
 'yr alban'	=> { 'x' => 'scotland',
		     't' => 'n',
		     '#' => 'capitalize' },
 'yr almaen'	=> { 'x' => 'germany',
		     't' => 'n',
		     '#' => 'capitalize' },
 'yr eidal'	=> { 'x' => 'italy',
		     't' => 'n',
		     '#' => 'capitalize' },
 'yr unol daleithiau'	=> { 'x' => 'united states of america',
		     't' => 'n',
		     '#' => 'capitalize',
		     '#' => ', usa' },
 'yran'	=> { 'x' => 'at present',
		     '#' => ', now' },
 'ysgol'	=> { 'x' => 'school' },
 'ysgrifennu'	=> { 'x' => 'write' },
 'ysgyfarnog'	=> { 'x' => 'hare' },
 'ystafell'	=> { 'x' => 'chamber',
		     '#' => ', room' },
 'b'		=> { 'x' => 'ape',
		     '#' => ', monkey' },
 'y'		=> { 'x' => 'egg' },
);
}

1;

