# vi: ts=8 sw=8 sts=8

package Tongues::Ellinika;

use strict;
use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $charset $grammar %dictionary);

use Exporter   ();
# set the version for version checking
@ISA         = qw(Exporter);
@EXPORT      = qw(charset grammar dictionary);
@EXPORT_OK   = qw();
$VERSION     = 0.00;

# Character set Windows Greek CP1253
# not ISO 8859-7

# Alphabetical order
#                        
#                        
#                                    in word-final position

sub new {
	my $class = shift;
	my $self = bless {}, $class;
	return $self;
}

sub charset {
	return $charset;
}

sub grammar {
	return $grammar;
}

sub dictionary {
	return \%dictionary;
}

sub BEGIN {

require Charsets::GreekWin;

$charset = new Charsets::GreekWin;

# Table for converting words to root form
$grammar = [
 # Noun case
 # Noun gender
 # Noun plural
 # Adjectives
 # Verb past participle
 # Verb gerund
 # Verb present participle
 # Verb present
 # Verb present subjunctive
 # Verb imperitive
 # Verb preterite
 # Verb imperfect
 # Verb future
 # Verb conditional
 # Adverb
 # Higher level transformations
];

#Fields:
# x -> translatioin		all words
# r -> root			irregular declensions
# t -> type:			all words
#	n -> noun
#	v -> verb
#	a -> adjective
#	p -> preposition
#	art -> article
#	pro -> pronoun
#	conj -> conjugation
#	adv -> adverb
# g -> gender:			nouns, pronouns, adjectives
#	m -> masculine		default
#	f -> feminine		default for words ending in a
# n -> number:			articles, pronouns, verbs, adjectives
#	s -> singular		default
#	p -> plural		default for words ending in s
# p -> person:			pronouns, verbs
#	1 -> 1st person
#	2 -> 2nd person
#	3 -> 3rd person		default
# c -> conjugation:
#	p -> present
#	i -> imperfect
#	f -> future
#	c -> conditional
#	t -> preterite
#	ps -> present subjunctive
#	is -> imperfect subjunctive
#	inf -> infinitive		default
#	pp -> past participle
#	g -> gerund
#	imp -> imperative

# Greek to English dictionary
%dictionary = (
 # Functional words
 #  Articles
 #   Definite articles
 #    Masculine
 #     Singular
 #     Plural
 #    Feminine
 #     Singular
 #     Plural
 #   Indefinite articles
 #  Pronouns & possessive adjectives
 #   1st person
 #   2nd person
 #   3rd person
 #  Other functional words
 ''		=> { 'x' => 'from',
		     '#' => 'of, by, through, than',
 		     't' => 'p' },
 ''		=> { 'x' => 'for',
		     '#' => 'because of, on behalf of',
 		     't' => 'p' },
 ''		=> { 'x' => 'not',
		     '#' => 'no' },
 ''	=> { 'x' => 'because',
		     '#' => 'as, for, since',
 		     't' => 'conj' },
 ''		=> { 'x' => 'the' },
 ''		=> { 'x' => 'or',
		     '#' => 'either',
 		     't' => 'conj' },
 ''		=> { 'x' => 'every',
		     '#' => 'each' },
 ''	=> { 'x' => 'everyone',
		     '#' => 'each one, everybody' },
 ''	=> { 'x' => 'someone',
		     '#' => 'anyone, noone, nobody' },
 ''		=> { 'x' => 'against',
		     '#' => 'upon, during, according to, by, about',
 		     't' => 'p' },
 ''		=> { 'x' => 'and',
		     '#' => 'also, too' },
 ''		=> { 'x' => 'with',
		     '#' => 'by, through, by means of, on, of',
 		     't' => 'p' },
 ''		=> { 'x' => 'that',
		     '#' => 'to, in order to, so as to' },
 ''		=> { 'x' => 'as',
		     '#' => 'for, like, just as, such as;',
		     '#' => 'while, as soon as;',
		     '#' => '; until, till, down to, up to,',
		     '#' => 'as far as; about' },
 ''	=> { 'x' => 'must',
		     '#' => 'it is necessary' },
 ''		=> { 'x' => 'to',
		     '#' => 'at, in; you' },
 ''		=> { 'x' => 'the',
		     '#' => 'them' },
 ''		=> { 'x' => 'the',
		     '#' => 'it' },
 #   Partitive / Contractions
 # Numbers: cardinal and ordinal
 # Days and months
 ''	=> { 'x' => 'sunday' },
 ''	=> { 'x' => 'monday' },
 ''	=> { 'x' => 'tuesday' },
 ''	=> { 'x' => 'wednesday' },
 ''	=> { 'x' => 'thursday' },
 ''	=> { 'x' => 'friday' },
 ''	=> { 'x' => 'saturday' },
 ''	=> { 'x' => 'january' },
 ''	=> { 'x' => 'february' },
 ''	=> { 'x' => 'march' },
 ''	=> { 'x' => 'april' },
 ''	=> { 'x' => 'may' },
 ''	=> { 'x' => 'june' },
 ''	=> { 'x' => 'july' },
 ''	=> { 'x' => 'august' },
 ''	=> { 'x' => 'september' },
 ''	=> { 'x' => 'october' },
 ''	=> { 'x' => 'november' },
 ''	=> { 'x' => 'december' },
 # Key verbs
 ''	=> { 'x' => 'article',
		     't' => 'n' },
 ''	=> { 'x' => 'be',
		     '#' => 'is, it is',
 		     't' => 'v' },
 ''		=> { 'x' => 'shall',
		     '#' => 'will, should, would',
 		     't' => 'v' },
 # Vocabulary
 ''	=> { 'x' => 'article',
		     '#' => 'clause, term',
 		     't' => 'n' },
 ''	=> { 'x' => 'astronaut',
 		     't' => 'n' },
 ''	=> { 'x' => 'person',
		     '#' => 'individual',
 		     't' => 'n' },
 ''	=> { 'x' => 'australia',
 		     't' => 'n' },
 ''	=> { 'x' => 'galaxy',
 		     't' => 'n' },
 ''	=> { 'x' => 'germany',
 		     't' => 'n' },
 ''	=> { 'x' => 'right',
		     '#' => 'claim',
 		     't' => 'n' },
 ''	=> { 'x' => 'electricity',
 		     't' => 'n' },
 ''	=> { 'x' => 'japan',
 		     't' => 'n' },
 ''	=> { 'x' => 'dictionary',
 		     't' => 'n' },
);
}

1;

