# vi: ts=8 sw=8

package Tongues::English;

use strict;
use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $charset $grammar %dictionary);

use Exporter   ();
# set the version for version checking
@ISA         = qw(Exporter);
@EXPORT      = qw(charset grammar dictionary);
@EXPORT_OK   = qw();
$VERSION     = 0.00;

# Character set Windows Western European CP1252 / ISO 8859-1 / Latin-1

# Alphabetical order
# A B C D E F G H I J K L M N O P Q R S T U V W X Y Z
# a b c d e f g h i j k l m n o p q r s t u v w x y z

# Extra letters
#  in nave
#  in faade

sub new {
	my $class = shift;
	my $self = bless {}, $class;
	return $self;
}

sub charset {
	return $charset;
}

sub grammar {
	return $grammar;
}

sub dictionary {
	return \%dictionary;
}

sub BEGIN {

require Charsets::WestEuroWin;

$charset = new Charsets::WestEuroWin;

$grammar = [
 # Noun plural
 [ 's',		'',	'',		's',	'n' ],
 [ 'ies',	'y',	'',		's',	'n' ],

 # Verb past tense / past participle
 [ 'ed',	'',	'',		'ado',	'v' ],
 [ 'ed',	'e',	'',		'ado',	'v' ],

 # verb present continuous / gerund
 [ 'ing',	'',	'',		'ando',	'v' ],
 [ 'ing',	'e',	'',		'ando',	'v' ],
 # Adverb
 # Higher level transformations
];

#Fields:
# x -> translation		all words
# r -> root			irregular declensions
# t -> type:			all words
#	n -> noun
#	v -> verb
#	a -> adjective
#	p -> preposition
#	art -> article
#	pro -> pronoun
#	conj -> conjugation
#	adv -> adverb
# g -> gender:			pronouns
#	m -> masculine		default
#	f -> feminine
# n -> number:			pronouns, verbs
#	s -> singular		default
#	p -> plural		default for words ending in s
# p -> person:			pronouns, verbs
#	1 -> 1st person
#	2 -> 2nd person
#	3 -> 3rd person		default
# c -> conjugation:
#	p -> present
#	s -> past
#	inf -> infinitive		default
#	pp -> past participle
#	g -> gerund
#	imp -> imperative

# English to Spanish dictionary
%dictionary = (
 # Functional words
 #  Articles
 #   Definite articles
 'the'		=> { 'x-es' => 'el' },
 #   Indefinite articles
 'a'		=> { 'x-es' => 'un',
		     '#' => 'cf "an"',
		     't' => 'art' },
 'an'		=> { 'x-es' => 'un',
		     '#' => 'cf "a"',
		     't' => 'art' },
 #  Pronouns & possessive adjectives
 #   1st person
 'i'		=> { 'x-es' => 'yo',
		     't' => 'pro',
		     'p' => '1',
		     'n' => 's' },
 'me'		=> { 'x-es' => 'me',
		     't' => 'pro',
		     'p' => '1',
		     'n' => 's' },
 'my'		=> { 'x-es' => 'mi',
		     'p' => '1',
		     'n' => 's' },
 'mine'		=> { 'x-es' => 'mio',
		     't' => 'pro',
		     'p' => '1',
		     'n' => 's' },
 'we'		=> { 'x-es' => 'nosotros',
		     't' => 'pro',
		     'p' => '1',
		     'n' => 'p' },
 'us'		=> { 'x-es' => 'nos',
		     't' => 'pro',
		     'p' => '1',
		     'n' => 'p' },
 'our'		=> { 'x-es' => 'nuestro',
		     'p' => '1',
		     'n' => 'p' },
 #   2nd person
 'you'		=> { 'x-es' => 't' },
 'your'		=> { 'x-es' => 'tuyo' },
 #   3rd person
 'he'		=> { 'x-es' => 'el',
		     '#' => 'subject',
 		     't' => 'pro',
		     'p' => '3',
		     'n' => 's',
		     'g' => 'm' },
 'him'		=> { 'x-es' => 'l' },
 'his'		=> { 'x-es' => 'su' },
 'her'		=> { 'x-es' => 'ella' },
 'hers'		=> { 'x-es' => 'su' },
 'it'		=> { 'x-es' => '(l)' },
 'its'		=> { 'x-es' => 'su' },
 'they'		=> { 'x-es' => 'ellos',
		     '#' => 'ellas' },
 'them'		=> { 'x-es' => 'les' },
 'their'	=> { 'x-es' => 'su' },
 'theirs'	=> { 'x-es' => 'suyo' },
 #  Indefinite pronouns and adverbs
 #   Something
 #   Anything
 #   Whatever
 #   Nothing
 #   Everything

 #   Somebody / Someone
 #   Anybody / Anyone
 #   Whoever
 #   Nobody / Noone
 #   Everybody / Everyone

 #   Somewhere
 #   Anywhere
 #   Whereever
 #   Nowhere
 #   Everywhere

 #   Sometime
 #   (Anytime, any time)
 #   Whenever
 #   Never
 #   Always

 #   Somehow
 #   (Anyhow, any way)
 #   However
 #   (nohow, no how)
 #   (everyhow, every way)

 #   (Somewhy, some reason)
 #   (Anywhy, any reason)
 #   (Whyever)
 #   (nowhy, for no reason)
 #   (everywhy)

 #  Interrogatives
 'how'		=> { 'x-es' => 'cmo' },
 'what'		=> { 'x-es' => 'qu' },
 'when'		=> { 'x-es' => 'cuando' },
 'where'	=> { 'x-es' => 'donde' },
 'which'	=> { 'x-es' => 'cual' },
 'who'		=> { 'x-es' => 'quien' },
 'whose'	=> { 'x-es' => 'cuyo' },
 'why'		=> { 'x-es' => 'por qu',
		     '#' => 'multiword?' },

 #  Other functional words
 'all'		=> { 'x-es' => 'todo' },
 'and'		=> { 'x-es' => 'y' },
 'as'		=> { 'x-es' => 'como',
		     '#' => 'tan' },
 'but'		=> { 'x-es' => 'pero' },
 'for'		=> { 'x-es' => 'por' },
 'from'		=> { 'x-es' => 'desde',
		     '#' => 'de' },
 'here'		=> { 'x-es' => 'aqu' },
 'if'		=> { 'x-es' => 'si' },
 'in'		=> { 'x-es' => 'en' },
 'more'		=> { 'x-es' => 'ms' },
 'no'		=> { 'x-es' => 'ningn',
		     '#' => 'interjection and adverb' },
 'nor'		=> { 'x-es' => 'ni' },
 'not'		=> { 'x-es' => 'no' },
 'now'		=> { 'x-es' => 'ahora' },
 'of'		=> { 'x-es' => 'de' },
 'on'		=> { 'x-es' => 'en',
		     't' => 'p' },
 'or'		=> { 'x-es' => 'o' },
 'own'		=> { 'x-es' => 'propio',
		     '#' => 'verb and adjective/adverb?' },
 'so'		=> { 'x-es' => 'tan' },
 'some'		=> { 'x-es' => 'unas' },
 'such'		=> { 'x-es' => 'tal' },
 'that'		=> { 'x-es' => 'que' },
 'then'		=> { 'x-es' => 'pues' },
 'there'	=> { 'x-es' => 'ah' },
 'these'	=> { 'x-es' => 'estes' },
 'this'		=> { 'x-es' => 'este' },
 'though'	=> { 'x-es' => 'aunque' },
 'thus'		=> { 'x-es' => 'as' },
 'to'		=> { 'x-es' => 'a' },
 'too'		=> { 'x-es' => 'demasiado',
		     '#' => 'tambin' },
 'towards'	=> { 'x-es' => 'hacia',
		     't' => 'p' },
 'until'	=> { 'x-es' => 'hasta' },
 'very'		=> { 'x-es' => 'muy' },
 'while'	=> { 'x-es' => 'mientras' },
 'with'		=> { 'x-es' => 'con' },
 'without'	=> { 'x-es' => 'sin' },
 'yes'		=> { 'x-es' => 's' },

 #   Partitive / Contractions
 # Numbers: cardinal and ordinal
 'one'		=> { 'x' => 'uno',
		     '#' => 'also pronoun' },
 # Days and months
 #  English days are capitalized
 'sunday'	=> { 'x' => 'sunday' },
 'monday'	=> { 'x' => 'monday' },
 'tuesday'	=> { 'x' => 'tuesday' },
 'wednesday'	=> { 'x' => 'wednesday' },
 'thursday'	=> { 'x' => 'thursday' },
 'friday'	=> { 'x' => 'friday' },
 'saturday'	=> { 'x' => 'saturday' },
 #  English months are capitalized
 'january'	=> { 'x' => 'january' },
 'february'	=> { 'x' => 'february' },
 'march'	=> { 'x' => 'march' },
 'april'	=> { 'x' => 'april' },
 'may'		=> { 'x' => 'may' },
 'june'		=> { 'x' => 'june' },
 'july'		=> { 'x' => 'july' },
 'august'	=> { 'x' => 'august' },
 'september'	=> { 'x' => 'september' },
 'october'	=> { 'x' => 'october' },
 'november'	=> { 'x' => 'november' },
 'december'	=> { 'x' => 'december' },
 # Key verbs
 'be'		=> { 'x-es' => 'estar',
		     '#' => 'irreg.; ser' },
  'is'		=> { 'x-es' => 'es',
		     'r' => 'be',
		     't' => 'v' },
  'are'		=> { 'x-es' => 'son',
		     '#' => 'somos, eres, estan, estamos, estas' },
  'was'		=> { 'x-es' => 'fue',
		     'r' => 'be',
		     't' => 'v' },

 'have'		=> { 'x-es' => 'tener',
		     '#' => 'have',
		     't' => 'v' },
  'has'		=> { 'x-es' => 'ha',
		     'r' => 'have',
		     't' => 'v',
		     'c' => 'p',
		     'p' => '3',
		     'n' => 's' },

 'do'		=> { 'x-es' => 'hacer',
		     '#' => 'irreg.',
 		     't' => 'v' },

 'go'		=> { 'x-es' => 'ir',
		     '#' => 'irreg.' },
 'can'		=> { 'x-es' => 'puede',
		     '#' => 'modal; irreg?' },
 'could'	=> { 't' => 'v',
		     '#' => 'modal; irreg?' },
 'will'		=> { 't' => 'v',
		     '#' => 'modal; irreg?' },
 'would'	=> { 't' => 'v',
		     '#' => 'modal; irreg?' },
 'shall'	=> { 't' => 'v',
		     '#' => 'modal; irreg?' },
 'should'	=> { 'x-es' => 'deber' },
 'must'		=> { 'x-de' => 'mssen',
		     '#' => 'modal; irreg.',
 		     't' => 'v' },

 # Vocabulary
 'get'		=> { 'x-es' => 'conseguir' },
 'make'		=> { 'x-es' => 'elaborar',
		     '#' => 'irreg.',
		     't' => 'v' },
  'made'	=> { 'x-es' => 'hecho' },

 # Numbers: cardinal and ordinal
 'zero'		=> { 'x-es' => 'cero' },
 'two'		=> { 'x-es' => 'dos' },
 'three'	=> { 'x-es' => 'tres' },
 'third'	=> { 'x-es' => 'tercer' },
 'four'		=> { 'x-es' => 'cuatro' },
 'five'		=> { 'x-es' => 'cinco' },
 'six'		=> { 'x-es' => 'seis' },
 'seven'	=> { 'x-es' => 'siete' },
 'eight'	=> { 'x-es' => 'ocho' },
 'nine'		=> { 'x-es' => 'nueve' },
 'ten'		=> { 'x-es' => 'diez' },
 'twenty'	=> { 'x-es' => 'veinte' },
 'thirty'	=> { 'x-es' => 'treinta' },
 'forty'	=> { 'x-es' => 'catorce' },
 'fifty'	=> { 'x-es' => 'cincuenta' },
 'sixty'	=> { 'x-es' => 'sesanta' },
 'seventy'	=> { 'x-es' => 'setanta' },
 'eighty'	=> { 'x-es' => 'ochenta' },
 'ninety'	=> { 'x-es' => 'noventa' },
 'hundred'	=> { 'x-es' => 'cien' },
 'thousand'	=> { 'x-es' => 'mil' },

 # Days and months
 'sunday'	=> { 'x-es' => 'domingo',
 		     'x-de' => 'sonntag' },
 'monday'	=> { 'x-es' => 'lunes',
 		     'x-de' => 'montag' },
 'tuesday'	=> { 'x-es' => 'martes' },
 'wednesday'	=> { 'x-es' => 'mircoles',
 		     'x-de' => 'mittwoch' },
 'thursday'	=> { 'x-es' => 'hueves' },
 'friday'	=> { 'x-es' => 'viernes',
 		     'x-de' => 'freitag' },
 'saturday'	=> { 'x-es' => 'sabado',
 		     'x-de' => 'samstag' },
 'january'	=> { 'x-es' => 'enero' },
 'february'	=> { 'x-es' => 'febrero' },
 'march'	=> { 'x-es' => 'marzo' },
 'april'	=> { 'x-es' => 'april' },
 'may'		=> { 'x-es' => 'mayo',
		     '#' => 'also aux. verb' },
 'june'		=> { 'x-es' => 'junio' },
 'july'		=> { 'x-es' => 'julio' },
 'august'	=> { 'x-es' => 'agosto' },
 'september'	=> { 'x-es' => 'septiembre' },
 'october'	=> { 'x-es' => 'octubre' },
 'november'	=> { 'x-es' => 'noviembre' },
 'december'	=> { 'x-es' => 'diciembre' },
 
 # Most words go here
 'abbey'	=> { 'x-es' => 'abada' },
 'abolish'	=> { 'x-es' => 'abolir' },
 'about'	=> { 'x-es' => 'sobre',
		     '#' => 'as in "read about"',
 		     'x-de' => 'ber',
		     '#' => 'as in "read about"' },
 'above'	=> { 'x-es' => 'arriba' },
 'abrupt'	=> { 'x-es' => 'abrupto' },
 'abuse'	=> { 'x-es' => 'abusar' },
 'accent'	=> { 'x-es' => 'acento' },
 'access'	=> { 'x-es' => 'acceso' },
 'account'	=> { 'x-es' => 'cuenta' },
 'accustom'	=> { 'x-es' => 'habituar' },
 'acquire'	=> { 'x-es' => 'adquirir' },
 'across'	=> { 'x-es' => 'travs' },
 'act'		=> { 'x-es' => 'actuar' },
 'actress'	=> { 'x-es' => 'actriz' },
 'add'		=> { 'x-es' => 'aadir' },
 'administrate'	=> { 'x-es' => 'administrar' },
 'advantage'	=> { 'x-es' => 'ventaja' },
 'advice'	=> { 'x-es' => 'consejo' },
 'after'	=> { 'x-es' => 'despus' },
 'afternoon'	=> { 'x-es' => 'tarde' },
 'aids'		=> { 'x-es' => 'sida' },
 'air'		=> { 'x-es' => 'vilo' },
 'airport'	=> { 'x-es' => 'aeropuerto',
 		     'x-de' => 'flughafen' },
 'almond'	=> { 'x-es' => 'almendra' },
 'almost'	=> { 'x-es' => 'casi' },
 'alone'	=> { 'x-es' => 'solo' },
 'already'	=> { 'x-es' => 'ya' },
 'also'		=> { 'x-es' => 'tambin',
 		     'x-de' => 'auch' },
 'always'	=> { 'x-es' => 'siempre',
 		     'x-de' => 'immer' },
 'american'	=> { 'x-es' => 'americano' },
 'ancient'	=> { 'x-es' => 'antiguo' },
 'annoy'	=> { 'x-es' => 'molestar' },
 'antiquity'	=> { 'x-es' => 'antigedad' },
 'anxious'	=> { 'x-es' => 'ansioso' },
 'anybody'	=> { 'x-es' => 'alguien' },
 'anyone'	=> { 'x-es' => 'alguien' },
 'apparition'	=> { 'x-es' => 'aparicin' },
 'appear'	=> { 'x-es' => 'aparecer' },
 'application'	=> { 'x-es' => 'aplicacin' },
 'approach'	=> { 'x-es' => 'acercarse' },
 'arise'	=> { 'x-es' => 'surgir' },
 'arm'		=> { 'x-es' => 'brazo' },
 'around'	=> { 'x-es' => 'alrededor' },
 'arrange'	=> { 'x-es' => 'disponer' },
 'arrive'	=> { 'x-es' => 'llegar',
 		     'x-de' => 'ankommen' },
 'ashtray'	=> { 'x-es' => 'cenicero' },
 'aunt'		=> { 'x-es' => 'ta' },
 'author'	=> { 'x-es' => 'autor' },
 'automobile'	=> { 'x-es' => 'automvil' },
 'available'	=> { 'x-es' => 'disponible' },
 'avenue'	=> { 'x-es' => 'avenida' },
 'avoid'	=> { 'x-es' => 'evitar' },
 'awake'	=> { 'x-es' => 'despierto' },
 'axle'		=> { 'x-es' => 'eje' },
 'baby'		=> { 'x-es' => 'nena' },
 'back'		=> { 'x-es' => 'espalda' },
 'bacon'	=> { 'x-es' => 'tocino' },
 'bad'		=> { 'x-es' => 'malo',
 		     'x-de' => 'schlecht' },
 'balcony'	=> { 'x-es' => 'terraza' },
 'band'		=> { 'x-es' => 'banda' },
 'base'		=> { 'x-es' => 'basar' },
 'basic'	=> { 'x-es' => 'bsico' },
 'bean'		=> { 'x-es' => 'frijol' },
 'beautiful'	=> { 'x-es' => 'bello',
 		     'x-de' => 'schn' },
 'because'	=> { 'x-es' => 'porque',
 		     'x-de' => 'weil' },
 'bed'		=> { 'x-es' => 'lecho' },
 'before'	=> { 'x-es' => 'antes' },
 'begin'	=> { 'x-es' => 'empezar' },
 'behind'	=> { 'x-es' => 'detrs' },
 'believe'	=> { 'x-es' => 'creer',
 		     'x-de' => 'glauben' },
 'below'	=> { 'x-es' => 'abajo' },
 'bench'	=> { 'x-es' => 'escao' },
 'besides'	=> { 'x-es' => 'adems' },
 'better'	=> { 'x-es' => 'mejor',
 		     'x-de' => 'besser' },
 'between'	=> { 'x-es' => 'entre' },
 'bibliography'	=> { 'x-es' => 'bibliografa' },
 'big'		=> { 'x-es' => 'grande',
		     '#' => 'irreg.',
 		     't' => 'a' },
 'bitch'	=> { 'x-es' => 'puta',
		     'x-de' => 'hundin' },
 'bite'		=> { 'x-es' => 'morder' },
 'black'	=> { 'x-es' => 'negro',
 		     'x-de' => 'schwarz' },
 'block'	=> { 'x-es' => 'estancar' },
 'blouse'	=> { 'x-es' => 'blusa' },
 'blow'		=> { 'x-es' => 'golpe',
		     '#' => 'noun & adj; irreg.' },
 'board'	=> { 'x-es' => 'abordar' },
 'body'		=> { 'x-es' => 'cuerpo' },
 'book'		=> { 'x-es' => 'libro',
 		     'x-de' => 'buch' },
 'boot'		=> { 'x-es' => 'arrancar' },
# 'born'	=> 				# adj? pp? v.irreg?
 'both'		=> { 'x-es' => 'ambos' },
 'boundless'	=> { 'x-es' => 'desorbitado' },
 'box'		=> { 'x-es' => 'caja' },
 'boy'		=> { 'x-es' => 'chico' },
 'boyfriend'	=> { 'x-es' => 'novio' },
 'braid'	=> { 't' => 'n',
		     '#' => 'am.; cf. plait' },
 'bread'	=> { 'x-es' => 'pan',
 		     'x-de' => 'brot' },
 'break'	=> { 'x-es' => 'romper',
		     '#' => 'irreg.' },
 'breakdown'	=> { 'x-es' => 'avera' },
 'breakfast'	=> { 'x-es' => 'desayunar' },
 'breast'	=> { 'x-es' => 'pecho' },
 'breathe'	=> { 'x-es' => 'respirar' },
 'breeze'	=> { 'x-es' => 'brisa' },
 'bring'	=> { 'x-es' => 'traer',
 		     'x-de' => 'bringen' },
 'broken'	=> { 'x-es' => 'roto',
 		     'x-de' => 'kaput' },
 'brother'	=> { 'x-es' => 'hermano' },
 'building'	=> { 'x-es' => 'edificio' },
 'bully'	=> { 'x-es' => 'matn' },
 'bus'		=> { 'x-es' => 'autobs' },
 'butterfly'	=> { 'x-es' => 'mariposa' },
 'buttocks'	=> { 'x-es' => 'nalgas' },
 'buy'		=> { 'x-es' => 'comprar',
		     '#' => 'irreg.',
 		     't' => 'v' },
 'buzzing'	=> { 'x-es' => 'zumbido' },
 'by'		=> { 'x-es' => 'por',
 		     'x-de' => 'bei',
		     't' => 'p' },
 'cadaver'	=> { 'x-es' => 'cadver' },
 'cakes'	=> { 'x-es' => 'pastas' },
 'call'		=> { 'x-es' => 'llamar' },
 'calm'		=> { 'x-es' => 'sereno' },
 'car'		=> { 'x-es' => 'coche',
 		     'x-de' => 'auto' },
 'card'		=> { 'x-es' => 'tarjeta' },
 'case'		=> { 'x-es' => 'caso' },
 'castilian'	=> { 'x-es' => 'castellano' },
 'cent'		=> { 'x-es' => 'centavo' },
 'century'	=> { 'x-es' => 'siglio',
 		     'x-de' => 'jahrhunnert' },
 'certain'	=> { 'x-es' => 'cierto' },
 'chair'	=> { 't' => 'n' },
 'change'	=> { 'x-es' => 'cambio' },
 'channel'	=> { 'x-es' => 'canal' },
 'character'	=> { 'x-es' => 'caracter' },
 'characterize'	=> { 'x-es' => 'caracterizar' },
 'christian'	=> { 'x-es' => 'cristiano' },
 'church'	=> { 'x-de' => 'kirche' },
 'city'		=> { 'x-es' => 'ciudad',
 		     'x-de' => 'stadt' },
 'clear'	=> { 'x-es' => 'claro' },
 'cliff'	=> { 'x-es' => 'despeadero' },
 'climb'	=> { 'x-es' => 'trepar' },
 'cloak'	=> { 'x-es' => 'capa' },
 'close'	=> { 'x-es' => 'cerrar' },
 'clothes'	=> { 'x-es' => 'ropa' },
 'code'		=> { 'x-es' => 'cdigo' },
 'coffee'	=> { 'x-es' => 'caf' },
 'coffin'	=> { 'x-es' => 'atad' },
 'collection'	=> { 'x-es' => 'coleccin' },
 'colour'	=> { 'x-es' => 'color' },
 'come'		=> { 'x-es' => 'venir',
 		     'x-de' => 'kommen' },
 'comfortable'	=> { 'x-es' => 'confortable' },
 'commence'	=> { 'x-es' => 'comenzar' },
 'common'	=> { 'x-es' => 'comn' },
 'compile'	=> { 'x-es' => 'recopilar' },
 'complication'	=> { 'x-es' => 'complicacin' },
 'compression'	=> { 'x-es' => 'compresin' },
 'computer'	=> { 'x-es' => 'ordenador' },
 'concrete'	=> { 'x-es' => 'concreto' },
 'configuration'	=> { 'x-es' => 'configuracin' },
 'conformant'	=> { 'x-es' => 'conforme' },
 'conserve'	=> { 'x-es' => 'conservar' },
 'construction'	=> { 'x-es' => 'construccin' },
 'contemplate'	=> { 'x-es' => 'contemplar' },
 'contrary'	=> { 'x-es' => 'contrario' },
 'contribute'	=> { 'x-es' => 'aportar' },
 'control'	=> { 'x-es' => 'controlar' },
 'conversation'	=> { 'x-es' => 'conversacin' },
 'convert'	=> { 'x-es' => 'convertir' },
 'copy'		=> { 'x-es' => 'copiar' },
 'corduroy'	=> { 'x-es' => 'pana' },
 'core'		=> { 'x-es' => 'ncleo' },
 'corner'	=> { 'x-es' => 'rincn' },
 'cost'		=> { 'x-es' => 'costar' },
 'country'	=> { 'x-es' => 'pas',
		     't' => 'n' },
 'course'	=> { 'x-es' => 'curso' },
 'cover'	=> { 'x-es' => 'cubrir' },
 'crazy'	=> { 'x-es' => 'loco' },
 'create'	=> { 'x-es' => 'crear' },
 'crowd'	=> { 'x-es' => 'muchedumbre' },
 'cry'		=> { 'x-es' => 'llorar' },
 'cup'		=> { 'x-es' => 'taza' },
 'current'	=> { 'x-es' => 'actual' },
 'curtain'	=> { 'x-es' => 'cortina' },
 'cylinder'	=> { 'x-es' => 'cilindro' },
 'dad'		=> { 'x-es' => 'pap' },
 'damage'	=> { 'x-es' => 'daar' },
 'damp'		=> { 'x-es' => 'hmedo' },
 'daring'	=> { 'x-es' => 'atrevido' },
 'dark'		=> { 'x-es' => 'oscuro' },
 'daughter'	=> { 'x-es' => 'hija',
 		     'x-de' => 'tochter' },
 'day'		=> { 'x-es' => 'da',
 		     'x-de' => 'tag' },
 'dead'		=> { 'x-es' => 'muerto',
 		     'x-de' => 'tot' },
 'death'	=> { 'x-es' => 'muerte' },
 'december'	=> { 'x-es' => 'diciembre',
		     't' => 'n' },
 'decide'	=> { 'x-es' => 'decidir' },
 'dedicate'	=> { 'x-es' => 'dedicar' },
 'defect'	=> { 'x-es' => 'defecto' },
 'define'	=> { 'x-es' => 'definir' },
 'desert'	=> { 'x-es' => 'desierto' },
 'design'	=> { 'x-es' => 'disear' },
 'detail'	=> { 'x-es' => 'detalle' },
 'develop'	=> { 'x-es' => 'desarrollar' },
 'diameter'	=> { 'x-es' => 'dimetro' },
 'die'		=> { 'x-es' => 'morir',
		     '#' => 'irreg.' },
 'different'	=> { 'x-es' => 'diferente' },
 'difficult'	=> { 'x-es' => 'difcil' },
 'direct'	=> { 'x-es' => 'directo' },
 'direction'	=> { 'x-es' => 'direccin' },
 'disappear'	=> { 'x-es' => 'desaparecer' },
 'disaster'	=> { 'x-es' => 'desastre' },
 'discard'	=> { 'x-es' => 'deshechar' },
 'disk'		=> { 'x-es' => 'disco' },
 'distant'	=> { 'x-es' => 'lejano' },
 'distribution'	=> { 'x-es' => 'distribucin' },
 'distributor'	=> { 'x-es' => 'distribuidor' },
 'dive'		=> { 't' => 'v',
		     '#' => 'irreg.' },
 'document'	=> { 'x-es' => 'documento' },
 'door'		=> { 'x-es' => 'puerta' },
 'double'	=> { 'x-es' => 'doble' },
 'doubt'	=> { 'x-es' => 'duda' },
 'dress'	=> { 'x-es' => 'vestir' },
 'drink'	=> { 'x-es' => 'beber',
		     '#' => 'noun & verb; irreg.',
 		     'x-de' => 'trinken' },
 'drive'	=> { 'x-es' => 'manejar',
		     '#' => 'irreg.' },
 'driver'	=> { 'x-es' => 'conductor' },
 'during'	=> { 'x-es' => 'durante' },
 'dusty'	=> { 'x-es' => 'polvoriento' },
 'dynamite'	=> { 'x-es' => 'dinamita' },
 'each'		=> { 'x-es' => 'cada' },
 'ear'		=> { 'x-es' => 'oreja' },
 'earth'	=> { 'x-es' => 'tierra' },
 'easy'		=> { 'x-es' => 'fcil' },
 'eat'		=> { 'x-es' => 'comer',
		     '#' => 'irreg.',
 		     'x-de' => 'essen' },
 'economy'	=> { 'x-es' => 'economa' },
 'edition'	=> { 'x-es' => 'edicin' },
 'egg'		=> { 'x-es' => 'huevo' },
 'electronic'	=> { 'x-es' => 'electrnico' },
 'element'	=> { 'x-es' => 'elemento' },
 'elevation'	=> { 'x-es' => 'elevacin' },
 'emulate'	=> { 'x-es' => 'emular' },
 'encrust'	=> { 'x-es' => 'incrustar' },
 'end'		=> { 'x-es' => 'final' },
 'english'	=> { 'x-es' => 'ingls',
 		     'x-de' => 'englisch' },
 'enough'	=> { 'x-es' => 'bastante',
 		     'x-de' => 'genug' },
 'enter'	=> { 'x-es' => 'entrar' },
 'enterprise'	=> { 'x-es' => 'empresa' },
 'entire'	=> { 'x-es' => 'entero' },
 'entrance'	=> { 'x-es' => 'entrada' },
 'equal'	=> { 'x-es' => 'igual' },
 'error'	=> { 'x-es' => 'error' },
 'establish'	=> { 'x-es' => 'arraigar' },
 'etc'		=> { 'x-es' => 'etc',
		     '#' => '?' },
 'even'		=> { 'x-es' => 'aun' },
 'evolution'	=> { 'x-es' => 'evolucin' },
 'examine'	=> { 'x-es' => 'examinar',
 		     't' => 'v' },
 'example'	=> { 'x-es' => 'ejemplo' },
 'exasperate'	=> { 'x-es' => 'desesperar' },
 'except'	=> { 'x-es' => 'sino' },
 'exhaust'	=> { 'x-es' => 'agotar' },
 'exist'	=> { 'x-es' => 'existir' },
 'expensive'	=> { 'x-es' => 'caro',
 		     'x-de' => 'teuer' },
 'experience'	=> { 'x-es' => 'experiencia' },
 'explosion'	=> { 'x-es' => 'explosin' },
 'express'	=> { 'x-es' => 'expresar' },
 'extend'	=> { 'x-es' => 'prolongar' },
 'extreme'	=> { 'x-es' => 'extremo' },
 'eye'		=> { 'x-es' => 'ojo' },
 'face'		=> { 'x-es' => 'cara' },
 'fact'		=> { 'x-es' => 'dato' },
 'faggot'	=> { 'x-es' => 'puto' },
 'fail'		=> { 'x-es' => 'fallar' },
 'fake'		=> { 'x-es' => 'fingir' },
 'familiar'	=> { 'x-es' => 'familiar' },
 'family'	=> { 'x-es' => 'familia' },
 'far'		=> { 'x-es' => 'lejos' },
 'fashion'	=> { 'x-es' => 'moda' },
 'father'	=> { 'x-es' => 'padre' },
 'fear'		=> { 'x-es' => 'miedo' },
 'feed'		=> { 't' => 'v',
		     '#' => 'irreg.' },
 'feel'		=> { 'x-es' => 'sentir' },
 'fight'	=> { 'x-es' => 'pelea' },
 'figure'	=> { 'x-es' => 'figura' },
 'file'		=> { 'x-es' => 'fichero',
		     '#' => 'archivo' },
 'find'		=> { 'x-es' => 'encontrar' },
 'finger'	=> { 'x-es' => 'dedo' },
 'finish'	=> { 'x-es' => 'terminar' },
 'firm'		=> { 'x-es' => 'firme' },
 'first'	=> { 'x-es' => 'primer',
 		     'x-de' => 'erst' },
 'fish'		=> { 't' => 'n',
		     '#' => 'invariant' },
 'fist'		=> { 'x-es' => 'puo' },
 'fit'		=> { 'x-es' => 'caber' },
 'flag'		=> { 'x-es' => 'bandera' },
 'flexible'	=> { 'x-es' => 'elstica' },
 'floor'	=> { 'x-es' => 'piso' },
 'flower'	=> { 'x-es' => 'flor' },
 'fly'		=> { 'x-es' => 'volar',
		     '#' => 'verb & noun',
 		     'x-de' => 'fliegen' },
 'flying'	=> { 'x-es' => 'volante' },
 'follow'	=> { 'x-es' => 'seguir' },
 'following'	=> { 'x-es' => 'siguiendo' },
 'fool'		=> { 'x-es' => 'bobo' },
 'foot'		=> { 'x-es' => 'pie' },
 'force'	=> { 'x-es' => 'esfuerzo' },
 'forget'	=> { 'x-es' => 'olvidar',
 		     'x-de' => 'vergessen' },
 'form'		=> { 'x-es' => 'forma' },
 'fraud'	=> { 'x-es' => 'fraude' },
 'free'		=> { 'x-es' => 'liberar' },
 'freedom'	=> { 'x-es' => 'libertad' },
 'fresh'	=> { 'x-es' => 'fresco' },
 'front'	=> { 'x-es' => 'frente' },
 'fuck'		=> { 'x-es' => 'chingar',
 		     'x-de' => 'ficken' },
 'full'		=> { 'x-es' => 'pleno' },
 'function'	=> { 'x-es' => 'funcionar' },
 'furniture'	=> { 'x-es' => 'muebles' },
 'future'	=> { 'x-es' => 'futuro' },
 'game'		=> { 'x-es' => 'juego',
 		     'x-de' => 'spiel' },
 'general'	=> { 'x-es' => 'general' },
 'gentleman'	=> { 'x-es' => 'caballero' },
 'german'	=> { 'x-es' => 'alemn',
 		     'x-de' => 'deutsch' },
 'ghost'	=> { 'x-es' => 'fantasma' },
 'giant'	=> { 'x-es' => 'gigante' },
 'girl'		=> { 'x-es' => 'chica' },
 'girlfriend'	=> { 'x-es' => 'novia' },
 'give'		=> { 'x-es' => 'dar',
		     '#' => 'irreg.',
 		     'x-de' => 'geben' },
 'glass'	=> { 'x-es' => 'vidrio' },
 'god'		=> { 'x-es' => 'dios' },
 'good'		=> { 'x-es' => 'buen',
		     '#' => 'bueno, bien; irreg.',
 		     'x-de' => 'gut',
		     't' => 'a' },
 'gossip'	=> { 'x-es' => 'comadre' },
 'grandfather'	=> { 'x-es' => 'abuelo' },
 'grandmother'	=> { 'x-es' => 'abuela' },
 'gratitude'	=> { 'x-es' => 'agradecimientos' },
 'great'	=> { 'x-es' => 'grande' },
 'green'	=> { 'x-es' => 'verde' },
 'grief'	=> { 'x-es' => 'pena' },
 'grill'	=> { 'x-es' => 'parrilla' },
 'ground'	=> { 'x-es' => 'suelo' },
 'group'	=> { 'x-es' => 'grupo' },
 'grow'		=> { 'x-es' => 'crecer',
		     '#' => 'irreg.' },
 'guide'	=> { 'x-es' => 'gua' },
 'hail'		=> { 'x-es' => 'granizar' },
 'hair'		=> { 'x-es' => 'cabello' },
 'half'		=> { 'x-es' => 'medio' },
 'hall'		=> { 'x-es' => 'vestbulo' },
 'hammock'	=> { 'x-es' => 'hamaca' },
 'hand'		=> { 'x-es' => 'mano' },
 'hang'		=> { 'x-es' => 'colgar',
		     '#' => 'irreg.' },
 'happen'	=> { 'x-es' => 'ocurrir' },
 'happy'	=> { 'x-es' => 'feliz' },
 'hard'		=> { 'x-es' => 'trabajoso' },
 'hat'		=> { 'x-es' => 'sombrero' },
 'hate'		=> { 'x-es' => 'odiar',
 		     'x-de' => 'hassen' },
 'head'		=> { 'x-es' => 'cabeza',
 		     'x-de' => 'kopf' },
 'headlamp'	=> { 'x-es' => 'faro' },
 'hear'		=> { 'x-es' => 'or',
		     '#' => 'irreg.',
 		     'x-de' => 'hren',
 		     't' => 'v' },
  'heard'	=> { 'x-es' => 'odo',
 		     'r' => 'hear',
		     't' => 'v',
		     'c' => 's',
		     '#' => 'paste tense, past participle' },
 'heart'	=> { 'x-es' => 'corazn',
 		     'x-de' => 'herz' },
 'heat'		=> { 'x-es' => 'calor' },
 'height'	=> { 'x-es' => 'altura' },
 'help'		=> { 'x-es' => 'ayudar',
		     '#' => 'verb & noun',
 		     'x-de' => 'hilfen' },
 'hemp'		=> { 'x-es' => 'camo' },
 'hide'		=> { 'x-es' => 'esconder' },
 'hire'		=> { 'x-es' => 'alquiler' },
 'horizontal'	=> { 'x-es' => 'horizontal' },
 'horse'	=> { 'x-es' => 'caballo',
 		     'x-de' => 'pferd' },
 'hotel'	=> { 'x-es' => 'hotel' },
 'hour'		=> { 'x-es' => 'hora' },
 'house'	=> { 'x-es' => 'casa',
 		     'x-de' => 'haus' },
 'hug'		=> { 'x-es' => 'abrazo',
		     '#' => 'noun & verb' },
 'human'	=> { 'x-es' => 'humano' },
 'hunger'	=> { 'x-es' => 'hambre' },
 'impede'	=> { 'x-es' => 'impedir' },
 'important'	=> { 'x-es' => 'importante' },
 'impress'	=> { 'x-es' => 'impresionar' },
 'impression'	=> { 'x-es' => 'impresin' },
 'improve'	=> { 'x-es' => 'mejorar' },
 'include'	=> { 'x-es' => 'incluir' },
 'indication'	=> { 'x-es' => 'muestra' },
 'indonesia'	=> { 'x-es' => 'indonesia' },
 'inform'	=> { 'x-es' => 'enterar' },
 'information'	=> { 'x-es' => 'informacin' },
 'injure'	=> { 'x-es' => 'herir' },
 'insert'	=> { 'x-es' => 'meter' },
 'inside'	=> { 'x-es' => 'dentro',
		     '#' => 'al dentro' },
 'install'	=> { 'x-es' => 'instalar' },
 'installation'	=> { 'x-es' => 'instalacin' },
 'instant'	=> { 'x-es' => 'instante' },
 'integrity'	=> { 'x-es' => 'integridad' },
 'interest'	=> { 'x-es' => 'interesar',
		     '#' => 'also a noun',
 		     't' => 'v' },
 'interior'	=> { 'x-es' => 'interior' },
 'invite'	=> { 'x-es' => 'invitar' },
 'iron'		=> { 'x-es' => 'hierro' },
 'irregular'	=> { 'x-es' => 'irregular' },
 'jacket'	=> { 'x-es' => 'chaqueta' },
 'jaw'		=> { 'x-es' => 'mandbula' },
 'join'		=> { 'x-es' => 'juntar',
 		     't' => 'v' },
 'joined'	=> { 'x-es' => 'junto' },
 'judge'	=> { 'x-es' => 'enjuiciar' },
 'jump'		=> { 'x-es' => 'saltar',
 		     't' => 'v' },
 'just'		=> { 'x-es' => 'slo',
		     '#' => 'justo, acabar de, unicamente' },
 'key'		=> { 'x-es' => 'tecla',
		     '#' => 'llave' },
 'keyboard'	=> { 'x-es' => 'teclado' },
 'kill'		=> { 'x-es' => 'matar',
		     't' => 'v' },
 'kiss'		=> { 'x-es' => 'beso',
		     't' => 'n' },
 'kitchen'	=> { 'x-es' => 'cocina' },
 'knob'		=> { 'x-es' => 'pomo' },
 'know'		=> { 'x-es' => 'saber',
		     '#' => 'conocer',
 		     'x-de' => 'wissen',
		     't' => 'v' },
 'lake'		=> { 'x-es' => 'lago' },
 'law'		=> { 'x-es' => 'ley',
		     't' => 'n' },
 'landing'	=> { 'x-es' => 'meseta' },
 'language'	=> { 'x-es' => 'idioma' },
 'last'		=> { 'x-es' => 'ltimo' },
 'later'	=> { 'x-es' => 'luego' },
 'latin'	=> { 'x-es' => 'latino' },
 'lazy'		=> { 'x-es' => 'flojo' },
 'leaf'		=> { 'x-es' => 'hoja' },
 'learn'	=> { 'x-es' => 'aprendir',
 		     'x-de' => 'lernen' },
 'leave'	=> { 'x-es' => 'salir' },
 'lend'		=> { 'x-es' => 'prestar' },
 'less'		=> { 'x-es' => 'menos' },
 'letter'	=> { 'x-es' => 'letra',
		     '#' => 'alphabet & mail' },
 'level'	=> { 'x-es' => 'nivel' },
 'library',	=> { 'x-es' => 'librera',
		     't' => 'n' },
 'licence'	=> { 'x-es' => 'licencia' },
 'lie'		=> { 'x-es' => 'mentir' },
 'life'		=> { 'x-es' => 'vida',
 		     'x-de' => 'leben' },
 'light'	=> { 'x-es' => 'luz' },
 'like'		=> { 'x-es' => 'como',
		     '#' => 'also a verb' },
 'limp'		=> { 'x-es' => 'cojear' },
 'line'		=> { 'x-es' => 'lnea' },
 'linen'	=> { 'x-es' => 'lino' },
 'lion'		=> { 'x-es' => 'len' },
 'lioness'	=> { 'x-es' => 'leona' },
 'lip'		=> { 'x-es' => 'labio' },
 'list'		=> { 'x-es' => 'lista' },
 'listen'	=> { 'x-es' => 'escuchar',
 		     'x-de' => 'hren' },
 'litre'	=> { 'x-es' => 'litro' },
 'little'	=> { 'x-es' => 'poco',
 		     'x-de' => 'klein' },
 'live'		=> { 'x-es' => 'vivir',
 		     'x-de' => 'leben' },
 'load'		=> { 'x-es' => 'carga' },
 'lonely'	=> { 'x-es' => 'solitario' },
 'long'		=> { 'x-es' => 'largo' },
 'look'		=> { 'x-es' => 'aspecto',
		     '#' => 'verb and noun' },
 'lose'		=> { 'x-es' => 'perder' },
 'lounge'	=> { 'x-es' => 'saln' },
 'love'		=> { 'x-es' => 'amar',
 		     'x-de' => 'lieben' },
 'lute'		=> { 'x-es' => 'lad' },
 'luxurious'	=> { 'x-es' => 'lujoso' },
 'lynx'		=> { 'x-es' => 'lince' },
 'mail'		=> { 'x-es' => 'correo' },
 'maintain'	=> { 'x-es' => 'mantener' },
 'majority'	=> { 'x-es' => 'mayora' },
 'man'		=> { 'x-es' => 'hombre',
		     '#' => 'irreg.',
 		     'x-de' => 'mann',
		     't' => 'n',
		     'p' => 'men' },
  'men'		=> { 'x-es' => 'hombres',
  		     'r' => 'man',
		     't' => 'n',
		     'n' => 'p' },
 'mark'		=> { 'x-es' => 'marcar' },
 'market'	=> { 'x-es' => 'mercado',
 		     'x-de' => 'markt' },
 'marry'	=> { 'x-es' => 'casar' },
 'mass'		=> { 'x-es' => 'misa' },
 'matter'	=> { 'x-es' => 'materia' },
 'maximum'	=> { 'x-es' => 'mximo' },
 'maybe'	=> { 'x-es' => 'quiza' },
 'meet'		=> { 'x-es' => 'reunir' },
 'melon'	=> { 'x-es' => 'meln' },
 'memory'	=> { 'x-es' => 'memoria' },
 'mention'	=> { 'x-es' => 'mentar' },
 'message'	=> { 'x-es' => 'mensaje' },
 'mexican'	=> { 'x-es' => 'mexicano',
		     '#' => 'noun & adjective' },
 'minimum'	=> { 'x-es' => 'mnimo' },
 'minute'	=> { 'x-es' => 'minuto' },
 'mirror'	=> { 'x-es' => 'espejo' },
 'mistreat'	=> { 'x-es' => 'maltratar' },
 'modem'	=> { 'x-es' => 'modem' },
 'modify'	=> { 'x-es' => 'modificar' },
 'moment'	=> { 'x-es' => 'momento' },
 'momentary'	=> { 'x-es' => 'momentneo' },
 'money'	=> { 'x-es' => 'dinero',
 		     'x-de' => 'geld' },
 'moon'		=> { 'x-es' => 'luna',
 		     'x-de' => 'mond' },
 'morning'	=> { 'x-es' => 'maana',
 		     'x-de' => 'morgen' },
 'mother'	=> { 'x-es' => 'madre',
 		     'x-de' => 'mutter' },
 'motor'	=> { 'x-es' => 'motor' },
 'mountain'	=> { 'x-es' => 'monte' },
 'mournful'	=> { 'x-es' => 'lgubre' },
 'mouth'	=> { 'x-es' => 'boca' },
 'move'		=> { 'x-es' => 'mover' },
 'much'		=> { 'x-es' => 'mucho',
 		     'x-de' => 'viel' },
 'mum'		=> { 'x-es' => 'mam' },
 'mushroom'	=> { 'x-es' => 'hongo' },
 'naked'	=> { 'x-es' => 'desnudo',
 		     'x-de' => 'nakt' },
 'name'		=> { 'x-es' => 'nombre' },
 'narrow'	=> { 'x-es' => 'angosto' },
 'natural'	=> { 'x-es' => 'natural' },
 'navigate'	=> { 'x-es' => 'navegar' },
 'necessary'	=> { 'x-es' => 'necesario' },
 'neck'		=> { 'x-es' => 'cuello' },
 'need'		=> { 'x-es' => 'necesitar' },
 'neither'	=> { 'x-es' => 'tampoco' },
 'net'		=> { 'x-es' => 'red' },
 'netherlands'	=> { 'x-es' => 'pases bajos',
		     '#' => 'proper; place; multiword',
		     'x-it' => 'paesi bassi',
		     'x-pt' => 'pases baixos',
		     't' => 'n' },
 'never'	=> { 'x-es' => 'nunca',
 		     'x-de' => 'nie',
		     '#' => 'niemals' },
 'new'		=> { 'x-es' => 'nuevo',
 		     'x-de' => 'neu' },
 'news'		=> { 'x-es' => 'noticias' },
 'night'	=> { 'x-es' => 'noche',
 		     'x-de' => 'nacht' },
 'nobody'	=> { 'x-es' => 'nadie',
 		     'x-de' => 'niemand' },
 'noise'	=> { 'x-es' => 'ruido' },
 'noodles'	=> { 'x-es' => 'tallarines' },
 'nose'		=> { 'x-es' => 'nariz' },
 'nostrils'	=> { 'x-es' => 'narices' },
 'nothing'	=> { 'x-es' => 'nada' },
 'notice'	=> { 'x-es' => 'advertir' },
 'november'	=> { 'x-es' => 'noviembre' },
 'number'	=> { 'x-es' => 'nmero',
 		     'x-de' => 'nummer' },
 'numerous'	=> { 'x-es' => 'numeroso' },
 'nylon'	=> { 'x-es' => 'niln' },
 'object'	=> { 'x-es' => 'objetivo' },
 'obtain'	=> { 'x-es' => 'obtener' },
 'occupy'	=> { 'x-es' => 'ocupar' },
 'odor'		=> { 'x-es' => 'olor' },
 'office'	=> { 'x-es' => 'oficina' },
 'old	'	=> { 'x-es' => 'viejo',
		     '#' => 'antiguo',
 		     'x-de' => 'alt',
		     't' => 'a' },
 'only'		=> { 'x-es' => 'nico',
		     '#' => 'unicamente',
		     'x-de' => 'einsige',
		     '#' => 'nur' },
 'open'		=> { 'x-es' => 'abrir',
 		     'x-de' => 'ffnen',
		     't' => 'v',
		     '#' => 'a' },
 'operator'	=> { 'x-es' => 'operativo' },
 'order'	=> { 'x-es' => 'orden' },
 'original'	=> { 'x-es' => 'original' },
 'other'	=> { 'x-es' => 'otro' },
 'over'		=> { 'x-es' => 'sobre',
 		     'x-de' => 'ber' },
 'pad'		=> { 'x-es' => 'acolchar' },
 'panel'	=> { 'x-es' => 'tabla' },
 'panic'	=> { 'x-es' => 'pnico' },
 'paper'	=> { 'x-es' => 'papel' },
 'parasol'	=> { 'x-es' => 'sombrilla' },
 'paris'	=> { 'x-es' => 'pars' },
 'park'		=> { 'x-es' => 'estacionar' },
 'part'		=> { 'x-es' => 'parte',
 		     'x-de' => 'teil' },
 'partition'	=> { 'x-es' => 'particin' },
 'party'	=> { 'x-es' => 'partido' },
 'pass'		=> { 'x-es' => 'pasar' },
 'passage'	=> { 'x-es' => 'pasillo' },
 'past'		=> { 'x-es' => 'pasado' },
 'path'		=> { 'x-es' => 'vereda',
		     '#' => 'sendero?' },
 'pavement'	=> { 'x-es' => 'acera' },
 'pay'		=> { 'x-es' => 'pagar',
 		     'x-de' => 'zahlen' },
 'peanut'	=> { 'x-es' => 'cacahuate' },
 'people'	=> { 'x-es' => 'gente',
 		     'x-de' => 'leute' },
 'perfect'	=> { 'x-es' => 'perfecto',
 		     'x-de' => 'perfekt' },
 'permit'	=> { 'x-es' => 'permitir' },
 'person'	=> { 'x-es' => 'persona' },
 'petrol'	=> { 'x-es' => 'gasolina' },
 'photo'	=> { 'x-es' => 'foto' },
 'physical'	=> { 'x-es' => 'fsico' },
 'piece'	=> { 'x-es' => 'pieza' },
 'pig'		=> { 'x-es' => 'cerdo' },
 'pillow'	=> { 'x-es' => 'almohada' },
 'pity'		=> { 'x-es' => 'compadecer' },
 'place'	=> { 'x-es' => 'lugar',
 		     'x-de' => 'platz' },
 'placid'	=> { 'x-es' => 'quieto' },
 'plait'	=> { 't' => 'n',
		     '#' => 'brit.; cf. braid' },
 'plane'	=> { 'x-es' => 'avin' },
 'planet'	=> { 'x-es' => 'planeta' },
 'plastic'	=> { 'x-es' => 'plstico' },
 'play'		=> { 'x-es' => 'jugar',
		     '#' => 'tocar',
 		     'x-de' => 'spielen' },
 'please'	=> { 'x-es' => 'gustar',
		     '#' => 'see also "like"',
 		     'x-de' => 'bitten' },
 'pocket'	=> { 'x-es' => 'bolsillo' },
 'point'	=> { 'x-es' => 'punta',
 		     'x-de' => 'punkt' },
 'poor'		=> { 'x-es' => 'pobre' },
 'pork'		=> { 'x-es' => 'puerco' },
 'possess'	=> { 'x-es' => 'poseer' },
 'possibility'	=> { 'x-es' => 'posibilidad' },
 'possible'	=> { 'x-es' => 'posible' },
 'potato'	=> { 'x-es' => 'papa' },
 'powder'	=> { 'x-es' => 'polvo' },
 'prepare'	=> { 'x-es' => 'preparar' },
 'pretty'	=> { 'x-es' => 'lindo' },
 'price'	=> { 'x-es' => 'precio' },
 'principal'	=> { 'x-es' => 'principal' },
 'problem'	=> { 'x-es' => 'problema' },
 'program'	=> { 'x-es' => 'programa' },
 'programmer'	=> { 'x-es' => 'programador' },
 'property'	=> { 'x-es' => 'propiedad',
		     't' => 'n' },
 'protect'	=> { 'x-es' => 'proteger' },
 'provide'	=> { 'x-es' => 'proveer' },
 'publish'	=> { 'x-es' => 'publicar' },
 'purple'	=> { 'x-es' => 'morado' },
 'put'		=> { 'x-es' => 'puesto',
		     '#' => 'poner' },
 'quantity'	=> { 'x-es' => 'cantidad' },
 'queer'	=> { 'x-es' => 'maricn' },
 'quick'	=> { 'x-es' => 'rpido',
 		     'x-de' => 'schnel' },
 'rabid'	=> { 'x-es' => 'rabioso' },
 'race'		=> { 'x-es' => 'raza' },
 'radical'	=> { 'x-es' => 'radical' },
 'rain'		=> { 'x-es' => 'lluvia' },
 'raise'	=> { 'x-es' => 'realzar' },
 'raw'		=> { 'x-es' => 'crudo' },
 'reach'	=> { 'x-es' => 'alcanzar' },
 'read'		=> { 'x-es' => 'leer',
 		     'x-de' => 'lesen',
		     't' => 'v' },
 'ready'	=> { 'x-es' => 'listo',
		     't' => 'a' },
 'really'	=> { 'x-es' => 'realmente' },
 'reason'	=> { 'x-es' => 'razn',
		     't' => 'n' },
 'receive'	=> { 'x-es' => 'recibir',
		     't' => 'v' },
 'reckon'	=> { 'x-es' => 'tantear',
		     't' => 'v' },
 'red'		=> { 'x-es' => 'rojo',
		     't' => 'a' },
 'reduce'	=> { 'x-es' => 'reducir' },
 'relative'	=> { 'x-es' => 'pariente' },
 'remember'	=> { 'x-es' => 'recordar' },
 'remove'	=> { 'x-es' => 'quitar' },
 'rent'		=> { 'x-es' => 'alquilar' },
 'replace'	=> { 'x-es' => 'reemplazar' },
 'report'	=> { 'x-es' => 'informe' },
 'represent'	=> { 'x-es' => 'representar' },
 'rest'		=> { 'x-es' => 'dems' },
 'return'	=> { 'x-es' => 'volver' },
 'revolutionary'	=> { 'x-es' => 'revolucionario' },
 'rich'		=> { 'x-es' => 'rico' },
 'ring'		=> { 'x-es' => 'argolla' },
 'rock'		=> { 'x-es' => 'roca' },
 'roman'	=> { 'x-es' => 'romano' },
 'rome'		=> { 'x-es' => 'roma' },
 'roof'		=> { 'x-es' => 'techo' },
 'room'		=> { 'x-es' => 'habitacin',
 		     'x-de' => 'zimmer' },
 'round'	=> { 'x-es' => 'redondo' },
 'rubbish'	=> { 'x-es' => 'desperdicios' },
 'ruin'		=> { 'x-es' => 'estrago' },
 'run'		=> { 'x-es' => 'correr',
		     '#' => 'irreg.',
 		     'x-de' => 'laufen' },
 'rythm'	=> { 'x-es' => 'ritmo' },
 'sad'		=> { 'x-es' => 'triste' },
 'same'		=> { 'x-es' => 'mismo' },
 'sandwich'	=> { 'x-es' => 'bocadillo' },
 'save'		=> { 'x-es' => 'ahorrar' },
 'say'		=> { 'x-es' => 'decir',
 		     'x-de' => 'sagen' },
 'scarce'	=> { 'x-es' => 'escaso' },
 'scarf'	=> { 'x-es' => 'pauelo' },
 'scatter'	=> { 'x-es' => 'sembrar' },
 'school'	=> { 'x-es' => 'escuela' },
 'screen'	=> { 'x-es' => 'pantalla' },
 'sea'		=> { 'x-es' => 'mar' },
 'seagull'	=> { 'x-es' => 'gaviota' },
 'seat'		=> { 'x-es' => 'asiento' },
 'second'	=> { 'x-es' => 'segundo' },
 'secure'	=> { 'x-es' => 'sujeto' },
 'see'		=> { 'x-es' => 'ver',
		     '#' => 'irreg.',
 		     'x-de' => 'sehen' },
  'seen'		=> { 'x-es' => 'visto',
 		     'r' => 'see',
		     't' => 'v',
		     'c' => 'pp' },
 'seed'		=> { 'x-es' => 'semilla' },
 'seem'		=> { 'x-es' => 'parecer' },
 'sell'		=> { 'x-es' => 'vender',
		     '#' => 'irreg.',
 		     'x-de' => 'verkaufen' },
 'seller'	=> { 'x-es' => 'vendedor' },
 'sensible'	=> { 'x-es' => 'sensato' },
 'serious'	=> { 'x-es' => 'serio' },
 'server'	=> { 'x-es' => 'servidor' },
 'several'	=> { 'x-es' => 'varios' },
 'sheep'	=> { 't' => 'n',
		     '#' => 'invariant' },
 'sheet'	=> { 'x-es' => 'lmina' },
 'shoe'		=> { 'x-es' => 'zapato' },
 'short'	=> { 'x-es' => 'corto',
		     't' => 'a' },
 'side'		=> { 'x-es' => 'lado' },
 'sight'	=> { 'x-es' => 'vista' },
 'sign'		=> { 'x-es' => 'sea',
		     '#' => 'seal' },
 'silence'	=> { 'x-es' => 'silencio' },
 'silk'		=> { 'x-es' => 'seda' },
 'silver'	=> { 'x-es' => 'plata' },
 'similar'	=> { 'x-es' => 'semejante' },
 'simple'	=> { 'x-es' => 'simple' },
 'simplify'	=> { 'x-es' => 'simplificar' },
 'sissy'	=> { 'x-es' => 'marica' },
 'sister'	=> { 'x-es' => 'hermana',
 		     'x-de' => 'schwester' },
 'sit'		=> { 'x-es' => 'sentar' },
 'site	'	=> { 'x-es' => 'sitio' },
 'skate'	=> { 'x-es' => 'patinar' },
 'skimp'	=> { 'x-es' => 'escatimar' },
 'skin'		=> { 'x-es' => 'piel' },
 'skirt'	=> { 'x-es' => 'falda' },
 'sky'		=> { 'x-es' => 'cielo' },
 'sleep'	=> { 'x-es' => 'dormir',
 		     'x-de' => 'schlafen' },
 'sleeve'	=> { 'x-es' => 'manga' },
 'small'	=> { 'x-es' => 'pequeo',
 		     'x-de' => 'klein' },
 'smell'	=> { 'x-es' => 'oler' },
 'snake'	=> { 'x-es' => 'serpentear' },
 'snow'		=> { 'x-es' => 'nevar' },
 'soft'		=> { 'x-es' => 'mullido' },
 'software'	=> { 'x-es' => 'software' },
 'solidity'	=> { 'x-es' => 'solidez' },
 'something'	=> { 'x-es' => 'algo',
 		     'x-de' => 'etwas' },
 'son'		=> { 'x-es' => 'hijo',
 		     'x-de' => 'sohn' },
 'soon'		=> { 'x-es' => 'pronto',
 		     'x-de' => 'bald' },
 'source'	=> { 'x-es' => 'fuente' },
 'space'	=> { 'x-es' => 'espacio' },
 'spacious'	=> { 'x-es' => 'amplio' },
 'spain'	=> { 'x-es' => 'espaa' },
 'spanish'	=> { 'x-es' => 'espaol',
 		     'x-de' => 'spanisch' },
 'speak'	=> { 'x-es' => 'hablar',
		     '#' => 'irreg.' },
 'special'	=> { 'x-es' => 'especial' },
 'speed'	=> { 'x-es' => 'rapidez' },
 'spiritual'	=> { 'x-es' => 'espiritual' },
 'split'	=> { 'x-es' => 'partir' },
 'spongy'	=> { 'x-es' => 'esponjoso' },
 'spoon'	=> { 'x-es' => 'cuchara',
 		     'x-de' => 'lffel' },
 'spread'	=> { 'x-es' => 'divulgar' },
 'spring'	=> { 'x-es' => 'muelle' },
 'square'	=> { 'x-es' => 'cuadrado' },
 'squeeze'	=> { 'x-es' => 'apretar' },
 'stain'	=> { 'x-es' => 'manchar' },
 'starch'	=> { 'x-es' => 'almidonar' },
 'state'	=> { 'x-es' => 'estado' },
 'stay'		=> { 'x-es' => 'quedar',
 		     'x-de' => 'bleiben' },
 'steel'	=> { 'x-es' => 'acero' },
 'step'		=> { 'x-es' => 'paso' },
 'stick'	=> { 'x-es' => 'bastn' },
 'still'	=> { 'x-es' => 'an' },
 'stone'	=> { 'x-es' => 'piedra' },
 'stop'		=> { 'x-es' => 'parar' },
 'storm'	=> { 'x-es' => 'tormenta' },
 'straight'	=> { 'x-es' => 'liso' },
 'strawberry'	=> { 'x-es' => 'fresa' },
 'street'	=> { 'x-es' => 'calle',
 		     'x-de' => 'strasse' },
 'stride'	=> { 'x-es' => 'tranco' },
 'strong'	=> { 'x-es' => 'fuerte' },
 'study'	=> { 'x-es' => 'estudiar',
		     '#' => 'also a noun',
 		     't' => 'v' },
 'style'	=> { 'x-es' => 'estilo' },
 'subtle'	=> { 'x-es' => 'sutil' },
 'suffer'	=> { 'x-es' => 'sufrir' },
 'suffocate'	=> { 'x-es' => 'sofocar' },
 'suggestion'	=> { 'x-es' => 'sugerencia' },
 'sun'		=> { 'x-es' => 'sol',
 		     'x-de' => 'sonne',
 		     't' => 'n' },
 'supermarket'	=> { 'x-es' => 'supermercado' },
 'supernatural'	=> { 'x-es' => 'sobrenatural' },
 'support'	=> { 'x-es' => 'apoyar' },
 'surpass'	=> { 'x-es' => 'superar' },
 'surprise'	=> { 'x-es' => 'sorpresa' },
 'surround'	=> { 'x-es' => 'rodear' },
 'survive'	=> { 'x-es' => 'conservarse' },
 'swan'		=> { 'x-es' => 'cisne',
 		     't' => 'n' },
 'swim'		=> { 'x-es' => 'nadar',
		     '#' => 'irreg.',
 		     'x-de' => 'schwimmen',
 		     't' => 'v' },
 'system'	=> { 'x-es' => 'sistema' },
 't-shirt'	=> { 'x-es' => 'playera' },
 'table'	=> { 'x-de' => 'tisch',
 		     'x-es' => 'mesa',
		     't' => 'n' },
 'tail'		=> { 'x-es' => 'cola' },
 'take'		=> { 'x-es' => 'tomar',
		     '#' => 'irreg.',
 		     't' => 'v' },
 'talk'		=> { 'x-es' => 'hablar',
		     't' => 'v' },
 'tame'		=> { 'x-es' => 'manso' },
 'taste'	=> { 'x-es' => 'gusto' },
 'teach'	=> { 'x-es' => 'ensear',
		     '#' => 'irreg.',
 		     'x-de' => 'lehren' },
 'terrible'	=> { 'x-es' => 'tremendo' },
 'text'		=> { 'x-es' => 'texto' },
 'thanks'	=> { 'x-es' => 'agradecimiento' },
 'theme'	=> { 'x-es' => 'tema' },
 'thick'	=> { 'x-es' => 'grueso' },
 'thickness'	=> { 'x-es' => 'espesor' },
 'thin'		=> { 'x-es' => 'tenue' },
 'thing'	=> { 'x-es' => 'cosa' },
 'think'	=> { 'x-es' => 'pensar',
		     '#' => 'irreg.',
 		     'x-de' => 'denken' },
 'thirst'	=> { 'x-es' => 'sed' },
 'thread'	=> { 'x-es' => 'hebra' },
 'throw'	=> { 'x-es' => 'tirar',
		     '#' => 'irreg.' },
 'tie'		=> { 'x-es' => 'lazo' },
 'time'		=> { 'x-es' => 'vez',
		     '#' => 'tiempo, also a verb',
 		     'x-de' => 'zeit',
		     't' => 'n' },
 'tip'		=> { 'x-es' => 'propina' },
 'tire'		=> { 'x-es' => 'cansar' },
 'title'	=> { 'x-es' => 'titulo',
		     't' => 'n' },
 'today'	=> { 'x-es' => 'hoy',
 		     'x-de' => 'heute' },
 'together'	=> { 'x-es' => 'juntos',
 		     'x-de' => 'zusammen' },
 'toilet'	=> { 'x-es' => 'bao',
		     't' => 'n' },
 'tongue'	=> { 'x-es' => 'lengua',
 		     'x-de' => 'zunge',
		     't' => 'n' },
 'tooth'	=> { 'x-es' => 'diente',
 		     't' => 'n',
		     'p' => 'teeth' },
  'teeth'	=> { 'x-es' => 'dientes',
  		     'r' => 'tooth',
		     't' => 'n',
		     'n' => 'p' },
 'top'		=> { 'x-es' => 'tapa' },
 'touch'	=> { 'x-es' => 'tocar' },
 'tourist'	=> { 'x-es' => 'turista' },
 'translate'	=> { 'x-es' => 'traduccir',
 		     'x-de' => 'bersetzen' },
 'transmit'	=> { 'x-es' => 'transmitir' },
 'travel'	=> { 'x-es' => 'viajar',
 		     'x-de' => 'reisen' },
 'trip'		=> { 'x-es' => 'tropezar',
		     '#' => 'viejo' },
 'trousers'	=> { 'x-es' => 'pantalones' },
 'truck'	=> { 'x-es' => 'camion' },
 'trunk'	=> { 'x-es' => 'bal' },
 'try'		=> { 'x-es' => 'intentar',
 		     'x-de' => 'versuchen' },
 'turn'		=> { 'x-es' => 'vuelta',
		     '#' => 'turno' },
 'type'		=> { 'x-es' => 'tipo' },
 'typography'	=> { 'x-es' => 'tipografa' },
 'tyre'		=> { 'x-es' => 'llanta' },
 'ugly'		=> { 'x-es' => 'feo' },
 'uncle'	=> { 'x-es' => 'to',
 		     'x-de' => 'onkel' },
 'under'	=> { 'x-es' => 'bajo',
 		     'x-de' => 'unter' },
 'underneath'	=> { 'x-es' => 'debajo' },
 'united'	=> { 'x-es' => 'unido' },
 'university'	=> { 'x-es' => 'universidad' },
 'unknown'	=> { 'x-es' => 'desconocido' },
 'untidy'	=> { 'x-es' => 'destartalado' },
 'upholstery'	=> { 'x-es' => 'tapicera' },
 'urgent'	=> { 'x-es' => 'urgente' },
 'use'		=> { 'x-es' => 'usar' },
 'user'		=> { 'x-es' => 'usuario' },
 'utility'	=> { 'x-es' => 'utilidad' },
 'valley'	=> { 'x-es' => 'valle' },
 'valve'	=> { 'x-es' => 'vlvula' },
 'variety'	=> { 'x-es' => 'variedad' },
 'version'	=> { 'x-es' => 'versin' },
 'village'	=> { 'x-es' => 'aldea' },
 'visa'		=> { 'x-es' => 'visa' },
 'visit'	=> { 'x-es' => 'visitar' },
 'visor'	=> { 'x-es' => 'visera' },
 'vote'		=> { 'x-es' => 'votar' },
 'wait'		=> { 'x-es' => 'espera',
 		     'x-de' => 'warten' },
 'walk'		=> { 'x-es' => 'andar' },
 'wall'		=> { 'x-es' => 'muralla' },
 'want'		=> { 'x-es' => 'querer' },
 'water'	=> { 'x-es' => 'agua' },
 'wave'		=> { 'x-es' => 'ola' },
 'way'		=> { 'x-es' => 'camino',
		     '#' => 'manera',
 		     'x-de' => 'weg' },
 'week'		=> { 'x-es' => 'semana',
 		     'x-de' => 'woche' },
 'welcome'	=> { 'x-es' => 'bienvenido',
 		     'x-de' => 'wilkommen' },
 'well'		=> { 'x-es' => 'bien' },
 'wheel'	=> { 'x-es' => 'rueda' },
 'whichever'	=> { 'x-es' => 'cualquiera' },
 'white'	=> { 'x-es' => 'blanco' },
 'window'	=> { 'x-es' => 'ventana',
 		     'x-de' => 'fenster' },
 'wine'		=> { 'x-es' => 'vino' },
 'wing'		=> { 'x-es' => 'ala' },
 'wish'		=> { 'x-es' => 'desear' },
 'withhold'	=> { 'x-es' => 'retener' },
 'woman'	=> { 'x-es' => 'mujer',
		     '#' => 'irreg.',
 		     'x-de' => 'frau',
		     't' => 'n',
		     'g' => 'f',
		     'p' => 'women' },
  'women'	=> { 'x-es' => 'mujeres',
  		     'r' => 'woman',
		     't' => 'n',
		     'n' => 'p' },
 'wood'		=> { 'x-es' => 'madera' },
 'word'		=> { 'x-es' => 'palabra',
 		     'x-de' => 'wort' },
 'work'		=> { 'x-es' => 'trabajar',
		     '#' => 'noun and verb' },
 'world'	=> { 'x-es' => 'mundo',
 		     'x-de' => 'welt' },
 'write'	=> { 'x-es' => 'escribir',
		     'x-de' => 'schreiben',
 		     't' => 'v' },
 'written'	=> { 'x-es' => 'escrito',
 		     'r' => 'write',
		     't' => 'v',
		     'c' => 'pp' },
 'year'		=> { 'x-es' => 'ao',
 		     'x-de' => 'jahr' },
 'yell'		=> { 'x-es' => 'gritar' },
 'yellow'	=> { 'x-es' => 'amarillo' },
 'zone'		=> { 'x-es' => 'zona' },
);
}

1;

