# vi: ts=8 sw=8 sts=8

package Tongues::Russky;

use strict;
use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $charset $grammar %dictionary);

use Exporter   ();
# set the version for version checking
@ISA         = qw(Exporter);
@EXPORT      = qw(charset grammar dictionary);
@EXPORT_OK   = qw();
$VERSION     = 0.00;

# Character set Windows Cyrillic CP1251
# not KOI8-R or ISO 8859-5

# Alphabetical order
#                                 
#                                 

sub new {
	my $class = shift;
	my $self = bless {}, $class;
	return $self;
}

sub charset {
	return $charset;
}

sub grammar {
	return $grammar;
}

sub dictionary {
	return \%dictionary;
}

sub BEGIN {

require Charsets::CyrillicWin;

$charset = new Charsets::CyrillicWin;

# Table for converting words to root form
$grammar = [
 # Noun case
 # Noun gender
 # Noun plural
 # Adjectives
 # Verb past participle
 # Verb gerund
 # Verb present participle
 # Verb present
 # Verb present subjunctive
 # Verb imperitive
 # Verb preterite
 # Verb imperfect
 # Verb future
 # Verb conditional
 # Adverb
 # Higher level transformations
];

#Fields:
# x -> translation		all words
# r -> root			irregular declensions
# t -> type:			all words
#	n -> noun
#	v -> verb
#	a -> adjective
#	p -> preposition
#	art -> article
#	pro -> pronoun
#	conj -> conjugation
#	adv -> adverb
# g -> gender:			nouns, pronouns, adjectives
#	m -> masculine		default
#	f -> feminine
#	n -> neuter
# n -> number:			articles, pronouns, verbs, adjectives
#	s -> singular		default
#	p -> plural		default for words ending in s
# p -> person:			pronouns, verbs
#	1 -> 1st person
#	2 -> 2nd person
#	3 -> 3rd person		default
# c -> conjugation:
#	p -> present
#	i -> imperfect
#	f -> future
#	c -> conditional
#	t -> preterite
#	ps -> present subjunctive
#	is -> imperfect subjunctive
#	inf -> infinitive		default
#	pp -> past participle
#	g -> gerund
#	imp -> imperative
# c -> case:
#	n -> nominative 
#	g -> genitive 
#	d -> dative 
#	a -> accusative 
#	v -> vocative 
#	l -> locative 
#	inst -> instrumental 

# Russian to English dictionary
%dictionary = (
 # Functional words
 #  Articles
 #   Definite articles
 #    Masculine
 #     Singular
 #     Plural
 #    Feminine
 #     Singular
 #     Plural
 #   Indefinite articles
 #  Pronouns & possessive adjectives
 #   1st person
 #   2nd person
 #   3rd person
 ''		=> { 'x' => 'him',
		     '#' => 'his, its' },
 #  Other functional words
 ''		=> { 'x' => 'in',
 		     't' => 'p' },
 ''		=> { 'x' => 'in',
 		     't' => 'p' },
 ''		=> { 'x' => 'all',
		     '#' => 'pron. everybody' },
 ''		=> { 'x' => 'even',
		     '#' => 'adverb' },
 ''		=> { 'x' => 'for',
		     '#' => 'to',
 		     't' => 'p' },
 ''		=> { 'x' => 'but',
		     '#' => 'however',
 		     't' => 'conj' },
 ''		=> { 'x' => 'and',
		     '#' => 'but, although',
 		     't' => 'conj' },
 ''		=> { 'x' => 'from',
		     '#' => 'out of, through',
 		     't' => 'p' },
 ''		=> { 'x' => 'or',
		     '#' => 'either',
 		     't' => 'conj' },
 ''		=> { 'x' => 'how',
		     '#' => 'as, like' },
 ''		=> { 'x' => 'at',
		     '#' => 'by',
 		     't' => 'p' },
 ''		=> { 'x' => 'not',
		     '#' => 'no, none' },
 ''		=> { 'x' => 'from',
		     '#' => 'of',
 		     't' => 'p' },
 ''		=> { 'x' => 'at',
		     '#' => 'by, in, on, to, up to',
 		     't' => 'p' },
 ''		=> { 'x' => 'at',
		     '#' => 'by, during, in, near',
 		     't' => 'p' },
 ''		=> { 'x' => 'what',
		     '#' => 'how' },
 ''	=> { 'x' => 'so that',
		     '#' => 'in order to',
 		     't' => 'p' },
 #   Partitive / Contractions
 # Numbers: cardinal and ordinal
 # Days and months
 ''	=> { 'x' => 'sunday' },
 ''	=> { 'x' => 'monday' },
 ''	=> { 'x' => 'tuesday' },
 ''	=> { 'x' => 'wednesday' },
 ''	=> { 'x' => 'thursday' },
 ''	=> { 'x' => 'friday' },
 ''	=> { 'x' => 'saturday' },
 ''	=> { 'x' => 'january' },
 ''	=> { 'x' => 'february' },
 ''		=> { 'x' => 'march' },
 ''	=> { 'x' => 'april' },
 ''		=> { 'x' => 'may' },
 ''		=> { 'x' => 'june' },
 ''		=> { 'x' => 'july' },
 ''	=> { 'x' => 'august' },
 ''	=> { 'x' => 'september' },
 ''	=> { 'x' => 'october' },
 ''	=> { 'x' => 'november' },
 ''	=> { 'x' => 'december' },
 # Key verbs
 # Vocabulary
 ''	=> { 'x' => 'australia',
 		     't' => 'n' },
 ''	=> { 'x' => 'astronaut',
 		     't' => 'n' },
 ''	=> { 'x' => 'version',
 		     't' => 'n' },
 ''	=> { 'x' => 'meeting',
 		     't' => 'n' },
 ''	=> { 'x' => 'galaxy',
 		     't' => 'n' },
 ''	=> { 'x' => 'newspaper',
 		     't' => 'n' },
 ''	=> { 'x' => 'germany',
 		     't' => 'n' },
 ''	=> { 'x' => 'hebrew',
 		     't' => 'n' },
 ''	=> { 'x' => 'hebrew',
 		     't' => 'a' },
 ''	=> { 'x' => 'electricity',
 			     't' => 'n' },
 ''	=> { 'x' => 'esperanto',
 		     't' => 'n' },
 ''	=> { 'x' => 'gesticulate',
 			     't' => 'v' },
 ''	=> { 'x' => 'industry',
 		     't' => 'n' },
 ''	=> { 'x' => 'interview',
 		     't' => 'n' },
 ''	=> { 'x' => 'internet',
 		     't' => 'n' },
 ''	=> { 'x' => 'cartography',
 		     't' => 'n' },
 ''	=> { 'x' => 'envelope',
 		     't' => 'n' },
 ''	=> { 'x' => 'cosmonaut',
 		     't' => 'n' },
 ''	=> { 'x' => 'minute',
 		     't' => 'n' },
 ''	=> { 'x' => 'modify',
			     't' => 'v' },
 ''	=> { 'x' => 'independent',
 		     't' => 'a' },
 ''		=> { 'x' => 'window',
 		     't' => 'n' },
 ''	=> { 'x' => 'paraguay',
		     '#' => 'proper; place',
 		     't' => 'n' },
 ''	=> { 'x' => 'passport',
 		     't' => 'n' },
 ''	=> { 'x' => 'swim',
 		     't' => 'v' },
 ''	=> { 'x' => 'project',
 		     't' => 'n' },
 ''	=> { 'x' => 'symbol',
 		     't' => 'n' },
 ''	=> { 'x' => 'dictionary',
 		     't' => 'n' },
 ''	=> { 'x' => 'solidarity',
 		     't' => 'n' },
		     ''	=> { 'x' => 'article',
			     't' => 'n' },
 ''	=> { 'x' => 'page',
 		     't' => 'n' },
 ''	=> { 'x' => 'uruguay',
		     '#' => 'proper; place',
 		     't' => 'n' },
 ''		=> { 'x' => 'language',
		     '#' => 'tongue',
 		     't' => 'n' },
 ''	=> { 'x' => 'japan',
 		     't' => 'n' },
);
}

1;

