# vi: ts=8 sw=8 sts=8

package Tongues::Suomi;

use strict;
use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $charset $grammar %dictionary);

use Exporter   ();
# set the version for version checking
@ISA         = qw(Exporter);
@EXPORT      = qw(charset grammar dictionary);
@EXPORT_OK   = qw();
$VERSION     = 0.00;

# Character set Windows Western European CP1252 / ISO 8859-1 / Latin-1

# Alphabetical order
# A B C D E F G H I J K L M N O P Q R S T U V W X Y Z   
# a b c d e f g h i j k l m n o p q r s t u v w x y z   

sub new {
	my $class = shift;
	my $self = bless {}, $class;
	return $self;
}

sub charset {
	return $charset;
}

sub grammar {
	return $grammar;
}

sub dictionary {
	return \%dictionary;
}

sub BEGIN {

require Charsets::WestEuroWin;

$charset = new Charsets::WestEuroWin;

# Table for converting words to root form
$grammar = [
 # Noun case
 [ 'n',		'',	'(of) ',	'',	'n' ],	# genetive
 [ 'a',		'',	'(some) ',	'',	'n' ],	# partitive
 [ 'na',	'',	'(as) ',	'',	'n' ],	# essive
 [ 'ksi',	'',	'(to) ',	'',	'n' ],	# translative
 [ 'ssa',	'',	'(in) ',	'',	'n' ],	# inessive
 [ 'sta',	'',	'(from) ',	'',	'n' ],	# elative
 [ 'in',	'',	'(into) ',	'',	'n' ],	# illitive
 [ 'lla',	'',	'(on) ',	'',	'n' ],	# adessive - at, with, by
 [ 'lta',	'',	'(from) ',	'',	'n' ],	# ablative
 [ 'lle',	'',	'(to) ',	'',	'n' ],	# allative - onto, for
 [ 'tta',	'',	'(without) ',	'',	'n' ],	# abessive
 [ 'ne',	'',	'(with) ',	'',	'n' ],	# comitative
 [ 'in',	'',	'(with) ',	'',	'n' ],	# using, by means of
 # Noun plural
 # Adjectives
 # Verb past participle
 # Verb gerund
 # Verb present participle
 # Verbs present
 [ 'en',	'la',	'(I) ',		'',	'v' ],	# 1s
 [ 'tan',	'ttaa',	'(I) ',		'',	'n' ],
 [ 'et',	'la',	'(you) ',	'',	'v' ],	# 2s
 [ 'tat',	'ttaa',	'(you) ',	'',	'v' ],
 [ 'ee',	'la',	'(he) ',	's',	'v' ],	# 3s (he/she)
 [ 'emme',	'la',	'(we) ',	'',	'v' ],	# 1p
 [ 'tamme',	'ttaa',	'(we) ',	'',	'v' ],
 [ 'ette',	'la',	'(you) ',	'',	'v' ],	# 2p
 [ 'tatte',	'ttaa',	'(you) ',	'',	'v' ],
 [ 'evat',	'la',	'(they) ',	'',	'v' ],	# 3p - also vt
 [ 'vat',	'a',	'(they) ',	'',	'v' ],
 # Verb present subjunctive
 # Verb imperitive
 # Verb preterite
 # Verb imperfect
 # Verb future
 # Verb conditional
 # Adverb
 # Higher level transformations
];

#Fields:
# x -> translation		all words
# r -> root			irregular declensions
# t -> type:			all words
#	n -> noun
#	v -> verb
#	a -> adjective
#	p -> preposition
#	pro -> pronoun
#	conj -> conjugation
#	adv -> adverb
# n -> number:			pronouns, verbs, adjectives
#	s -> singular		default
#	p -> plural		default for words ending in s
# p -> person:			pronouns, verbs
#	1 -> 1st person
#	2 -> 2nd person
#	3 -> 3rd person		default
# c -> conjugation:
#	p -> present
#	t -> preterite
#	inf -> infinitive		default
#	pp -> past participle
#	g -> gerund
#	imp -> imperative
# c -> case:
#	n -> nominative
#	g -> genitive
#	part -> partitive
#	a -> accusative
#	iness -> inessive
#	el -> elative
#	il -> illative
#	adess -> adessive
#	abl -> ablative
#	al -> allative
#	abess -> abessive
#	ess -> essive
#	trans -> translative
#	com -> comitative
#	instruct -> instructive

# Finnish to English dictionary
%dictionary = (
 # Functional words
 #  Pronouns & possessive adjectives
 'min'	=> { 'x' => 'I',
 	     't' => 'pro',
	     'p' => '1',
	     'n' => 's' },
 'me'	=> { 'x' => 'we',
 	     't' => 'pro',
	     'p' => '1',
	     'n' => 'p' },
 'sin' => { 'x' => 'you',
 	     't' => 'pro',
	     'p' => '2',
	     'n' => 's' },
 'te'	=> { 'x' => 'you',
 	     't' => 'pro',
	     'p' => '2',
	     'n' => 'p' },
 'hn'	=> { 'x' => 'he',
 	     't' => 'pro',
	     'p' => '3',
	     'n' => 's' },
 'he'	=> { 'x' => 'they',
		     '#' => '?',
 	     't' => 'pro',
	     'p' => '3',
	     'n' => 'p' },
 'ne'	=> { 'x' => 'they',
 	     't' => 'pro',
	     'p' => '3',
	     'n' => 'p' },

 # Other functional words
 'ehk'		=> { 'x' => 'perhaps' },
 'enemmn'	=> { 'x' => 'more' },
 'ett'		=> { 'x' => 'that' },
 'hei'		=> { 'x' => 'hello',
 		     't' => 'interj' },
 'ja'		=> { 'x' => 'and',
		     '#' => 'conjunction' },
 'jahka'	=> { 'x' => 'when',
		     '#' => 'until, if' },
 'joo'		=> { 'x' => 'yes',
 		     't' => 'interj' },
 'joskus'	=> { 'x' => 'sometimes',
 		     't' => 'adv' },
 'jotta'	=> { 'x' => 'so that',
		     '#' => 'in order to' },
 'kaikki'	=> { 'x' => 'all',
		     '#' => 'everybody, everything; pron. and adj.?' },
 'kuinka'	=> { 'x' => 'how' },
 'kun'		=> { 'x' => 'when',
		     '#' => 'while' },
 'mik'		=> { 'x' => 'what',
		     '#' => 'interr.',
 		     't' => 'adv' },
 'miten'	=> { 'x' => 'how' },
 'mutta'	=> { 'x' => 'but' },
 'mys'		=> { 'x' => 'also',
		     '#' => 'conj.?' },
 'no'		=> { 'x' => 'well',
 		     't' => 'adv' },
 'nyt'		=> { 'x' => 'now',
 		     't' => 'adv' },
 'paitsi'	=> { 'x' => 'except' },
 'sek'		=> { 'x' => 'and' },
 'siis'		=> { 'x' => 'so',
		     '#' => 'therefore, thus' },
 'sill'	=> { 'x' => 'because' },
 'tahi'		=> { 'x' => 'or',
 		     't' => 'conj' },
 'tahikka'	=> { 'x' => 'or',
 		     't' => 'conj' },
 'tai'		=> { 'x' => 'or',
		     't' => 'conj' },
 'taikka'	=> { 'x' => 'or',
 		     't' => 'conj' },
 'tll'	=> { 'x' => 'here is',
		     '#' => 'multiword' },
 'tm'		=> { 'x' => 'this',
		     '#' => 'adj. or pron.?' },
 'tss'	=> { 'x' => 'here is',
		     '#' => 'multiword' },
 'vaan'		=> { 'x' => 'but' },
 'vai'		=> { 'x' => 'or',
 		     't' => 'conj' },
 'vain'		=> { 'x' => 'only',
		     '#' => 'adv. and/or adj.?' },
 'vasta'	=> { 'x' => 'only',
		     '#' => '(of time)' },
 'viel'	=> { 'x' => 'still',
		     '#' => 'further, also' },
 'yli'		=> { 'x' => 'past',
		     '#' => 'over, across' },

 #   Partitive / Contractions
 # Numbers: cardinal and ordinal
 # Days and months
 'sunnuntai'	=> { 'x' => 'sunday' },
 'maanantai'	=> { 'x' => 'monday' },
 'tiistai'	=> { 'x' => 'tuesday' },
 'keskiviikko'	=> { 'x' => 'wednesday' },
 'torstai'	=> { 'x' => 'thursday' },
 'perjantai'	=> { 'x' => 'friday' },
 'lauantai'	=> { 'x' => 'saturday' },
 'tammikuu'	=> { 'x' => 'january' },
 'helmikuu'	=> { 'x' => 'february' },
 'maaliskuu'	=> { 'x' => 'march' },
 'huhtikuu'	=> { 'x' => 'april' },
 'toukokuu'	=> { 'x' => 'may' },
 'keskuu'	=> { 'x' => 'june' },
 'heinkuu'	=> { 'x' => 'july' },
 'elokuu'	=> { 'x' => 'august' },
 'syyskuu'	=> { 'x' => 'september' },
 'lokakuu'	=> { 'x' => 'october' },
 'marraskuu'	=> { 'x' => 'november' },
 'joulukuu'	=> { 'x' => 'december' },
 # Key verbs
 #  to be
 'olen'		=> { 'x' => 'i am',
 		     't' => 'v' },
 # Vocabulary
 'aakkoset'	=> { 'x' => 'alphabet',
 		     't' => 'n' },
 'aanteeksi'	=> { 'x' => 'excuse me',
		     '#' => 'multiword; i\'m sorry',
 		     't' => 'interj' },
 'alkaa'	=> { 'x' => 'start',
		     '#' => 'begin',
 		     't' => 'v' },
 'antaa'	=> { 'x' => 'give',
		     '#' => 'let, allow',
 		     't' => 'v' },
 'artikla'	=> { 'x' => 'article',
 		     't' => 'n' },
 'asua'		=> { 'x' => 'reside',
		     '#' => 'live in',
 		     't' => 'v' },
 'australia'	=> { 'x' => 'australia',
 		     't' => 'n' },
 'automaattinen'	=> { 'x' => 'automatic',
 			     't' => 'a' },
 'auttaa'	=> { 'x' => 'help',
 		     't' => 'v' },
 'avain'	=> { 'x' => 'key',
 		     't' => 'n' },
 'avata'	=> { 'x' => 'open',
 		     't' => 'v' },
 'cikk'		=> { 'x' => 'article',
		     't' => 'n' },
 'englantilainen'	=> { 'x' => 'english',
			     '#' => 'noun and adj.' },
 'englantia'	=> { 'x' => 'english',
		     '#' => 'language',
 		     't' => 'n' },
 'espanjaa'	=> { 'x' => 'spanish',
		     '#' => 'language',
 		     't' => 'n' },
 'etsi'	=> { 'x' => 'seek',
		     '#' => 'look for',
 		     't' => 'v' },
 'haluta'	=> { 'x' => 'live',
 		     't' => 'v' },
 'hindi'	=> { 'x' => 'hindi',
 		     't' => 'n' },
 'hitaasti'	=> { 'x' => 'slowly',
 		     't' => 'adv' },
 'hyvin'	=> { 'x' => 'well',
 		     't' => 'adv' },
 'ihmiset'	=> { 'x' => 'people',
		     '#' => '"the people"',
 		     't' => 'n' },
 'ikkuna'	=> { 'x' => 'window',
 		     't' => 'n' },
 'intialainen'	=> { 'x' => 'indian',
		     '#' => 'noun and adj.' },
 'iso'		=> { 'x' => 'big',
 		     't' => 'a' },
 'japani'	=> { 'x' => 'japan',
 		     't' => 'n' },
 'julistaa'	=> { 'x' => 'announce',
		     '#' => 'declare',
 		     't' => 'v' },
 'julistuksen'	=> { 'x' => 'declaration',
		     '#' => 'announcement?',
 		     't' => 'n' },
 'juoda'	=> { 'x' => 'drink',
 		     't' => 'v' },
 'jd'	=> { 'x' => 'stay',
 		     't' => 'v' },
 'kantaa'	=> { 'x' => 'carry',
 		     't' => 'v' },
 'katsoa'	=> { 'x' => 'look at',
 		     't' => 'v' },
 'kirjekuori'	=> { 'x' => 'envelope',
 		     't' => 'n' },
 'kirjoittaa'	=> { 'x' => 'write',
 		     't' => 'v' },
 'kokeilla'	=> { 'x' => 'try',
 		     't' => 'v' },
 'koko'		=> { 'x' => 'size',
 		     't' => 'n' },
 'kokous'	=> { 'x' => 'meeting',
 		     't' => 'n' },
 'kysy'	=> { 'x' => 'ask',
 		     't' => 'v' },
 'lhte'	=> { 'x' => 'leave',
 		     't' => 'v' },
 'lakata'	=> { 'x' => 'stop',
 		     't' => 'v' },
 'levt'	=> { 'x' => 'rest',
 		     't' => 'v' },
 'lukea'	=> { 'x' => 'read',
		     '#' => 'count',
 		     't' => 'v' },
 'meksikolainen'	=> { 'x' => 'mexican',
		     '#' => 'noun and adj.' },
 'menn'	=> { 'x' => 'go',
 		     't' => 'v' },
 'minuutti'	=> { 'x' => 'minute',
 		     't' => 'n' },
 'myyd'	=> { 'x' => 'sell',
 		     't' => 'v' },
 'nauttia'	=> { 'x' => 'enjoy',
 		     't' => 'v' },
 'nkyy'	=> { 'x' => 'is visible',
		     '#' => 'multiword; can be seen; v or adj.?' },
 'opetella'	=> { 'x' => 'learn',
 		     't' => 'v' },
 'opiskella'	=> { 'x' => 'study',
 		     't' => 'v' },
 'oppia'	=> { 'x' => 'learn',
 		     't' => 'v' },
 'osata'	=> { 'x' => 'know how',
		     '#' => 'sabes',
 		     't' => 'v' },
 'ostaa'	=> { 'x' => 'buy',
 		     't' => 'v' },
 'ottaa'	=> { 'x' => 'take',
 		     't' => 'v' },
 'puhua'	=> { 'x' => 'speak',
 		     't' => 'v' },
 'raja'		=> { 'x' => 'limit',
		     '#' => 'border',
 		     't' => 'n' },
 'rakastaa'	=> { 'x' => 'love',
 		     't' => 'v' },
 'ranskaa'	=> { 'x' => 'french',
		     '#' => 'language',
 		     't' => 'n' },
 'ranskalainen'	=> { 'x' => 'french',
		     '#' => 'noun and adj.' },
 'ruotsalainen'	=> { 'x' => 'swedish',
		     '#' => 'noun and adj.' },
 'ruotsia'	=> { 'x' => 'swedish',
		     '#' => 'language',
 		     't' => 'n' },
 'ruveta'	=> { 'x' => 'start',
 		     't' => 'v' },
 'saksa'	=> { 'x' => 'germany',
 		     't' => 'n' },
 'saksaa'	=> { 'x' => 'german',
		     '#' => 'language',
 		     't' => 'n' },
 'saksalainen'	=> { 'x' => 'german',
		     '#' => 'noun and adj.' },
 'sallia'	=> { 'x' => 'allow',
 		     't' => 'v' },
 'sana'		=> { 'x' => 'word',
 		     't' => 'n' },
 'sanakirja'	=> { 'x' => 'dictionary',
 		     't' => 'n' },
 'sanoa'	=> { 'x' => 'say',
 		     't' => 'v' },
 'sanoma'	=> { 'x' => 'message',
 		     't' => 'n' },
 'siitt'	=> { 'x' => 'generate',
 		     't' => 'v' },
 'skotlantilainen'	=> { 'x' => 'scottish',
		     '#' => 'noun and adj.' },
 'suomea'	=> { 'x' => 'finnish',
		     '#' => 'language',
 		     't' => 'n' },
 'suomi'	=> { 'x' => 'finland',
		     '#' => 'proper; place',
 		     't' => 'n' },
 'suomalainen'	=> { 'x' => 'finnish',
		     '#' => 'noun and adj.' },
 'suudella'	=> { 'x' => 'kiss',
 		     't' => 'v' },
 'syd'	=> { 'x' => 'eat',
 		     't' => 'v' },
 'shk'	=> { 'x' => 'electricity',
 		     't' => 'n' },
 'tarvita'	=> { 'x' => 'need',
 		     't' => 'v' },
 'teksti'	=> { 'x' => 'text',
		     '#' => 'subtitles',
 		     't' => 'n' },
 'tietokone'	=> { 'x' => 'computer',
 		     't' => 'n' },
 'tiet'	=> { 'x' => 'know',
		     '#' => 'as in "saber"',
 		     't' => 'v' },
 'tukka'	=> { 'x' => 'hair',
 		     't' => 'n' },
 'tuli'		=> { 'x' => 'fire',
 		     't' => 'n' },
 'tulla'	=> { 'x' => 'come',
 		     't' => 'v' },
 'tuntea'	=> { 'x' => 'feel',
 		     't' => 'v' },
 'tuoda'	=> { 'x' => 'bring',
 		     't' => 'v' },
 'tuoli'	=> { 'x' => 'chair',
 		     't' => 'n' },
 'tupakoida'	=> { 'x' => 'smoke',
 		     't' => 'v' },
 'tuuli'	=> { 'x' => 'wind',
 		     't' => 'n' },
 'tykt'	=> { 'x' => 'like',
 		     't' => 'v' },
 'uida'		=> { 'x' => 'swim',
 		     't' => 'v' },
 'unohtaa'	=> { 'x' => 'forget',
 		     't' => 'v' },
 'vapaa'	=> { 'x' => 'free',
 		     't' => 'a' },
 'venj'	=> { 'x' => 'russian',
		     '#' => 'language',
 		     't' => 'n' },
 'venlinen'	=> { 'x' => 'russian',
		     '#' => 'noun and adj.' },
 'viro'		=> { 'x' => 'estonia',
		     '#' => 'proper; place',
 		     't' => 'n' },
 'voida'	=> { 'x' => 'can',
		     '#' => 'be able to',
 		     't' => 'v' },
 'vhn'	=> { 'x' => 'little',
		     '#' => 'a little' },
 'ymmrt'	=> { 'x' => 'understand',
 		     't' => 'v' },
 'ntminen'	=> { 'x' => 'pronunciation',
 		     't' => 'n' },
 # Below here auto-converted from online dictionary
 'aalto'	=> { 'x' => 'fluid',
		     '#' => ', liquid' },
 'aamu'		=> { 'x' => 'morning' },
 'aamurusko'	=> { 'x' => 'aurora',
		     '#' => ', dawn' },
 'aasi'		=> { 'x' => 'ass',
		     '#' => ', donkey' },
 'aasialainen'	=> { 'x' => 'asian' },
 'aate'		=> { 'x' => 'idea' },
 'aavistaa'	=> { 'x' => 'guess' },
 'afrikka'	=> { 'x' => 'africa' },
 'afrikkalainen'	=> { 'x' => 'african' },
 'ahkera'	=> { 'x' => 'diligent',
		     '#' => ', hardworking, industrious' },
 'ahne'		=> { 'x' => 'avid',
		     '#' => ', eager for, greedy' },
 'ahven'	=> { 'x' => 'bass' },
 'aihe'		=> { 'x' => 'subject',
		     '#' => ', theme, topic' },
 'aika'		=> { 'x' => 'time' },
 'aikainen'	=> { 'x' => 'early' },
 'aikaisin'	=> { 'x' => 'early' },
 'aikana'	=> { 'x' => 'during',
		     '#' => ', for, while, whilst' },
 'aina'		=> { 'x' => 'always' },
 'ainakin'	=> { 'x' => 'at least' },
 'aistillinen'	=> { 'x' => 'erotic' },
 'aivan'	=> { 'x' => 'at all',
		     '#' => ', entirely, wholly' },
 'aivastaa'	=> { 'x' => 'sneeze' },
 'aivot'	=> { 'x' => 'brain' },
 'ajaa'		=> { 'x' => 'go',
		     '#' => ', ride, travel' },
 'ajanjakso'	=> { 'x' => 'age',
		     '#' => ', epoch, era' },
 'ajatella'	=> { 'x' => 'think' },
 'alankomaat'	=> { 'x' => 'holland',
		     '#' => ', the netherlands' },
 'alaston'	=> { 'x' => 'bare',
		     '#' => ', naked, nude' },
 'alistua'	=> { 'x' => 'abandon',
		     '#' => ', give up, renounce, resign' },
 'alku'		=> { 'x' => 'beginning',
		     '#' => ', commencement, start' },
 'alkuaine'	=> { 'x' => 'element' },
 'alkusoitto'	=> { 'x' => 'overture' },
 'alla'		=> { 'x' => 'below',
		     '#' => ', beneath, under' },
 'aloittaa'	=> { 'x' => 'begin',
		     '#' => ', commence, start' },
 'alushousut'	=> { 'x' => 'drawers',
		     '#' => ', panties, underpants' },
 'alusta'	=> { 'x' => 'base',
		     '#' => ', basis, bench, easel, tressle, workbench' },
 'amerikka'	=> { 'x' => 'america',
		     '#' => ', usa, united states of america' },
 'amerikkalainen'	=> { 'x' => 'american',
		     '#' => ', us citizen' },
 'ammatti'	=> { 'x' => 'profession' },
 'ammentaa'	=> { 'x' => 'draw' },
 'ammua'	=> { 'x' => 'bellow',
		     '#' => ', bleat, neigh' },
 'ampiainen'	=> { 'x' => 'wasp' },
 'ankara'	=> { 'x' => 'rigorous',
		     '#' => ', severe, strict, stringent' },
 'ankerias'	=> { 'x' => 'eel' },
 'ankkuri'	=> { 'x' => 'anchor' },
 'ansaita'	=> { 'x' => 'be worthy of',
		     '#' => ', deserve, merit' },
 'antaa'	=> { 'x' => 'give' },
 'antaa anteeksi'	=> { 'x' => 'forgive',
		     '#' => ', pardon' },
 'antaa ilmi'	=> { 'x' => 'denounce' },
 'antaa tehtvksi'	=> { 'x' => 'entrust',
		     '#' => ', tell' },
 'apina'	=> { 'x' => 'ape',
		     '#' => ', monkey' },
 'appelsiini'	=> { 'x' => 'orange' },
 'arabi'	=> { 'x' => 'arab' },
 'arabialainen'	=> { 'x' => 'arabian',
		     '#' => ', arabic' },
 'armahtaa'	=> { 'x' => 'be lenient with',
		     '#' => ', indulge, spare' },
 'arpi'		=> { 'x' => 'scar' },
 'arvella'	=> { 'x' => 'deem',
		     '#' => ', opine, think' },
 'arvioida'	=> { 'x' => 'appraise',
		     '#' => ', estimate, rate' },
 'arvo'		=> { 'x' => 'value',
		     '#' => ', worth' },
 'arvoinen'	=> { 'x' => 'deserving',
		     '#' => ', worthy' },
 'arvoitus'	=> { 'x' => 'enigma',
		     '#' => ', puzzle, riddle' },
 'arvostaa'	=> { 'x' => 'appreciate',
		     '#' => ', like' },
 'arvovalta'	=> { 'x' => 'authority' },
 'asema'	=> { 'x' => 'stage',
		     '#' => ', station, stop' },
 'asentaa'	=> { 'x' => 'assemble',
		     '#' => ', link, mount' },
 'asia'		=> { 'x' => 'affair',
		     '#' => ', business, business deal, case, matter' },
 'asiakas'	=> { 'x' => 'client',
		     '#' => ', customer' },
 'askel'	=> { 'x' => 'pace',
		     '#' => ', step, stride' },
 'aste'		=> { 'x' => 'degree',
		     '#' => ', grade' },
 'asteikko'	=> { 'x' => 'scale' },
 'astia'	=> { 'x' => 'vase',
		     '#' => ', vessel' },
 'asua'		=> { 'x' => 'dwell',
		     '#' => ', live' },
 'atlantti'	=> { 'x' => 'atlantic',
		     '#' => ', atlantic ocean' },
 'aurinko'	=> { 'x' => 'sun' },
 'australia'	=> { 'x' => 'australia' },
 'australialainen'	=> { 'x' => 'australian' },
 'autiomaa'	=> { 'x' => 'desert' },
 'auto'		=> { 'x' => 'automobile',
		     '#' => ', car, motor car, motor-car' },
 'auttaa'	=> { 'x' => 'accomodate',
		     '#' => ', aid, assist, help' },
 'avara'	=> { 'x' => 'extensive',
		     '#' => ', spacious, vast, wide' },
 'brasiliaikka'	=> { 'x' => 'brazilfrica' },
 'brasilialainen'	=> { 'x' => 'brazilian' },
 'brittilinen'	=> { 'x' => 'british' },
 'bussi'	=> { 'x' => 'omnibus' },
 'chilipippuri'	=> { 'x' => 'chilli' },
 'edelleen'	=> { 'x' => 'further',
		     '#' => ', more' },
 'edess'	=> { 'x' => 'before',
		     '#' => ', in front of' },
 'edisty'	=> { 'x' => 'get along',
		     '#' => ', proceed, progress' },
 'egypti'	=> { 'x' => 'egypt' },
 'egyptilinen'	=> { 'x' => 'egyptian' },
 'ehdottaa'	=> { 'x' => 'offer',
		     '#' => ', propose, suggest' },
 'ehdottomasti'	=> { 'x' => 'absolutely',
		     '#' => ', definitely, without fail' },
 'ehto'		=> { 'x' => 'condition',
		     '#' => ', stipulation, terms' },
 'ei'		=> { 'x' => 'no',
		     '#' => ', not' },
 'ei kenenkn'	=> { 'x' => 'no-one\'s' },
 'ei koskaan'	=> { 'x' => 'never' },
 'ei kuinkaan'	=> { 'x' => 'by no means',
		     '#' => ', in no way, not at all' },
 'ei kukaan'	=> { 'x' => 'no-one',
		     '#' => ', nobody' },
 'ei lainkaan'	=> { 'x' => 'none' },
 'ei mikn'	=> { 'x' => 'nothing' },
 'ei missn'	=> { 'x' => 'nowhere' },
 'eik'		=> { 'x' => 'neither' },
 'eilen'	=> { 'x' => 'yesterday' },
 'ele'		=> { 'x' => 'gesture' },
 'elokuu'	=> { 'x' => 'august' },
 'elin'	=> { 'x' => 'animal',
		     '#' => ', beast' },
 'el'		=> { 'x' => 'be alive' },
 'enemmn'	=> { 'x' => 'more' },
 'englanti'	=> { 'x' => 'england' },
 'englantilainen'	=> { 'x' => 'english',
		     '#' => ', englishman, sassenach' },
 'eniten'	=> { 'x' => 'most' },
 'enkeli'	=> { 'x' => 'angel' },
 'epill'	=> { 'x' => 'doubt',
		     '#' => ', suspect' },
 'erehty'	=> { 'x' => 'err',
		     '#' => ', make a mistake' },
 'eri'		=> { 'x' => 'apart',
		     '#' => ', particular, separate, special' },
 'erilainen'	=> { 'x' => 'diverse',
		     '#' => ', varied, various' },
 'erota'	=> { 'x' => 'be different',
		     '#' => ', differ' },
 'erottaa'	=> { 'x' => 'distinguish' },
 'erotus'	=> { 'x' => 'difference' },
 'esimerkki'	=> { 'x' => 'example' },
 'esine'	=> { 'x' => 'article',
		     '#' => ', object, thing' },
 'esitt'	=> { 'x' => 'introduce',
		     '#' => ', perform, present' },
 'espanja'	=> { 'x' => 'spain' },
 'espanjalainen'	=> { 'x' => 'spaniard',
		     '#' => ', spanish' },
 'etana'	=> { 'x' => 'slug' },
 'etel'	=> { 'x' => 'south' },
 'etel-afrikka'	=> { 'x' => 'south africa' },
 'etenkin'	=> { 'x' => 'above all',
		     '#' => ', chiefly, especially, mainly' },
 'etev'	=> { 'x' => 'eminent' },
 'etsi'	=> { 'x' => 'look for',
		     '#' => ', seek' },
 'ettika'	=> { 'x' => 'vinegar' },
 'ett'		=> { 'x' => 'that' },
 'etisyys'	=> { 'x' => 'distance',
		     '#' => ', offset' },
 'euroopalainen'	=> { 'x' => 'european' },
 'eurooppa'	=> { 'x' => 'europe' },
 'eurooppalainen'	=> { 'x' => 'european' },
 'fysiikka'	=> { 'x' => 'physics' },
 'haapa'	=> { 'x' => 'aspen' },
 'haarukka'	=> { 'x' => 'fork' },
 'hai'		=> { 'x' => 'shark' },
 'haistaa'	=> { 'x' => 'smell' },
 'haka'		=> { 'x' => 'hook' },
 'hakata'	=> { 'x' => 'chop',
		     '#' => ', cut, hack' },
 'hakkailla'	=> { 'x' => 'flirt',
		     '#' => ', flit, flutter' },
 'haljeta'	=> { 'x' => 'burst' },
 'hallita'	=> { 'x' => 'control',
		     '#' => ', govern, restrain, rule' },
 'haltia'	=> { 'x' => 'fairy' },
 'haluta'	=> { 'x' => 'desire',
		     '#' => ', wish' },
 'hame'		=> { 'x' => 'skirt' },
 'hammas'	=> { 'x' => 'tooth' },
 'hammasharja'	=> { 'x' => 'tooth-brush' },
 'hammassrky'	=> { 'x' => 'toothache' },
 'hammastahna'	=> { 'x' => 'tooth-paste' },
 'han'		=> { 'x' => 'certainly',
		     '#' => ', indeed, rather, surely' },
 'hana'		=> { 'x' => 'faucet',
		     '#' => ', tap' },
 'hanhi'	=> { 'x' => 'goose' },
 'hankkia'	=> { 'x' => 'acquire',
		     '#' => ', attain, get, obtain' },
 'hansikas'	=> { 'x' => 'glove',
		     '#' => ', mitten' },
 'happo'	=> { 'x' => 'acid' },
 'haravoida'	=> { 'x' => 'rake' },
 'harja'	=> { 'x' => 'brush' },
 'harkita'	=> { 'x' => 'consider',
		     '#' => ', esteem, regard' },
 'harmaa'	=> { 'x' => 'gray',
		     '#' => ', grey' },
 'harmonikka'	=> { 'x' => 'accordion' },
 'hartia'	=> { 'x' => 'shoulder' },
 'hattu'	=> { 'x' => 'hat' },
 'hauki'	=> { 'x' => 'pike' },
 'haukkua'	=> { 'x' => 'bark' },
 'haukotella'	=> { 'x' => 'yawn' },
 'haulipanos'	=> { 'x' => 'cartridge' },
 'hauta'	=> { 'x' => 'grave',
		     '#' => ', tomb' },
 'he'		=> { 'x' => 'them',
		     '#' => ', they' },
 'hedelm'	=> { 'x' => 'fruit' },
 'hehkua'	=> { 'x' => 'glow',
		     '#' => ', glow with heat' },
 'heiluttaa'	=> { 'x' => 'brandish',
		     '#' => ', fling, swing, wave, wave about' },
 'heinkuu'	=> { 'x' => 'july' },
 'heint'	=> { 'x' => 'hay' },
 'heitt'	=> { 'x' => 'throw' },
 'helmi'	=> { 'x' => 'pearl' },
 'helmikuu'	=> { 'x' => 'february' },
 'helppo'	=> { 'x' => 'easy',
		     '#' => ', facile' },
 'hengitt'	=> { 'x' => 'breathe' },
 'henkev'	=> { 'x' => 'lively',
		     '#' => ', witty' },
 'henki'	=> { 'x' => 'spirit' },
 'henkil'	=> { 'x' => 'person' },
 'herjata'	=> { 'x' => 'blaspheme',
		     '#' => ', curse, cuss, swear' },
 'herkutella'	=> { 'x' => 'relish' },
 'hertt'	=> { 'x' => 'arouse',
		     '#' => ', awaken, wake, wake up' },
 'heti'		=> { 'x' => 'at once',
		     '#' => ', right away, right now' },
 'hetki'	=> { 'x' => 'instant',
		     '#' => ', moment' },
 'hevonen'	=> { 'x' => 'horse' },
 'hiekka'	=> { 'x' => 'sand' },
 'hienon hieno'	=> { 'x' => 'subtle' },
 'hiha'		=> { 'x' => 'sleeve' },
 'hiili'	=> { 'x' => 'coal' },
 'hiiri'	=> { 'x' => 'mouse' },
 'hikoilla'	=> { 'x' => 'sweat' },
 'hinta'	=> { 'x' => 'price' },
 'hirsi'	=> { 'x' => 'beam',
		     '#' => ', girder' },
 'hirvi'	=> { 'x' => 'deer',
		     '#' => ', elk, moose' },
 'historia'	=> { 'x' => 'history',
		     '#' => ', story' },
 'hius'		=> { 'x' => 'hair' },
 'hoitaa'	=> { 'x' => 'attend',
		     '#' => ', look after, nurse, tend to' },
 'hollantilainen'	=> { 'x' => 'dutch',
		     '#' => ', dutchman, hollander' },
 'hopea'	=> { 'x' => 'silver' },
 'horisontti'	=> { 'x' => 'horizon' },
 'hotelli'	=> { 'x' => 'hotel' },
 'houkutella'	=> { 'x' => 'attract',
		     '#' => ', decoy, lure' },
 'hourailla'	=> { 'x' => 'be delirious' },
 'housut'	=> { 'x' => 'pants',
		     '#' => ', trousers' },
 'huhtikuu'	=> { 'x' => 'april' },
 'huilu'	=> { 'x' => 'flute' },
 'hukkua'	=> { 'x' => 'drown' },
 'hullu'	=> { 'x' => 'crazy',
		     '#' => ', insane, mad, nuts' },
 'hummeri'	=> { 'x' => 'lobster' },
 'hunaja'	=> { 'x' => 'honey' },
 'huokailla'	=> { 'x' => 'groan',
		     '#' => ', moan' },
 'huolehtia'	=> { 'x' => 'care',
		     '#' => ', see, take care, worry' },
 'huolimatta'	=> { 'x' => 'despite',
		     '#' => ', in spite of, notwithstanding' },
 'huomata'	=> { 'x' => 'notice' },
 'huomenna'	=> { 'x' => 'tomorrow' },
 'huone'	=> { 'x' => 'chamber',
		     '#' => ', place, room' },
 'huonekalu'	=> { 'x' => 'piece of furniture' },
 'hurmata'	=> { 'x' => 'delight' },
 'hurskas'	=> { 'x' => 'pious' },
 'hutiloida'	=> { 'x' => 'botch',
		     '#' => ', bungle, screw up, spoil' },
 'huuli'	=> { 'x' => 'lip' },
 'huutaa'	=> { 'x' => 'cry out',
		     '#' => ', scream, shout' },
 'huvi'		=> { 'x' => 'fun',
		     '#' => ', pleasure' },
 'huvittaa'	=> { 'x' => 'amuse' },
 'huvivene'	=> { 'x' => 'yacht' },
 'hyeena'	=> { 'x' => 'hyaena',
		     '#' => ', hyena' },
 'hylly'	=> { 'x' => 'shelf' },
 'hypt'	=> { 'x' => 'jump',
		     '#' => ', leap, spring' },
 'hytti'	=> { 'x' => 'cabin' },
 'hyv'		=> { 'x' => 'good',
		     '#' => ', nice, okay' },
 'hyvill'	=> { 'x' => 'caress',
		     '#' => ', chuck, fondle, stroke' },
 'hyvksyminen'	=> { 'x' => 'acceptance' },
 'hyvksy'	=> { 'x' => 'approve' },
 'hyvsti'	=> { 'x' => 'adieu',
		     '#' => ', bye, farewell, good-bye, goodbye' },
 'hydyllinen'	=> { 'x' => 'advantageous',
		     '#' => ', useful' },
 'hykt'	=> { 'x' => 'assault',
		     '#' => ', attack' },
 'hynteinen'	=> { 'x' => 'bug',
		     '#' => ', insect' },
 'hyty'	=> { 'x' => 'profit' },
 'hirit'	=> { 'x' => 'distract',
		     '#' => ', divert, entertain' },
 'hmment'	=> { 'x' => 'confuse',
		     '#' => ', puzzle' },
 'hmr'	=> { 'x' => 'dusk',
		     '#' => ', twilight' },
 'hn'		=> { 'x' => 'he',
		     '#' => ', her, him, she' },
 'hnt'	=> { 'x' => 'tail' },
 'hrk'	=> { 'x' => 'bovine',
		     '#' => ', bovine animal' },
 'hvitt'	=> { 'x' => 'exterminate',
		     '#' => ', wipe out' },
 'hyry'	=> { 'x' => 'steam',
		     '#' => ', vapor, vapour' },
 'ies'		=> { 'x' => 'yoke' },
 'ihmetell'	=> { 'x' => 'marvel',
		     '#' => ', marvel at, wonder' },
 'ihminen'	=> { 'x' => 'human being',
		     '#' => ', man' },
 'iho'		=> { 'x' => 'skin' },
 'ihra'		=> { 'x' => 'bacon' },
 'ikkuna'	=> { 'x' => 'window' },
 'ik'		=> { 'x' => 'age' },
 'ikvystyy'	=> { 'x' => 'bore' },
 'ikvid'	=> { 'x' => 'be bored',
		     '#' => ', be tired of something' },
 'iknkuin'	=> { 'x' => 'as if',
		     '#' => ', as though, in a way' },
 'ilke'	=> { 'x' => 'malicious',
		     '#' => ', mischievous, nasty, vicious' },
 'ilma'		=> { 'x' => 'air' },
 'ilmaista'	=> { 'x' => 'express' },
 'ilman'	=> { 'x' => 'without' },
 'ilmapiiri'	=> { 'x' => 'atmosphere',
		     '#' => ', ethos, mood' },
 'ilmasto'	=> { 'x' => 'climate' },
 'ilme'		=> { 'x' => 'expression' },
 'ilmeinen'	=> { 'x' => 'evident',
		     '#' => ', obvious' },
 'ilmi'	=> { 'x' => 'phenomenon' },
 'ilmoitus'	=> { 'x' => 'ad',
		     '#' => ', advertisement' },
 'ilo'		=> { 'x' => 'gladness',
		     '#' => ', joy' },
 'iloinen'	=> { 'x' => 'cheerful',
		     '#' => ', gay, merry' },
 'ilta'		=> { 'x' => 'evening' },
 'iltapiv'	=> { 'x' => 'afternoon' },
 'imarrella'	=> { 'x' => 'flatter' },
 'ime'		=> { 'x' => 'absorb',
		     '#' => ', sip, suck' },
 'info:'	=> { 'x' => '<a href="http://www.freedict.com/">freedict.com</a> database from finnish to english' },
 'inhimillinen'	=> { 'x' => 'humane' },
 'inhottava'	=> { 'x' => 'nasty' },
 'innostus'	=> { 'x' => 'enthusiasm',
		     '#' => ', verve, vivacity' },
 'intia'	=> { 'x' => 'india' },
 'intialainen'	=> { 'x' => 'indian' },
 'into'		=> { 'x' => 'fervor',
		     '#' => ', fervour, zeal' },
 'intohimo'	=> { 'x' => 'lust',
		     '#' => ', passion' },
 'irlanti'	=> { 'x' => 'ireland' },
 'irlantilainen'	=> { 'x' => 'irish',
		     '#' => ', irishman' },
 'iske'	=> { 'x' => 'hit',
		     '#' => ', knock, strike' },
 'islanti'	=> { 'x' => 'iceland' },
 'iso'		=> { 'x' => 'big',
		     '#' => ', great, large' },
 'iso-brittania'	=> { 'x' => 'britain',
		     '#' => ', great britain' },
 'isois'	=> { 'x' => 'grandfather' },
 'israel'	=> { 'x' => 'israel' },
 'israelilainen'	=> { 'x' => 'israelian' },
 'istua'	=> { 'x' => 'sit' },
 'is'		=> { 'x' => 'father' },
 'isnt'	=> { 'x' => 'boss',
		     '#' => ', master' },
 'italia'	=> { 'x' => 'italy' },
 'italialainen'	=> { 'x' => 'italian' },
 'itke'	=> { 'x' => 'cry',
		     '#' => ', weep' },
 'itse'		=> { 'x' => 'herself',
		     '#' => ', himself, itself, self' },
 'itsepinen'	=> { 'x' => 'obstinate',
		     '#' => ', stubborn' },
 'itu'		=> { 'x' => 'germ' },
 'it'		=> { 'x' => 'east',
		     '#' => ', east' },
 'ja'		=> { 'x' => 'and' },
 'jakaa'	=> { 'x' => 'divide',
		     '#' => ', separate, share' },
 'jakso'	=> { 'x' => 'cycle' },
 'jalka'	=> { 'x' => 'foot',
		     '#' => ', paw' },
 'jalo'		=> { 'x' => 'noble' },
 'jalokivi'	=> { 'x' => 'jewel' },
 'japani'	=> { 'x' => 'japan' },
 'japanilainen'	=> { 'x' => 'japanese' },
 'jarru'	=> { 'x' => 'brake' },
 'jatkaa'	=> { 'x' => 'continue',
		     '#' => ', go on, proceed with' },
 'jauhaa'	=> { 'x' => 'grind',
		     '#' => ', pulverize' },
 'jauhot'	=> { 'x' => 'flour',
		     '#' => ', meal' },
 'jo'		=> { 'x' => 'already',
		     '#' => ', by now, yet' },
 'jogurtti'	=> { 'x' => 'yoghourt',
		     '#' => ', yoghurt' },
 'jokainen'	=> { 'x' => 'all',
		     '#' => ', each, every, everyone' },
 'jokaisen'	=> { 'x' => 'everyone\'s' },
 'joki'		=> { 'x' => 'river',
		     '#' => ', stream' },
 'jokin'	=> { 'x' => 'anything',
		     '#' => ', something' },
 'joku'		=> { 'x' => 'a',
		     '#' => ', any, anybody, some, somebody, someone' },
 'jolloinkin'	=> { 'x' => 'at some time',
		     '#' => ', ever' },
 'jonkin verran'	=> { 'x' => 'a little',
		     '#' => ', some, to some extend' },
 'jonkinlainen'	=> { 'x' => 'some kind of' },
 'jonkun'	=> { 'x' => 'someones' },
 'jos'		=> { 'x' => 'if',
		     '#' => ', provided that' },
 'jossakin'	=> { 'x' => 'anywhere',
		     '#' => ', somewhere' },
 'jostakin syyst'	=> { 'x' => 'for some reason' },
 'jotenkin'	=> { 'x' => 'somehow' },
 'joulu'	=> { 'x' => 'christmas',
		     '#' => ', yule' },
 'joulukuu'	=> { 'x' => 'december' },
 'joutsen'	=> { 'x' => 'swan' },
 'jugoslaavi'	=> { 'x' => 'yugoslav',
		     '#' => ', yugoslavian' },
 'jugoslavia'	=> { 'x' => 'yugoslavia' },
 'jugoslavialainen'	=> { 'x' => 'yugoslav',
		     '#' => ', yugoslavian' },
 'juhla'	=> { 'x' => 'celebration',
		     '#' => ', festival, party' },
 'juhlallinen'	=> { 'x' => 'ceremonious',
		     '#' => ', solemn' },
 'juhlia'	=> { 'x' => 'celebrate' },
 'juliste'	=> { 'x' => 'notice',
		     '#' => ', placard, poster' },
 'julma'	=> { 'x' => 'cruel' },
 'jumala'	=> { 'x' => 'god' },
 'juna'		=> { 'x' => 'train' },
 'juoda'	=> { 'x' => 'drink' },
 'juomalasi'	=> { 'x' => 'glass' },
 'juonitella'	=> { 'x' => 'intrigue' },
 'juopunut'	=> { 'x' => 'drunk',
		     '#' => ', intoxicated' },
 'juosta'	=> { 'x' => 'run' },
 'juova'	=> { 'x' => 'ray',
		     '#' => ', strip, stripe' },
 'juuri'	=> { 'x' => 'just',
		     '#' => ', just now' },
 'juusto'	=> { 'x' => 'cheese' },
 'juutalainen'	=> { 'x' => 'hebrew',
		     '#' => ', jewish' },
 'jyrkk'	=> { 'x' => 'abrupt',
		     '#' => ', radical, steep' },
 'jyv'		=> { 'x' => 'grain',
		     '#' => ', granule, pip' },
 'jljent'	=> { 'x' => 'copy' },
 'jljitell'	=> { 'x' => 'imitate' },
 'jlkeen'	=> { 'x' => 'after' },
 'jlkelinen'	=> { 'x' => 'child',
		     '#' => ', offspring, young' },
 'jlki'	=> { 'x' => 'trace',
		     '#' => ', track' },
 'jlleen'	=> { 'x' => 'again',
		     '#' => ', all over again, anew' },
 'jlleen-'	=> { 'x' => 're-' },
 'jnis'	=> { 'x' => 'hare' },
 'jnne'	=> { 'x' => 'cord',
		     '#' => ', string' },
 'jnnitt'	=> { 'x' => 'strech',
		     '#' => ', wind up' },
 'jnnitys'	=> { 'x' => 'tension' },
 'jrjestelm'	=> { 'x' => 'system' },
 'jrjestys'	=> { 'x' => 'order' },
 'jrjest'	=> { 'x' => 'arrange',
		     '#' => ', fix up' },
 'jrki'	=> { 'x' => 'logical reasoning',
		     '#' => ', reason' },
 'jrvi'	=> { 'x' => 'lake',
		     '#' => ', loch' },
 'jsen'	=> { 'x' => 'limb',
		     '#' => ', member, supporter' },
 'jsenmaksu'	=> { 'x' => 'dues',
		     '#' => ', subscription' },
 'jtt'	=> { 'x' => 'allow',
		     '#' => ', leave, let, release' },
 'j'		=> { 'x' => 'ice' },
 'jd'	=> { 'x' => 'remain',
		     '#' => ', stay, stay over' },
 'kaali'	=> { 'x' => 'cabbage' },
 'kaapia'	=> { 'x' => 'grate',
		     '#' => ', rasp' },
 'kaappi'	=> { 'x' => 'cabinet',
		     '#' => ', closet, cupboard, sideboard' },
 'kaari'	=> { 'x' => 'arc',
		     '#' => ', bow' },
 'kaasu'	=> { 'x' => 'gas' },
 'kaataa'	=> { 'x' => 'pour',
		     '#' => ', scatter, shed' },
 'kaava'	=> { 'x' => 'model',
		     '#' => ', pattern, scheme' },
 'kadehtia'	=> { 'x' => 'envy' },
 'kadottaa'	=> { 'x' => 'lose' },
 'kahdeksan'	=> { 'x' => 'eight' },
 'kahdeksankymment'	=> { 'x' => 'eighty' },
 'kahdeksantoista'	=> { 'x' => 'eighteen' },
 'kahdeksas'	=> { 'x' => 'eighth' },
 'kahvi'	=> { 'x' => 'coffee' },
 'kaikenlainen'	=> { 'x' => 'every kind of' },
 'kaikin tavoin'	=> { 'x' => 'in every way' },
 'kaikki'	=> { 'x' => 'altogether',
		     '#' => ', everything' },
 'kaikkialla'	=> { 'x' => 'all about',
		     '#' => ', everywhere' },
 'kaivaa'	=> { 'x' => 'dig',
		     '#' => ', grub, spade' },
 'kaivata'	=> { 'x' => 'long for',
		     '#' => ', yearn' },
 'kaivo'	=> { 'x' => 'fountain',
		     '#' => ', source, spring, well' },
 'kakku'	=> { 'x' => 'cake' },
 'kaksi'	=> { 'x' => 'two' },
 'kaksikymment'	=> { 'x' => 'twenty' },
 'kaksitoista'	=> { 'x' => 'twelve' },
 'kala'		=> { 'x' => 'fish' },
 'kalenteri'	=> { 'x' => 'calendar' },
 'kalkkuna'	=> { 'x' => 'turkey' },
 'kallio'	=> { 'x' => 'rock' },
 'kallis'	=> { 'x' => 'dear',
		     '#' => ', expensive, lovely, valuable' },
 'kallistaa'	=> { 'x' => 'bend',
		     '#' => ', incline, tilt' },
 'kalpea'	=> { 'x' => 'pale',
		     '#' => ', sallow' },
 'kammata'	=> { 'x' => 'comb' },
 'kanada'	=> { 'x' => 'canada' },
 'kanadalainen'	=> { 'x' => 'canadian' },
 'kanava'	=> { 'x' => 'canal',
		     '#' => ', channel' },
 'kangas'	=> { 'x' => 'cloth',
		     '#' => ', material' },
 'kani'		=> { 'x' => 'rabbit' },
 'kankea'	=> { 'x' => 'rigid',
		     '#' => ', stiff' },
 'kansa'	=> { 'x' => 'folk',
		     '#' => ', nation, people' },
 'kansakunta'	=> { 'x' => 'nation' },
 'kansallisuus'	=> { 'x' => 'nationality' },
 'kanssa'	=> { 'x' => 'with' },
 'kantaa'	=> { 'x' => 'carry',
		     '#' => ', wear' },
 'kapinoida'	=> { 'x' => 'rebel',
		     '#' => ', revolt' },
 'kapteeni'	=> { 'x' => 'captain' },
 'karkottaa'	=> { 'x' => 'chase',
		     '#' => ', drive, drive on, impel, shoo' },
 'karppi'	=> { 'x' => 'carp' },
 'kartta'	=> { 'x' => 'map' },
 'kasa'		=> { 'x' => 'crowd',
		     '#' => ', heap, mass, multitude, pile' },
 'kassa'	=> { 'x' => 'cashier\'s stand',
		     '#' => ', fund, money box, money-box, till' },
 'kastike'	=> { 'x' => 'gravy',
		     '#' => ', sauce' },
 'kasvaa'	=> { 'x' => 'grow',
		     '#' => ', vegetate' },
 'kasvattaa'	=> { 'x' => 'breed',
		     '#' => ', bring up, educate, raise' },
 'kasvi'	=> { 'x' => 'plant' },
 'kasvot'	=> { 'x' => 'face' },
 'katolinen'	=> { 'x' => 'catholic' },
 'katsella'	=> { 'x' => 'consider',
		     '#' => ', deem, look, look at, regard, view' },
 'katto'	=> { 'x' => 'roof' },
 'kattohaikara'	=> { 'x' => 'stork' },
 'katu'		=> { 'x' => 'street' },
 'katua'	=> { 'x' => 'repent' },
 'kauhu'	=> { 'x' => 'terror' },
 'kaula'	=> { 'x' => 'neck' },
 'kaunis'	=> { 'x' => 'beautiful',
		     '#' => ', fine, handsome, lovely' },
 'kauppa'	=> { 'x' => 'business',
		     '#' => ', trade' },
 'kaupunki'	=> { 'x' => 'city',
		     '#' => ', town' },
 'kaura'	=> { 'x' => 'oats' },
 'kehitty'	=> { 'x' => 'develop',
		     '#' => ', evolve' },
 'keho'		=> { 'x' => 'body' },
 'kehottaa'	=> { 'x' => 'admonish',
		     '#' => ', scold' },
 'kehys'	=> { 'x' => 'cadre',
		     '#' => ', frame, framework' },
 'keino'	=> { 'x' => 'means',
		     '#' => ', remedy, resources' },
 'keinuttaa'	=> { 'x' => 'rock',
		     '#' => ', swing' },
 'keitto'	=> { 'x' => 'soup' },
 'keitt'	=> { 'x' => 'cook' },
 'kellari'	=> { 'x' => 'basement',
		     '#' => ', cellar' },
 'kello'	=> { 'x' => 'clock',
		     '#' => ', watch' },
 'keltainen'	=> { 'x' => 'yellow' },
 'kelvata'	=> { 'x' => 'be suitable',
		     '#' => ', fit, suit' },
 'kenen'	=> { 'x' => 'which one\'s',
		     '#' => ', whose' },
 'kenk'	=> { 'x' => 'shoe' },
 'keppi'	=> { 'x' => 'baton',
		     '#' => ', cane, stick' },
 'kerho'	=> { 'x' => 'club',
		     '#' => ', society' },
 'kerros'	=> { 'x' => 'floor',
		     '#' => ', layer, storey, story' },
 'kerta'	=> { 'x' => 'occasion',
		     '#' => ', time' },
 'kertoa'	=> { 'x' => 'relate',
		     '#' => ', tell' },
 'kert'	=> { 'x' => 'collect',
		     '#' => ', gather, pick up' },
 'kesken'	=> { 'x' => 'among',
		     '#' => ', between' },
 'keskiarvo'	=> { 'x' => 'average' },
 'keskipiste'	=> { 'x' => 'average',
		     '#' => ', middle' },
 'keskiviikko'	=> { 'x' => 'wednesday' },
 'keskus'	=> { 'x' => 'center',
		     '#' => ', centre' },
 'kest'	=> { 'x' => 'continue',
		     '#' => ', endure, keep on, last' },
 'kes'		=> { 'x' => 'summer' },
 'keskuu'	=> { 'x' => 'june' },
 'ketju'	=> { 'x' => 'chain' },
 'keuhko'	=> { 'x' => 'lung' },
 'kevt'	=> { 'x' => 'spring',
		     '#' => ', springtime' },
 'kiduttaa'	=> { 'x' => 'abuse',
		     '#' => ', torment, torture' },
 'kiehua'	=> { 'x' => 'boil' },
 'kiekko'	=> { 'x' => 'dial',
		     '#' => ', disc, disk, record' },
 'kieli'	=> { 'x' => 'language',
		     '#' => ', tongue' },
 'kiihottaa'	=> { 'x' => 'abet',
		     '#' => ', agitate, incite, rouse, stimulate, stir up' },
 'kiikari'	=> { 'x' => 'binoculars' },
 'kiina'	=> { 'x' => 'china' },
 'kiinalainen'	=> { 'x' => 'chinese' },
 'kiinnitt'	=> { 'x' => 'affix',
		     '#' => ', attach, determine, fasten, fix, make fast' },
 'kiinnostaa'	=> { 'x' => 'interest' },
 'kiireellinen'	=> { 'x' => 'pressing',
		     '#' => ', urgent' },
 'kiitt'	=> { 'x' => 'thank' },
 'kilogramma'	=> { 'x' => 'kilo' },
 'kilpailla'	=> { 'x' => 'compete',
		     '#' => ', rival' },
 'kimpale'	=> { 'x' => 'chunk',
		     '#' => ', clod, lump' },
 'kinkku'	=> { 'x' => 'ham' },
 'kirja'	=> { 'x' => 'book' },
 'kirjain'	=> { 'x' => 'letter' },
 'kirjata'	=> { 'x' => 'record',
		     '#' => ', register' },
 'kirje'	=> { 'x' => 'letter' },
 'kirjekuori'	=> { 'x' => 'envelope' },
 'kirjoittaa'	=> { 'x' => 'write' },
 'kirkko'	=> { 'x' => 'church',
		     '#' => ', kirk' },
 'kirsikka'	=> { 'x' => 'cherry' },
 'kissa'	=> { 'x' => 'cat' },
 'kitara'	=> { 'x' => 'guitar' },
 'kivi'		=> { 'x' => 'stone' },
 'koettaa'	=> { 'x' => 'aim',
		     '#' => ', attempt, endeavour, test, try' },
 'kohista'	=> { 'x' => 'murmur',
		     '#' => ', mutter' },
 'kohta'	=> { 'x' => 'soon' },
 'kohtalokas'	=> { 'x' => 'fateful',
		     '#' => ', ill-fated' },
 'kohtaus'	=> { 'x' => 'scene' },
 'kohtelias'	=> { 'x' => 'courteous',
		     '#' => ', polite, well-mannered' },
 'kohti'	=> { 'x' => 'at the rate of' },
 'koira'	=> { 'x' => 'dog' },
 'koivu'	=> { 'x' => 'birch' },
 'koje'		=> { 'x' => 'apparatus',
		     '#' => ', device, means, set, tool' },
 'kokenut'	=> { 'x' => 'experienced',
		     '#' => ', expert' },
 'koko'		=> { 'x' => 'entire',
		     '#' => ', overall, whole' },
 'kokous'	=> { 'x' => 'assemblage',
		     '#' => ', gathering, meeting' },
 'kolmas'	=> { 'x' => 'third' },
 'kolmastoista'	=> { 'x' => 'thirteen' },
 'kolme'	=> { 'x' => 'three' },
 'kolmekymment'	=> { 'x' => 'thirty' },
 'kolmio'	=> { 'x' => 'triangle' },
 'kolo'		=> { 'x' => 'cave',
		     '#' => ', cavity' },
 'kompassi'	=> { 'x' => 'compass' },
 'kondomi'	=> { 'x' => 'condom',
		     '#' => ', rubber' },
 'kone'		=> { 'x' => 'engine',
		     '#' => ', machine' },
 'konjakki'	=> { 'x' => 'brandy',
		     '#' => ', cognac' },
 'konsertti'	=> { 'x' => 'concert' },
 'koostua'	=> { 'x' => 'consist of' },
 'korjata'	=> { 'x' => 'correct',
		     '#' => ', harvest' },
 'korkea'	=> { 'x' => 'high',
		     '#' => ', lofty, tall' },
 'korkeus'	=> { 'x' => 'altitude',
		     '#' => ', height' },
 'korkki'	=> { 'x' => 'cork' },
 'korko'	=> { 'x' => 'income',
		     '#' => ', return' },
 'kortti'	=> { 'x' => 'card',
		     '#' => ', map, menu' },
 'korva'	=> { 'x' => 'ear' },
 'koska'	=> { 'x' => 'because',
		     '#' => ', for, since' },
 'koskettaa'	=> { 'x' => 'touch' },
 'kosketus'	=> { 'x' => 'contact' },
 'kostaa'	=> { 'x' => 'avenge',
		     '#' => ', avenge oneself' },
 'koti'		=> { 'x' => 'home' },
 'kotka'	=> { 'x' => 'eagle' },
 'koulia'	=> { 'x' => 'tame',
		     '#' => ', train' },
 'koulu'	=> { 'x' => 'school' },
 'kreikka'	=> { 'x' => 'greece' },
 'kreikkalainen'	=> { 'x' => 'greek' },
 'kristitty'	=> { 'x' => 'christian' },
 'kristus'	=> { 'x' => 'christ' },
 'kuin'		=> { 'x' => 'than' },
 'kuiskata'	=> { 'x' => 'whisper' },
 'kuitenkin'	=> { 'x' => 'but',
		     '#' => ', however, nevertheless, yet' },
 'kuiva'	=> { 'x' => 'dry' },
 'kuka'		=> { 'x' => 'that',
		     '#' => ', which, which one, who' },
 'kukka'	=> { 'x' => 'bloom',
		     '#' => ', flower' },
 'kukkakaali'	=> { 'x' => 'cauliflower' },
 'kukko'	=> { 'x' => 'chicken',
		     '#' => ', fowl' },
 'kulma'	=> { 'x' => 'corner' },
 'kulta'	=> { 'x' => 'gold' },
 'kuluttaa'	=> { 'x' => 'consume',
		     '#' => ', use up' },
 'kummallinen'	=> { 'x' => 'curious',
		     '#' => ', interesting, odd, peculiar, quaint' },
 'kumota'	=> { 'x' => 'overthrow',
		     '#' => ', turn, turn over, upset' },
 'kuningas'	=> { 'x' => 'king' },
 'kunnioittaa'	=> { 'x' => 'commend',
		     '#' => ', esteem, glorify, laud, think well of' },
 'kunta'	=> { 'x' => 'community' },
 'kuolla'	=> { 'x' => 'die',
		     '#' => ', expire, pass away' },
 'kuorma-auto'	=> { 'x' => 'lorry',
		     '#' => ', truck' },
 'kupari'	=> { 'x' => 'copper' },
 'kuponki'	=> { 'x' => 'coupon' },
 'kuppi'	=> { 'x' => 'cup' },
 'kuri'		=> { 'x' => 'discipline' },
 'kurja'	=> { 'x' => 'poor' },
 'kurjuus'	=> { 'x' => 'misery' },
 'kurki'	=> { 'x' => 'crane' },
 'kurssi'	=> { 'x' => 'class',
		     '#' => ', course' },
 'kutittaa'	=> { 'x' => 'tickle' },
 'kutoa'	=> { 'x' => 'weave' },
 'kutsua'	=> { 'x' => 'call',
		     '#' => ', invite, summon' },
 'kuu'		=> { 'x' => 'moon' },
 'kuudes'	=> { 'x' => 'sixth' },
 'kuukausi'	=> { 'x' => 'month' },
 'kuula'	=> { 'x' => 'bullet' },
 'kuulla'	=> { 'x' => 'hear' },
 'kuume'	=> { 'x' => 'fever' },
 'kuunnella'	=> { 'x' => 'listen' },
 'kuuro'	=> { 'x' => 'deaf' },
 'kuusi'	=> { 'x' => 'six' },
 'kuusikymment'	=> { 'x' => 'sixty' },
 'kuusitoista'	=> { 'x' => 'sixteen' },
 'kuva'		=> { 'x' => 'image',
		     '#' => ', picture' },
 'kuvitelma'	=> { 'x' => 'fiction' },
 'kuvittaa'	=> { 'x' => 'illustrate' },
 'kykenev'	=> { 'x' => 'able',
		     '#' => ', capable' },
 'kyky'		=> { 'x' => 'talent' },
 'kylliksi'	=> { 'x' => 'enough',
		     '#' => ', rather, sufficiently' },
 'kyll'	=> { 'x' => 'yes' },
 'kyllinen'	=> { 'x' => 'full',
		     '#' => ', replete, satisfied' },
 'kyllst'	=> { 'x' => 'saturate' },
 'kylvett'	=> { 'x' => 'bathe' },
 'kylv'	=> { 'x' => 'sow' },
 'kyl'		=> { 'x' => 'village' },
 'kymmenen'	=> { 'x' => 'ten' },
 'kynnys'	=> { 'x' => 'sill',
		     '#' => ', threshold' },
 'kynsi'	=> { 'x' => 'nail' },
 'kynsi'	=> { 'x' => 'scratch' },
 'kynttil'	=> { 'x' => 'candle' },
 'kynt'	=> { 'x' => 'plough' },
 'kyn'		=> { 'x' => 'feather',
		     '#' => ', pen' },
 'kypr'	=> { 'x' => 'helmet' },
 'kysely'	=> { 'x' => 'inquiry',
		     '#' => ', investigation' },
 'kysy'	=> { 'x' => 'ask' },
 'kytke'	=> { 'x' => 'connect',
		     '#' => ', connect up, plug in, switch, turn on' },
 'kyttyr'	=> { 'x' => 'bump',
		     '#' => ', hump' },
 'kyyhkynen'	=> { 'x' => 'dove',
		     '#' => ', pigeon' },
 'kyynel'	=> { 'x' => 'tear' },
 'kki'		=> { 'x' => 'cuckoo' },
 'krki'	=> { 'x' => 'peak',
		     '#' => ', point, summit, tip' },
 'krpnen'	=> { 'x' => 'fly',
		     '#' => ', housefly' },
 'krryt'	=> { 'x' => 'cart',
		     '#' => ', chariot' },
 'krsi'	=> { 'x' => 'abide',
		     '#' => ', bear, endure, put up with, suffer' },
 'ksi'		=> { 'x' => 'hand' },
 'ksivarsi'	=> { 'x' => 'arm' },
 'kske'	=> { 'x' => 'command',
		     '#' => ', order, tell' },
 'kteinen'	=> { 'x' => 'cash',
		     '#' => ', in cash' },
 'kyd vieraissa'	=> { 'x' => 'attend',
		     '#' => ', call on, see, visit' },
 'kyr'	=> { 'x' => 'bent',
		     '#' => ', curved' },
 'kyttyty'	=> { 'x' => 'behave',
		     '#' => ', conduct oneself' },
 'kytt'	=> { 'x' => 'employ',
		     '#' => ', make use of, use' },
 'knt'	=> { 'x' => 'translate',
		     '#' => ', turn, turn around, turn round' },
 'kri'	=> { 'x' => 'roll',
		     '#' => ', roll up, wind, wind up' },
 'kli'		=> { 'x' => 'keel' },
 'kysi'	=> { 'x' => 'cord',
		     '#' => ', rope, string' },
 'laahata'	=> { 'x' => 'drag',
		     '#' => ', tow' },
 'laajuus'	=> { 'x' => 'bulk',
		     '#' => ', dimension, extend, size' },
 'laakea'	=> { 'x' => 'flat' },
 'laakso'	=> { 'x' => 'valley' },
 'laatia'	=> { 'x' => 'compose',
		     '#' => ', create, write' },
 'laatu'	=> { 'x' => 'property',
		     '#' => ', quality' },
 'laguuni'	=> { 'x' => 'lagoon' },
 'lahja'	=> { 'x' => 'gift',
		     '#' => ', present' },
 'lahna'	=> { 'x' => 'bream' },
 'lahti'	=> { 'x' => 'golf',
		     '#' => ', gulf' },
 'lainata'	=> { 'x' => 'borrow',
		     '#' => ', lend, loan' },
 'laine'	=> { 'x' => 'wave' },
 'laipio'	=> { 'x' => 'ceiling' },
 'laituri'	=> { 'x' => 'platform',
		     '#' => ', quay, wharf' },
 'laiva'	=> { 'x' => 'ship',
		     '#' => ', vessel' },
 'laivan kansi'	=> { 'x' => 'deck' },
 'laivasto'	=> { 'x' => 'fleet' },
 'laji'		=> { 'x' => 'kind',
		     '#' => ', sort' },
 'lakata'	=> { 'x' => 'cease',
		     '#' => ', stop' },
 'laki'		=> { 'x' => 'law' },
 'lakka'	=> { 'x' => 'lacquer' },
 'lammas'	=> { 'x' => 'mutton' },
 'lamppu'	=> { 'x' => 'lamp' },
 'lanka'	=> { 'x' => 'thread' },
 'lanta'	=> { 'x' => 'dung',
		     '#' => ', excrement' },
 'lapsellinen'	=> { 'x' => 'naif',
		     '#' => ', naive, naf, nave' },
 'lapsi'	=> { 'x' => 'child',
		     '#' => ', infant' },
 'lasi'		=> { 'x' => 'glass' },
 'laskea'	=> { 'x' => 'calculate',
		     '#' => ', count, figure, work out' },
 'laskea leikki'	=> { 'x' => 'jest',
		     '#' => ', joke' },
 'laskea vesille'	=> { 'x' => 'launch' },
 'laskea yhteen'	=> { 'x' => 'add',
		     '#' => ', add up' },
 'lasti'	=> { 'x' => 'burden',
		     '#' => ', charge, load' },
 'latoa'	=> { 'x' => 'typeset' },
 'lattia'	=> { 'x' => 'floor' },
 'laulaa'	=> { 'x' => 'sing' },
 'laulukirja'	=> { 'x' => 'songbook' },
 'lause'	=> { 'x' => 'sentence' },
 'lautanen'	=> { 'x' => 'plate' },
 'lautta'	=> { 'x' => 'raft' },
 'lehti'	=> { 'x' => 'leaf',
		     '#' => ', sheet' },
 'lehtisalaatti'	=> { 'x' => 'lettuce' },
 'leijona'	=> { 'x' => 'lion' },
 'leikata'	=> { 'x' => 'clip',
		     '#' => ', cut, shear, slice' },
 'leikki'	=> { 'x' => 'play' },
 'leimata'	=> { 'x' => 'mark',
		     '#' => ', stamp' },
 'leipoa'	=> { 'x' => 'bake' },
 'leip'	=> { 'x' => 'bread',
		     '#' => ', loaf' },
 'lempe'	=> { 'x' => 'gentle',
		     '#' => ', mild' },
 'lenntin'	=> { 'x' => 'telegraph' },
 'lentokentt'	=> { 'x' => 'airport' },
 'lentokone'	=> { 'x' => 'aeroplane',
		     '#' => ', air-plane, airplane, plane' },
 'lent'	=> { 'x' => 'fly' },
 'leski'	=> { 'x' => 'widower' },
 'leskirouva'	=> { 'x' => 'widow' },
 'leve'	=> { 'x' => 'broad' },
 'levitt'	=> { 'x' => 'lay out',
		     '#' => ', spread, spread out' },
 'levt'	=> { 'x' => 'repose',
		     '#' => ', rest' },
 'liekki'	=> { 'x' => 'flame' },
 'liha'		=> { 'x' => 'flesh',
		     '#' => ', meat' },
 'lihas'	=> { 'x' => 'muscle' },
 'liiaksi'	=> { 'x' => 'too',
		     '#' => ', too much' },
 'liikenne'	=> { 'x' => 'traffic' },
 'liikuttaa'	=> { 'x' => 'move',
		     '#' => ', stir' },
 'liima'	=> { 'x' => 'glue' },
 'liimata'	=> { 'x' => 'glue',
		     '#' => ', stick' },
 'liina'	=> { 'x' => 'cloth' },
 'liitto'	=> { 'x' => 'connection',
		     '#' => ', league' },
 'liitty'	=> { 'x' => 'associate',
		     '#' => ', come together, join, pool' },
 'liitu'	=> { 'x' => 'chalk' },
 'lima'		=> { 'x' => 'mud',
		     '#' => ', slime' },
 'limonaadi'	=> { 'x' => 'lemonade' },
 'linssi'	=> { 'x' => 'lens' },
 'lintu'	=> { 'x' => 'bird' },
 'lippu'	=> { 'x' => 'banner',
		     '#' => ', bill, flag, note, ticket' },
 'lista'	=> { 'x' => 'list' },
 'list'	=> { 'x' => 'add' },
 'litra'	=> { 'x' => 'liter',
		     '#' => ', litre' },
 'liukua'	=> { 'x' => 'glide',
		     '#' => ', slip' },
 'liverre'	=> { 'x' => 'trill' },
 'lohduttaa'	=> { 'x' => 'comfort',
		     '#' => ', console' },
 'lohi'		=> { 'x' => 'salmon' },
 'loistaa'	=> { 'x' => 'shine' },
 'loistava'	=> { 'x' => 'bright',
		     '#' => ', brilliant' },
 'loka'		=> { 'x' => 'mud' },
 'lokakuu'	=> { 'x' => 'october' },
 'lokero'	=> { 'x' => 'branch',
		     '#' => ', compartment, department, pigeonhole' },
 'lokki'	=> { 'x' => 'seagull' },
 'lonkka'	=> { 'x' => 'hip' },
 'lopetta'	=> { 'x' => 'accomodate',
		     '#' => ', end, finish, terminate' },
 'loppu'	=> { 'x' => 'end',
		     '#' => ', ending' },
 'lounas'	=> { 'x' => 'lunch',
		     '#' => ', snack' },
 'luento'	=> { 'x' => 'lecture' },
 'luetella'	=> { 'x' => 'count' },
 'luettelo'	=> { 'x' => 'catalog',
		     '#' => ', catalogue, directory' },
 'luja'		=> { 'x' => 'fast',
		     '#' => ', firm, stable' },
 'lukea'	=> { 'x' => 'read' },
 'lukita'	=> { 'x' => 'bolt',
		     '#' => ', fasten, lock' },
 'lukko'	=> { 'x' => 'lock' },
 'lumi'		=> { 'x' => 'snow' },
 'luoda'	=> { 'x' => 'create' },
 'luomisvire'	=> { 'x' => 'inspiration' },
 'luona'	=> { 'x' => 'at',
		     '#' => ', beside, with' },
 'luoto'	=> { 'x' => 'reef' },
 'luottaa'	=> { 'x' => 'confide',
		     '#' => ', have faith, have faith in, trust' },
 'lusikka'	=> { 'x' => 'spoon' },
 'luu'		=> { 'x' => 'bone' },
 'luultavasti'	=> { 'x' => 'probably' },
 'luuttu'	=> { 'x' => 'lute' },
 'luvata'	=> { 'x' => 'promise' },
 'lyijy'	=> { 'x' => 'lead' },
 'lyijykyn'	=> { 'x' => 'pencil' },
 'lyps'	=> { 'x' => 'milk' },
 'lyd'	=> { 'x' => 'beat',
		     '#' => ', hit, strike' },
 'lyd vetoa'	=> { 'x' => 'bet',
		     '#' => ', wager' },
 'lheinen'	=> { 'x' => 'close',
		     '#' => ', near, nearby, next' },
 'lhett'	=> { 'x' => 'send',
		     '#' => ', transmit' },
 'lhtien'	=> { 'x' => 'from',
		     '#' => ', since' },
 'lmmin'	=> { 'x' => 'warm' },
 'lmmitt'	=> { 'x' => 'heat',
		     '#' => ', stoke' },
 'lnsi'	=> { 'x' => 'west',
		     '#' => ', west' },
 'lpi'		=> { 'x' => 'through' },
 'lke'	=> { 'x' => 'drug',
		     '#' => ', medicine, pharmaceutical' },
 'lkri'	=> { 'x' => 'doctor',
		     '#' => ', physician' },
 'lrptell'	=> { 'x' => 'chat',
		     '#' => ', chatter' },
 'lyt'	=> { 'x' => 'find' },
 'maa'		=> { 'x' => 'country',
		     '#' => ', earth, ground, grounds, land, terrain' },
 'maailma'	=> { 'x' => 'world' },
 'maalata'	=> { 'x' => 'paint' },
 'maali'	=> { 'x' => 'aim',
		     '#' => ', goal, purpose' },
 'maaliskuu'	=> { 'x' => 'march' },
 'maanantai'	=> { 'x' => 'monday' },
 'maanosa'	=> { 'x' => 'continent',
		     '#' => ', mainland' },
 'maantiede'	=> { 'x' => 'geography' },
 'maaphkin'	=> { 'x' => 'peanut' },
 'maata'	=> { 'x' => 'lie',
		     '#' => ', recline' },
 'maatila'	=> { 'x' => 'estate',
		     '#' => ', farm, property, ranch' },
 'mahdollinen'	=> { 'x' => 'contingent',
		     '#' => ', eventual, possible' },
 'mahdollisuus'	=> { 'x' => 'chance',
		     '#' => ', luck' },
 'mahtipontisuus'	=> { 'x' => 'accent',
		     '#' => ', emphasis' },
 'maine'	=> { 'x' => 'fame',
		     '#' => ', renown' },
 'mainita'	=> { 'x' => 'mention' },
 'mainos'	=> { 'x' => 'advertisement' },
 'maisema'	=> { 'x' => 'landscape',
		     '#' => ', scenery' },
 'maissi'	=> { 'x' => 'indian corn',
		     '#' => ', corn, maize, mealies' },
 'maito'	=> { 'x' => 'milk' },
 'makea'	=> { 'x' => 'gentle',
		     '#' => ', soft, sweet, tender' },
 'makkara'	=> { 'x' => 'sausage' },
 'maksa'	=> { 'x' => 'liver' },
 'maksaa'	=> { 'x' => 'cost',
		     '#' => ', pay' },
 'maksaa osansa'	=> { 'x' => 'contribute' },
 'maku'		=> { 'x' => 'taste' },
 'malja'	=> { 'x' => 'goblet',
		     '#' => ', toast' },
 'malli'	=> { 'x' => 'model' },
 'mandariini'	=> { 'x' => 'tangerine' },
 'markkinat'	=> { 'x' => 'fair',
		     '#' => ', market, sales activity' },
 'marraskuu'	=> { 'x' => 'november' },
 'marssia'	=> { 'x' => 'march',
		     '#' => ', walk' },
 'massa'	=> { 'x' => 'lump',
		     '#' => ', mass' },
 'matka'	=> { 'x' => 'journey',
		     '#' => ', trip, voyage' },
 'matkailija'	=> { 'x' => 'tourist' },
 'matkalaukku'	=> { 'x' => 'trunk' },
 'matkustaa'	=> { 'x' => 'travel' },
 'mato'		=> { 'x' => 'worm' },
 'matto'	=> { 'x' => 'mat' },
 'me'		=> { 'x' => 'us',
		     '#' => ', we' },
 'mehilinen'	=> { 'x' => 'bee' },
 'mehu'		=> { 'x' => 'juice',
		     '#' => ', sap' },
 'meksiko'	=> { 'x' => 'mexico' },
 'meksikolainen'	=> { 'x' => 'mexican' },
 'melkein'	=> { 'x' => 'almost',
		     '#' => ', nearly' },
 'mellakka'	=> { 'x' => 'riot',
		     '#' => ', tumult' },
 'meloni'	=> { 'x' => 'melon' },
 'meluta'	=> { 'x' => 'make a noise' },
 'menesty'	=> { 'x' => 'succeed' },
 'menetell'	=> { 'x' => 'proceed' },
 'menetelm'	=> { 'x' => 'method' },
 'menn'	=> { 'x' => 'go' },
 'menn ohi'	=> { 'x' => 'pass',
		     '#' => ', pass by' },
 'meri'		=> { 'x' => 'sea' },
 'merirosvo'	=> { 'x' => 'pirate' },
 'merkitys'	=> { 'x' => 'meaning',
		     '#' => ', sense' },
 'merkit'	=> { 'x' => 'imply',
		     '#' => ', mean, signify' },
 'merkki'	=> { 'x' => 'character',
		     '#' => ', mark, sign, signal, token' },
 'mestari'	=> { 'x' => 'maestro',
		     '#' => ', master' },
 'metri'	=> { 'x' => 'meter',
		     '#' => ', metre' },
 'metsst'	=> { 'x' => 'chase',
		     '#' => ', hunt' },
 'mielelln'	=> { 'x' => 'willingly' },
 'mieli'	=> { 'x' => 'mind' },
 'mielikuvitus'	=> { 'x' => 'fantasy' },
 'mielivaltainen'	=> { 'x' => 'arbitrary' },
 'miellyttv'	=> { 'x' => 'agreeable',
		     '#' => ', enjoyable, lovely, nice, pleasant' },
 'miellytt'	=> { 'x' => 'please' },
 'mies'		=> { 'x' => 'fellow',
		     '#' => ', man' },
 'mietti'	=> { 'x' => 'meditate',
		     '#' => ', think to oneself' },
 'miksi'	=> { 'x' => 'what for',
		     '#' => ', why' },
 'mik'		=> { 'x' => 'what' },
 'miljoona'	=> { 'x' => 'million' },
 'millainen'	=> { 'x' => 'what kind of',
		     '#' => ', what sort of' },
 'millimetri'	=> { 'x' => 'millimeter',
		     '#' => ', millimetre' },
 'milloin'	=> { 'x' => 'when' },
 'minne'	=> { 'x' => 'where ... to' },
 'minuutti'	=> { 'x' => 'minute' },
 'min'		=> { 'x' => 'i',
		     '#' => ', me' },
 'miss'	=> { 'x' => 'where' },
 'mist tahansa syyst'	=> { 'x' => 'for every reason' },
 'mitata'	=> { 'x' => 'measure' },
 'miten'	=> { 'x' => 'as',
		     '#' => ', how, like, such as' },
 'mit ... sit'	=> { 'x' => 'the ... the' },
 'moittia'	=> { 'x' => 'blame',
		     '#' => ', rebuke, reproach, reprove, scold' },
 'molemmat'	=> { 'x' => 'both' },
 'monesko'	=> { 'x' => 'how many',
		     '#' => ', what number' },
 'moni'		=> { 'x' => 'a lot of',
		     '#' => ', much' },
 'moottori'	=> { 'x' => 'engine',
		     '#' => ', motor' },
 'muistaa'	=> { 'x' => 'recall',
		     '#' => ', recollect, remember' },
 'muistiinpano'	=> { 'x' => 'grade',
		     '#' => ', note' },
 'muna'		=> { 'x' => 'egg' },
 'muoti'	=> { 'x' => 'fashion',
		     '#' => ', mode' },
 'muoto'	=> { 'x' => 'form',
		     '#' => ', shape' },
 'muovi'	=> { 'x' => 'plastic' },
 'murhata'	=> { 'x' => 'murder' },
 'murskata'	=> { 'x' => 'crush',
		     '#' => ', shatter, smash' },
 'museo'	=> { 'x' => 'museum' },
 'musiikiopisto'	=> { 'x' => 'academy of music' },
 'musiikki'	=> { 'x' => 'music' },
 'musta'	=> { 'x' => 'black' },
 'muste'	=> { 'x' => 'ink' },
 'mutkistaa'	=> { 'x' => 'complicate' },
 'mutta'	=> { 'x' => 'but' },
 'muu'		=> { 'x' => 'accidental',
		     '#' => ', additional, remaining, rest of' },
 'muuri'	=> { 'x' => 'wall' },
 'muutama'	=> { 'x' => 'some' },
 'muuttaa'	=> { 'x' => 'change',
		     '#' => ', turn' },
 'mykk'	=> { 'x' => 'dumb',
		     '#' => ', mute, speechless' },
 'myyd'	=> { 'x' => 'dispose of',
		     '#' => ', sell, vend' },
 'myyml'	=> { 'x' => 'boutique',
		     '#' => ', shop, store' },
 'mynt'	=> { 'x' => 'assent',
		     '#' => ', say yes' },
 'mys'		=> { 'x' => 'also',
		     '#' => ', too' },
 'myttunto'	=> { 'x' => 'sympathy' },
 'mdt'	=> { 'x' => 'putrefy',
		     '#' => ', rot' },
 'mnty'	=> { 'x' => 'pine',
		     '#' => ', pine tree' },
 'mnt'	=> { 'x' => 'piston' },
 'mti'		=> { 'x' => 'roe' },
 'myr'	=> { 'x' => 'badger' },
 'mritell'	=> { 'x' => 'define',
		     '#' => ', determine' },
 'mr'	=> { 'x' => 'quantity' },
 'mkki'	=> { 'x' => 'cabin',
		     '#' => ', hut, shack' },
 'naamari'	=> { 'x' => 'mask' },
 'naapuri'	=> { 'x' => 'neighbor',
		     '#' => ', neighbour' },
 'nahka'	=> { 'x' => 'leather' },
 'nappi'	=> { 'x' => 'button' },
 'narista'	=> { 'x' => 'creak',
		     '#' => ', grate' },
 'nauha'	=> { 'x' => 'binding',
		     '#' => ', strip, tape' },
 'naula'	=> { 'x' => 'nail' },
 'nauraa'	=> { 'x' => 'laugh' },
 'nauta'	=> { 'x' => 'head of cattle' },
 'nauttia'	=> { 'x' => 'delight in',
		     '#' => ', enjoy' },
 'ne'		=> { 'x' => 'them',
		     '#' => ', they' },
 'neekeri'	=> { 'x' => 'negro' },
 'neli'	=> { 'x' => 'square' },
 'nelj'	=> { 'x' => 'four' },
 'neljkymment'	=> { 'x' => 'forty' },
 'neljnnestunti'	=> { 'x' => 'fourth' },
 'neljs'	=> { 'x' => 'fourth' },
 'neljtoista'	=> { 'x' => 'fourteen' },
 'nen'		=> { 'x' => 'nose' },
 'nerous'	=> { 'x' => 'genius' },
 'netto'	=> { 'x' => 'cleanly cut',
		     '#' => ', neat, net, precize' },
 'neula'	=> { 'x' => 'needle',
		     '#' => ', pin' },
 'neuvoa'	=> { 'x' => 'advice',
		     '#' => ', advise, counsel' },
 'neuvotella'	=> { 'x' => 'deal with',
		     '#' => ', handle, treat' },
 'nimi'		=> { 'x' => 'appellation',
		     '#' => ', name' },
 'niska'	=> { 'x' => 'back of the neck',
		     '#' => ', nape' },
 'nis'		=> { 'x' => 'breast',
		     '#' => ', teat' },
 'no'		=> { 'x' => 'now',
		     '#' => ', well, well then' },
 'noin'		=> { 'x' => 'about',
		     '#' => ', approximately' },
 'nojata'	=> { 'x' => 'lean',
		     '#' => ', support, sustain' },
 'noki'		=> { 'x' => 'soot' },
 'nokka'	=> { 'x' => 'beak',
		     '#' => ', bill' },
 'nolla'	=> { 'x' => 'nought',
		     '#' => ', zero' },
 'nopea'	=> { 'x' => 'fast',
		     '#' => ', quick, rapid, speedy, swift' },
 'norja'	=> { 'x' => 'norway' },
 'norjalainen'	=> { 'x' => 'norwegian' },
 'norsu'	=> { 'x' => 'elephant' },
 'nostaa'	=> { 'x' => 'lever',
		     '#' => ', lift, raise' },
 'nukkua'	=> { 'x' => 'be asleep' },
 'numero'	=> { 'x' => 'cipher',
		     '#' => ', digit, figure, number, numeral' },
 'nuori'	=> { 'x' => 'young' },
 'nuottiavain'	=> { 'x' => 'clef' },
 'nurista'	=> { 'x' => 'growl',
		     '#' => ', grumble' },
 'nyt'		=> { 'x' => 'at present',
		     '#' => ', now' },
 'nhd'	=> { 'x' => 'see' },
 'nky'		=> { 'x' => 'vision' },
 'nrksty'	=> { 'x' => 'be indignant' },
 'nyte'	=> { 'x' => 'sample',
		     '#' => ', specimen' },
 'nyttelij'	=> { 'x' => 'actor' },
 'nyttely'	=> { 'x' => 'exhibition',
		     '#' => ', exposition' },
 'nytt'	=> { 'x' => 'appear',
		     '#' => ', appear to be, indicate, point out, show' },
 'nytt toteen'	=> { 'x' => 'prove' },
 'nyr'	=> { 'x' => 'humble' },
 'odottaa'	=> { 'x' => 'abide',
		     '#' => ', await, expect, wait, wait for' },
 'ohi'		=> { 'x' => 'beyond',
		     '#' => ', past, straight past' },
 'ohjelmoida'	=> { 'x' => 'program',
		     '#' => ', programme' },
 'oikea'	=> { 'x' => 'correct',
		     '#' => ', exact, proper, right' },
 'oikeanpuolinen'	=> { 'x' => 'right',
		     '#' => ', righthand' },
 'oikeudenmukainen'	=> { 'x' => 'fair',
		     '#' => ', just, righteous' },
 'oikeus'	=> { 'x' => 'right' },
 'oikku'	=> { 'x' => 'caprice',
		     '#' => ', whim' },
 'ojentaa'	=> { 'x' => 'extend',
		     '#' => ', strech out' },
 'oksa'		=> { 'x' => 'bough',
		     '#' => ', branch' },
 'olemus'	=> { 'x' => 'essence',
		     '#' => ', gist' },
 'olettaa'	=> { 'x' => 'guess',
		     '#' => ', presume, suppose, surmise' },
 'oliivi'	=> { 'x' => 'olive' },
 'oliiviljy'	=> { 'x' => 'oil of olives',
		     '#' => ', olive-oil' },
 'olio'		=> { 'x' => 'chap',
		     '#' => ', fellow, guy, person' },
 'olla'		=> { 'x' => 'be' },
 'olla avoinna'	=> { 'x' => 'be vacant' },
 'olla kvelyll'	=> { 'x' => 'go for a walk',
		     '#' => ', stroll' },
 'olla nimeltn'	=> { 'x' => 'be called' },
 'olla oikeassa'	=> { 'x' => 'be right' },
 'olla olemassa'	=> { 'x' => 'exist' },
 'olla olevinaan'	=> { 'x' => 'attitudinize',
		     '#' => ', pose, put on airs' },
 'olla velkaa'	=> { 'x' => 'owe' },
 'olla vlittmtt'	=> { 'x' => 'ignore' },
 'olut'		=> { 'x' => 'ale',
		     '#' => ', beer' },
 'oma'		=> { 'x' => 'own',
		     '#' => ', personal' },
 'omatunto'	=> { 'x' => 'conscience' },
 'omena'	=> { 'x' => 'apple' },
 'ominaisuus'	=> { 'x' => 'property',
		     '#' => ', quality' },
 'omistaa'	=> { 'x' => 'have',
		     '#' => ', have got, own, possess' },
 'onnellinen'	=> { 'x' => 'fortunate',
		     '#' => ', happy' },
 'onnetar'	=> { 'x' => 'fortune' },
 'onnitella'	=> { 'x' => 'congratulate' },
 'ooppera'	=> { 'x' => 'opera' },
 'opastaa'	=> { 'x' => 'conduct',
		     '#' => ', direct, guide, head, lead' },
 'opettaa'	=> { 'x' => 'teach' },
 'opiskella'	=> { 'x' => 'study' },
 'oppia'	=> { 'x' => 'learn' },
 'orava'	=> { 'x' => 'squirrel' },
 'orvokki'	=> { 'x' => 'violet' },
 'osa'		=> { 'x' => 'destiny',
		     '#' => ', fate, fortune, luck, part, piece, share' },
 'osake'	=> { 'x' => 'share' },
 'osanen'	=> { 'x' => 'element',
		     '#' => ', fragment, item, particle' },
 'osoite'	=> { 'x' => 'address' },
 'ostaa'	=> { 'x' => 'buy',
		     '#' => ', purchase' },
 'osua'		=> { 'x' => 'striking' },
 'otaksua'	=> { 'x' => 'conjecture',
		     '#' => ', surmise' },
 'ottaa'	=> { 'x' => 'get',
		     '#' => ', lay hold of, pick up, take' },
 'ottaa vastaan'	=> { 'x' => 'accept',
		     '#' => ', receive, take, take in' },
 'ovi'		=> { 'x' => 'door',
		     '#' => ', gate' },
 'paeta'	=> { 'x' => 'flee',
		     '#' => ', run away' },
 'paikka'	=> { 'x' => 'location',
		     '#' => ', place, position, spot' },
 'painaa'	=> { 'x' => 'print',
		     '#' => ', weigh' },
 'painia'	=> { 'x' => 'struggle',
		     '#' => ', wrestle' },
 'painos'	=> { 'x' => 'edition' },
 'paistaa'	=> { 'x' => 'roast',
		     '#' => ', toast' },
 'paita'	=> { 'x' => 'shirt' },
 'paitsi'	=> { 'x' => 'apart from',
		     '#' => ', besides, except' },
 'pakastaa'	=> { 'x' => 'freeze' },
 'pakata'	=> { 'x' => 'pack' },
 'pakistan'	=> { 'x' => 'pakistan' },
 'pakistanilainen'	=> { 'x' => 'pakistani' },
 'paksu'	=> { 'x' => 'bold',
		     '#' => ', corpulent, fat, thick' },
 'pala'		=> { 'x' => 'lump',
		     '#' => ', piece, spare part' },
 'palaa'	=> { 'x' => 'burn' },
 'paljonko'	=> { 'x' => 'how many',
		     '#' => ', how much' },
 'palkata'	=> { 'x' => 'employ',
		     '#' => ', hire' },
 'palkinto'	=> { 'x' => 'premium',
		     '#' => ', prize' },
 'palkka'	=> { 'x' => 'salary',
		     '#' => ', wage, wages' },
 'pallo'	=> { 'x' => 'ball',
		     '#' => ', ball-bearing, globe' },
 'palvella'	=> { 'x' => 'serve' },
 'panna'	=> { 'x' => 'lay down',
		     '#' => ', place, put, put down' },
 'pannu'	=> { 'x' => 'frying pan',
		     '#' => ', frying-pan' },
 'paperi'	=> { 'x' => 'paper' },
 'papukaija'	=> { 'x' => 'parrot' },
 'parantaa'	=> { 'x' => 'care for',
		     '#' => ', cure, treat' },
 'pari'		=> { 'x' => 'pair' },
 'parsa'	=> { 'x' => 'asparagus' },
 'parta'	=> { 'x' => 'beard' },
 'partiolainen'	=> { 'x' => 'boy scout',
		     '#' => ', boyscout, scout' },
 'parveke'	=> { 'x' => 'gallery' },
 'pato'		=> { 'x' => 'dike',
		     '#' => ', embankment' },
 'patsas'	=> { 'x' => 'statue' },
 'pehme'	=> { 'x' => 'soft' },
 'peili'	=> { 'x' => 'mirror' },
 'peitt'	=> { 'x' => 'cover' },
 'pelastaa'	=> { 'x' => 'keep',
		     '#' => ', rescue, save' },
 'pelti'	=> { 'x' => 'sheet metal',
		     '#' => ', tin, tin plate' },
 'pelto'	=> { 'x' => 'field' },
 'pelt'	=> { 'x' => 'be afraid of',
		     '#' => ', fear' },
 'peninkulma'	=> { 'x' => 'mile' },
 'pensasaita'	=> { 'x' => 'hedge' },
 'perhe'	=> { 'x' => 'family' },
 'perhonen'	=> { 'x' => 'butterfly' },
 'perinne'	=> { 'x' => 'tradition' },
 'peri'	=> { 'x' => 'inherit' },
 'perjantai'	=> { 'x' => 'friday' },
 'persikka'	=> { 'x' => 'peach' },
 'persilja'	=> { 'x' => 'parsley' },
 'peruna'	=> { 'x' => 'potato' },
 'perustaa'	=> { 'x' => 'erect',
		     '#' => ', establish, found' },
 'pest'	=> { 'x' => 'wash' },
 'pes'		=> { 'x' => 'den',
		     '#' => ', nest' },
 'pett'	=> { 'x' => 'betray',
		     '#' => ', cheat, deceive' },
 'peukalo'	=> { 'x' => 'thumb' },
 'piano'	=> { 'x' => 'piano' },
 'pidin'	=> { 'x' => 'holder',
		     '#' => ', socket' },
 'piha'		=> { 'x' => 'court',
		     '#' => ', courtyard, yard' },
 'piikki'	=> { 'x' => 'thorn' },
 'piilottaa'	=> { 'x' => 'conceal',
		     '#' => ', hide' },
 'piippu'	=> { 'x' => 'pipe' },
 'piirre'	=> { 'x' => 'feature',
		     '#' => ', trait' },
 'piirt'	=> { 'x' => 'design',
		     '#' => ', draw' },
 'pikkuinen'	=> { 'x' => 'tiny' },
 'pilata'	=> { 'x' => 'damage',
		     '#' => ', injure, spoil' },
 'pilkata'	=> { 'x' => 'jeer at',
		     '#' => ', make fun of, mock' },
 'pilvi'	=> { 'x' => 'cloud' },
 'pinaatti'	=> { 'x' => 'spinach' },
 'piparjuuri'	=> { 'x' => 'horse-radish',
		     '#' => ', horseradish' },
 'pippuri'	=> { 'x' => 'pepper' },
 'piste'	=> { 'x' => 'dot',
		     '#' => ', period, point, spot' },
 'pist'	=> { 'x' => 'pick',
		     '#' => ', stab, sting' },
 'pitkin'	=> { 'x' => 'according to',
		     '#' => ', along' },
 'pitk'	=> { 'x' => 'long' },
 'pit'	=> { 'x' => 'hang onto',
		     '#' => ', hold' },
 'pit parempana'	=> { 'x' => 'prefer' },
 'pizza'	=> { 'x' => 'pizza' },
 'pohja'	=> { 'x' => 'bottom',
		     '#' => ', foundation, ground' },
 'pohjoinen'	=> { 'x' => 'north',
		     '#' => ', north' },
 'pohtia'	=> { 'x' => 'discuss' },
 'poika'	=> { 'x' => 'boy',
		     '#' => ', son' },
 'poiketa'	=> { 'x' => 'turn' },
 'poikki'	=> { 'x' => 'across',
		     '#' => ', on the other side of' },
 'pois'		=> { 'x' => 'away' },
 'poissaoleva'	=> { 'x' => 'absent' },
 'poljin'	=> { 'x' => 'pedal' },
 'polkka'	=> { 'x' => 'polka' },
 'polku'	=> { 'x' => 'path' },
 'polkupyr'	=> { 'x' => 'bicycle',
		     '#' => ', bike, cycle' },
 'polttoaine'	=> { 'x' => 'fuel' },
 'polvi'	=> { 'x' => 'knee' },
 'ponnistella'	=> { 'x' => 'aim',
		     '#' => ', attempt, endeavour, take steps, undertake' },
 'porata'	=> { 'x' => 'bore',
		     '#' => ', drill' },
 'porkkana'	=> { 'x' => 'carrot' },
 'porras'	=> { 'x' => 'rung',
		     '#' => ', stair, step' },
 'porvari'	=> { 'x' => 'middleclass citizen' },
 'poski'	=> { 'x' => 'cheek' },
 'posti'	=> { 'x' => 'mail',
		     '#' => ', post' },
 'postilaatikko'	=> { 'x' => 'letterbox',
		     '#' => ', mailbox' },
 'postimaksu'	=> { 'x' => 'postage' },
 'postimerkkeily'	=> { 'x' => 'philately',
		     '#' => ', stamp-collecting' },
 'potkuri'	=> { 'x' => 'helix',
		     '#' => ', propeller' },
 'proomu'	=> { 'x' => 'ferry' },
 'protestanttinen'	=> { 'x' => 'protestant' },
 'pudistaa'	=> { 'x' => 'shake',
		     '#' => ', shock' },
 'pudota'	=> { 'x' => 'drop',
		     '#' => ', fall' },
 'puhaltaa'	=> { 'x' => 'blow' },
 'puhdas'	=> { 'x' => 'clean',
		     '#' => ', pure' },
 'puhelin'	=> { 'x' => 'telephone' },
 'puhemies'	=> { 'x' => 'chairman',
		     '#' => ', president' },
 'puhua'	=> { 'x' => 'speak',
		     '#' => ', talk' },
 'puida'	=> { 'x' => 'thresh' },
 'puisto'	=> { 'x' => 'park' },
 'puku'		=> { 'x' => 'costume',
		     '#' => ', dress, gown, outfit, robe, suit' },
 'pula'		=> { 'x' => 'abashment',
		     '#' => ', embarrassment, perplexity' },
 'pullo'	=> { 'x' => 'bottle' },
 'pulpetti'	=> { 'x' => 'bench' },
 'pumpata'	=> { 'x' => 'pump' },
 'punainen'	=> { 'x' => 'red' },
 'puolalainen'	=> { 'x' => 'pole' },
 'puolikas'	=> { 'x' => 'half' },
 'puoliso'	=> { 'x' => 'husband' },
 'puoskari'	=> { 'x' => 'charlatan',
		     '#' => ', imposter, quack' },
 'puristaa'	=> { 'x' => 'oppress',
		     '#' => ', press, squeeze' },
 'purje'	=> { 'x' => 'sail' },
 'purra'	=> { 'x' => 'bite' },
 'pusero'	=> { 'x' => 'blouse' },
 'putki'	=> { 'x' => 'barrel',
		     '#' => ', channel, pipe, tube' },
 'puu'		=> { 'x' => 'timber',
		     '#' => ', tree, wood' },
 'puuro'	=> { 'x' => 'gruel',
		     '#' => ', mess, mush' },
 'puutarha'	=> { 'x' => 'garden' },
 'puuttua'	=> { 'x' => 'be lacking',
		     '#' => ', be missing' },
 'puuvilla'	=> { 'x' => 'cotton' },
 'pylvs'	=> { 'x' => 'column',
		     '#' => ', pillar' },
 'pyrki'	=> { 'x' => 'aspire',
		     '#' => ', aspire to, hope for, strive for' },
 'pysyv'	=> { 'x' => 'constant',
		     '#' => ', continual, permanent, sustained' },
 'pysy'	=> { 'x' => 'abide',
		     '#' => ', persevere, persist' },
 'pyshty'	=> { 'x' => 'come to a halt',
		     '#' => ', halt, stop' },
 'pyydyst'	=> { 'x' => 'capture',
		     '#' => ', catch, grapple' },
 'pyyt'	=> { 'x' => 'ask',
		     '#' => ', ask for, beg, bid, request' },
 'pyre'	=> { 'x' => 'round' },
 'pyrty'	=> { 'x' => 'faint',
		     '#' => ', swoon' },
 'pyr'	=> { 'x' => 'wheel' },
 'phkin'	=> { 'x' => 'nut' },
 'pivyst'	=> { 'x' => 'be on duty',
		     '#' => ', serve' },
 'piv'	=> { 'x' => 'day' },
 'pivmr'	=> { 'x' => 'date' },
 'pivntasaaja'	=> { 'x' => 'equator' },
 'pssi'	=> { 'x' => 'sheep' },
 'ptev'	=> { 'x' => 'able',
		     '#' => ', competent, valid' },
 'p'		=> { 'x' => 'head',
		     '#' => ', pate' },
 'pllikk'	=> { 'x' => 'boss',
		     '#' => ', chief, leader' },
 'pmr'	=> { 'x' => 'aim',
		     '#' => ', goal, purpose' },
 'pryn'	=> { 'x' => 'pear' },
 'psiinen'	=> { 'x' => 'easter' },
 'pskynen'	=> { 'x' => 'swallow' },
 'pst karkuun'	=> { 'x' => 'escape',
		     '#' => ', flee' },
 'ptt'	=> { 'x' => 'decide' },
 'ply'		=> { 'x' => 'dust' },
 'pyt'	=> { 'x' => 'table' },
 'raaka'	=> { 'x' => 'crude',
		     '#' => ', raw, rough' },
 'raapia'	=> { 'x' => 'scrape',
		     '#' => ', scratch' },
 'radio'	=> { 'x' => 'radio',
		     '#' => ', wireless' },
 'raesade'	=> { 'x' => 'hail' },
 'raha'		=> { 'x' => 'money' },
 'rahasto'	=> { 'x' => 'fund' },
 'raihnas'	=> { 'x' => 'decayed',
		     '#' => ', decrepit, dilapidated, lapsed, rickety' },
 'raitiovaunu'	=> { 'x' => 'streetcar',
		     '#' => ', tram' },
 'raivoisa'	=> { 'x' => 'furious' },
 'raja'		=> { 'x' => 'boundary',
		     '#' => ', frontier, limit' },
 'rakastaa'	=> { 'x' => 'love' },
 'rakentaa'	=> { 'x' => 'build',
		     '#' => ', construct' },
 'rangaista'	=> { 'x' => 'punish' },
 'ranskalainen'	=> { 'x' => 'french',
		     '#' => ', frenchman' },
 'ranta'	=> { 'x' => 'bank',
		     '#' => ', border, edge, shore' },
 'rasia'	=> { 'x' => 'box' },
 'rasva'	=> { 'x' => 'fat',
		     '#' => ', grease' },
 'ratsastaa'	=> { 'x' => 'ride' },
 'rauha'	=> { 'x' => 'peace' },
 'rauta'	=> { 'x' => 'iron' },
 'rautatie'	=> { 'x' => 'railroad',
		     '#' => ', railway' },
 'rautatieasema'	=> { 'x' => 'station' },
 'ravintola'	=> { 'x' => 'restaurant' },
 'ravita'	=> { 'x' => 'feed',
		     '#' => ', nourish' },
 'rehellinen'	=> { 'x' => 'above-board',
		     '#' => ', honest' },
 'reik'	=> { 'x' => 'hole' },
 'reisi'	=> { 'x' => 'thigh' },
 'rengas'	=> { 'x' => 'ring' },
 'repale'	=> { 'x' => 'rag',
		     '#' => ', scrap' },
 'repi'	=> { 'x' => 'rip',
		     '#' => ', tear' },
 'retiisi'	=> { 'x' => 'radish' },
 'reuna'	=> { 'x' => 'brim',
		     '#' => ', edge, rim' },
 'riimi'	=> { 'x' => 'rhyme' },
 'riippua'	=> { 'x' => 'droop',
		     '#' => ', hang' },
 'riisi'	=> { 'x' => 'rice' },
 'riitt'	=> { 'x' => 'suffice' },
 'rikas'	=> { 'x' => 'rich',
		     '#' => ', wealthy, well-off' },
 'rimpuilla'	=> { 'x' => 'flounder',
		     '#' => ', struggle, writhe' },
 'rinne'	=> { 'x' => 'acclivity',
		     '#' => ', hillside, slope' },
 'rinta'	=> { 'x' => 'bosom',
		     '#' => ', breast, chest' },
 'risteill'	=> { 'x' => 'cruise' },
 'risti'	=> { 'x' => 'cross' },
 'ristiriita'	=> { 'x' => 'conflict' },
 'riuku'	=> { 'x' => 'lath',
		     '#' => ', slat' },
 'rivi'		=> { 'x' => 'file',
		     '#' => ', line, rank, row, turn' },
 'rohkea'	=> { 'x' => 'brave',
		     '#' => ', courageous, valiant' },
 'roisto'	=> { 'x' => 'cheat',
		     '#' => ', crook, rogue' },
 'romanssi'	=> { 'x' => 'romance' },
 'romantiikka'	=> { 'x' => 'romanticism' },
 'rommi'	=> { 'x' => 'rum' },
 'rotta'	=> { 'x' => 'rat' },
 'rotu'		=> { 'x' => 'breed',
		     '#' => ', race' },
 'rukoilla'	=> { 'x' => 'pray' },
 'rumpu'	=> { 'x' => 'drum' },
 'runotar'	=> { 'x' => 'muse' },
 'runsas'	=> { 'x' => 'abundant' },
 'ruoho'	=> { 'x' => 'grass' },
 'ruokahalu'	=> { 'x' => 'appetite' },
 'ruokalista'	=> { 'x' => 'menu' },
 'ruoste'	=> { 'x' => 'rust' },
 'ruotsalainen'	=> { 'x' => 'swede',
		     '#' => ', swedish' },
 'ruotsi'	=> { 'x' => 'sweden' },
 'ruskea'	=> { 'x' => 'brown' },
 'ruukku'	=> { 'x' => 'jug',
		     '#' => ', pot' },
 'ruumis'	=> { 'x' => 'cadaver',
		     '#' => ', corpse' },
 'ruusu'	=> { 'x' => 'rose' },
 'ruuvi'	=> { 'x' => 'screw' },
 'ryhm'	=> { 'x' => 'group' },
 'ryple'	=> { 'x' => 'grape' },
 'rytmi'	=> { 'x' => 'rhythm' },
 'ryst'	=> { 'x' => 'plunder',
		     '#' => ', rob' },
 'rjht'	=> { 'x' => 'explode' },
 'saada'	=> { 'x' => 'get',
		     '#' => ', have, receive' },
 'saakka'	=> { 'x' => 'until' },
 'saapas'	=> { 'x' => 'boot' },
 'saari'	=> { 'x' => 'island' },
 'saattaa'	=> { 'x' => 'accompany' },
 'saavuttaa'	=> { 'x' => 'accomplish',
		     '#' => ', attain, reach' },
 'sade'		=> { 'x' => 'rain' },
 'sahata'	=> { 'x' => 'saw' },
 'saippua'	=> { 'x' => 'soap' },
 'saita'	=> { 'x' => 'avaricious',
		     '#' => ', miserly, stingy' },
 'saksa'	=> { 'x' => 'germany' },
 'saksalainen'	=> { 'x' => 'german' },
 'saksanphkin'	=> { 'x' => 'walnut' },
 'salama'	=> { 'x' => 'lightning' },
 'sallia'	=> { 'x' => 'allow',
		     '#' => ', permit' },
 'samanlainen'	=> { 'x' => 'same' },
 'sammakko'	=> { 'x' => 'frog' },
 'sammuttaa'	=> { 'x' => 'extinguish',
		     '#' => ', put out' },
 'sana'		=> { 'x' => 'word' },
 'sangen'	=> { 'x' => 'quite',
		     '#' => ', very, very much' },
 'sankari'	=> { 'x' => 'hero' },
 'sanoa'	=> { 'x' => 'say',
		     '#' => ', tell' },
 'sanoma'	=> { 'x' => 'errand',
		     '#' => ', message' },
 'sanomalehti'	=> { 'x' => 'gazette',
		     '#' => ', magazine, newspaper, periodical' },
 'sata'		=> { 'x' => 'hundred',
		     '#' => ', one hundred' },
 'sataa'	=> { 'x' => 'rain' },
 'satama'	=> { 'x' => 'harbor',
		     '#' => ', harbour, port' },
 'sattuma'	=> { 'x' => 'accidence',
		     '#' => ', chance, hazard' },
 'savi'		=> { 'x' => 'clay' },
 'savuke'	=> { 'x' => 'cigarette' },
 'savuta'	=> { 'x' => 'smoke' },
 'se'		=> { 'x' => 'it',
		     '#' => ', that, that one, that over there, those' },
 'seikkaperinen'	=> { 'x' => 'detailed' },
 'sein'	=> { 'x' => 'wall' },
 'seisoa'	=> { 'x' => 'stand' },
 'seitsemn'	=> { 'x' => 'seven' },
 'seitsemnkymment'	=> { 'x' => 'seventy' },
 'seitsemntoista'	=> { 'x' => 'seventeen' },
 'seitsems'	=> { 'x' => 'seventh' },
 'sekoittaa'	=> { 'x' => 'blend',
		     '#' => ', mingle, mix, shuffle' },
 'sekunti'	=> { 'x' => 'second' },
 'selk'	=> { 'x' => 'back' },
 'selkranka'	=> { 'x' => 'spine' },
 'sello'	=> { 'x' => 'cello' },
 'selostaa'	=> { 'x' => 'report',
		     '#' => ', review' },
 'selv'	=> { 'x' => 'clear',
		     '#' => ', distinct, plain' },
 'sentti'	=> { 'x' => 'cent' },
 'set'		=> { 'x' => 'uncle' },
 'seura'	=> { 'x' => 'society' },
 'seurakunta'	=> { 'x' => 'parish' },
 'seurata'	=> { 'x' => 'follow' },
 'sherry'	=> { 'x' => 'sherry' },
 'sianliha'	=> { 'x' => 'pork' },
 'siell'	=> { 'x' => 'there',
		     '#' => ', yonder' },
 'sielu'	=> { 'x' => 'soul' },
 'sieni'	=> { 'x' => 'fungus',
		     '#' => ', mushroom, sponge' },
 'sihteeri'	=> { 'x' => 'secretary' },
 'siideri'	=> { 'x' => 'cider' },
 'siis'		=> { 'x' => 'so',
		     '#' => ', then, therefore' },
 'siitt'	=> { 'x' => 'beget',
		     '#' => ', generate' },
 'sijaan'	=> { 'x' => 'instead of' },
 'sijaita'	=> { 'x' => 'be situated' },
 'sika'		=> { 'x' => 'pig' },
 'siksi'	=> { 'x' => 'therefore' },
 'sile'	=> { 'x' => 'smooth' },
 'silli'	=> { 'x' => 'herring' },
 'silloin'	=> { 'x' => 'then' },
 'silm'	=> { 'x' => 'eye' },
 'silta'	=> { 'x' => 'bridge' },
 'sinappi'	=> { 'x' => 'mustard' },
 'sinfonia'	=> { 'x' => 'symphony' },
 'sininen'	=> { 'x' => 'blue' },
 'sinne'	=> { 'x' => 'there',
		     '#' => ', thither' },
 'sin'		=> { 'x' => 'you' },
 'sipuli'	=> { 'x' => 'onion' },
 'sirkus'	=> { 'x' => 'circus' },
 'siro'		=> { 'x' => 'graceful' },
 'sisinen'	=> { 'x' => 'inner',
		     '#' => ', internal' },
 'siteerata'	=> { 'x' => 'cite',
		     '#' => ', quote' },
 'siten'	=> { 'x' => 'like this',
		     '#' => ', so, that way, thus' },
 'sitoa'	=> { 'x' => 'bind',
		     '#' => ', connect, join, tie, tie up' },
 'sitruuna'	=> { 'x' => 'lemon' },
 'sitten'	=> { 'x' => 'afterwards',
		     '#' => ', next, subsequently' },
 'siunata'	=> { 'x' => 'bless' },
 'siveellisyys'	=> { 'x' => 'morals' },
 'sivistynyt'	=> { 'x' => 'cultured',
		     '#' => ', educated, learned, well-informed' },
 'sivu'		=> { 'x' => 'page',
		     '#' => ', side' },
 'skotlanti'	=> { 'x' => 'scotland' },
 'skotlantilainen'	=> { 'x' => 'scotsman',
		     '#' => ', scottish' },
 'sohva'	=> { 'x' => 'sofa' },
 'soida'	=> { 'x' => 'peal',
		     '#' => ', ring, sound' },
 'soikea'	=> { 'x' => 'oval' },
 'sointuoppi'	=> { 'x' => 'harmonica' },
 'soitin'	=> { 'x' => 'musical instrument' },
 'sokea'	=> { 'x' => 'blind' },
 'sokeri'	=> { 'x' => 'sugar' },
 'solmu'	=> { 'x' => 'knot',
		     '#' => ', node' },
 'solu'		=> { 'x' => 'cell' },
 'sonaatti'	=> { 'x' => 'sonata' },
 'sopia'	=> { 'x' => 'be appropriate',
		     '#' => ', be fitting, befit, suit' },
 'sora'		=> { 'x' => 'gravel',
		     '#' => ', grit' },
 'sormi'	=> { 'x' => 'finger' },
 'sorsa'	=> { 'x' => 'duck' },
 'sorvata'	=> { 'x' => 'turn' },
 'sota'		=> { 'x' => 'war' },
 'soutaa'	=> { 'x' => 'row' },
 'soutuvene'	=> { 'x' => 'boat' },
 'sudenkorento'	=> { 'x' => 'dragonfly' },
 'suhista'	=> { 'x' => 'rustle',
		     '#' => ', swish' },
 'suhtautua'	=> { 'x' => 'concern',
		     '#' => ', relate' },
 'suhteellinen'	=> { 'x' => 'relative' },
 'suihkuttaa'	=> { 'x' => 'shower' },
 'sukka'	=> { 'x' => 'stocking' },
 'suklaa'	=> { 'x' => 'chocolate' },
 'sukulainen'	=> { 'x' => 'relative' },
 'sukupolvi'	=> { 'x' => 'generation' },
 'sukupuoli'	=> { 'x' => 'sex' },
 'sulattaa'	=> { 'x' => 'melt' },
 'sulhanen'	=> { 'x' => 'fianc' },
 'sulkea'	=> { 'x' => 'close',
		     '#' => ', shut' },
 'suloinen'	=> { 'x' => 'charming',
		     '#' => ', lovely' },
 'summa'	=> { 'x' => 'amount',
		     '#' => ', sum' },
 'sumu'		=> { 'x' => 'fog',
		     '#' => ', mist' },
 'sunnuntai'	=> { 'x' => 'sunday' },
 'suo'		=> { 'x' => 'marsh',
		     '#' => ', swamp' },
 'suodattaa'	=> { 'x' => 'filter' },
 'suojata'	=> { 'x' => 'protect',
		     '#' => ', shelter' },
 'suojella'	=> { 'x' => 'protect' },
 'suola'	=> { 'x' => 'salt' },
 'suoli'	=> { 'x' => 'intestine' },
 'suomalainen'	=> { 'x' => 'finnish' },
 'suomi'	=> { 'x' => 'finland' },
 'suopea'	=> { 'x' => 'advantageous',
		     '#' => ', favourable' },
 'suora'	=> { 'x' => 'direct',
		     '#' => ', straight' },
 'suositella'	=> { 'x' => 'recommend',
		     '#' => ', register' },
 'suostua'	=> { 'x' => 'accede',
		     '#' => ', agree, consent' },
 'suostuttaa'	=> { 'x' => 'persuade' },
 'supistaa'	=> { 'x' => 'reduce' },
 'surista'	=> { 'x' => 'buzz',
		     '#' => ', hum' },
 'surukseni'	=> { 'x' => 'regrettably',
		     '#' => ', unfortunately' },
 'surullinen'	=> { 'x' => 'dismal',
		     '#' => ', dreary, sad' },
 'survoa'	=> { 'x' => 'crush',
		     '#' => ', pound' },
 'susi'		=> { 'x' => 'wolf' },
 'suu'		=> { 'x' => 'mouth' },
 'suudella'	=> { 'x' => 'kiss' },
 'suunnata'	=> { 'x' => 'direct',
		     '#' => ', guide, manage, steer' },
 'suunnitella'	=> { 'x' => 'plan' },
 'suuttua'	=> { 'x' => 'be angry' },
 'sveitsi'	=> { 'x' => 'switzerland' },
 'sveitsilinen'	=> { 'x' => 'swiss' },
 'sydn'	=> { 'x' => 'heart' },
 'syksy'	=> { 'x' => 'autumn' },
 'synnytt'	=> { 'x' => 'be in labour',
		     '#' => ', bear, give birth, labour' },
 'synti'	=> { 'x' => 'sin',
		     '#' => ', transgression' },
 'synty'	=> { 'x' => 'arise',
		     '#' => ', be born' },
 'syv'		=> { 'x' => 'deep',
		     '#' => ', profound' },
 'syy'		=> { 'x' => 'cause',
		     '#' => ', reason' },
 'syyllinen'	=> { 'x' => 'guilty' },
 'syyskuu'	=> { 'x' => 'september' },
 'syytt'	=> { 'x' => 'accuse',
		     '#' => ', blame' },
 'syd'	=> { 'x' => 'eat',
		     '#' => ', feed' },
 'sde'		=> { 'x' => 'beam',
		     '#' => ', ray' },
 'se'		=> { 'x' => 'verse' },
 'shk'	=> { 'x' => 'electricity' },
 'sie'		=> { 'x' => 'fiber',
		     '#' => ', fibre' },
 'sili'	=> { 'x' => 'box',
		     '#' => ', container, jug, vessel' },
 'silytt'	=> { 'x' => 'conserve',
		     '#' => ', keep, maintain, preserve' },
 'skki'	=> { 'x' => 'bag',
		     '#' => ', sack' },
 'smpyl'	=> { 'x' => 'roll' },
 'srke'	=> { 'x' => 'break' },
 'svelasteikko'	=> { 'x' => 'gamut',
		     '#' => ', key, scale' },
 'svelm'	=> { 'x' => 'melody',
		     '#' => ', tune' },
 'svelt'	=> { 'x' => 'compose' },
 's'		=> { 'x' => 'weather' },
 'sli'	=> { 'x' => 'have compassion on',
		     '#' => ', pity' },
 'snnnmukainen'	=> { 'x' => 'normal' },
 'snt'	=> { 'x' => 'norm',
		     '#' => ', standard' },
 'sri'	=> { 'x' => 'leg',
		     '#' => ', paw' },
 'sst'	=> { 'x' => 'save',
		     '#' => ', spare' },
 'taata'	=> { 'x' => 'guarantee',
		     '#' => ', warrant' },
 'tahansa'	=> { 'x' => 'at all',
		     '#' => ', ever' },
 'tahdikas'	=> { 'x' => 'discrete' },
 'tahra'	=> { 'x' => 'blot',
		     '#' => ', spot' },
 'tahti'	=> { 'x' => 'musical time',
		     '#' => ', tact' },
 'tahtoa'	=> { 'x' => 'be willing to',
		     '#' => ', want, wish' },
 'tai'		=> { 'x' => 'or' },
 'taide'	=> { 'x' => 'art' },
 'taikoa'	=> { 'x' => 'bewitch' },
 'taimen'	=> { 'x' => 'trout' },
 'taipumus'	=> { 'x' => 'tendency' },
 'taipuvainen'	=> { 'x' => 'inclined' },
 'taitava'	=> { 'x' => 'clever',
		     '#' => ', dexterous, skillful' },
 'taivas'	=> { 'x' => 'heaven',
		     '#' => ', sky' },
 'taivuttaa'	=> { 'x' => 'bend',
		     '#' => ', fold' },
 'tajuta'	=> { 'x' => 'be aware of',
		     '#' => ', be conscious of, realise, realize' },
 'takki'	=> { 'x' => 'cloak',
		     '#' => ', mantle' },
 'takoa'	=> { 'x' => 'forge' },
 'talja'	=> { 'x' => 'fur',
		     '#' => ', hide, skin' },
 'tallata'	=> { 'x' => 'trample on',
		     '#' => ', tread' },
 'tallettaa'	=> { 'x' => 'deposit' },
 'talo'		=> { 'x' => 'house' },
 'talvi'	=> { 'x' => 'winter' },
 'tammikuu'	=> { 'x' => 'january' },
 'tanska'	=> { 'x' => 'denmark' },
 'tanskalainen'	=> { 'x' => 'dane',
		     '#' => ', danish' },
 'tanssiaiset'	=> { 'x' => 'ball',
		     '#' => ', dance' },
 'tapa'		=> { 'x' => 'custom',
		     '#' => ', habit, manner, mode, mores, way' },
 'tapahtua'	=> { 'x' => 'come about',
		     '#' => ', happen, occur' },
 'tapaturma'	=> { 'x' => 'accident' },
 'taputtaa ksin'	=> { 'x' => 'acclaim',
		     '#' => ', applaud, clap' },
 'tarjoilija'	=> { 'x' => 'waiter' },
 'tarjoiluhuone'	=> { 'x' => 'buffet' },
 'tarkastaa'	=> { 'x' => 'audit',
		     '#' => ', check, check up on, inspect, supervise' },
 'tarkastaja'	=> { 'x' => 'auditor',
		     '#' => ', government inspector' },
 'tarkka'	=> { 'x' => 'accurate',
		     '#' => ', precise' },
 'tarkkaavainen'	=> { 'x' => 'attentive' },
 'tarvita'	=> { 'x' => 'need',
		     '#' => ', require' },
 'tasainen'	=> { 'x' => 'even',
		     '#' => ', flat, level, smooth' },
 'tasapaino'	=> { 'x' => 'equilibrium' },
 'tasku'	=> { 'x' => 'pocket' },
 'taso'		=> { 'x' => 'level' },
 'tauko'	=> { 'x' => 'break',
		     '#' => ', intermission, pause, recess' },
 'taulu'	=> { 'x' => 'board',
		     '#' => ', plank' },
 'taulukko'	=> { 'x' => 'index',
		     '#' => ', table, tablet, tabulation' },
 'tausta'	=> { 'x' => 'background' },
 'tavallinen'	=> { 'x' => 'common',
		     '#' => ', ordinary, usual' },
 'tavara'	=> { 'x' => 'commodity',
		     '#' => ', merchandise, wares' },
 'tavata'	=> { 'x' => 'come across',
		     '#' => ', encounter, meet, see' },
 'tee'		=> { 'x' => 'tea' },
 'teeskennell'	=> { 'x' => 'dissemble' },
 'tehdas'	=> { 'x' => 'factory',
		     '#' => ', mill' },
 'tehd'	=> { 'x' => 'act',
		     '#' => ', cause, do, make, perform' },
 'tehd aloite'	=> { 'x' => 'initiate',
		     '#' => ', start' },
 'tehd johtopts'	=> { 'x' => 'abstract',
		     '#' => ', gather, induce, infer' },
 'tehd yhteenveto'	=> { 'x' => 'abstract',
		     '#' => ', summarize' },
 'teho'		=> { 'x' => 'effect',
		     '#' => ', impression' },
 'teko'		=> { 'x' => 'act',
		     '#' => ', action' },
 'teksti'	=> { 'x' => 'lyric',
		     '#' => ', text' },
 'teltta'	=> { 'x' => 'tent' },
 'terve'	=> { 'x' => 'healthy',
		     '#' => ', well' },
 'tervehdys'	=> { 'x' => 'greeting' },
 'tervehti'	=> { 'x' => 'greet',
		     '#' => ', salute' },
 'ter'		=> { 'x' => 'blade' },
 'ters'	=> { 'x' => 'steel' },
 'terv'	=> { 'x' => 'abrasive',
		     '#' => ', lurid, sharp' },
 'teurastaa'	=> { 'x' => 'butcher',
		     '#' => ', slaughter' },
 'tie'		=> { 'x' => 'road',
		     '#' => ', route, way' },
 'tiede'	=> { 'x' => 'science' },
 'tietysti'	=> { 'x' => 'of course' },
 'tiet'	=> { 'x' => 'know',
		     '#' => ', know how' },
 'tihe'	=> { 'x' => 'concentrated',
		     '#' => ', dense, thick' },
 'tiistai'	=> { 'x' => 'tuesday' },
 'tikka'	=> { 'x' => 'woodpecker' },
 'tila'		=> { 'x' => 'condition',
		     '#' => ', state' },
 'tilanne'	=> { 'x' => 'circumstances',
		     '#' => ', condition, situation' },
 'tilapinen'	=> { 'x' => 'provisional',
		     '#' => ', temporary' },
 'tilata'	=> { 'x' => 'book',
		     '#' => ', order, reserve, subscribe' },
 'tili'		=> { 'x' => 'account' },
 'todellinen'	=> { 'x' => 'actual',
		     '#' => ', practical, real' },
 'todennkinen'	=> { 'x' => 'probable' },
 'todeta'	=> { 'x' => 'ascertain',
		     '#' => ', establish, take note' },
 'todistaa'	=> { 'x' => 'attest',
		     '#' => ', bear witness of, testify' },
 'toimia'	=> { 'x' => 'act',
		     '#' => ', function, operate, run, work' },
 'toimittaa'	=> { 'x' => 'edit' },
 'toinen'	=> { 'x' => 'another',
		     '#' => ', else, other, second' },
 'toistaa'	=> { 'x' => 'repeat' },
 'toivoa'	=> { 'x' => 'hope' },
 'tomaatti'	=> { 'x' => 'tomato' },
 'tonava'	=> { 'x' => 'danube' },
 'tonttu'	=> { 'x' => 'goblin',
		     '#' => ', imp' },
 'tori'		=> { 'x' => 'plaza',
		     '#' => ', public square, square' },
 'torni'	=> { 'x' => 'castle',
		     '#' => ', tower' },
 'torstai'	=> { 'x' => 'thursday' },
 'torvi'	=> { 'x' => 'trumpet' },
 'tosi'		=> { 'x' => 'true' },
 'tosiasia'	=> { 'x' => 'fact' },
 'totuus'	=> { 'x' => 'reality',
		     '#' => ', truth' },
 'toukka'	=> { 'x' => 'caterpillar',
		     '#' => ', grub, larva' },
 'toukokuu'	=> { 'x' => 'may' },
 'tsaari'	=> { 'x' => 'czar' },
 'tuhat'	=> { 'x' => 'one thousand',
		     '#' => ', thousand' },
 'tuhka'	=> { 'x' => 'ash',
		     '#' => ', cinder' },
 'tuhoutua'	=> { 'x' => 'perish' },
 'tukehduttaa'	=> { 'x' => 'choke',
		     '#' => ', quell, suffocate, suppress' },
 'tuleva'	=> { 'x' => 'future' },
 'tuli'		=> { 'x' => 'fire' },
 'tulitikku'	=> { 'x' => 'match' },
 'tulkita'	=> { 'x' => 'interpret' },
 'tulla'	=> { 'x' => 'come' },
 'tulla joksikin'	=> { 'x' => 'become',
		     '#' => ', get, grow' },
 'tulla nkyviin'	=> { 'x' => 'appear',
		     '#' => ', emerge, perform' },
 'tulppaani'	=> { 'x' => 'tulip' },
 'tunneli'	=> { 'x' => 'tunnel' },
 'tunnus'	=> { 'x' => 'emblem' },
 'tuntea'	=> { 'x' => 'be acquainted with',
		     '#' => ', feel, know, sense' },
 'tunti'	=> { 'x' => 'hour',
		     '#' => ', o\'clock, time' },
 'tuoli'	=> { 'x' => 'chair' },
 'tuomita'	=> { 'x' => 'judge' },
 'tuomita kadotukseen'	=> { 'x' => 'damn' },
 'tuore'	=> { 'x' => 'fresh',
		     '#' => ', recent' },
 'tuottaa'	=> { 'x' => 'bear',
		     '#' => ', produce' },
 'tupakka'	=> { 'x' => 'tobacco' },
 'turha'	=> { 'x' => 'abortive',
		     '#' => ', futile, useless, vain' },
 'turhanpiten'	=> { 'x' => 'for no reason' },
 'turkis'	=> { 'x' => 'fur',
		     '#' => ', fur coat, fur piece' },
 'turkki'	=> { 'x' => 'turkey' },
 'turkkilainen'	=> { 'x' => 'turkish' },
 'turve'	=> { 'x' => 'peat' },
 'tuska'	=> { 'x' => 'agony',
		     '#' => ', anguish, fear' },
 'tuskin'	=> { 'x' => 'barely',
		     '#' => ', hardly, only just, scarcely' },
 'tutkia'	=> { 'x' => 'examine',
		     '#' => ', explore, investigate, research' },
 'tuttu'	=> { 'x' => 'well-known' },
 'tuuli'	=> { 'x' => 'wind' },
 'tuutia'	=> { 'x' => 'lull',
		     '#' => ', rock' },
 'tyhj'	=> { 'x' => 'empty',
		     '#' => ', void' },
 'tyhm'	=> { 'x' => 'foolish',
		     '#' => ', stupid' },
 'tylpp'	=> { 'x' => 'dull',
		     '#' => ', obtuse' },
 'tyrkytt'	=> { 'x' => 'force',
		     '#' => ', impose' },
 'tyyli'	=> { 'x' => 'style' },
 'tyyni'	=> { 'x' => 'calm',
		     '#' => ', quiet, serene, tranquil, untroubled' },
 'tyyni valtameri'	=> { 'x' => 'pacific',
		     '#' => ', pacific ocean' },
 'tyyppi'	=> { 'x' => 'type' },
 'tyytyvinen'	=> { 'x' => 'contented',
		     '#' => ', pleased, satisfied' },
 'tynt'	=> { 'x' => 'push',
		     '#' => ', push along, shove, thrust' },
 'tyskennell'	=> { 'x' => 'work' },
 'thti'	=> { 'x' => 'star' },
 'thyst'	=> { 'x' => 'keep an eye on',
		     '#' => ', spy on' },
 'tm'		=> { 'x' => 'this' },
 'tnn'	=> { 'x' => 'to-day',
		     '#' => ', today' },
 'trke'	=> { 'x' => 'important',
		     '#' => ', serious' },
 'tsmllinen'	=> { 'x' => 'accurate',
		     '#' => ', exact, on time, prompt, punctual' },
 'tss'	=> { 'x' => 'behold',
		     '#' => ', here are, here is, look' },
 'tydellinen'	=> { 'x' => 'absolute',
		     '#' => ', complete, perfect' },
 'tysi'	=> { 'x' => 'complete',
		     '#' => ', full' },
 'tyty'	=> { 'x' => 'have to',
		     '#' => ', must, ought to, should' },
 'tllistell'	=> { 'x' => 'gape',
		     '#' => ', gawk' },
 'trmt'	=> { 'x' => 'collide' },
 'uhata'	=> { 'x' => 'menace',
		     '#' => ', threaten' },
 'uida'		=> { 'x' => 'float',
		     '#' => ', swim' },
 'ukkonen'	=> { 'x' => 'thunder' },
 'uljas'	=> { 'x' => 'brave',
		     '#' => ', gallant' },
 'ulkomailla'	=> { 'x' => 'abroad' },
 'ulkoportaat'	=> { 'x' => 'platform',
		     '#' => ', railway platform' },
 'ulkopuolella'	=> { 'x' => 'outside',
		     '#' => ', outside of' },
 'ulos'		=> { 'x' => 'from',
		     '#' => ', out of' },
 'ulostaa'	=> { 'x' => 'defecate' },
 'ulottuvuus'	=> { 'x' => 'dimension',
		     '#' => ', measurement' },
 'uneksia'	=> { 'x' => 'daydream',
		     '#' => ', dream, fancy' },
 'uni'		=> { 'x' => 'dream' },
 'unkari'	=> { 'x' => 'hungary' },
 'unkarilainen'	=> { 'x' => 'hungarian' },
 'unohtaa'	=> { 'x' => 'forget' },
 'untuva'	=> { 'x' => 'down',
		     '#' => ', fluff' },
 'urut'		=> { 'x' => 'organ' },
 'useahkot'	=> { 'x' => 'several' },
 'usein'	=> { 'x' => 'frequently',
		     '#' => ', often, regularly' },
 'uskoa'	=> { 'x' => 'believe',
		     '#' => ', deem' },
 'uskollinen'	=> { 'x' => 'faithful',
		     '#' => ', loyal' },
 'uuni'		=> { 'x' => 'furnace',
		     '#' => ', kiln, oven, stove' },
 'uusi'		=> { 'x' => 'new',
		     '#' => ', novel' },
 'vaahto'	=> { 'x' => 'foam',
		     '#' => ', froth' },
 'vaalea'	=> { 'x' => 'blond',
		     '#' => ', bright, clear, fair, light' },
 'vaara'	=> { 'x' => 'danger',
		     '#' => ', peril' },
 'vaarantaa'	=> { 'x' => 'hazard',
		     '#' => ', risk, venture' },
 'vaatia'	=> { 'x' => 'demand',
		     '#' => ', postulate, require' },
 'vaatimalla vaatia'	=> { 'x' => 'insist' },
 'vaatimaton'	=> { 'x' => 'modest' },
 'vadelma'	=> { 'x' => 'raspberry' },
 'vaeltaa'	=> { 'x' => 'migrate',
		     '#' => ', roam, wander, wander about' },
 'vahvistaa'	=> { 'x' => 'confirm',
		     '#' => ', corroborate' },
 'vaieta'	=> { 'x' => 'be quiet' },
 'vaihdella'	=> { 'x' => 'vary' },
 'vaihe'	=> { 'x' => 'phase',
		     '#' => ', stage' },
 'vaihtaa'	=> { 'x' => 'interchange',
		     '#' => ', swap' },
 'vaihtaa kirjeit'	=> { 'x' => 'correspond' },
 'vaikka'	=> { 'x' => 'although',
		     '#' => ', though' },
 'vaikutin'	=> { 'x' => 'motive',
		     '#' => ', reason' },
 'vaikuttaa'	=> { 'x' => 'act',
		     '#' => ', be effective, have effect' },
 'vaikutus'	=> { 'x' => 'impression' },
 'vain'		=> { 'x' => 'exclusively',
		     '#' => ', just, only' },
 'vaisto'	=> { 'x' => 'instinct' },
 'vaivata'	=> { 'x' => 'bother',
		     '#' => ', disturb, hinder, trouble' },
 'vakava'	=> { 'x' => 'earnest',
		     '#' => ', serious' },
 'vakuuttaa'	=> { 'x' => 'convince',
		     '#' => ', persuade' },
 'valaista'	=> { 'x' => 'shine' },
 'valas'	=> { 'x' => 'whale' },
 'valehdella'	=> { 'x' => 'lie',
		     '#' => ', tell a lie' },
 'valita'	=> { 'x' => 'choose',
		     '#' => ', elect, pick out' },
 'valitella'	=> { 'x' => 'lament',
		     '#' => ', wail' },
 'valittaa'	=> { 'x' => 'be sorry about',
		     '#' => ', regret' },
 'valitus'	=> { 'x' => 'complaint' },
 'valkea'	=> { 'x' => 'blank',
		     '#' => ', white' },
 'valmis'	=> { 'x' => 'finished',
		     '#' => ', ready, through' },
 'valo'		=> { 'x' => 'light' },
 'valokuva'	=> { 'x' => 'photograph' },
 'valokuvata'	=> { 'x' => 'photograph' },
 'valtakatu'	=> { 'x' => 'highway' },
 'valtakunta'	=> { 'x' => 'realm',
		     '#' => ', state' },
 'valtameri'	=> { 'x' => 'ocean' },
 'valtio'	=> { 'x' => 'state' },
 'vanavesi'	=> { 'x' => 'distribution' },
 'vanha'	=> { 'x' => 'old' },
 'vanilja'	=> { 'x' => 'vanilla' },
 'vannoa'	=> { 'x' => 'swear' },
 'vapaa'	=> { 'x' => 'free' },
 'vapaamielinen'	=> { 'x' => 'liberal' },
 'varastaa'	=> { 'x' => 'steal' },
 'varasto'	=> { 'x' => 'stock' },
 'varata'	=> { 'x' => 'occupy',
		     '#' => ', take' },
 'varjo'	=> { 'x' => 'shade',
		     '#' => ', shadow' },
 'varma'	=> { 'x' => 'certain',
		     '#' => ', safe, secure, sure' },
 'varoittaa'	=> { 'x' => 'caution',
		     '#' => ', warn' },
 'varpunen'	=> { 'x' => 'sparrow' },
 'varten'	=> { 'x' => 'for',
		     '#' => ', in order to, to' },
 'vartioida'	=> { 'x' => 'guard',
		     '#' => ', keep, look after, watch over' },
 'vasikanpaisti'	=> { 'x' => 'veal' },
 'vastaan'	=> { 'x' => 'across from',
		     '#' => ', against, in exchange for, opposed to' },
 'vastakkainen'	=> { 'x' => 'reverse',
		     '#' => ', reversed' },
 'vastata'	=> { 'x' => 'answer',
		     '#' => ', reply, respond' },
 'vastavaikutus'	=> { 'x' => 'reaction' },
 'vastavuoroinen'	=> { 'x' => 'mutual',
		     '#' => ', reciprocal' },
 'vastustus'	=> { 'x' => 'opposition' },
 'vati'		=> { 'x' => 'basin',
		     '#' => ', bowl, course, dish, pelvis, platter' },
 'vatsa'	=> { 'x' => 'abdomen',
		     '#' => ', belly, tummy' },
 'vaunu'	=> { 'x' => 'carriage',
		     '#' => ', coach, railway carriage, waggon' },
 'vaunuosasto'	=> { 'x' => 'compartment',
		     '#' => ', coup' },
 'vauva'	=> { 'x' => 'baby' },
 'vavista'	=> { 'x' => 'quiver',
		     '#' => ', shiver, tremble' },
 'veist'	=> { 'x' => 'build',
		     '#' => ', build from wood' },
 'veli'		=> { 'x' => 'brother' },
 'velvollisuus'	=> { 'x' => 'duty',
		     '#' => ', obligation' },
 'venlinen'	=> { 'x' => 'russian' },
 'verho'	=> { 'x' => 'curtain' },
 'veri'		=> { 'x' => 'blood' },
 'verkko'	=> { 'x' => 'net',
		     '#' => ', network' },
 'verrata'	=> { 'x' => 'compare' },
 'vesi'		=> { 'x' => 'water' },
 'vesimeloni'	=> { 'x' => 'water-melon' },
 'veturi'	=> { 'x' => 'engine' },
 'vet'	=> { 'x' => 'drag',
		     '#' => ', draw, haul, pull, tug' },
 'vied maasta'	=> { 'x' => 'export' },
 'viekas'	=> { 'x' => 'clever',
		     '#' => ', cunning, sly, smart' },
 'viel'	=> { 'x' => 'still',
		     '#' => ', yet' },
 'vielp'	=> { 'x' => 'even' },
 'vieras'	=> { 'x' => 'alien',
		     '#' => ', foreign, guest, strange' },
 'vieress'	=> { 'x' => 'at',
		     '#' => ', beside, by, near to, next to' },
 'viett'	=> { 'x' => 'pass',
		     '#' => ', spend' },
 'vihannes'	=> { 'x' => 'vegetable' },
 'vihelt'	=> { 'x' => 'whistle' },
 'vihko'	=> { 'x' => 'exercise-book',
		     '#' => ', folder, notebook' },
 'vihre'	=> { 'x' => 'green' },
 'viides'	=> { 'x' => 'fifth' },
 'viikko'	=> { 'x' => 'week' },
 'viilata'	=> { 'x' => 'file' },
 'viimeinen'	=> { 'x' => 'last' },
 'viini'	=> { 'x' => 'wine' },
 'viisas'	=> { 'x' => 'sagacious',
		     '#' => ', sage, wise' },
 'viisi'	=> { 'x' => 'five' },
 'viisikymment'	=> { 'x' => 'fifty' },
 'viisitoista'	=> { 'x' => 'fifteen' },
 'viitata'	=> { 'x' => 'allude',
		     '#' => ', hint, indicate, suggest' },
 'viiva'	=> { 'x' => 'line' },
 'vilja'	=> { 'x' => 'grain' },
 'viljell'	=> { 'x' => 'cultivate',
		     '#' => ', grow' },
 'villa'	=> { 'x' => 'wool' },
 'virhe'	=> { 'x' => 'aberration',
		     '#' => ', error, mistake' },
 'viritt'	=> { 'x' => 'tune' },
 'virka'	=> { 'x' => 'function',
		     '#' => ', job, office, post' },
 'virkailija'	=> { 'x' => 'officer',
		     '#' => ', official' },
 'virrata'	=> { 'x' => 'flow' },
 'viski'	=> { 'x' => 'whiskey',
		     '#' => ', whisky' },
 'viulu'	=> { 'x' => 'violin' },
 'vodka'	=> { 'x' => 'vodka' },
 'voi'		=> { 'x' => 'butter',
		     '#' => ', woe' },
 'voida'	=> { 'x' => 'be able to',
		     '#' => ', can, fare, may' },
 'voidella'	=> { 'x' => 'anoint',
		     '#' => ', smear, spread' },
 'voileip'	=> { 'x' => 'sandwich' },
 'voimakas'	=> { 'x' => 'intense',
		     '#' => ', intensive, strong' },
 'voittaa'	=> { 'x' => 'defeat',
		     '#' => ', earn, gain, win, win over' },
 'vuode'	=> { 'x' => 'bed' },
 'vuodenaika'	=> { 'x' => 'season' },
 'vuokrasopimus'	=> { 'x' => 'farm' },
 'vuokrata'	=> { 'x' => 'hire' },
 'vuokrata maata'	=> { 'x' => 'farm',
		     '#' => ', lease' },
 'vuoksi'	=> { 'x' => 'because of',
		     '#' => ', for sake of, on account of' },
 'vuori'	=> { 'x' => 'mountain' },
 'vuoron pern'	=> { 'x' => 'in turn' },
 'vuosi'	=> { 'x' => 'year' },
 'vy'		=> { 'x' => 'belt',
		     '#' => ', girdle' },
 'vyhyke'	=> { 'x' => 'zone' },
 'vijy'	=> { 'x' => 'set a trap',
		     '#' => ', set a trap for' },
 'visty'	=> { 'x' => 'cede',
		     '#' => ', give in, give up, give way, relinquish' },
 'vlttmtn'	=> { 'x' => 'necessary' },
 'vltt'	=> { 'x' => 'avoid',
		     '#' => ', evade' },
 'vrvt'	=> { 'x' => 'recruit' },
 'vrhdell'	=> { 'x' => 'vibrate' },
 'vsynyt'	=> { 'x' => 'tired' },
 'vrent'	=> { 'x' => 'falsify' },
 'watti'	=> { 'x' => 'watt' },
 'ydin'		=> { 'x' => 'core',
		     '#' => ', kernel, nucleus, pit' },
 'yhdeksn'	=> { 'x' => 'nine' },
 'yhdeksnkymment'	=> { 'x' => 'ninety' },
 'yhdeksntoista'	=> { 'x' => 'nineteen' },
 'yhdekss'	=> { 'x' => 'ninth' },
 'yhdistyneet kansakunnat'	=> { 'x' => 'united nations' },
 'yhdysvallat'	=> { 'x' => 'usa',
		     '#' => ', united states of america' },
 'yhteinen'	=> { 'x' => 'common',
		     '#' => ', joint' },
 'yhtenevinen'	=> { 'x' => 'compatible',
		     '#' => ', congruent' },
 'yhtlinen'	=> { 'x' => 'equal',
		     '#' => ', even, level, similar' },
 'yksi'		=> { 'x' => 'one' },
 'yksil'	=> { 'x' => 'copy' },
 'yksin'	=> { 'x' => 'alone',
		     '#' => ', only, sole, solitary' },
 'yksinkertainen'	=> { 'x' => 'simple',
		     '#' => ', straightforward' },
 'yksitoista'	=> { 'x' => 'eleven' },
 'yksityinen'	=> { 'x' => 'private' },
 'yleinen'	=> { 'x' => 'general',
		     '#' => ', usual' },
 'yleis'	=> { 'x' => 'public' },
 'ylhll'	=> { 'x' => 'above',
		     '#' => ', on top, overhead, upstairs' },
 'ylist'	=> { 'x' => 'commend',
		     '#' => ', laud, praise' },
 'yllytt'	=> { 'x' => 'encourage',
		     '#' => ', impel, instigate, spur on, stimulate' },
 'ylltt'	=> { 'x' => 'surprise' },
 'ylpe'	=> { 'x' => 'proud' },
 'ylpuolella'	=> { 'x' => 'above',
		     '#' => ', over' },
 'ymmll'	=> { 'x' => 'perplexed',
		     '#' => ', taken aback' },
 'ymmrt'	=> { 'x' => 'realise',
		     '#' => ', realize, understand' },
 'ympyr'	=> { 'x' => 'circle' },
 'ymprill'	=> { 'x' => 'about',
		     '#' => ', around, round' },
 'yritt'	=> { 'x' => 'undertake' },
 'ystv'	=> { 'x' => 'friend' },
 'ystvllinen'	=> { 'x' => 'affable',
		     '#' => ', friendly, good-natured, kind' },
 'y'		=> { 'x' => 'night' },
 'killinen'	=> { 'x' => 'abrupt',
		     '#' => ', sudden' },
 'llistytt'	=> { 'x' => 'appall',
		     '#' => ', dismay, puzzle' },
 'lyks'	=> { 'x' => 'intelligent',
		     '#' => ', prudent, reasonable, sagacious' },
 'mpri'	=> { 'x' => 'bucket',
		     '#' => ', pail' },
 'rsytt'	=> { 'x' => 'abet',
		     '#' => ', excite, incite, provoke, rouse, stimulate' },
 'neks'	=> { 'x' => 'loud' },
 'nest'	=> { 'x' => 'vote' },
 'nt'	=> { 'x' => 'pronounce' },
 'rimminen'	=> { 'x' => 'extreme' },
 'ljy'		=> { 'x' => 'oil' },
);
}

1;

