# vi: ts=8 sw=8

package Tongues::Ukrayinska;

use strict;
use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $charset $grammar %dictionary);

use Exporter   ();
# set the version for version checking
@ISA         = qw(Exporter);
@EXPORT      = qw(charset grammar dictionary);
@EXPORT_OK   = qw();
$VERSION     = 0.00;

# Character set Windows Cyrillic CP1251
# not KOI8-U or ISO 8859-5

# Alphabetical order
#                                
#                                

# Does  come between  and  or between  and ?
# Does  come between  and , at the end, or is it a separate symbol?

# Extra characters (Windows)
#  '

sub new {
	my $class = shift;
	my $self = bless {}, $class;
	return $self;
}

sub charset {
	return $charset;
}

sub grammar {
	return $grammar;
}

sub dictionary {
	return \%dictionary;
}

sub BEGIN {

require Charsets::CyrillicWin;

$charset = new Charsets::CyrillicWin;

# Table for converting words to root form
$grammar = [
 # Noun case
 # Noun gender
 # Noun plural
 # Adjectives
 # Verb past participle
 # Verb gerund
 # Verb present participle
 # Verb present
 # Verb present subjunctive
 # Verb imperitive
 # Verb preterite
 # Verb imperfect
 # Verb future
 # Verb conditional
 # Adverb
 # Higher level transformations
];

#Fields:
# x -> translation		all words
# r -> root			irregular declensions
# t -> type:			all words
#	n -> noun
#	v -> verb
#	a -> adjective
#	p -> preposition
#	art -> article
#	pro -> pronoun
#	conj -> conjugation
#	adv -> adverb
# g -> gender:			nouns, pronouns, adjectives
#	m -> masculine		default
#	f -> feminine
#	n -> neuter
# n -> number:			articles, pronouns, verbs, adjectives
#	s -> singular		default
#	p -> plural		default for words ending in s
# p -> person:			pronouns, verbs
#	1 -> 1st person
#	2 -> 2nd person
#	3 -> 3rd person		default
# c -> conjugation:
#	p -> present
#	i -> imperfect
#	f -> future
#	c -> conditional
#	t -> preterite
#	ps -> present subjunctive
#	is -> imperfect subjunctive
#	inf -> infinitive		default
#	pp -> past participle
#	g -> gerund
#	imp -> imperative
# c -> case:
#	n -> nominative
#	g -> genitive
#	d -> dative
#	a -> accusative
#	v -> vocative
#	l -> locative
#	inst -> instrumental

# Ukrainian to English dictionary
%dictionary = (
 # Functional words
 #  Articles
 #   Definite articles
 #    Masculine
 #     Singular
 #     Plural
 #    Feminine
 #     Singular
 #     Plural
 #   Indefinite articles
 #  Pronouns & possessive adjectives
 #   1st person
 #   2nd person
 #   3rd person
 #  Interrogatives
 ''	=> { 'x' => 'where from' },
 ''		=> { 'x' => 'where' },
 ''		=> { 'x' => 'whom' },
 ''		=> { 'x' => 'when' },
 ''	=> { 'x' => 'which' },
 ''		=> { 'x' => 'where' },
 ''	=> { 'x' => 'what for' },
 ''	=> { 'x' => 'how many' },
 ''		=> { 'x' => 'who' },
 ''		=> { 'x' => 'why' },
 ''		=> { 'x' => 'what' },
 ''		=> { 'x' => 'how' },
 ''		=> { 'x' => 'what kind of' },
# ' '	=> { 'x' => 'how' },
 #  Other functional words
# ' '	=> { 'x' => 'please' },
 ''	=> { 'x' => 'hello',
		     '#' => 'hallo' },
 ''		=> { 'x' => 'with' },
 ''	=> { 'x' => 'always' },
 ''	=> { 'x' => 'now' },
 ''	=> { 'x' => 'sometimes' },
 ''	=> { 'x' => 'above' },
 ''	=> { 'x' => 'soon' },
 ''		=> { 'x' => 'no' },
 ''	=> { 'x' => 'never' },
 ''	=> { 'x' => 'nowhere' },
 ''	=> { 'x' => 'behind' },
 ''		=> { 'x' => 'here' },
 ''		=> { 'x' => 'yes' },
 ''		=> { 'x' => 'there' },
 ''		=> { 'x' => 'then' },
 ''		=> { 'x' => 'there' },
 ''		=> { 'x' => 'here' },
 ''	=> { 'x' => 'below' },
 ''		=> { 'x' => 'all' },
 ''	=> { 'x' => 'often' },
 #   Partitive / Contractions
 # Numbers: cardinal and ordinal
 ''		=> { 'x' => 'zero' },
 ''		=> { 'x' => 'one' },
 ''		=> { 'x' => 'two' },
 ''		=> { 'x' => 'three' },
 ''	=> { 'x' => 'four' },
 '\''	=> { 'x' => 'five' },
 ''	=> { 'x' => 'six' },
 ''		=> { 'x' => 'seven' },
 ''	=> { 'x' => 'eight' },
 '\''	=> { 'x' => 'nine' },
 ''	=> { 'x' => 'ten' },
 ''	=> { 'x' => 'eleven' },
 ''	=> { 'x' => 'twelve' },
 ''	=> { 'x' => 'thirteen' },
 ''	=> { 'x' => 'fourteen' },
 '\''	=> { 'x' => 'fifteen' },
 ''	=> { 'x' => 'sixteen' },
 ''	=> { 'x' => 'seventeen' },
 ''	=> { 'x' => 'eighteen' },
 '\''	=> { 'x' => 'nineteen' },
 ''	=> { 'x' => 'twenty' },
# ' '	=> { 'x' => 'twenty one' },
# ' '	=> { 'x' => 'twenty two' },
 ''	=> { 'x' => 'thirty' },
 ''	=> { 'x' => 'forty' },
 '\''	=> { 'x' => 'fifty' },
 ''	=> { 'x' => 'sixty' },
 ''	=> { 'x' => 'seventy' },
 ''	=> { 'x' => 'eighty' },
 '\''	=> { 'x' => 'ninety' },
 ''		=> { 'x' => 'hundred' },
 ''	=> { 'x' => 'two hundred' },
 ''	=> { 'x' => 'three hundred' },
 ''	=> { 'x' => 'four hundred' },
 '\''	=> { 'x' => 'five hundred' },
 ''	=> { 'x' => 'seven hundred' },
 ''	=> { 'x' => 'eight hundred' },
 '\''	=> { 'x' => 'nine hundred' },
 ''	=> { 'x' => 'one thousand' },
# ' '	=> { 'x' => 'two thousand' },
 ''	=> { 'x' => 'one million' },
 # Days and months
 ''	=> { 'x' => 'sunday' },
 ''	=> { 'x' => 'monday' },
 ''	=> { 'x' => 'tuesday' },
 ''	=> { 'x' => 'wednesday' },
 ''	=> { 'x' => 'thursday' },
 ''	=> { 'x' => 'friday' },
 ''	=> { 'x' => 'saturday' },
 # From ?
 ''	=> { 'x' => 'january' },
 ''	=> { 'x' => 'february' },
 ''	=> { 'x' => 'march' },
 ''	=> { 'x' => 'april' },
 ''	=> { 'x' => 'may' },
 ''	=> { 'x' => 'june' },
 ''	=> { 'x' => 'july' },
 ''	=> { 'x' => 'august' },
 ''	=> { 'x' => 'september' },
 ''	=> { 'x' => 'october' },
 ''	=> { 'x' => 'november' },
 ''	=> { 'x' => 'december' },
 # From http://oss.software.ibm.com/cgi-bin/icu/lx/en_AU/?_=uk&
 ''	=> { 'x' => 'january' },
 ''	=> { 'x' => 'february' },
 ''	=> { 'x' => 'march' },
 ''	=> { 'x' => 'april' },
 ''	=> { 'x' => 'may' },
 ''	=> { 'x' => 'june' },
 ''	=> { 'x' => 'july' },
 ''	=> { 'x' => 'august' },
 ''	=> { 'x' => 'september' },
 ''	=> { 'x' => 'october' },
 ''	=> { 'x' => 'november' },
 ''	=> { 'x' => 'december' },
 # Key verbs
 # Vocabulary
 '볿'	=> { 'x' => 'australia',
		     '#' => 'country; place',
		     't' => 'n' },
 ''	=> { 'x' => 'bus',
		     't' => 'n' },
 ''	=> { 'x' => 'bus station',
		     '#' => 'place',
		     't' => 'n' },
 ''	=> { 'x' => 'airport',
		     '#' => 'place',
		     't' => 'n' },
 ''	=> { 'x' => 'airport',
		     '#' => 'place',
		     't' => 'n' },
 ''	=> { 'x' => 'pineapple',
		     't' => 'n' },
 ''	=> { 'x' => 'chemist\'s shop',
		     't' => 'n' },
 ''	=> { 'x' => 'grandmother',
		     '#' => 'person; animate',
		     't' => 'n' },
 ''	=> { 'x' => 'rich',
		     't' => 'a' },
 ''	=> { 'x' => 'a lot' },
 ''	=> { 'x' => 'banana',
		     't' => 'n' },
 ''		=> { 'x' => 'bank',
		     't' => 'n' },
 ''		=> { 'x' => 'bar',
		     't' => 'n' },
 ''	=> { 'x' => 'mutton',
		     't' => 'n' },
 ''	=> { 'x' => 'battery',
		     't' => 'n' },
 ''	=> { 'x' => 'parents',
		     '#' => 'person; animate; plural?',
		     't' => 'n' },
 ''	=> { 'x' => 'father',
		     '#' => 'person; animate',
		     't' => 'n' },
 ''	=> { 'x' => 'fawn-coloured',
		     't' => 'a' },
 ''	=> { 'x' => 'colourless',
		     't' => 'a' },
 ''	=> { 'x' => 'undoubtedly' },
 ''	=> { 'x' => 'poor',
		     't' => 'a' },
 ''		=> { 'x' => 'white',
		     't' => 'a' },
 ''	=> { 'x' => 'white',
		     't' => 'a' },
 ''	=> { 'x' => 'turquoise',
		     '#' => 'noun and adjective?' },
 ''	=> { 'x' => 'beefsteak',
		     't' => 'n' },
 ''	=> { 'x' => 'light-blue',
		     't' => 'a' },
 ''	=> { 'x' => 'lightning',
		     't' => 'n' },
 ''	=> { 'x' => 'dish',
		     't' => 'n' },
 ''	=> { 'x' => 'claret',
		     '#' => 'noun or possibly colour?' },
 ''		=> { 'x' => 'borsch',
		     '#' => 'borscht',
		     't' => 'n' },
 ''		=> { 'x' => 'brother',
		     '#' => 'person; animate',
		     't' => 'n' },
 ''	=> { 'x' => 'razor',
		     't' => 'n' },
 ''	=> { 'x' => 'bronze',
		     '#' => 'noun or possibly colour?' },
 ''	=> { 'x' => 'dirty',
		     't' => 'a' },
 ''	=> { 'x' => 'roll',
		     '#' => 'noun or verb?' },
 ''	=> { 'x' => 'broth',
		     't' => 'n' },
 ''	=> { 'x' => 'beet',
		     't' => 'n' },
 ''	=> { 'x' => 'sandwich',
		     't' => 'n' },
 ''	=> { 'x' => 'heavy',
		     't' => 'a' },
 ''	=> { 'x' => 'suitcase',
		     't' => 'n' },
 ''	=> { 'x' => 'bath',
		     '#' => 'noun or verb?' },
 ''	=> { 'x' => 'boiled',
		     't' => 'a' },
 ''	=> { 'x' => 'come in' },
 ''	=> { 'x' => 'vegetarian' },
 ''	=> { 'x' => 'large',
		     't' => 'a' },
 ''	=> { 'x' => 'big',
		     't' => 'a' },
 ''	=> { 'x' => 'cheerful',
		     't' => 'a' },
 ''	=> { 'x' => 'rainbow',
		     't' => 'n' },
 ''	=> { 'x' => 'wedding',
		     't' => 'n' },
 ''	=> { 'x' => 'spring',
		     't' => 'n' },
 ''	=> { 'x' => 'supper',
		     't' => 'n' },
 ''	=> { 'x' => 'evening',
		     't' => 'n' },
 ''	=> { 'x' => 'shoe',
		     't' => 'n' },
 ''	=> { 'x' => 'footwear',
		     't' => 'n' },
 ''	=> { 'x' => 'sorry',
		     't' => 'a' },
 ''	=> { 'x' => 'fork',
		     't' => 'n' },
 ''		=> { 'x' => 'wine',
		     't' => 'n' },
 ''	=> { 'x' => 'high',
		     't' => 'a' },
 ''	=> { 'x' => 'exit',
		     '#' => 'noun and/or verb?' },
 ''	=> { 'x' => 'exit',
		     '#' => 'noun and/or verb?' },
# ''		=> { 'x' => 'push' },
 ''	=> { 'x' => 'thaw',
		     't' => 'v' },
 ''	=> { 'x' => 'whisky',
		     't' => 'n' },
 ''	=> { 'x' => 'wind',
		     't' => 'n' },
 ''	=> { 'x' => 'step-father',
		     '#' => 'person; animate',
		     't' => 'n' },
 ''	=> { 'x' => 'wool',
		     '#' => 'noun or adjective?' },
 ''	=> { 'x' => 'dampness',
		     't' => 'n' },
 ''		=> { 'x' => 'water' },
 ''		=> { 'x' => 'water' },
 ''	=> { 'x' => 'railway station',
		     't' => 'n' },
 ''	=> { 'x' => 'railway station',
		     't' => 'n' },
 ''	=> { 'x' => 'narrow',
		     't' => 'a' },
 ''	=> { 'x' => 'narrow',
		     't' => 'a' },
 ''		=> { 'x' => 'entrance',
		     't' => 'n' },
 ''	=> { 'x' => 'entry' },
 ''	=> { 'x' => 'in time' },
 ''	=> { 'x' => 'purse',
		     't' => 'n' },
 ''	=> { 'x' => 'good',
		     't' => 'a' },
 ''	=> { 'x' => 'hot' },
 ''	=> { 'x' => 'food store',
		     't' => 'n' },
 ''	=> { 'x' => 'bitter',
		     't' => 'a' },
 ''	=> { 'x' => 'mustard',
		     't' => 'n' },
 ''	=> { 'x' => 'smooth',
		     't' => 'a' },
 ''	=> { 'x' => 'deep',
		     't' => 'a' },
 ''	=> { 'x' => 'hour',
		     't' => 'n' },
 ''	=> { 'x' => 'watch',
		     '#' => 'hours',
		     't' => 'n' },
 ''	=> { 'x' => 'needle',
		     't' => 'n' },
 ''	=> { 'x' => 'loud',
		     't' => 'a' },
 ''	=> { 'x' => 'vodka',
		     't' => 'n' },
 ''	=> { 'x' => 'peas',
		     't' => 'n' },
 ''	=> { 'x' => 'party',
		     't' => 'n' },
 ''	=> { 'x' => 'sharp',
		     't' => 'a' },
 ''		=> { 'x' => 'hailstones',
		     't' => 'n' },
 ''	=> { 'x' => 'degree',
		     't' => 'n' },
 ''	=> { 'x' => 'mushrooms',
		     't' => 'n' },
 ''		=> { 'x' => 'thunder',
		     't' => 'n' },
 ''	=> { 'x' => 'thunder-storm',
		     't' => 'n' },
 ''	=> { 'x' => 'rich',
		     't' => 'a' },
 ''	=> { 'x' => 'far',
		     't' => 'a' },
 ''	=> { 'x' => 'two-coloured',
		     't' => 'a' },
 ''	=> { 'x' => 'double',
		     '#' => 'adjective or verb?' },
 ''		=> { 'x' => 'day' },
 ''	=> { 'x' => 'cheap',
		     't' => 'a' },
 ''	=> { 'x' => 'jeans',
		     '#' => 'plural?',
		     't' => 'n' },
 ''		=> { 'x' => 'melon' },
 ''	=> { 'x' => 'child',
		     '#' => 'person; animate',
		     't' => 'n' },
 ''	=> { 'x' => 'grandfather',
		     '#' => 'person; animate',
		     't' => 'n' },
 ''	=> { 'x' => 'certainly' },
 ''		=> { 'x' => 'children',
		     '#' => 'person; animate; plural?',
		     't' => 'n' },
 ''		=> { 'x' => 'day',
		     't' => 'n' },
# ' '	=> { 'x' => 'good-bye' },
# ''		=> { 'x' => 'pull' },
 ''		=> { 'x' => 'day',
		     '#' => 'twenty four hours',
		     't' => 'n' },
 ''	=> { 'x' => 'good',
		     't' => 'a' },
 ''	=> { 'x' => 'okay',
		     '#' => 'okey; adjective?' },
 ''	=> { 'x' => 'good',
		     't' => 'a' },
 ''	=> { 'x' => 'long',
		     't' => 'a' },
 ''	=> { 'x' => 'long',
		     't' => 'a' },
 ''	=> { 'x' => 'help',
		     't' => 'v' },
 ''	=> { 'x' => 'expensive',
		     't' => 'a' },
 ''	=> { 'x' => 'daughter',
		     '#' => 'animate; person',
		     't' => 'n' },
 ''		=> { 'x' => 'rain',
		     '#' => 'noun or verb?' },
 ''	=> { 'x' => 'fine' },
# ' '	=> { 'x' => 'thank-you very much' },
 ''	=> { 'x' => 'silly',
		     't' => 'a' },
 ''	=> { 'x' => 'sweltering heat' },
 ''	=> { 'x' => 'shower',
		     't' => 'n' },
 ''	=> { 'x' => 'uncle',
		     '#' => 'animate; person',
		     't' => 'n' },
 ''	=> { 'x' => 'thank-you' },
 ''	=> { 'x' => 'greasy',
		     't' => 'a' },
 ''	=> { 'x' => 'woman',
		     '#' => 'person; animate',
		     't' => 'n' },
 ''	=> { 'x' => 'yellow',
		     't' => 'a' },
 ''	=> { 'x' => 'orange',
		     't' => 'a' },
 ''	=> { 'x' => 'pleasure',
		     't' => 'n' },
 ''	=> { 'x' => 'smoke',
		     '#' => 'noun or verb?' },
 ''	=> { 'x' => 'invitation',
		     't' => 'n' },
 ''	=> { 'x' => 'closed',
		     't' => 'a' },
 ''	=> { 'x' => 'of course' },
 ''	=> { 'x' => 'agree',
		     '#' => 'for a man' },
 ''	=> { 'x' => 'agree',
		     '#' => 'for a woman' },
 ''	=> { 'x' => 'green',
		     't' => 'a' },
 ''		=> { 'x' => 'winter' },
 ''	=> { 'x' => 'downpour' },
 ''	=> { 'x' => 'familiar' },
 ''	=> { 'x' => 'station',
		     '#' => '(bus, tram, taxi)' },
 ''		=> { 'x' => 'son-in-law',
		     '#' => 'person; animate',
		     't' => 'n' },
 ''		=> { 'x' => 'caviar',
		     't' => 'n' },
 ''		=> { 'x' => 'hoarfrost',
		     '#' => '?' },
 ''		=> { 'x' => 'meal' },
 '\''	=> { 'x' => 'cafe' },
 ''		=> { 'x' => 'coffee' },
 ''	=> { 'x' => 'water-melon',
		     't' => 'n' },
 ''	=> { 'x' => 'cocoa',
		     't' => 'n' },
 ''	=> { 'x' => 'canada',
		     '#' => 'country; place',
		     't' => 'n' },
 ''	=> { 'x' => 'hat',
		     't' => 'n' },
 ''	=> { 'x' => 'cabbage',
		     't' => 'n' },
 ''	=> { 'x' => 'potatoes',
		     't' => 'n' },
 ''	=> { 'x' => 'potatoes',
		     '#' => 'plural',
		     't' => 'n' },
 ''		=> { 'x' => 'booking office',
		     '#' => 'cash-desk' },
 ''		=> { 'x' => 'cafe' },
 ''	=> { 'x' => 'glass',
		     '#' => 'noun or adjective?' },
 ''	=> { 'x' => 'sour',
		     't' => 'a' },
 ''		=> { 'x' => 'cinema',
		     't' => 'n' },
 ''	=> { 'x' => 'climate',
		     't' => 'n' },
 ''	=> { 'x' => 'book',
		     '#' => 'noun or verb?' },
 ''	=> { 'x' => 'sausage',
		     't' => 'n' },
 ''	=> { 'x' => 'sausage',
		     't' => 'n' },
 ''	=> { 'x' => 'coco' },
 ''	=> { 'x' => 'colour',
		     '#' => 'color' },
 ''	=> { 'x' => 'compote' },
 ''	=> { 'x' => 'cognac',
		     't' => 'n' },
 ''	=> { 'x' => 'brown',
		     't' => 'a' },
 ''	=> { 'x' => 'short',
		     't' => 'a' },
 ''	=> { 'x' => 'short',
		     't' => 'a' },
 ''	=> { 'x' => 'costume',
		     't' => 'n' },
 ''	=> { 'x' => 'jacket',
		     't' => 'n' },
 ''	=> { 'x' => 'shop',
		     '#' => 'small',
		     't' => 'n' },
 ''	=> { 'x' => 'beautiful',
		     't' => 'a' },
 ''	=> { 'x' => 'hen',
		     't' => 'n' },
 ''	=> { 'x' => 'jacket',
		     't' => 'n' },
 ''	=> { 'x' => 'chicken',
		     't' => 'n' },
 ''	=> { 'x' => 'chicken',
		     't' => 'n' },
 ''	=> { 'x' => 'easy',
		     't' => 'a' },
 ''	=> { 'x' => 'lemonade',
		     't' => 'n' },
 ''	=> { 'x' => 'lemonade',
		     't' => 'n' },
 ''	=> { 'x' => 'at the left' },
 ''		=> { 'x' => 'ice',
		     't' => 'n' },
 ''	=> { 'x' => 'liquor',
		     't' => 'n' },
 ''	=> { 'x' => 'lilac',
		     '#' => 'noun or possibly colour?' },
 ''		=> { 'x' => 'summer' },
 ''		=> { 'x' => 'lift',
		     '#' => 'elevator',
		     't' => 'n' },
 ''	=> { 'x' => 'spoon',
		     't' => 'n' },
 '\''	=> { 'x' => 'meat',
		     't' => 'n' },
 ''	=> { 'x' => 'shop',
		     't' => 'n' },
 ''	=> { 'x' => 'small',
		     't' => 'a' },
 ''		=> { 'x' => 'small',
		     '#' => 'not enough' },
 ''	=> { 'x' => 'oil',
		     't' => 'n' },
 ''		=> { 'x' => 'mother',
		     '#' => 'person; animate',
		     't' => 'n' },
 ''	=> { 'x' => 'step-mother',
		     '#' => 'person; animate',
		     't' => 'n' },
 ''	=> { 'x' => 'furniture',
		     't' => 'n' },
 ''	=> { 'x' => 'furniture',
		     't' => 'n' },
 ''		=> { 'x' => 'menu',
		     't' => 'n' },
 ''	=> { 'x' => 'metro',
		     '#' => 'underground',
		     't' => 'n' },
 ''	=> { 'x' => 'police',
		     't' => 'n' },
 ''	=> { 'x' => 'mineral' },
 ''	=> { 'x' => 'month' },
 ''	=> { 'x' => 'wet',
		     't' => 'a' },
 ''	=> { 'x' => 'young',
		     't' => 'a' },
 ''	=> { 'x' => 'carrots' },
 ''	=> { 'x' => 'frost' },
 ''	=> { 'x' => 'ice-cream' },
 ''	=> { 'x' => 'turbid' },
 '\''	=> { 'x' => 'soft',
		     't' => 'a' },
 '\''	=> { 'x' => 'meat' },
 ''	=> { 'x' => 'on the contrary' },
 ''	=> { 'x' => 'good night' },
 ''	=> { 'x' => 'back',
		     '#' => 'noun or adverb?' },
 ''	=> { 'x' => 'drinks' },
 ''	=> { 'x' => 'bride' },
 ''	=> { 'x' => 'daughter-in-law' },
 ''	=> { 'x' => 'unfamiliar' },
 ''	=> { 'x' => 'ugly',
		     't' => 'a' },
 ''	=> { 'x' => 'imbossible' },
 ''	=> { 'x' => 'no soon' },
 ''	=> { 'x' => 'tasteless' },
 ''	=> { 'x' => 'uninteresting' },
 ''	=> { 'x' => 'low',
		     't' => 'a' },
 ''	=> { 'x' => 'thread' },
 ''		=> { 'x' => 'knife' },
 ''	=> { 'x' => 'germany' },
 ''		=> { 'x' => 'night' },
 ''	=> { 'x' => 'new',
		     't' => 'a' },
 ''	=> { 'x' => 'scissors' },
 ''	=> { 'x' => 'room' },
 ''		=> { 'x' => 'night' },
 ''	=> { 'x' => 'boring' },
 '\''	=> { 'x' => 'detour' },
 ''		=> { 'x' => 'dinner' },
# ' '	=> { 'x' => 'currency exchange' },
 ''	=> { 'x' => 'vegetable' },
 ''	=> { 'x' => 'cucumber' },
 ''	=> { 'x' => 'one-colour' },
 ''	=> { 'x' => 'single' },
 ''		=> { 'x' => 'clothes' },
 ''	=> { 'x' => 'ice-covered-ground' },
 ''	=> { 'x' => 'glasses',
		     '#' => 'for eyes' },
 ''		=> { 'x' => 'grandson' },
 ''	=> { 'x' => 'precipitation' },
 ''	=> { 'x' => 'sturgeon' },
 ''	=> { 'x' => 'autumn' },
 ''		=> { 'x' => 'vinegar' },
 ''	=> { 'x' => 'smoking' },
 ''	=> { 'x' => 'coat' },
 ''	=> { 'x' => 'stockings',
		     '#' => 'plural?',
		     't' => 'n' },
 ''	=> { 'x' => 'umbrella',
		     't' => 'n' },
 ''	=> { 'x' => 'parking' },
 ''	=> { 'x' => 'passport',
		     't' => 'n' },
 ''	=> { 'x' => 'paste',
		     't' => 'n' },
 ''	=> { 'x' => 'interval',
		     '#' => 'break',
		     't' => 'n' },
 ''	=> { 'x' => 'cross',
		     '#' => '(the street, way etc)',
		     't' => 'v' },
 ''	=> { 'x' => 'hairdresser\'s shop',
		     '#' => 'barber\'s shop' },
 ''		=> { 'x' => 'beer',
		     't' => 'n' },
 ''		=> { 'x' => 'beer',
		     't' => 'n' },
 ''	=> { 'x' => 'midnight' },
 ''	=> { 'x' => 'jacket',
		     't' => 'n' },
 ''	=> { 'x' => 'lean',
		     't' => 'a' },
 ''	=> { 'x' => 'dress',
		     '#' => 'noun or verb?' },
 ''		=> { 'x' => 'raincoat',
		     't' => 'n' },
 ''	=> { 'x' => 'nephew',
		     '#' => 'person; animate',
		     't' => 'n' },
 ''	=> { 'x' => 'niece',
		     '#' => 'person; animate',
		     't' => 'n' },
 ''	=> { 'x' => 'larger',
		     't' => 'a' },
 ''	=> { 'x' => 'slow',
		     't' => 'a' },
 ''	=> { 'x' => 'slowly' },
 ''	=> { 'x' => 'full',
		     't' => 'a' },
 ''	=> { 'x' => 'bad',
		     't' => 'a' },
 ''	=> { 'x' => 'weather' },
 ''	=> { 'x' => 'cheaper',
		     't' => 'a' },
 ''	=> { 'x' => 'midday' },
 ''	=> { 'x' => 'smaller',
		     't' => 'a' },
 ''	=> { 'x' => 'tomato' },
 ''	=> { 'x' => 'in front' },
 ''	=> { 'x' => 'advice' },
 ''	=> { 'x' => 'empty' },
 ''	=> { 'x' => 'near' },
 ''	=> { 'x' => 'ugly' },
 ''	=> { 'x' => 'later on' },
 ''	=> { 'x' => 'trains' },
 ''	=> { 'x' => 'post' },
 ''	=> { 'x' => 'on the right' },
 ''	=> { 'x' => 'iron',
		     '#' => 'for clothes' },
 ''	=> { 'x' => 'perfect' },
 ''	=> { 'x' => 'hi' },
 ''	=> { 'x' => 'pleasant' },
 ''	=> { 'x' => 'natural' },
 ''	=> { 'x' => 'food-stuff' },
 ''	=> { 'x' => 'grocery' },
 ''	=> { 'x' => 'transparent' },
 ''	=> { 'x' => 'opposite' },
 ''	=> { 'x' => 'bye' },
 ''	=> { 'x' => 'direct' },
 ''		=> { 'x' => 'mashed' },
 ''	=> { 'x' => 'morning' },
 ''	=> { 'x' => 'morning' },
 ''	=> { 'x' => 'restaurant' },
 ''		=> { 'x' => 'fish' },
 ''	=> { 'x' => 'liquid' },
 ''		=> { 'x' => 'year' },
 ''	=> { 'x' => 'family' },
 ''	=> { 'x' => 'pink' },
 ''	=> { 'x' => 'divorced',
		     't' => 'a' },
 ''	=> { 'x' => 'clever',
		     't' => 'a' },
 ''		=> { 'x' => 'rum' },
 ''	=> { 'x' => 'roast beef' },
 ''	=> { 'x' => 'towel' },
 ''	=> { 'x' => 'rucksack' },
 ''	=> { 'x' => 'salad' },
 ''	=> { 'x' => 'sweater' },
 ''	=> { 'x' => 'pork' },
 ''	=> { 'x' => 'light',
		     '#' => 'noun or adjective?' },
 ''	=> { 'x' => 'light',
		     '#' => 'noun or adjective?' },
 ''	=> { 'x' => 'second',
		     '#' => 'unit of time' },
 ''	=> { 'x' => 'napkin' },
 ''	=> { 'x' => 'sister' },
 ''	=> { 'x' => 'strong',
		     't' => 'a' },
 ''		=> { 'x' => 'son',
		     '#' => 'person; animate',
		     't' => 'n' },
 ''	=> { 'x' => 'dark blue',
		     't' => 'a' },
 ''		=> { 'x' => 'cheese',
		     't' => 'n' },
 ''		=> { 'x' => 'cheese',
		     't' => 'n' },
 ''		=> { 'x' => 'juice',
		     't' => 'n' },
 ''		=> { 'x' => 'salt',
		     't' => 'n' },
 ''	=> { 'x' => 'grey',
		     '#' => 'gray',
		     't' => 'a' },
 ''	=> { 'x' => 'glass',
		     '#' => 'noun or adjective?' },
 ''	=> { 'x' => 'weak',
		     't' => 'a' },
 ''	=> { 'x' => 'fried',
		     't' => 'a' },
 ''	=> { 'x' => 'tasty',
		     't' => 'a' },
 ''	=> { 'x' => 'sad',
		     't' => 'a' },
 ''		=> { 'x' => 'snow',
		     '#' => 'noun or verb?' },
 ''	=> { 'x' => 'snowfall',
		     't' => 'n' },
 ''	=> { 'x' => 'breakfast',
		     't' => 'n' },
 ''		=> { 'x' => 'juice',
		     't' => 'n' },
 ''	=> { 'x' => 'sweet',
		     't' => 'a' },
 ''	=> { 'x' => 'salty' },
 ''	=> { 'x' => 'sun' },
 ''	=> { 'x' => 'shirt' },
 ''	=> { 'x' => 'sausage' },
 ''		=> { 'x' => 'sauce' },
 ''	=> { 'x' => 'thanks' },
 ''	=> { 'x' => 'heat' },
 ''	=> { 'x' => 'skirt' },
 ''	=> { 'x' => 'station',
		     '#' => '(metro, railway)' },
 ''	=> { 'x' => 'old',
		     't' => 'a' },
 ''	=> { 'x' => 'article' },
 ''		=> { 'x' => 'stop' },
 ''	=> { 'x' => 'spotted',
		     't' => 'a' },
 ''	=> { 'x' => 'souvenirs' },
 ''	=> { 'x' => 'bag' },
 ''	=> { 'x' => 'worry' },
 ''		=> { 'x' => 'soup' },
 ''	=> { 'x' => 'supermarket' },
 ''	=> { 'x' => 'dry',
		     't' => 'a' },
 ''		=> { 'x' => 'usa' },
 ''	=> { 'x' => 'taxi' },
 ''	=> { 'x' => 'plate' },
 ''	=> { 'x' => 'rigid',
		     't' => 'a' },
 ''	=> { 'x' => 'theatre' },
 ''	=> { 'x' => 'tv' },
 ''	=> { 'x' => 'telegraph' },
 ''	=> { 'x' => 'telephone',
		     '#' => 'noun or verb?' },
 ''	=> { 'x' => 'telephone',
		     '#' => 'noun or verb?' },
 ''	=> { 'x' => 'dark',
		     't' => 'a' },
 ''	=> { 'x' => 'dark',
		     't' => 'a' },
 ''	=> { 'x' => 'temperature',
		     't' => 'n' },
 ''	=> { 'x' => 'thermometer',
		     't' => 'n' },
 ''	=> { 'x' => 'father-in-law',
		     '#' => 'person; animate',
		     't' => 'n' },
 ''		=> { 'x' => 'mother-in-law',
		     '#' => 'person; animate',
		     't' => 'n' },
 ''	=> { 'x' => 'week',
		     't' => 'n' },
 ''		=> { 'x' => 'pressure',
		     't' => 'n' },
 ''	=> { 'x' => 'silent',
		     't' => 'a' },
 ''	=> { 'x' => 'cake',
		     't' => 'n' },
 ''	=> { 'x' => 'aunt',
		     't' => 'n' },
 ''	=> { 'x' => 'fabric',
		     't' => 'n' },
 ''	=> { 'x' => 'fabrics',
		     't' => 'n' },
 ''	=> { 'x' => 'thick',
		     't' => 'a' },
 ''	=> { 'x' => 'thin',
		     't' => 'a' },
 ''		=> { 'x' => 'pie' },
 ''	=> { 'x' => 'tram' },
 ''	=> { 'x' => 'happen' },
 ''	=> { 'x' => 'crash' },
 ''	=> { 'x' => 'trolleybus' },
 ''	=> { 'x' => 'cowards' },
 ''	=> { 'x' => 'toilet' },
 ''	=> { 'x' => 'toilet' },
 ''	=> { 'x' => 'fog' },
 ''	=> { 'x' => 'blunt',
		     't' => 'a' },
 ''	=> { 'x' => 'shoe' },
 ''	=> { 'x' => 'attention' },
 ''	=> { 'x' => 'come in' },
 ''	=> { 'x' => 'widower' },
 ''	=> { 'x' => 'widow' },
 ''	=> { 'x' => 'forward' },
 ''	=> { 'x' => 'hurricane' },
 ''		=> { 'x' => 'fan',
		     '#' => 'for hair?' },
 ''	=> { 'x' => 'violet',
		     't' => 'a' },
 ''	=> { 'x' => 'trout' },
 ''	=> { 'x' => 'france' },
 ''	=> { 'x' => 'fruit' },
 ''	=> { 'x' => 'dressing gown' },
 ''	=> { 'x' => 'minute' },
 ''		=> { 'x' => 'bread' },
 ''	=> { 'x' => 'cold' },
 ''	=> { 'x' => 'refrigerator' },
 ''	=> { 'x' => 'cold',
		     't' => 'a' },
 ''	=> { 'x' => 'bachelor',
		     '#' => 'person; animate',
		     't' => 'n' },
 ''	=> { 'x' => 'blizzard',
		     't' => 'n' },
 ''	=> { 'x' => 'handkerchief',
		     't' => 'n' },
 ''	=> { 'x' => 'onions',
		     't' => 'n' },
 ''	=> { 'x' => 'interesting',
		     't' => 'a' },
 ''		=> { 'x' => 'tea',
		     't' => 'n' },
 ''	=> { 'x' => 'wine-glass',
		     't' => 'n' },
 ''	=> { 'x' => 'garlic',
		     't' => 'n' },
 ''	=> { 'x' => 'red',
		     't' => 'a' },
 ''	=> { 'x' => 'red',
		     't' => 'a' },
 ''	=> { 'x' => 'boots',
		     't' => 'n' },
 ''	=> { 'x' => 'clean',
		     '#' => 'adjective or verb?' },
 ''	=> { 'x' => 'high boots',
		     't' => 'n' },
 ''	=> { 'x' => 'husband',
		     '#' => 'person; animate',
		     't' => 'n' },
 ''	=> { 'x' => 'man',
		     '#' => 'person; animate',
		     't' => 'n' },
 ''	=> { 'x' => 'black',
		     't' => 'a' },
 ''	=> { 'x' => 'champagne' },
 ''	=> { 'x' => 'cap' },
 ''		=> { 'x' => 'scarf' },
 ''	=> { 'x' => 'fast',
		     't' => 'a' },
 ''	=> { 'x' => 'quickly' },
 ''	=> { 'x' => 'ham' },
 ''	=> { 'x' => 'wide',
		     't' => 'a' },
 ''	=> { 'x' => 'wide',
		     't' => 'a' },
 ''	=> { 'x' => 'leather' },
 ''	=> { 'x' => 'sorry' },
 ''		=> { 'x' => 'marriage' },
 ''	=> { 'x' => 'schnitzel' },
 ''	=> { 'x' => 'lace' },
 ''		=> { 'x' => 'silk' },
 ''	=> { 'x' => 'rough',
		     't' => 'a' },
 ''	=> { 'x' => 'shorts' },
 ''		=> { 'x' => 'highway' },
 ''	=> { 'x' => 'suit trousers' },
 ''	=> { 'x' => 'artificial' },
 ''		=> { 'x' => 'fur coat' },
 ''	=> { 'x' => 'fried eggs' },
 ''	=> { 'x' => 'beef' },
 '-'	=> { 'x' => 'scarlet' },
);
}

1;

