# vi: ts=8 sw=8 sts=8

package Tongues::BahasaMalaysia;

use strict;
use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $charset $grammar %dictionary);

use Exporter   ();
# set the version for version checking
@ISA         = qw(Exporter);
@EXPORT      = qw(charset grammar dictionary);
@EXPORT_OK   = qw();
$VERSION     = 0.00;

# Character set Windows Western European CP1252 / ISO 8859-1 / Latin-1

# Alphabetical order
# A B C D E F G H I J K L M N O P Q R S T U V W X Y Z
# a b c d e f g h i j k l m n o p q r s t u v w x y z

sub new {
	my $class = shift;
	my $self = bless {}, $class;
	return $self;
}

sub charset {
	return $charset;
}

sub grammar {
	return $grammar;
}

sub dictionary {
	return \%dictionary;
}

sub BEGIN {

require Charsets::WestEuroWin;

$charset = new Charsets::WestEuroWin;

# Table for converting words to root form
$grammar = [
 # Noun case
 # Noun gender
 # Noun plural
 # Adjectives
 # Verb past participle
 # Verb gerund
 # Verb present participle
 # Verb present
 # Verb present subjunctive
 # Verb imperitive
 # Verb preterite
 # Verb imperfect
 # Verb future
 # Verb conditional
 # Adverb
 # Higher level transformations
];

#Fields:
# x -> translatioin		all words
# r -> root			irregular declensions
# t -> type:			all words
#	n -> noun
#	v -> verb
#	a -> adjective
#	p -> preposition
#	art -> article
#	pro -> pronoun
#	conj -> conjugation
#	adv -> adverb
# g -> gender:			nouns, pronouns, adjectives
#	m -> masculine		default
#	f -> feminine
# n -> number:			articles, pronouns, verbs, adjectives
#	s -> singular		default
#	d -> dual
#	t -> trial
#	p -> plural
# p -> person:			pronouns, verbs
#	1 -> 1st person
#	2 -> 2nd person
#	3 -> 3rd person		default
# c -> conjugation:
#	p -> present
#	i -> imperfect
#	f -> future
#	c -> conditional
#	t -> preterite
#	ps -> present subjunctive
#	is -> imperfect subjunctive
#	inf -> infinitive		default
#	pp -> past participle
#	g -> gerund
#	imp -> imperative
# c -> case:
#	n -> nominative 		default
#	a -> accusative 
# df -> derived from

# BahasaMalaysia to English dictionary
%dictionary = (
 # Functional words
 #  Articles
 #   Definite articles
 #    Masculine
 #     Singular
 #     Plural
 #    Feminine
 #     Singular
 #     Plural
 #   Indefinite articles
 #  Pronouns & possessive adjectives
 #   1st person
 'saya'		=> { 'x' => 'i',
		     '#' => 'me',
		     't' => 'pro',
		     'p' => '1',
		     'n' => 's' },
 'patik'	=> { 'x' => 'i',
		     '#' => 'me (used when talking to royal person)' },
 'kita'		=> { 'x' => 'we',
		     '#' => 'us; inclusive',
		     't' => 'pro',
		     'p' => '1',
		     'n' => 'p' },
 'kami'		=> { 'x' => 'we',
		     '#' => 'us; exclusive',
		     't' => 'pro',
		     'p' => '1',
		     'n' => 'p' },
# 'ku'		=> { 'x' => 'i; me (abbreviation of "aku")' },
 #   2nd person
 'anda'		=> { 'x' => 'you',
		     '#' => 'formal',
		     't' => 'pro',
		     'p' => '2' },
 'saudara'	=> { 'x' => 'you',
		     '#' => 'polite',
		     't' => 'pro',
		     'p' => '2' },
 'kamu'		=> { 'x' => 'you',
		     '#' => 'familiar',
		     't' => 'pro',
		     'p' => '2' },
# 'mu'		=> { 'x' => 'you; abbreviation of "kamu"' },
 #   3rd person
 'dia'		=> { 'x' => 'he',
		     '#' => 'she',
		     't' => 'pro',
		     'p' => '3',
		     'n' => 's' },
 'mereka'	=> { 'x' => 'they',
		     '#' => 'them',
		     't' => 'pro',
		     'p' => '3',
		     'n' => 'p' },
 'beliau'	=> { 'x' => 'he/she',
		     '#' => 'he or she' },
 #   Other pronouns
 #  Interrogatives
 'apa'		=> { 'x' => 'what',
		     '#' => 'interr. pronoun',
		     't' => 'pro' },
 'bagaimana'	=> { 'x' => 'how',
		     '#' => 'interr.',
		     't' => 'adv' },
 'berapa'	=> { 'x' => 'how much',
		     '#' => 'interr.',
		     't' => 'a' },
 'bila'		=> { 'x' => 'when',
		     '#' => 'interr.',
		     't' => 'adv' },
 'kenapa'	=> { 'x' => 'why',
		     '#' => 'interr.',
		     't' => 'adv' },
 'mana'		=> { 'x' => 'where',
		     '#' => 'interr.',
		     't' => 'adv' },
 'siapa'	=> { 'x' => 'who',
		     '#' => 'interr. pronoun',
		     't' => 'pro' },
# 'yang mana'	=> { 'x' => 'which',
#		     '#' => 'interr. and adv.; multiword',
# 		     't' => 'pro' },

 #  Other functional words
 'adakalanya'	=> { 'x' => 'sometimes',
		     't' => 'adv',
		     'df' => 'ada' },
 'adapun'	=> { 'x' => 'with regard to',
		     't' => 'p',
		     'df' => 'ada' },
# 'aduhai'	=> { 'x' => 'exclamation of sorrow' },
# 'agar'		=> { 'x' => 'so that' },
# 'ah'		=> { 'x' => 'exclamation of surprise' },
# 'aha'		=> { 'x' => 'exclamation of triumph' },
 'amin'		=> { 'x' => 'amen',
		     '#' => 'so be it' },
 'anda'		=> { 'x' => 'you' },
 'anti'		=> { 'x' => 'against',
		     '#' => 'opposed to, counteracting; against',
		     't' => 'p' },
# 'anu'		=> { 'x' => 'so and so' },
 'banyak'	=> { 'x' => 'much',
		     '#' => 'many' },
 'begini'	=> { 'x' => 'like this' },
 'begitu'	=> { 'x' => 'like that',
		     '#' => 'so' },
 'belaka'	=> { 'x' => 'altogether',
		     '#' => '; entirely; quite' },
 'betapa'	=> { 'x' => 'how',
		     '#' => 'emphasising the degree',
		     'x-es' => 'qué' },
# 'boo'		=> { 'x' => 'exclamation of disapproval' },
 'demikian'	=> { 'x' => 'thus',
		     '#' => '; hence; therefore' },
 'dengan'	=> { 'x' => 'with' },
 'di'		=> { 'x' => 'at' },
 'dia'		=> { 'x' => 'he or she',
		     '#' => 'him or her; it; his' },
 'dikau'	=> { 'x' => 'you' },
# 'eh'		=> { 'x' => 'exclamation of enquiry' },
 'hingga'	=> { 'x' => 'till',
		     '#' => '; until' },
 'iaitu'	=> { 'x' => 'namely',
		     '#' => 'that is to say' },
 'ialah'	=> { 'x' => 'is',
		     '#' => '; are' },
 'jika'		=> { 'x' => 'if' },
 'jikalau'	=> { 'x' => 'if' },
 'justeru'	=> { 'x' => 'hence',
		     '#' => 'for this reason' },
 'kara'		=> { 'x' => 'all alone' },
 'kenapa'	=> { 'x' => 'why' },
 'kendati'	=> { 'x' => 'although' },
 'lepas'	=> { 'x' => 'after',
		     '#' => 'past (2)to free',
		     't' => 'p' },
 'maka'		=> { 'x' => 'then',
		     '#' => '; therefore; hence; so' },
# 'mahupun'	=> { 'x' => '(1)although (2)either/or' },
 'mana'		=> { 'x' => 'where' },
# 'mana satu'	=> { 'x' => 'which one' },
 'mana-mana'	=> { 'x' => 'anywhere',
		     '#' => 'wherever' },
# 'masing-masing'	=> { 'x' => 'each and everyone' },
 'meskipun'	=> { 'x' => 'although',
		     '#' => 'in spite of' },
 'nya'		=> { 'x' => 'his',
		     '#' => '; her; its' },
# 'oh'		=> { 'x' => 'exclamation of delight, pain or emphasis' },
# 'oi'		=> { 'x' => 'a shout for attention' },
# 'ooh'		=> { 'x' => 'exclamation of surprise, pleasure or pain' },
 'pada'		=> { 'x' => 'at',
		     '#' => 'on; in; to; according to' },
 'paling'	=> { 'x' => 'extremely',
		     '#' => '(1)the most (2)to turn away',
		     't' => 'adv' },
 'puan'		=> { 'x' => 'lady',
		     '#' => 'mrs (2)plate for betel-leaf',
		     't' => 'n' },
 'pula'		=> { 'x' => 'again',
		     '#' => '; also; yet; too' },
 'saban'	=> { 'x' => 'every' },
 'sampai'	=> { 'x' => 'reach',
		     '#' => '(verb); to arrive (2)till; until' },
 'sangat'	=> { 'x' => 'very',
		     '#' => '; extremely' },
 'sebanyak'	=> { 'x' => 'as much as',
		     '#' => '; as many as',
		     'df' => 'banyak' },
 'sebanyak-banyaknya'	=> { 'x' => 'at the most',
			     'df' => 'banyak' },
# 'sedang'	=> { 'x' => '(1)to be in the process of',
#		     '#' => 'while (2)medium (size); average; sufficient' },
 'segala'	=> { 'x' => 'all',
		     '#' => '; entire; whole; every' },
 'segala-galanya'	=> { 'x' => 'everything' },
 'sejak'	=> { 'x' => 'since' },
# 'sekaligus'	=> { 'x' => 'all at once' },
 'sekalipun'	=> { 'x' => 'although' },
 'selalu'	=> { 'x' => 'always' },
 'semesta'	=> { 'x' => 'all',
		     '#' => 'entire; the whole' },
 'sempena'	=> { 'x' => 'in conjunction with',
		     '#' => 'in commemoration of' },
 'semua'	=> { 'x' => 'all' },
 'semuanya'	=> { 'x' => 'wholly',
		     '#' => '; entirely' },
# 'sendiri'	=> { 'x' => 'alone; on one\'s own' },
 'sendiri-sendiri'	=> { 'x' => 'each',
		     '#' => 'individually' },
 'sentiasa'	=> { 'x' => 'always' },
 'seraya'	=> { 'x' => 'while',
		     '#' => '; simultaneously' },
 'serba'	=> { 'x' => 'all' },
 'serba aneka'	=> { 'x' => 'various',
		     '#' => 'all sorts' },
# 'serba-serbi'	=> { 'x' => 'various sorts' },
# 'seri paduka'	=> { 'x' => 'his majesty' },
 'sering'	=> { 'x' => 'often',
		     '#' => '; frequently' },
 'seringkali'	=> { 'x' => 'often',
		     '#' => '; frequently' },
# 'serta'	=> { 'x' => '(1)together with',
#		     '#' => 'along with (2)as soon as' },
# 'seruan'	=> { 'x' => 'an exclamation' },
 'sini'		=> { 'x' => 'here' },
 'supaya'	=> { 'x' => 'so that',
		     '#' => 'in order to' },
 'syahdan'	=> { 'x' => 'meanwhile',
		     '#' => '; then; furthermore; moreover' },
 'tuanku'	=> { 'x' => 'sir',
		     '#' => '(to royalty), your highness' },
 'telah'	=> { 'x' => 'already',
		     '#' => 'have; did; has (2)to forecast; to predict' },
 'terbanyak'	=> { 'x' => 'the most',
		     'df' => 'banyak' },
# 'terima kasih'	=> { 'x' => 'thank you' },
 'tetapi'	=> { 'x' => 'but',
		     '#' => '; yet' },
 'tiada'	=> { 'x' => 'no',
		     '#' => 'not; not any' },
 'tiap'		=> { 'x' => 'every',
		     '#' => '; each' },
 'tidak'	=> { 'x' => 'no',
		     '#' => '; not' },
# 'tidak apa'	=> { 'x' => 'never mind' },
 'walaupun'	=> { 'x' => 'although' },
 'walhal'	=> { 'x' => 'in fact' },
 'walhasil'	=> { 'x' => 'eventually',
		     '#' => 'finally ' },
 'yang'		=> { 'x' => 'who',
		     '#' => '; which; that' },
 #   Partitive / Contractions
 # Numbers: cardinal and ordinal
 'tiga'		=> { 'x' => 'three' },
 'lima'		=> { 'x' => 'five' },
 'panca'	=> { 'x' => 'five' },
 'enam'		=> { 'x' => 'six' },
 'tujuh'	=> { 'x' => 'seven' },
 'delapan'	=> { 'x' => 'eight' },
 'sembilan'	=> { 'x' => 'nine' },
 'puluh'	=> { 'x' => 'ten' },
 'ratus'	=> { 'x' => 'hundred' },
 'ribu'		=> { 'x' => 'thousand' },
 # Days and months
 'ahad'		=> { 'x' => 'sunday' },
 'isnin'	=> { 'x' => 'monday' },
 'selasa'	=> { 'x' => 'tuesday' },
 'rabu'		=> { 'x' => 'wednesday',
		     '#' => 'from online malay dictionary' },
 'rahu'		=> { 'x' => 'wednesday',
		     '#' => 'from http://oss.software.ibm.com/cgi-bin/icu/lx/en_AU/?_=ms&' },
 'khamis'	=> { 'x' => 'thursday' },
 'jumaat'	=> { 'x' => 'friday' },
 'sabtu'	=> { 'x' => 'saturday' },
 'januari'	=> { 'x' => 'january' },
 'februari'	=> { 'x' => 'february' },
 'mac'		=> { 'x' => 'march' },
 'april'	=> { 'x' => 'april' },
 'mei'		=> { 'x' => 'may' },
 'jun'		=> { 'x' => 'june' },
 'julai'	=> { 'x' => 'july' },
 'ogos'		=> { 'x' => 'august' },
 'september'	=> { 'x' => 'september' },
 'oktober'	=> { 'x' => 'october' },
 'november'	=> { 'x' => 'november' },
 'disember'	=> { 'x' => 'december' },
# 'muharam'	=> { 'x' => 'first month of muslim calendar' },
# 'rabiulawal'	=> { 'x' => 'third month of the muslim calendar' },
# 'rabiulakhir'	=> { 'x' => 'fourth month of the muslim calendar' },
# 'jamadilawal'	=> { 'x' => 'fifth month of the muslim calendar' },
# 'jamadilakhir'	=> { 'x' => 'sixth month of the muslim calendar' },
# 'rejab'	=> { 'x' => 'the seventh month of the muslim calendar' },
# 'syaaban'	=> { 'x' => 'eighth month of the muslim calendar' },
# 'ramadan'	=> { 'x' => 'ninth month of the muslim calendar (the fasting month)' },
# 'syawal'	=> { 'x' => 'tenth month of the muslim calendar' },
# 'zulkaedah'	=> { 'x' => 'the eleventh month of the muslim calendar' },
# 'zulhijah'	=> { 'x' => 'the twelfth month of the muslim calendar' },
 # Key verbs
 'ada'		=> { 'x' => 'have',
		     '#' => 'possess; contain',
		     't' => 'v' },
 'adalah'	=> { 'x' => 'be',
		     '#' => 'is; are; am; was; were',
		     't' => 'v',
		     'df' => 'ada' },
 'wujud'	=> { 'x' => 'exist',
		     '#' => 'become visible; become a fact',
		     't' => 'v' },
 'semayam'	=> { 'x' => 'reside',
		     '#' => 'to sit; to rest (of rulers)',
		     't' => 'v' },
 'pergi'	=> { 'x' => 'go',
		     't' => 'v' },
 'laku'		=> { 'x' => 'happen',
		     '#' => 'to occur (2)marketable',
		     't' => 'v' },
 # Vocabulary
 'abah'		=> { 'x' => 'father' },
 'abah-abah'	=> { 'x' => 'harness' },
 'abjad'	=> { 'x' => 'alphabet' },
 'abuk'		=> { 'x' => 'dust' },
 'abung'	=> { 'x' => 'pomelo' },
 'acapkali'	=> { 'x' => 'often' },
 'acar'		=> { 'x' => 'pickle' },
 'aci'		=> { 'x' => 'shaft' },
 'adas'		=> { 'x' => 'fennel' },
 'adegan'	=> { 'x' => 'scene' },
 'adib'		=> { 'x' => 'well-mannered',
		     't' => 'a' },
# 'adikung'	=> { 'x' => 'assistant officer' },
# 'adinda'	=> { 'x' => 'younger sibling',
#		     '#' => 'younger brother or sister (esp. in letter-writing)' },
 'afrit'	=> { 'x' => 'goblin',
		     '#' => 'mischievous elf or spirit' },
 'agam'		=> { 'x' => 'immeasurable',
		     '#' => '; immense',
		     't' => 'a' },
 'agar-agar'	=> { 'x' => 'jelly',
		     't' => 'n' },
 'agas'		=> { 'x' => 'gnat',
		     '#' => '; sandfly',
		     't' => 'n' },
 'aguk'		=> { 'x' => 'pendant',
		     't' => 'a' },
 'ahmak'	=> { 'x' => 'stupid',
		     't' => 'a' },
 'ajal'		=> { 'x' => 'doom',
		     '#' => '; death',
		     't' => 'n' },
# 'akaid'	=> { 'x' => 'religious dogma' },
 'akhbar'	=> { 'x' => 'newspaper',
		     't' => 'n' },
 'akhirat'	=> { 'x' => 'eternity',
		     '#' => 'the next world; life after death',
		     't' => 'n' },
 'akhlak'	=> { 'x' => 'behaviour',
		     '#' => '; character; morals',
		     't' => 'n' },
 'akidah'	=> { 'x' => 'belief',
		     '#' => '; faith; confidence',
		     't' => 'n' },
# 'akikah'	=> { 'x' => 'head-shaving of an infant' },
# 'akrab'	=> { 'x' => 'intimate in relationship' },
 'akta'		=> { 'x' => 'act',
		     '#' => 'law passed by legislative body',
		     't' => 'n' },
 'akusaksi'	=> { 'x' => 'attest',
		     't' => 'v' },
 'alabangka'	=> { 'x' => 'crowbar',
		     't' => 'n' },
 'algojo'	=> { 'x' => 'hangman',
		     '#' => '; executioner',
		     't' => 'n' },
 'alim'		=> { 'x' => 'learned',
		     '#' => '; pious; religious',
		     't' => 'a' },
 'alis'		=> { 'x' => 'eyebrow',
		     't' => 'n' },
 'aliterasi'	=> { 'x' => 'alliteration',
		     't' => 'n' },
# 'alkisah'	=> { 'x' => 'the story is that' },
# 'allah'	=> { 'x' => 'muslim name for god' },
 'allahyarham'	=> { 'x' => 'the late',
		     '#' => 'the deceased' },
# 'almarhum'	=> { 'x' => 'the late (for male royalty)' },
# 'almarhumah'	=> { 'x' => 'the late (for female royalty)' },
 'almari'	=> { 'x' => 'cupboard',
		     't' => 'n' },
 'alpukat'	=> { 'x' => 'avocado',
		     't' => 'n' },
 'alur'		=> { 'x' => 'groove',
		     '#' => '; furrow',
		     't' => 'n' },
 'am'		=> { 'x' => 'common',
		     '#' => 'general (not detailed or specific)',
		     't' => 'a' },
 'amah'		=> { 'x' => 'maid',
		     '#' => 'female housekeeper',
		     't' => 'n' },
 'amanat'	=> { 'x' => 'commendation' },
 'amaran'	=> { 'x' => 'warning' },
 'amboi'	=> { 'x' => 'oh!' },
 'ambung'	=> { 'x' => 'back-basket' },
# 'amir'		=> { 'x' => 'emir (muslim ruler or commander)' },
 'anai, anai-anai'	=> { 'x' => 'termite' },
 'andas'	=> { 'x' => 'anvil',
		     '#' => 'chopping block' },
# 'anduh'	=> { 'x' => 'suspend by means of a sling' },
 'aneh'		=> { 'x' => 'bizarre',
		     '#' => '; odd; unconventional; funny; strange' },
 'angau'	=> { 'x' => 'lovesick' },
 'anggerik'	=> { 'x' => 'orchid' },
# 'angkara'	=> { 'x' => 'bad or nasty behaviour' },
 'angkup'	=> { 'x' => 'callipers',
		     '#' => '; pincers; forceps' },
 'angsa'	=> { 'x' => 'goose' },
 'anjing'	=> { 'x' => 'dog' },
# 'anjung'	=> { 'x' => 'projecting facade (of a building)' },
# 'anjungan'	=> { 'x' => 'bridge (platform on a ship)' },
# 'antah'	=> { 'x' => 'rice grains left unhusked after pounding' },
 'antan'	=> { 'x' => 'pestle' },
 'antarabangsa'	=> { 'x' => 'international' },
 'ara'		=> { 'x' => 'fig' },
 'aral'		=> { 'x' => 'obstacle',
		     '#' => '; hinderance; difficulty' },
 'aras'		=> { 'x' => 'level',
		     't' => 'n' },
 'arca'		=> { 'x' => 'image',
		     '#' => '; picture' },
 'arkib'	=> { 'x' => 'archives' },
 'arloji'	=> { 'x' => 'clock',
		     '#' => '; watch' },
 'arnab'	=> { 'x' => 'rabbit' },
# 'arus'		=> { 'x' => 'current (flow) of water, air or electricity' },
# 'arwah'	=> { 'x' => 'late (no longer living)' },
 'asa'		=> { 'x' => 'hope' },
 'asar'		=> { 'x' => 'afternoon' },
 'asasi'	=> { 'x' => 'basic',
		     '#' => '; fundamental' },
 'askar'	=> { 'x' => 'soldier' },
 'asrama'	=> { 'x' => 'hostel' },
 'astaka'	=> { 'x' => 'pavilion' },
 'atuk'		=> { 'x' => 'grandfather' },
 'aur'		=> { 'x' => 'bamboo' },
# 'aurat'	=> { 'x' => 'parts of the body that should not be exposed according to islamic belief' },
 'auta'		=> { 'x' => 'bluff',
		     '#' => '; deceit' },
 'awam'		=> { 'x' => 'civil',
		     '#' => '; public; common; general' },
 'ayak-ayak'	=> { 'x' => 'crane-fly' },
 'ayan'		=> { 'x' => 'tin',
		     '#' => 'corrugated iron' },
# 'ayat'		=> { 'x' => 'sentence (set of words)' },
# 'ayatullah'	=> { 'x' => 'senior muslim religious leader' },
 'ayu'		=> { 'x' => 'pretty' },
# 'azali'	=> { 'x' => 'from time immemorial' },
# 'azan'		=> { 'x' => 'a muslim call to prayer' },
 'azimat'	=> { 'x' => 'talisman' },

 'bab'		=> { 'x' => 'chapter' },
 'babad'	=> { 'x' => 'chronicle' },
 'babak'	=> { 'x' => 'act',
		     '#' => 'or scene(of a play), episode; section of a long piece of music',
		     't' => 'n' },
 'babi'		=> { 'x' => 'pig' },
 'badai'	=> { 'x' => 'hurricane' },
 'badak'	=> { 'x' => 'rhinoceros' },
 'badam'	=> { 'x' => 'almond' },
 'badik'	=> { 'x' => 'dagger' },
 'badut'	=> { 'x' => 'clown',
		     '#' => '; comedian' },
 'badui'	=> { 'x' => 'bedouin' },
 'bagasi'	=> { 'x' => 'baggage',
		     '#' => '; cargo' },
 'baghal'	=> { 'x' => 'mule' },
# 'baginda'	=> { 'x' => 'his or her majesty' },
# 'bagur'	=> { 'x' => 'large and clumsy' },
 'bagus'	=> { 'x' => 'nice',
		     '#' => '; pleasant; good' },
 'bah'		=> { 'x' => 'deluge',
		     '#' => '; flood' },
# 'bahana'	=> { 'x' => 'loud noise or sound' },
# 'bahantara'	=> { 'x' => 'medium (environment)' },
 'bahasa'	=> { 'x' => 'language',
		     't' => 'n' },
 'bahari'	=> { 'x' => 'ancient' },
 'bahawa'	=> { 'x' => 'that' },
 'bahkan'	=> { 'x' => 'moreover' },
 'bahlul'	=> { 'x' => 'inane',
		     '#' => '; silly' },
 'bahu'		=> { 'x' => 'shoulder' },
 'baiduri'	=> { 'x' => 'opal' },
 'bait'		=> { 'x' => 'couplet',
		     '#' => 'a poem with two lines',
		     't' => 'n' },
 'baitulmal'	=> { 'x' => 'treasury' },
 'bajingan'	=> { 'x' => 'scoundrel',
		     '#' => '; rascal' },
 'bak'		=> { 'x' => 'like',
		     '#' => '; similar' },
 'bakal'	=> { 'x' => 'future',
		     '#' => 'aspirant; destined to become',
		     't' => 'a' },
 'bakau'	=> { 'x' => 'mangrove' },
# 'bakawali'	=> { 'x' => 'a medicinal herbal plant' },
 'bakhil'	=> { 'x' => 'stingy',
		     '#' => '; miserly' },
 'bakul'	=> { 'x' => 'basket' },
# 'bakung'	=> { 'x' => 'amaryllis (lily-like plant)' },
 'bala'		=> { 'x' => 'disaster',
		     '#' => '; calamity' },
 'balada'	=> { 'x' => 'ballad' },
# 'balang'	=> { 'x' => 'flagon (vessel with lid, lip and handle for serving wine)' },
 'balar'	=> { 'x' => 'albino' },
 'baldi'	=> { 'x' => 'pail',
		     '#' => '; bucket' },
 'baldu'	=> { 'x' => 'velvet' },
 'baligh'	=> { 'x' => 'puberty' },
 'baling-baling'	=> { 'x' => 'propeller',
		     '#' => 'wind-vane' },
 'balu'		=> { 'x' => 'widow' },
 'baluarti'	=> { 'x' => 'bulwark',
		     '#' => 'stone wall of defence' },
# 'balung'	=> { 'x' => 'comb (of fowl)' },
 'bandela'	=> { 'x' => 'bale',
		     '#' => 'large bundle' },
 'banduan'	=> { 'x' => 'convict',
		     '#' => '; prisoner' },
 'bangang'	=> { 'x' => 'duff',
		     '#' => '; stupid' },
 'bangat'	=> { 'x' => 'fast',
		     '#' => '; quick' },
 'bangau'	=> { 'x' => 'stork',
		     '#' => '; flamingo' },
 'banggul'	=> { 'x' => 'hillock',
		     '#' => '; mound' },
 'bangkai'	=> { 'x' => 'carcass' },
 'bangku'	=> { 'x' => 'bench',
		     '#' => '; stool' },
 'bangsal'	=> { 'x' => 'barn',
		     '#' => '; shed' },
 'bangsat'	=> { 'x' => 'vagrant',
		     '#' => '; scoundrel' },
 'bangsawan'	=> { 'x' => 'nobility',
		     '#' => 'high class or rank; malay opera',
		     't' => 'n' },
# 'bangsi'	=> { 'x' => 'bamboo flute' },
# 'banyak-banyak'	=> { 'x' => 'in large quantities',
#			     'df' => 'banyak' },
 'banyaknya'	=> { 'x' => 'amount',
		     '#' => '; a large number of',
		     't' => 'n',
		     'df' => 'banyak' },
 'baran'	=> { 'x' => 'grumpy',
		     '#' => 'ill-tempered' },
 'barangkali'	=> { 'x' => 'perhaps',
		     '#' => '; maybe' },
 'barut'	=> { 'x' => 'diaper',
		     '#' => '; dressing; bandage' },
 'basi'		=> { 'x' => 'stale',
		     '#' => 'mouldy (of food)' },
 'bata'		=> { 'x' => 'brick' },
# 'batik'	=> { 'x' => 'type of textile print' },
 'bauk'		=> { 'x' => 'sideburns',
		     '#' => '; whiskers' },
 'bawal'	=> { 'x' => 'ponfret' },
 'bayam'	=> { 'x' => 'spinach' },
 'bayi'		=> { 'x' => 'baby' },
 'bayu'		=> { 'x' => 'breeze' },
 'bebal'	=> { 'x' => 'imbecile',
		     '#' => '; idiotic; silly; foolish; stupid' },
# 'bebawang'	=> { 'x' => 'bulb (of plant)' },
 'beberapa'	=> { 'x' => 'several' },
 'bebibir'	=> { 'x' => 'flange',
		     '#' => 'projecting rim' },
 'beca'		=> { 'x' => 'trishaw',
		     '#' => '; rickshaw' },
 'becak'	=> { 'x' => 'muddy' },
 'becok'	=> { 'x' => 'talkative',
		     '#' => 'fond of chatting',
		     't' => 'a' },
# 'beduk'	=> { 'x' => 'big drum used in the mosque' },
 'begar'	=> { 'x' => 'headstrong',
		     '#' => '; hard; firm' },
 'beguk'	=> { 'x' => 'mumps' },
 'bejana'	=> { 'x' => 'canister' },
 'bekat'	=> { 'x' => 'full' },
 'bekuan'	=> { 'x' => 'hot' },
# 'belacan'	=> { 'x' => 'shrimp paste' },
 'belacu'	=> { 'x' => 'calico' },
 'belak'	=> { 'x' => 'mottled' },
 'belalai'	=> { 'x' => 'trunk',
		     '#' => '(of elephant); proboscis',
		     't' => 'n' },
 'belalang'	=> { 'x' => 'grasshopper',
		     't' => 'n' },
 'belanda'	=> { 'x' => 'dutch' },
# 'belanga'	=> { 'x' => 'clay cooking pot' },
 'belangkas'	=> { 'x' => 'king-crab' },
 'belantan'	=> { 'x' => 'club',
		     '#' => '; bludgeon; truncheon' },
 'belantara'	=> { 'x' => 'forest' },
 'belat'	=> { 'x' => 'fish-trap' },
 'belati'	=> { 'x' => 'european' },
 'belebas'	=> { 'x' => 'ledge',
		     '#' => '; lath' },
 'belengas'	=> { 'x' => 'sticky' },
 'belerang'	=> { 'x' => 'sulphur' },
 'belia'	=> { 'x' => 'youth' },
 'belikat'	=> { 'x' => 'shoulder-blade' },
 'belimbing'	=> { 'x' => 'starfruit' },
 'beliung'	=> { 'x' => 'hatchet',
		     '#' => 'small axe; adze' },
 'belukar'	=> { 'x' => 'bush',
		     '#' => 'shrub; secondary forest' },
 'belulang'	=> { 'x' => 'hide',
		     '#' => 'untanned leather; patch of hardened skin' },
 'belut'	=> { 'x' => 'eel' },
 'benak'	=> { 'x' => 'silly',
		     '#' => '; stupid' },
 'benang'	=> { 'x' => 'thread' },
 'bencana'	=> { 'x' => 'harmful',
		     '#' => 'very unpleasant (2) disaster',
		     't' => 'a' },
 'bendahari'	=> { 'x' => 'treasurer',
		     '#' => '; bursar' },
 'bendalir'	=> { 'x' => 'fluid' },
# 'bendang'	=> { 'x' => 'wet rice-fields' },
# 'bendar'	=> { 'x' => 'ditch or moat' },
 'bendela'	=> { 'x' => 'bale',
		     '#' => '; package' },
 'bendera'	=> { 'x' => 'flag' },
 'bendi'	=> { 'x' => 'lady\'s finger' },
 'bendul'	=> { 'x' => 'cross-beam' },
 'bengal'	=> { 'x' => 'temporarily deaf',
		     '#' => 'stubborn' },
# 'bengang'	=> { 'x' => 'buzzing or ringing in the ears' },
 'bengkarung'	=> { 'x' => 'newt' },
 'bengkel'	=> { 'x' => 'workshop' },
 'bengkung'	=> { 'x' => 'sash for the waist',
		     '#' => 'corset; girdle' },
 'benguk'	=> { 'x' => 'goitre' },
 'benih'	=> { 'x' => 'seed' },
 'bening'	=> { 'x' => 'transparent',
		     '#' => '; clear; limpid' },
# 'benjol'	=> { 'x' => 'bump or swelling, esp. left by a blow' },
 'bentan'	=> { 'x' => 'relapse' },
 'bentara'	=> { 'x' => 'herald',
		     '#' => 'state proclamation officer' },
 'benua'	=> { 'x' => 'continent' },
 'bera'		=> { 'x' => 'blush',
		     '#' => 'flushing of face' },
 'berada'	=> { 'x' => 'rich',
		     '#' => '(2) to be',
		     'df' => 'ada' },
 'beranda'	=> { 'x' => 'gallery',
		     '#' => '; verandah; terrace' },
 'berang'	=> { 'x' => 'disgruntled',
		     '#' => '; discontented; annoyed' },
 'berangan'	=> { 'x' => 'chestnut' },
 'berangus'	=> { 'x' => 'muzzle' },
 'berbahasa'	=> { 'x' => 'courteous',
		     '#' => '; cultured; using a language',
		     't' => 'a',
		     'df' => 'bahasa' },
 'berenga'	=> { 'x' => 'maggot' },
 'berhad'	=> { 'x' => 'limited' },
 'berhala'	=> { 'x' => 'idol',
		     '#' => 'image; fetish; worshipped object' },
# 'beringin'	=> { 'x' => 'banyan tree' },
 'berlian'	=> { 'x' => 'diamond' },
 'bernas'	=> { 'x' => 'full',
		     '#' => '(of grain), highly spirited (of speech); factual and convincing (of writing); fertile and productive (of cultivation)',
		     't' => 'a' },
 'beroti'	=> { 'x' => 'batten' },
 'bersin'	=> { 'x' => 'sneeze' },
 'bersut'	=> { 'x' => 'glower',
		     '#' => '; scowl' },
 'beruang'	=> { 'x' => 'bear' },
 'berudu'	=> { 'x' => 'tadpole' },
 'beruk'	=> { 'x' => 'monkey' },
# 'besan'	=> { 'x' => 'parents of a married couple' },
 'besok'	=> { 'x' => 'tomorrow' },
 'bestari'	=> { 'x' => 'well-bred',
		     '#' => 'intelligent' },
 'beta'		=> { 'x' => 'i',
		     '#' => 'me (used by king)' },
 'betah'	=> { 'x' => 'recovered',
		     '#' => '; accustomed' },
 'betik'	=> { 'x' => 'papaya' },
 'betina'	=> { 'x' => 'female' },
 'beting'	=> { 'x' => 'sandbar',
		     '#' => '; sandbank' },
# 'betis'	=> { 'x' => 'calf (of leg)' },
 'biara'	=> { 'x' => 'convent',
		     '#' => '; monastery' },
 'biasiswa'	=> { 'x' => 'scholarship' },
 'biawak'	=> { 'x' => 'iguana' },
 'bibir'	=> { 'x' => 'lip' },
# 'bicu'		=> { 'x' => 'jack (for lifting heavy objects)' },
 'bidaah'	=> { 'x' => 'heresy' },
# 'bidadari'	=> { 'x' => 'houri (beautiful woman of the muslim paradise)' },
 'bidai'	=> { 'x' => 'blinds',
		     '#' => '; screen' },
 'bidak'	=> { 'x' => 'pawn' },
 'bidan'	=> { 'x' => 'midwife' },
 'bidang'	=> { 'x' => 'domain',
		     '#' => 'field or range of activity; numeral coefficient for things that are spread out and flat' },
# 'biduan'	=> { 'x' => 'male singer' },
 'biduanda'	=> { 'x' => 'pageboy',
		     '#' => '; valet' },
# 'biduanita'	=> { 'x' => 'female singer' },
# 'bijan'	=> { 'x' => 'sesame seed' },
 'bijirin'	=> { 'x' => 'cereal' },
 'biku'		=> { 'x' => 'edging',
		     '#' => '; trimming' },
 'bilah'	=> { 'x' => 'blade',
		     '#' => '(of knife or sword), lath; numerical coefficient for weapons of sharpened metal',
		     't' => 'n' },
 'bilal'	=> { 'x' => 'muezzin' },
 'bilik'	=> { 'x' => 'room' },
# 'bilis'	=> { 'x' => 'bloodshot eye' },
# 'bin'		=> { 'x' => 'son of' },
 'bincut'	=> { 'x' => 'lump',
		     '#' => '; swelling' },
 'bingal'	=> { 'x' => 'stubborn' },
# 'bingka'	=> { 'x' => 'a type of cake made from tapioca' },
 'bingkah'	=> { 'x' => 'nugget',
		     '#' => '; chunk' },
 'bingkai'	=> { 'x' => 'frame' },
 'bingung'	=> { 'x' => 'bewildered',
		     '#' => '; confused' },
# 'binti'	=> { 'x' => 'daughter of' },
 'bintil'	=> { 'x' => 'nodule',
		     '#' => '; pimple',
		     't' => 'n' },
 'biola'	=> { 'x' => 'violin',
		     't' => 'n' },
 'birai'	=> { 'x' => 'blind',
		     '#' => 'or screen, esp. on roller, for window, balustrade',
		     't' => 'n' },
# 'biras'	=> { 'x' => 'relationship between two brothers\' wives or between two sisters\' husbands' },
 'biri-biri'	=> { 'x' => 'sheep' },
 'biskop'	=> { 'x' => 'bishop',
		     't' => 'n' },
 'bistari'	=> { 'x' => 'expert',
		     '#' => '; skilled',
		     't' => 'a' },
 'bisul'	=> { 'x' => 'boil',
		     '#' => '; abscess',
		     't' => 'n' },
 'boh'		=> { 'x' => 'moo',
		     '#' => '(of a cow)' },
 'bola'		=> { 'x' => 'ball' },
# 'bomba'	=> { 'x' => 'fire brigade' },
# 'bomoh'	=> { 'x' => 'malay medicine-man' },
 'bonda'	=> { 'x' => 'mother' },
 'boneka'	=> { 'x' => 'doll',
		     '#' => '; puppet' },
 'bongkak'	=> { 'x' => 'arrogant',
		     '#' => '; boastful' },
 'bongsu'	=> { 'x' => 'youngest',
		     '#' => '(of children), lowest (of rungs of ladder or steps)',
		     't' => 'a' },
 'bonjol'	=> { 'x' => 'bulge',
		     '#' => '; a lump',
		     't' => 'n' },
 'bopeng'	=> { 'x' => 'pock-marked' },
# 'bor'		=> { 'x' => 'tool for drilling' },
# 'borang'	=> { 'x' => 'form (document)' },
 'borek'	=> { 'x' => 'speckled',
		     '#' => '; spotted' },
 'boyak'	=> { 'x' => 'drab',
		     '#' => '; dull; uninteresting; tasteless' },
 'boyot'	=> { 'x' => 'pot-bellied' },
 'buak'		=> { 'x' => 'effervescence' },
 'buasir'	=> { 'x' => 'pile',
		     '#' => '; haemorrhoid' },
# 'bubu'		=> { 'x' => 'fish-trap made of bamboo and rattan' },
 'bubuk'	=> { 'x' => 'woodworm' },
 'bubul'	=> { 'x' => 'cobble',
		     '#' => 'mend roughly' },
 'bubur'	=> { 'x' => 'porridge' },
 'bucu'		=> { 'x' => 'corner',
		     '#' => '; angle' },
 'budiman'	=> { 'x' => 'wise',
		     '#' => '; generous' },
# 'bugar'	=> { 'x' => 'strong and healthy' },
 'bujang'	=> { 'x' => 'celebate',
		     '#' => '(2)unmarried man, bachelor' },
 'bulbul'	=> { 'x' => 'nightingale' },
# 'buli-buli'	=> { 'x' => '(1)small flask or jug (2)small gland' },
 'buluh'	=> { 'x' => 'bamboo' },
 'bungkal'	=> { 'x' => 'lump',
		     '#' => '; weight' },
# 'bunian'	=> { 'x' => 'invisible forest elf or spirit' },
# 'buntak'	=> { 'x' => 'short and stout' },
 'buntal'	=> { 'x' => 'bloated',
		     '#' => 'pot-bellied (2)globe-fish',
		     't' => 'a' },
# 'buntil'	=> { 'x' => 'cloth knapsack' },
# 'bunting'	=> { 'x' => 'pregnant (of animals)' },
# 'buruj'	=> { 'x' => 'constellation of stars' },
 'burung'	=> { 'x' => 'bird' },
 'burut'	=> { 'x' => 'hernia' },
 'busung'	=> { 'x' => 'bloated',
		     '#' => '; distended' },
# 'busur'	=> { 'x' => 'bow (for shooting arrows)' },
 'busut'	=> { 'x' => 'molehill',
		     '#' => '; anthill' },
 'butang'	=> { 'x' => 'button' },
 'butir'	=> { 'x' => 'item',
		     '#' => 'fact; point (2)numeral coefficient for small round objects',
		     't' => 'n' },
 'buyung'	=> { 'x' => 'earthenware' },

 'cabai'	=> { 'x' => 'chilli' },
 'cacing'	=> { 'x' => 'worm' },
 'cadar'	=> { 'x' => 'bedsheet' },
 'cakah'	=> { 'x' => 'obtuse',
		     '#' => '; blunt' },
 'cekerawala'	=> { 'x' => 'universe',
		     '#' => '; firmament' },
 'calung'	=> { 'x' => 'dipper',
		     '#' => 'ladle; cup for collecting latex' },
 'camar'	=> { 'x' => 'seagull' },
 'camca'	=> { 'x' => 'spoon' },
 'candat'	=> { 'x' => 'grapnel' },
 'candu'	=> { 'x' => 'opium' },
 'canggung'	=> { 'x' => 'gauche',
		     '#' => '; awkward; clumsy' },
 'cangkat'	=> { 'x' => 'hillock' },
# 'cangkir'	=> { 'x' => 'small cup' },
 'capal'	=> { 'x' => 'sandals' },
 'carta'	=> { 'x' => 'chart',
		     '#' => '; map; table; diagram' },
 'caruk'	=> { 'x' => 'gorge',
		     '#' => 'eat greedily' },
# 'cas'		=> { 'x' => 'electrical charge' },
 'catur'	=> { 'x' => 'chess' },
 'catut'	=> { 'x' => 'pincers' },
 'cauk'		=> { 'x' => 'dimple' },
 'cawak'	=> { 'x' => 'dimple' },
 'cawan'	=> { 'x' => 'cup' },
# 'cawangan'	=> { 'x' => 'branch (e.g. of office)' },
 'cecair'	=> { 'x' => 'liquid' },
 'ceceh'	=> { 'x' => 'bleat' },
 'cecekik'	=> { 'x' => 'noose' },
# 'cekah'	=> { 'x' => 'to crack or split' },
 'cekang'	=> { 'x' => 'stiff',
		     '#' => '; taut; tight' },
 'cekung'	=> { 'x' => 'concave' },
# 'celaan'	=> { 'x' => 'severe criticism and rebuke' },
 'celak'	=> { 'x' => 'eye-liner' },
 'celana'	=> { 'x' => 'trousers' },
# 'celepa'	=> { 'x' => 'metal containers for cigarettes, tobacco, etc' },
 'celopar'	=> { 'x' => 'talkative',
		     '#' => 'out-spoken; very frank' },
# 'celungap'	=> { 'x' => 'eat greedily' },
 'cemara'	=> { 'x' => 'wig',
		     '#' => 'artificial hair' },
 'cembul'	=> { 'x' => 'container',
		     '#' => '; receptacle' },
 'cembung'	=> { 'x' => 'convex' },
 'cemburu'	=> { 'x' => 'jealous' },
 'cemeti'	=> { 'x' => 'whip' },
# 'cempaka'	=> { 'x' => 'a type of tree with sweet-smelling flowers' },
# 'cempedak'	=> { 'x' => 'a fruit resembling the jackfruit' },
# 'cencaluk'	=> { 'x' => 'prawn pickle' },
# 'cencorot'	=> { 'x' => 'musk-shrew or shrew-mouse' },
 'cendana'	=> { 'x' => 'sandalwood',
		     't' => 'n' },
 'cendera'	=> { 'x' => 'moon',
		     '#' => '(2) deity',
		     't' => 'n' },
 'cenderamata'	=> { 'x' => 'souvenir' },
 'cenderawasih'	=> { 'x' => 'bird of paradise',
		     't' => 'n' },
# 'cendol'	=> { 'x' => 'a drink made of jelly-like strands of dough and coconut milk' },
 'cengkadak'	=> { 'x' => 'praying mantis',
		     't' => 'n' },
 'cengkeram'	=> { 'x' => 'deposit' },
# 'cengkerik'	=> { 'x' => 'cricket or cicada (insect)' },
 'cengkih'	=> { 'x' => 'clove',
		     '#' => '(spice)',
		     't' => 'n' },
# 'cengkung'	=> { 'x' => 'sunken or hollow (of eyes or cheeks)' },
 'cenuram'	=> { 'x' => 'cliff',
		     't' => 'n' },
 'cepiau'	=> { 'x' => 'bonnet',
		     '#' => 'hat with strings that tie under the chin',
		     't' => 'n' },
 'cepoa'	=> { 'x' => 'abacus' },
 'cepoh'	=> { 'x' => 'club-footed' },
 'cepumas'	=> { 'x' => 'jackpot' },
 'ceracap'	=> { 'x' => 'castanets' },
 'cerah'	=> { 'x' => 'bright',
		     '#' => 'fair (light-coloured); fine (weather); promising' },
# 'cerana'	=> { 'x' => 'metal box' },
 'cerang'	=> { 'x' => 'moor' },
 'cerat'	=> { 'x' => 'nozzle' },
 'cerek'	=> { 'x' => 'kettle' },
 'cereka'	=> { 'x' => 'story',
		     '#' => '; fiction' },
 'cerewet'	=> { 'x' => 'fussy',
		     '#' => '; fastidious' },
 'cerobong'	=> { 'x' => 'chimney',
		     '#' => 'ship\'s funnel',
		     't' => 'n' },
 'cerompong'	=> { 'x' => 'muzzle',
		     '#' => '(of firearm)',
		     't' => 'n' },
 'cerpelai'	=> { 'x' => 'mongoose',
		     't' => 'n' },
# 'cerucuk'	=> { 'x' => 'pile driven into the ground' },
 'cerucup'	=> { 'x' => 'love-grass' },
 'ceruk'	=> { 'x' => 'nook',
		     '#' => '; corner',
		     't' => 'n' },
 'cerutu'	=> { 'x' => 'cigar' },
 'cetek'	=> { 'x' => 'shallow' },
# 'ceti'		=> { 'x' => 'money lender' },
 'cicak'	=> { 'x' => 'lizard' },
 'Cik'		=> { 'x' => 'Miss' },
 'cikgu'	=> { 'x' => 'teacher' },
# 'ciku'		=> { 'x' => 'sapodilla (fruit)' },
 'Cina'		=> { 'x' => 'Chinese' },
 'cincin'	=> { 'x' => 'ring' },
# 'cipan'	=> { 'x' => '(1) battle-axe (2) tapir' },
 'cirit-birit'	=> { 'x' => 'diarrhoea' },
 'coklat'	=> { 'x' => 'brown',
		     '#' => '; chocolate' },
# 'cokmar'	=> { 'x' => 'ceremonial mace' },
 'coli'		=> { 'x' => 'brassiere' },
 'colok'	=> { 'x' => 'joss-stick' },
 'comel'	=> { 'x' => 'cute' },
 'comot'	=> { 'x' => 'dirty',
		     '#' => '; grubby' },
# 'compang-camping'	=> { 'x' => 'in rags or tatters (clothes)' },
# 'congak'	=> { 'x' => 'count mentally' },
 'congkak'	=> { 'x' => 'conceited',
		     '#' => '; proud' },
 'corat-coret'	=> { 'x' => 'sketch',
		     '#' => 'scrawl' },
 'corek'	=> { 'x' => 'scratch' },
# 'coret'	=> { 'x' => 'scribble or scrawl' },
 'corong'	=> { 'x' => 'funnel',
		     '#' => '; chimney; microphone' },
 'corot'	=> { 'x' => 'hindmost' },
 'cota'		=> { 'x' => 'baton' },
 'cuaca'	=> { 'x' => 'weather',
		     '#' => '; climate' },
 'cuak'		=> { 'x' => 'afraid',
		     '#' => '; nervous' },
 'cucunda'	=> { 'x' => 'grandchild' },
# 'cula'		=> { 'x' => 'horn of rhinoceros' },
 'culas'	=> { 'x' => 'lazy' },
# 'cupak'	=> { 'x' => 'a cubic measure' },
 'cuping'	=> { 'x' => 'ear-lobe' },
 'curut'	=> { 'x' => 'cigar',
		     '#' => '; cheroot' },

# 'dabik'	=> { 'x' => 'to beat or thump' },
# 'dacing'	=> { 'x' => 'weighing scale or balance' },
 'dadah'	=> { 'x' => 'drug' },
 'dadak'	=> { 'x' => 'sudden',
		     '#' => '; abrupt' },
 'dadih'	=> { 'x' => 'curdle' },
 'dadu'		=> { 'x' => 'dice' },
 'daging'	=> { 'x' => 'meat',
		     '#' => '; flesh' },
 'dagu'		=> { 'x' => 'chin' },
# 'dahan'	=> { 'x' => 'branch (of plant)' },
 'dahi'		=> { 'x' => 'forehead' },
 'dahsyat'	=> { 'x' => 'horrible',
		     '#' => '; awful; terrible' },
 'dajal'	=> { 'x' => 'mischievous' },
 'dakwat'	=> { 'x' => 'ink' },
 'dakyah'	=> { 'x' => 'propaganda' },
# 'dalal'	=> { 'x' => 'fee or commission' },
 'dalil'	=> { 'x' => 'proof' },
# 'dam'		=> { 'x' => 'draughts (board game)' },
# 'damak'	=> { 'x' => 'dart (for blow-pipe)' },
 'damar'	=> { 'x' => 'resin' },
 'dan'		=> { 'x' => 'and' },
 'danau'	=> { 'x' => 'lake' },
# 'dangau'	=> { 'x' => 'small temporary hut (in rice-field or orchard)' },
 'dansa'	=> { 'x' => 'dance' },
 'dapur'	=> { 'x' => 'kitchen',
		     '#' => '; stove' },
 'dara'		=> { 'x' => 'maiden',
		     '#' => '; virgin' },
# 'dari'		=> { 'x' => 'from (place or time)' },
# 'daripada'	=> { 'x' => 'from (person)' },
 'darjah'	=> { 'x' => 'degree',
		     '#' => '; standard; class' },
 'darurat'	=> { 'x' => 'emergency' },
# 'das'		=> { 'x' => 'gun or rifle shot' },
# 'datin'	=> { 'x' => 'a title of distinction for woman' },
# 'datuk'	=> { 'x' => '(1)grandfather (2)title of distinction for man and woman' },
# 'dayang'	=> { 'x' => 'court maiden' },
# 'dayus'	=> { 'x' => 'man whose wife has committed adultery' },
# 'debus'	=> { 'x' => 'whistling or rustling sound' },
 'dedak'	=> { 'x' => 'bran' },
 'dekah'	=> { 'x' => 'guffaw',
		     '#' => 'loud laughter' },
 'dekan'	=> { 'x' => 'dean' },
# 'delima'	=> { 'x' => '(1) ruby (2) pomegranate' },
 'demam'	=> { 'x' => 'fever' },
 'denai'	=> { 'x' => 'spoor',
		     '#' => 'track or scent left by an animal' },
# 'denda'	=> { 'x' => 'fine (imposed for offence)' },
 'dengus'	=> { 'x' => 'snort',
		     't' => 'n' },
# 'dengut'	=> { 'x' => 'emit a long murmur' },
# 'denting'	=> { 'x' => 'a tinkling sound' },
 'derai'	=> { 'x' => 'crumble' },
# 'derap'	=> { 'x' => '(1)footstep (2)pattering sound' },
 'deras'	=> { 'x' => 'rapid',
		     '#' => '; quick; swift' },
# 'derau'	=> { 'x' => 'sound of wind in the rain' },
# 'deria'	=> { 'x' => 'sense (e.g. sight, smell, hearing, taste, touch)' },
# 'dermaga'	=> { 'x' => 'wharf or dock' },
 'desa'		=> { 'x' => 'countryside' },
 'desas-desus'	=> { 'x' => 'heresay',
		     '#' => 'rumour' },
# 'desing'	=> { 'x' => 'whistle of the wind' },
 'destar'	=> { 'x' => 'turban' },
# 'desur'	=> { 'x' => 'babbling sound' },
# 'detak'	=> { 'x' => 'throbbing or thumping' },
# 'dewi'		=> { 'x' => 'female deity or goddess' },
 'diadakan'	=> { 'x' => 'be held',
		     '#' => 'passive',
		     't' => 'v',
		     'df' => 'ada' },
 'dian'		=> { 'x' => 'candle',
		     't' => 'n' },
 'dif'		=> { 'x' => 'guess' },
# 'dinihari'	=> { 'x' => 'before dawn' },
 'diraja'	=> { 'x' => 'royal' },
# 'dobi'		=> { 'x' => 'laundry or dhobi' },
# 'dodol'	=> { 'x' => 'a sweet malay delicacy' },
 'dompet'	=> { 'x' => 'purse',
		     '#' => '; wallet',
		     't' => 'n' },
 'dubur'	=> { 'x' => 'anus',
		     't' => 'n' },
 'duda'		=> { 'x' => 'widower',
		     't' => 'n' },
 'duit'		=> { 'x' => 'money',
		     't' => 'n' },
 'dukun'	=> { 'x' => 'medicine man',
		     't' => 'n' },
 'duli'		=> { 'x' => 'your majesty',
		     '#' => 'dust' },
 'durjana'	=> { 'x' => 'evil',
		     '#' => '; wicked',
		     't' => 'a' },
 'dusun'	=> { 'x' => 'orchard' },
 'duyung'	=> { 'x' => 'mermaid' },
 'ehwal'	=> { 'x' => 'matters',
		     '#' => '; affairs' },
 'eka'		=> { 'x' => 'one',
		     '#' => '; sole' },
 'ekanada'	=> { 'x' => 'monotone' },
 'ekar'		=> { 'x' => 'acre' },
 'ekasuku'	=> { 'x' => 'monosyllable' },
# 'ela'		=> { 'x' => 'yard (measure of length)' },
 'emak'		=> { 'x' => 'mother' },
# 'embut'	=> { 'x' => 'raise a fishing-line slowly' },
 'emper'	=> { 'x' => 'penthouse' },
 'emping'	=> { 'x' => 'flake',
		     '#' => '(e.g. of snow), sweetmeat made from unripe rice fried and pounded flat',
		     't' => 'n' },
 'empuk'	=> { 'x' => 'soft',
		     '#' => '; tender' },
# 'empulur'	=> { 'x' => 'pith (of stem or fruit)' },
 'enak'		=> { 'x' => 'delicious' },
 'enapan'	=> { 'x' => 'sediment' },
# 'enau'		=> { 'x' => 'kind of palm' },
 'encik'	=> { 'x' => 'mr.' },
 'endul'	=> { 'x' => 'cradle' },
 'enggang'	=> { 'x' => 'hornbill' },
 'engkau'	=> { 'x' => 'you',
		     '#' => '; your' },
# 'engkol'	=> { 'x' => 'crank of a machine' },
 'engsel'	=> { 'x' => 'hinge' },
# 'engsot'	=> { 'x' => 'move slightly and slowly' },
 'epal'		=> { 'x' => 'apple' },
 'epipusat'	=> { 'x' => 'epicentre' },
 'eropah'	=> { 'x' => 'europe',
		     '#' => 'of european origin' },
 'esa'		=> { 'x' => 'sole',
		     '#' => 'only one' },
 'esak'		=> { 'x' => 'sob' },
# 'faharasat'	=> { 'x' => 'index to a book' },
 'fajar'	=> { 'x' => 'dawn' },
# 'fakir'	=> { 'x' => 'religious beggar' },
 'falak'	=> { 'x' => 'universe',
		     '#' => '; astronomy' },
 'falsafah'	=> { 'x' => 'philosophy' },
 'fana'		=> { 'x' => 'ephemeral',
		     '#' => 'short-lived' },
 'faraj'	=> { 'x' => 'vagina' },
 'fardu'	=> { 'x' => 'duty',
		     '#' => '; obligation' },
# 'fasal'	=> { 'x' => '(1)clause in a treaty, law or contract (2)about' },
# 'fikah'	=> { 'x' => 'law based on muslim theology' },
# 'filipina'	=> { 'x' => 'of the philippines' },
 'firasah'	=> { 'x' => 'hunch',
		     '#' => 'intuitive feeling; premonition' },
 'firasat'	=> { 'x' => 'clairvoyance' },
 'firaun'	=> { 'x' => 'pharaoh' },
 'firdaus'	=> { 'x' => 'paradise',
		     '#' => '; heaven' },
# 'firman'	=> { 'x' => 'divine decree' },
 'furak'	=> { 'x' => 'difference',
		     '#' => '; dissimilarity' },
 'gabus'	=> { 'x' => 'cork' },
# 'gada'		=> { 'x' => 'club used for fighting' },
 'gada-gada'	=> { 'x' => 'pennant' },
 'gadang'	=> { 'x' => 'colossal',
		     '#' => 'immense (2)large round tray used for winnowing',
		     't' => 'a' },
 'gading'	=> { 'x' => 'ivory',
		     '#' => '; tusk' },
# 'gado-gado'	=> { 'x' => '(1) a malay dish made from vegetables (2) mixed up',
#		     '#' => 'disorderly' },
 'gagak'	=> { 'x' => 'crow' },
 'gagang'	=> { 'x' => 'handle',
		     '#' => 'cradle (of telephone); stem' },
# 'gahara'	=> { 'x' => 'of royal descent' },
 'gaharu'	=> { 'x' => 'sandalwood' },
 'gajah'	=> { 'x' => 'elephant' },
# 'gajus'	=> { 'x' => 'cashew nut' },
# 'gak'		=> { 'x' => 'caw (e.g. of a rook)' },
# 'gala'		=> { 'x' => 'a type of resin' },
 'galang'	=> { 'x' => 'obstruct' },
# 'gamang'	=> { 'x' => 'suffering from acrophobia (fear of heights)' },
 'gamat'	=> { 'x' => 'noisy',
		     '#' => '; unruly; chaotic' },
 'gambang'	=> { 'x' => 'xylophone' },
# 'gambus'	=> { 'x' => 'an arab musical instrument with six strings' },
 'gambut'	=> { 'x' => 'peat',
		     '#' => 'soft and loose (of soil)' },
# 'gamelan'	=> { 'x' => 'javanese orchestra' },
 'gampang'	=> { 'x' => 'easy' },
# 'gancu'	=> { 'x' => 'long hooked stick' },
# 'gandik'	=> { 'x' => '(1) gold ornament on bride\'s forehead (2) decoration on hilt of kris' },
 'gandin'	=> { 'x' => 'mallet' },
 'gandum'	=> { 'x' => 'wheat' },
# 'ganggang'	=> { 'x' => 'dry over a fire' },
 'gangsa'	=> { 'x' => 'bronze' },
 'ganja'	=> { 'x' => 'cannabis',
		     '#' => '; hemp' },
 'ganjal'	=> { 'x' => 'base',
		     '#' => '; stand; wedge' },
 'ganjil'	=> { 'x' => 'odd',
		     '#' => '; queer; strange' },
# 'gantang'	=> { 'x' => 'a cubic measure' },
# 'ganyar'	=> { 'x' => 'tough (not tender)' },
 'gapah'	=> { 'x' => 'hurriedly',
		     '#' => '; hastily' },
 'gapura'	=> { 'x' => 'arch' },
# 'garau'	=> { 'x' => 'hoarse (of voice)' },
 'gari'		=> { 'x' => 'handcuffs' },
 'garing'	=> { 'x' => 'crisp' },
 'garpu'	=> { 'x' => 'fork' },
# 'garuk'	=> { 'x' => 'hoarse, deep or husky (of voice)' },
 'gasal'	=> { 'x' => 'odd' },
# 'gasang'	=> { 'x' => 'lecherous person' },
# 'gasar'	=> { 'x' => 'fierce and rough' },
 'gasing'	=> { 'x' => 'top',
		     't' => 'n' },
 'gawal'	=> { 'x' => 'confused',
		     '#' => '; mistaken' },
# 'gawang'	=> { 'x' => 'waving with both arms' },
# 'gayat'	=> { 'x' => 'feeling dizzy looking down from a high place' },
# 'gayung'	=> { 'x' => 'water dipper' },
 'gebar'	=> { 'x' => 'blanket' },
 'gebu'		=> { 'x' => 'soft',
		     '#' => 'delicate in texture; fluffy' },
# 'gecar'	=> { 'x' => '(1) saliva (2) watery' },
 'gedabir'	=> { 'x' => 'dewlap' },
 'gedang'	=> { 'x' => 'huge',
		     '#' => '; massive' },
 'gedempol'	=> { 'x' => 'fat' },
# 'gedempong'	=> { 'x' => 'very fat' },
# 'gedoboh'	=> { 'x' => 'big and loose' },
 'gedung'	=> { 'x' => 'storehouse',
		     '#' => 'office; large building' },
# 'gegabah'	=> { 'x' => 'wildly impulsive (person)' },
 'gegancu'	=> { 'x' => 'sprocket' },
 'gegap'	=> { 'x' => 'noisy' },
# 'gegat'	=> { 'x' => 'worm that lives in books' },
 'gegua'	=> { 'x' => 'cavern' },
# 'gejala'	=> { 'x' => 'symptom or sign' },
 'gelabir'	=> { 'x' => 'dewlap',
		     '#' => '; wattle' },
 'geladak'	=> { 'x' => 'deck',
		     '#' => '(of ship) (2) stray dog (3) crook',
		     '#' => 'criminal',
		     't' => 'n' },
 'gelagat'	=> { 'x' => 'indication',
		     '#' => '; habits' },
 'gelambir'	=> { 'x' => 'dewlap' },
 'gelanggang'	=> { 'x' => 'arena',
		     '#' => '; court' },
 'gelangsar'	=> { 'x' => 'slide',
		     '#' => '; glide; slip' },
 'gelatuk'	=> { 'x' => 'tremble' },
 'gelebar'	=> { 'x' => 'flapping' },
# 'gelebat'	=> { 'x' => 'double blade paddle' },
 'gelecah'	=> { 'x' => 'slip' },
# 'gelecek'	=> { 'x' => 'slip; lose one\'s balance' },
 'geledak'	=> { 'x' => 'cur' },
# 'geledang'	=> { 'x' => 'stretch out both arms' },
 'geleding'	=> { 'x' => 'warp' },
 'gelegar'	=> { 'x' => 'girder' },
 'gelegata'	=> { 'x' => 'urticaria',
		     '#' => 'a skin condition',
		     't' => 'n' },
# 'gelekak'	=> { 'x' => 'peel off' },
 'gelekek'	=> { 'x' => 'chuckle' },
 'gelema'	=> { 'x' => 'phlegm' },
 'geleman'	=> { 'x' => 'scared',
		     '#' => '; afraid' },
 'gelendong'	=> { 'x' => 'spindle' },
# 'gelentang'	=> { 'x' => 'roll over and over' },
 'gelepai'	=> { 'x' => 'dangling' },
 'gelepik'	=> { 'x' => 'dangling',
		     '#' => 'hanging down limply' },
# 'gelepur'	=> { 'x' => 'leaping up flapping its wings' },
 'gelesek'	=> { 'x' => 'rub' },
 'geleser'	=> { 'x' => 'flap',
		     '#' => 'the wings, start turning (of wheels)',
		     't' => 'v' },
# 'geletuk'	=> { 'x' => 'making a sound like the teeth chattering' },
 'geliang-geliut'	=> { 'x' => 'wriggling' },
# 'gelimun'	=> { 'x' => 'covered (with blanket)' },
 'gelincat'	=> { 'x' => 'sprained',
		     '#' => '; rebound' },
 'gelincuh'	=> { 'x' => 'stumble' },
# 'gelintar'	=> { 'x' => 'search all over' },
# 'gelobor'	=> { 'x' => 'too long or baggy (for clothes)' },
 'gelodak'	=> { 'x' => 'arouse' },
 'gelodar'	=> { 'x' => 'struggle' },
# 'gelojak'	=> { 'x' => 'big flame' },
 'gelojoh'	=> { 'x' => 'greedy' },
 'gelugut'	=> { 'x' => 'shiver',
		     '#' => 'chatter (of teeth)' },
 'geluh'	=> { 'x' => 'loam',
		     '#' => 'rich soil' },
# 'gelulur'	=> { 'x' => 'slide down' },
 'gemal'	=> { 'x' => 'handful',
		     '#' => '; a bunch',
		     't' => 'n' },
# 'gemala'	=> { 'x' => 'bezoar stone' },
 'gemalai'	=> { 'x' => 'swaying' },
# 'gemam'	=> { 'x' => 'to hold (sweet) in mouth' },
 'gemap'	=> { 'x' => 'shocked' },
# 'gemawan'	=> { 'x' => 'fleeting of clouds' },
 'gembereng'	=> { 'x' => 'cymbal' },
 'gembung'	=> { 'x' => 'swollen' },
 'gementar'	=> { 'x' => 'tremble' },
# 'gemercik'	=> { 'x' => 'splattering sound' },
# 'gemerencang'	=> { 'x' => 'loud clash (e.g. of cymbals)' },
 'gempa'	=> { 'x' => 'tremor',
		     '#' => '; earthquake' },
 'gempal'	=> { 'x' => 'sturdy',
		     '#' => '; chubby; plump' },
 'gempita'	=> { 'x' => 'noisy' },
 'genahar'	=> { 'x' => 'crater' },
 'gendak'	=> { 'x' => 'mistress' },
 'gendang'	=> { 'x' => 'drum' },
# 'genderang'	=> { 'x' => 'big drum' },
 'genggang'	=> { 'x' => 'apart' },
# 'genit'	=> { 'x' => 'cute and petite' },
 'genjang'	=> { 'x' => 'parallelogram',
		     '#' => '(2) askew, awry',
		     't' => 'n' },
 'genjot'	=> { 'x' => 'askew',
		     '#' => '; awry' },
 'genjur'	=> { 'x' => 'stiff' },
# 'genta'	=> { 'x' => 'large bell' },
# 'gentas'	=> { 'x' => '(1) severed (2) end or finish' },
 'gentat'	=> { 'x' => 'dented' },
 'gentian'	=> { 'x' => 'fibre' },
 'gepok'	=> { 'x' => 'bundle' },
 'gepuh'	=> { 'x' => 'padlock' },
# 'gerabak'	=> { 'x' => 'railway coach' },
# 'geragai'	=> { 'x' => 'hook for catching crocodiles' },
# 'geragas'	=> { 'x' => 'comb one\'s hair in anger' },
# 'geragau'	=> { 'x' => 'a small shrimp' },
 'geraham'	=> { 'x' => 'molar' },
 'gerai'	=> { 'x' => 'stall' },
 'gerangan'	=> { 'x' => 'perhaps' },
 'gerantang'	=> { 'x' => 'din',
		     '#' => 'of voices, outburst of noise',
		     't' => 'n' },
# 'gerat'	=> { 'x' => 'causing teeth to chatter' },
 'gerbang'	=> { 'x' => 'gateway' },
# 'gerecak'	=> { 'x' => 'sound like water boiling' },
 'gereja'	=> { 'x' => 'church' },
 'gerek'	=> { 'x' => 'perforated' },
 'gerenyam'	=> { 'x' => 'lustful' },
 'gergasi'	=> { 'x' => 'giant' },
 'gerhana'	=> { 'x' => 'eclipse' },
 'geriak'	=> { 'x' => 'swarm' },
# 'gericau'	=> { 'x' => 'screeching sound' },
 'geridip'	=> { 'x' => 'glitter',
		     '#' => '; sparkle' },
 'gerigi'	=> { 'x' => 'serrated' },
# 'gerigis'	=> { 'x' => 'unevenly serrated' },
 'gerimis'	=> { 'x' => 'drizzle' },
 'gerimit'	=> { 'x' => 'drill',
		     't' => 'n' },
# 'gering'	=> { 'x' => 'sick (for king)' },
# 'gerinjam'	=> { 'x' => '(1) grindstone for teeth (2) ear scoop' },
 'germut'	=> { 'x' => 'swarm' },
 'gerenyut'	=> { 'x' => 'squirm',
		     '#' => '; throb' },
# 'gerobak'	=> { 'x' => 'coach or cart' },
 'gerobok'	=> { 'x' => 'cupboard' },
# 'gerodak'	=> { 'x' => 'rattling sound' },
# 'gerombong'	=> { 'x' => 'group or party' },
 'geronggang'	=> { 'x' => 'hollow' },
 'geronyot'	=> { 'x' => 'throbbing' },
 'gersang'	=> { 'x' => 'dry',
		     '#' => '; uninteresting; dull' },
 'gerugut'	=> { 'x' => 'grooved' },
 'geruh'	=> { 'x' => 'misfortune' },
 'geruk'	=> { 'x' => 'wrap',
		     't' => 'v' },
 'getas'	=> { 'x' => 'brittle',
		     '#' => '; sensitive' },
 'getir'	=> { 'x' => 'bitter' },
 'ghalib'	=> { 'x' => 'usual' },
 'gilang-gemilang'	=> { 'x' => 'bright',
		     '#' => 'glittering' },
 'gilas'	=> { 'x' => 'crush',
		     '#' => 'run over' },
# 'gilis'	=> { 'x' => 'run over by a train' },
 'ginjal'	=> { 'x' => 'kidney' },
 'giring'	=> { 'x' => 'herd',
		     't' => 'v' },
 'glur'		=> { 'x' => 'voluptuous' },
# 'godam'	=> { 'x' => 'large mace' },
# 'godok'	=> { 'x' => 'base of skull' },
 'gogok'	=> { 'x' => 'gulp',
		     't' => 'n' },
 'golok'	=> { 'x' => 'machete' },
# 'gondok'	=> { 'x' => '(1)short and fat (2)goitre' },
 'gonyeh'	=> { 'x' => 'munch' },
# 'goyah'	=> { 'x' => 'loose (not firm)' },
 'gua'		=> { 'x' => 'cave' },
 'guam'		=> { 'x' => 'disagree',
		     '#' => '; dispute' },
 'gubuk'	=> { 'x' => 'hut' },
 'gudang'	=> { 'x' => 'godown',
		     '#' => '; warehouse' },
 'gulai'	=> { 'x' => 'curry' },
 'guli'		=> { 'x' => 'marble' },
 'gundah'	=> { 'x' => 'depressed' },
 'gundik'	=> { 'x' => 'concubine' },
# 'guni'		=> { 'x' => 'jute bag or sack' },
 'guntur'	=> { 'x' => 'thunder' },
# 'gurindam'	=> { 'x' => 'a proverbial verse' },
 'gurun'	=> { 'x' => 'desert' },
# 'gusi'		=> { 'x' => 'gum (dental)' },
 'haba'		=> { 'x' => 'heat' },
# 'habuan'	=> { 'x' => 'share (e.g. of prize)' },
# 'hadas'	=> { 'x' => 'ritual impurity' },
 'haid'		=> { 'x' => 'menstruation' },
 'haiwan'	=> { 'x' => 'animal' },
# 'hajah'	=> { 'x' => 'a muslim woman who has fulfilled the pilgrimage to mecca' },
# 'haji'		=> { 'x' => 'a muslim man who has fulfilled the pilgrimage to mecca' },
 'hakikat'	=> { 'x' => 'truth',
		     '#' => '; reality' },
 'hakiki'	=> { 'x' => 'true',
		     '#' => '; real' },
 'halaju'	=> { 'x' => 'velocity' },
# 'halaman'	=> { 'x' => '(1) compound (2) page' },
 'halia'	=> { 'x' => 'ginger' },
 'halilintar'	=> { 'x' => 'thunder' },
 'halimunan'	=> { 'x' => 'invisible' },
# 'halkum'	=> { 'x' => 'larynx; adam\'s apple' },
 'haloba'	=> { 'x' => 'greed',
		     '#' => '; greedy' },
# 'halwa'	=> { 'x' => 'fruits preserved in syrup' },
 'hama'		=> { 'x' => 'germ' },
 'hambar'	=> { 'x' => 'tasteless',
		     '#' => '; insipid' },
 'hamis'	=> { 'x' => 'stink' },
 'hampagas'	=> { 'x' => 'vacuum' },
 'hancing'	=> { 'x' => 'stinking',
		     '#' => 'foul-smelling' },
 'handai'	=> { 'x' => 'friend',
		     '#' => '; associate' },
 'hangat'	=> { 'x' => 'hot' },
# 'hangit'	=> { 'x' => 'having a burning smell' },
 'hangus'	=> { 'x' => 'burnt',
		     '#' => '; scorched' },
 'hanyir'	=> { 'x' => 'stinking',
		     '#' => '; fishy' },
# 'hanyutan'	=> { 'x' => 'drifting movement' },
 'hapak'	=> { 'x' => 'musty',
		     '#' => 'stale-smelling' },
 'harafiah'	=> { 'x' => 'literal' },
 'harimau'	=> { 'x' => 'tiger' },
 'hasad'	=> { 'x' => 'jealous',
		     '#' => '; envious; malevolent' },
# 'hasta'	=> { 'x' => 'length from elbow to tip of middle finger' },
 'hawa'		=> { 'x' => 'atmosphere',
		     '#' => '; air; climate' },
 'hegeh'	=> { 'x' => 'flaunting',
		     '#' => '; swagger' },
 'helah'	=> { 'x' => 'contrivance',
		     '#' => '; trick; excuse' },
 'helai'	=> { 'x' => 'piece' },
 'helang'	=> { 'x' => 'eagle' },
 'hemah'	=> { 'x' => 'manners' },
 'hempedal'	=> { 'x' => 'gizzard' },
 'hempedu'	=> { 'x' => 'bile' },
 'herot'	=> { 'x' => 'crooked' },
 'hidayat'	=> { 'x' => 'guidance' },
 'hikayat'	=> { 'x' => 'story',
		     '#' => '; history' },
 'hikmat'	=> { 'x' => 'wisdom',
		     '#' => 'magical powers' },
 'hingar-bingar'	=> { 'x' => 'noisy' },
# 'hingus'	=> { 'x' => 'mucus from nose' },
 'hinggut'	=> { 'x' => 'shake',
		     '#' => '; sway' },
 'hiruk-pikuk'	=> { 'x' => 'clamour',
		     '#' => 'uproar' },
 'hodoh'	=> { 'x' => 'ugly' },
 'honar'	=> { 'x' => 'chaos',
		     '#' => '; deceit; fraud' },
 'hulu'		=> { 'x' => 'butt',
		     '#' => 'handle (of tool or weapon) (2) upstream ',
		     't' => 'n' },
 'hulubalang'	=> { 'x' => 'commander',
		     '#' => '; warlord' },
# 'huma'		=> { 'x' => 'dry field' },
 'hunjam'	=> { 'x' => 'dive',
		     '#' => 'bore vertically; plunge down',
		     't' => 'v' },
 'hurung'	=> { 'x' => 'cancel',
		     't' => 'v' },
 'ibadat'	=> { 'x' => 'pious duties',
		     '#' => 'worship' },
 'iblis'	=> { 'x' => 'dickens',
		     '#' => 'deuce; devil (in exclamation)' },
 'ibrani'	=> { 'x' => 'hebrew' },
# 'ihsan'	=> { 'x' => 'good deed' },
# 'ijazah'	=> { 'x' => 'degree (academic)' },
 'ijtihad'	=> { 'x' => 'study' },
# 'ijuk'		=> { 'x' => 'black fibre of enau palm' },
 'ikhtisar'	=> { 'x' => 'compendium',
		     '#' => '; summary; digest' },
 'ikhtisas'	=> { 'x' => 'professional' },
 'ikhwan'	=> { 'x' => 'brothers' },
 'iklim'	=> { 'x' => 'climate' },
# 'ikrab'	=> { 'x' => '(1) inflexion (changing of the form of a word grammatically) (2) intimate' },
 'iktibar'	=> { 'x' => 'example',
		     '#' => '; teaching' },
 'iktisad'	=> { 'x' => 'economy' },
 'ilmiah'	=> { 'x' => 'erudite',
		     '#' => '; learned; scholarly' },
 'ilmiawan'	=> { 'x' => 'scholar' },
# 'imam'		=> { 'x' => 'muslim spiritual leader who leads the congregation in prayer' },
 'iman'		=> { 'x' => 'piety' },
# 'imla'		=> { 'x' => 'dictate (words)' },
# 'imsak'	=> { 'x' => 'the time of commencement of fast' },
# 'inang'	=> { 'x' => 'nursery maid' },
# 'incar'	=> { 'x' => 'gimlet (a tool for boring)' },
 'inci'		=> { 'x' => 'inch' },
 'incut'	=> { 'x' => 'lame',
		     '#' => '; crippled' },
# 'india'	=> { 'x' => 'of india or indians' },
 'indik'	=> { 'x' => 'trample' },
 'inding'	=> { 'x' => 'covet',
		     '#' => 'desire eagerly' },
# 'induk'	=> { 'x' => 'mother (animal)' },
 'inframerah'	=> { 'x' => 'infra-red' },
 'inggeris'	=> { 'x' => 'english' },
 'ini'		=> { 'x' => 'this' },
 'injil'	=> { 'x' => 'bible' },
 'insan'	=> { 'x' => 'mankind' },
# 'insang'	=> { 'x' => 'gill (of fish)' },
 'intan'	=> { 'x' => 'diamond' },
 'intim'	=> { 'x' => 'intimate' },
 'intisari'	=> { 'x' => 'kernel',
		     '#' => 'central or important part' },
 'iras'		=> { 'x' => 'alike' },
# 'iris'		=> { 'x' => 'slice or thin broad piece' },
 'isirung'	=> { 'x' => 'kernel' },
# 'islam'	=> { 'x' => 'of the muslim religion' },
 'istana'	=> { 'x' => 'palace' },
 'istiadat'	=> { 'x' => 'ceremony',
		     '#' => '; ceremonial' },
 'istirehat'	=> { 'x' => 'rest',
		     '#' => '; relax; interval' },
# 'isyak'	=> { 'x' => 'evening prayer (of muslims)' },
 'itik'		=> { 'x' => 'duck' },
 'itu'		=> { 'x' => 'that' },
# 'jaat'		=> { 'x' => 'a kind of bean' },
# 'jabal'	=> { 'x' => '(1) mountain (2) rob' },
 'jabang'	=> { 'x' => 'baby' },
# 'jabar'	=> { 'x' => 'almighty (for god)' },
# 'jabarut'	=> { 'x' => 'sphere attained by the mystic' },
 'jabel'	=> { 'x' => 'nab' },
 'jabhati'	=> { 'x' => 'determination' },
 'jabil'	=> { 'x' => 'sac',
		     '#' => 'pouch; small cloth purse' },
# 'jabing'	=> { 'x' => 'prominent or large (of ears)' },
# 'jabu'		=> { 'x' => 'billowy (of dust, smoke, etc)' },
# 'jabun'	=> { 'x' => 'billowy (of dense foliage)' },
 'jabung'	=> { 'x' => 'glue',
		     '#' => '; resin' },
 'jabur'	=> { 'x' => 'mixed up',
		     '#' => 'psalm' },
 'jadah'	=> { 'x' => 'bastard' },
# 'jadam'	=> { 'x' => 'a kind of medicine' },
# 'jadar'	=> { 'x' => 'a kind of plant' },
 'jae'		=> { 'x' => 'ginger' },
 'jagang'	=> { 'x' => 'shore' },
 'jagoan'	=> { 'x' => 'fighting cock',
		     '#' => 'champion; candidate' },
 'jaguh'	=> { 'x' => 'champion' },
 'jagung'	=> { 'x' => 'maize',
		     '#' => '; corn' },
 'jagur'	=> { 'x' => 'robust',
		     '#' => '; burly' },
 'jah'		=> { 'x' => 'respect',
		     '#' => '; honour' },
# 'jahang'	=> { 'x' => '(1) to abuse angrily (2) dark red' },
 'jahar'	=> { 'x' => 'aloud' },
 'jaharu'	=> { 'x' => 'low-class scoundrel',
		     '#' => 'pariah' },
 'jahi'		=> { 'x' => 'ginger' },
 'jahid'	=> { 'x' => 'ascetic' },
# 'jahim'	=> { 'x' => 'blazing (of hell)' },
 'jahudi'	=> { 'x' => 'jew' },
# 'jail'		=> { 'x' => '(1) rod with noose of fibre (2) sneaky',
#		     '#' => 'nagging' },
 'jais'		=> { 'x' => 'unreceptive',
		     '#' => '; inattentive' },
# 'jaiz'		=> { 'x' => 'lawful or permitted (of muslims)' },
# 'jajal'	=> { 'x' => 'try or attempt' },
# 'jajan'	=> { 'x' => 'buy sweets' },
 'jajat'	=> { 'x' => 'mimic' },
 'jaksa'	=> { 'x' => 'judicial officer',
		     '#' => 'justice' },
 'jalad'	=> { 'x' => 'executioner' },
# 'jamak'	=> { 'x' => 'plural (in grammar)' },
 'jambak'	=> { 'x' => 'bunch of flowers',
		     '#' => 'bouquet; compliment' },
 'jamban'	=> { 'x' => 'latrine',
		     '#' => '; toilet; lavatory' },
 'jambu'	=> { 'x' => 'guava' },
 'jambul'	=> { 'x' => 'crest',
		     '#' => 'tuft on head; plume on helmet' },
 'jampi'	=> { 'x' => 'incantation',
		     '#' => 'magic spell' },
 'jampuk'	=> { 'x' => 'owl' },
# 'janggus'	=> { 'x' => 'a type of tree bearing edible fruit' },
 'jangkung'	=> { 'x' => 'heron' },
 'janin'	=> { 'x' => 'foetus' },
 'jantina'	=> { 'x' => 'gender',
		     '#' => '; sex' },
 'jarah'	=> { 'x' => 'pillage',
		     '#' => '; plunder; rob' },
# 'jaram'	=> { 'x' => 'a compress or pad to stop bleeding, etc' },
 'jari'		=> { 'x' => 'finger' },
 'jasad'	=> { 'x' => 'body' },
 'jata'		=> { 'x' => 'blazon' },
 'jauhari'	=> { 'x' => 'jeweller',
		     '#' => '; expert' },
# 'jawi'		=> { 'x' => 'arabic characters' },
 'jeda'		=> { 'x' => 'interval' },
 'jejaka'	=> { 'x' => 'bachelor',
		     '#' => 'young man' },
 'jejambat'	=> { 'x' => 'flyover' },
 'jejantas'	=> { 'x' => 'flyover' },
 'jejari'	=> { 'x' => 'radius' },
 'jelaga'	=> { 'x' => 'soot' },
 'jelah'	=> { 'x' => 'legible' },
 'jelak'	=> { 'x' => 'fed up',
		     '#' => 'bored' },
# 'jelang'	=> { 'x' => 'eve of' },
 'jelapang'	=> { 'x' => 'granary',
		     '#' => 'rice bowl' },
 'jelata'	=> { 'x' => 'commoner',
		     '#' => 'ordinary people' },
 'jelatang'	=> { 'x' => 'nettle' },
 'jelik'	=> { 'x' => 'ugly',
		     '#' => '; bad; repulsive' },
 'jeluas'	=> { 'x' => 'gory',
		     '#' => '; bloody' },
 'jelujur'	=> { 'x' => 'baste',
		     '#' => 'temporary stitches' },
 'jemaah'	=> { 'x' => 'pilgrim',
		     '#' => '; assembly; congregation' },
 'jemala'	=> { 'x' => 'chump',
		     '#' => '; block' },
 'jembalang'	=> { 'x' => 'gnome' },
 'jempul'	=> { 'x' => 'superfine' },
# 'jemput-jemput'	=> { 'x' => 'dumpling made from mixture of flour and bananas' },
 'jenang'	=> { 'x' => 'window or door frame',
		     '#' => 'jamb' },
 'jenazah'	=> { 'x' => 'corpse' },
 'jendela'	=> { 'x' => 'window' },
 'jentera'	=> { 'x' => 'machinery',
		     '#' => '; machine' },
 'jentolak'	=> { 'x' => 'bulldozer' },
 'jenuh'	=> { 'x' => 'satisfied',
		     '#' => '; full' },
 'jera'		=> { 'x' => 'discourage',
		     '#' => '; dishearten; dissuade' },
 'jeram'	=> { 'x' => 'rapids' },
 'jerami'	=> { 'x' => 'hay',
		     '#' => '; straw' },
 'jeran'	=> { 'x' => 'discourage' },
# 'jerangkap'	=> { 'x' => 'booby trap' },
# 'jerangkung'	=> { 'x' => 'human skeleton' },
 'jerawat'	=> { 'x' => 'pimple' },
 'jerebu'	=> { 'x' => 'haze' },
 'jerekit'	=> { 'x' => 'cohere' },
 'jerih'	=> { 'x' => 'tired' },
 'jeriji'	=> { 'x' => 'grate',
		     't' => 'n' },
# 'jering'	=> { 'x' => 'a type of tree and its malodorous fruit' },
 'jerjak'	=> { 'x' => 'trellis',
		     '#' => '; lattice' },
 'jeruk'	=> { 'x' => 'pickle' },
 'jerumat'	=> { 'x' => 'darn',
		     't' => 'v' },
 'jerung'	=> { 'x' => 'shark' },
 'jidal'	=> { 'x' => 'thimble' },
# 'jihad'	=> { 'x' => 'holy war' },
 'jidar'	=> { 'x' => 'margin',
		     '#' => '; border; edge' },
 'jimak'	=> { 'x' => 'copulation' },
 'jin'		=> { 'x' => 'spirit' },
# 'jingga'	=> { 'x' => 'orange (colour)' },
# 'jinjang'	=> { 'x' => 'long and slender (of neck)' },
# 'jiplak'	=> { 'x' => 'copy or trace' },
# 'jirat'	=> { 'x' => 'non-muslim grave' },
 'jisim'	=> { 'x' => 'body',
		     '#' => '; mass' },
# 'jong'		=> { 'x' => 'junk (sailing ship)' },
# 'jongang'	=> { 'x' => 'protruding (of teeth)' },
 'jongkang-jongket'	=> { 'x' => 'see-saw' },
 'jongkok'	=> { 'x' => 'cringe',
		     '#' => 'cower',
		     't' => 'v' },
 'jongkong'	=> { 'x' => 'ingot',
		     '#' => 'bullion (2) large dug-out canoe',
		     't' => 'n' },
# 'joran'	=> { 'x' => 'fishing rod' },
# 'joreng'	=> { 'x' => 'a small piece or shred' },
# 'jorong'	=> { 'x' => '(1) betel leaf container (2) funnel' },
 'jua'		=> { 'x' => 'also' },
 'juadah'	=> { 'x' => 'comestibles',
		     '#' => 'things to eat' },
# 'juak'		=> { 'x' => 'court page' },
 'jubah'	=> { 'x' => 'robe',
		     '#' => '; chasuble' },
 'jubin'	=> { 'x' => 'tile' },
 'juga'		=> { 'x' => 'also',
		     '#' => '; too' },
 'juita'	=> { 'x' => 'lovely',
		     '#' => '; sweet' },
 'julap'	=> { 'x' => 'laxative' },
 'juling'	=> { 'x' => 'squint' },
 'julukan'	=> { 'x' => 'nickname',
		     '#' => 'pet name; epithet' },
 'jumbai'	=> { 'x' => 'frill' },
 'juru'		=> { 'x' => 'expert' },
 'juruacara'	=> { 'x' => 'master of ceremonies',
		     '#' => 'compere' },
 'juruaudit'	=> { 'x' => 'auditor' },
 'juruazan'	=> { 'x' => 'muezzin' },
 'jurubahasa'	=> { 'x' => 'interpreter' },
 'jurubina'	=> { 'x' => 'architect' },
 'jurucakap'	=> { 'x' => 'spokesman' },
 'jurugambar'	=> { 'x' => 'photographer' },
 'juruhebah'	=> { 'x' => 'announcer' },
 'jurukamera'	=> { 'x' => 'cameraman' },
 'jurukira'	=> { 'x' => 'accountant' },
 'jurulatih'	=> { 'x' => 'coach',
		     '#' => '; trainer' },
 'jurumasak'	=> { 'x' => 'chef' },
 'jurumudi'	=> { 'x' => 'helmsman' },
 'juruoptik'	=> { 'x' => 'optician' },
 'jururawat'	=> { 'x' => 'nurse' },
 'jurusawat'	=> { 'x' => 'mechanic' },
 'juruselam'	=> { 'x' => 'diver' },
 'jurusolek'	=> { 'x' => 'beautician' },
 'jurutaip'	=> { 'x' => 'typist' },
 'juruteknik'	=> { 'x' => 'technician' },
# 'juruterbang'	=> { 'x' => 'air pilot' },
 'jurutrengkas'	=> { 'x' => 'stenographer' },
 'juruulas'	=> { 'x' => 'commentator' },
 'juruwang'	=> { 'x' => 'cashier' },
# 'kaabah'	=> { 'x' => 'cubic black stone building in the mosque in mecca' },
# 'kabisat'	=> { 'x' => 'leap year' },
 'kabus'	=> { 'x' => 'mist' },
 'kaca'		=> { 'x' => 'glass' },
 'kacak'	=> { 'x' => 'handsome',
		     '#' => 'smart-looking' },
 'kacip'	=> { 'x' => 'nutcracker' },
 'kacung'	=> { 'x' => 'mantis' },
# 'kadam'	=> { 'x' => 'sole of foot' },
# 'kadi'		=> { 'x' => 'muslim judge' },
# 'kaduk'	=> { 'x' => 'fool (of malay folklore)' },
 'kaedah'	=> { 'x' => 'method',
		     '#' => '; procedure' },
 'kafan'	=> { 'x' => 'shroud' },
 'kafilah'	=> { 'x' => 'caravan',
		     '#' => 'convoy of travellers' },
 'kahak'	=> { 'x' => 'phlegm' },
 'kain'		=> { 'x' => 'cloth' },
 'kajai'	=> { 'x' => 'collar' },
 'kajang'	=> { 'x' => 'awning',
		     '#' => 'roofing (for boat or cart)' },
 'kaji bintang'	=> { 'x' => 'astronomy' },
 'kaji bumi'	=> { 'x' => 'geology' },
 'kaji cuaca'	=> { 'x' => 'meteorology' },
 'kaji haiwan'	=> { 'x' => 'zoology' },
 'kaji hayat'	=> { 'x' => 'biology' },
 'kaji purba'	=> { 'x' => 'archaeology' },
# 'kaji selidik'	=> { 'x' => 'survey or study' },
 'kaji tumbuhan'	=> { 'x' => 'botany' },
# 'kakak'	=> { 'x' => 'elder sister' },
 'kakak ipar'	=> { 'x' => 'sister-in-law' },
 'kakaktua'	=> { 'x' => 'cockatoo',
		     '#' => '; parrot' },
# 'kakanda'	=> { 'x' => 'elder brother or sister' },
 'kaki ayam'	=> { 'x' => 'barefoot' },
# 'kaki bangku'	=> { 'x' => 'one who cannot play football' },
# 'kaki bola'	=> { 'x' => 'one who loves football' },
 'kaki gaduh'	=> { 'x' => 'trouble-maker' },
 'kaki judi'	=> { 'x' => 'gambler' },
# 'kalam'	=> { 'x' => 'writing pen' },
# 'kalang'	=> { 'x' => 'transverse support' },
# 'kalangan'	=> { 'x' => 'circle or group with similar interests' },
 'kalbu'	=> { 'x' => 'heart' },
 'kaldu'	=> { 'x' => 'broth' },
# 'kalimantang'	=> { 'x' => 'fluorescent light' },
 'kalimat'	=> { 'x' => 'sentence',
		     '#' => '; period' },
 'kalis'	=> { 'x' => 'proof',
		     '#' => 'able to withstand' },
 'kalis air'	=> { 'x' => 'waterproof' },
 'kalis api'	=> { 'x' => 'fireproof' },
 'kalis karat'	=> { 'x' => 'rust-proof' },
 'kalis peluru'	=> { 'x' => 'bullet-proof' },
 'kaloi'	=> { 'x' => 'carp' },
 'kalut'	=> { 'x' => 'muddle',
		     '#' => '; confusion; disorder' },
 'kamar'	=> { 'x' => 'room' },
 'kami'		=> { 'x' => 'we',
		     '#' => '; us' },
 'kamir'	=> { 'x' => 'yeast' },
 'kampit'	=> { 'x' => 'portable case',
		     '#' => 'sack' },
 'kamu'		=> { 'x' => 'you',
		     '#' => '; your' },
 'kamus'	=> { 'x' => 'dictionary' },
 'kanak-kanak'	=> { 'x' => 'child' },
# 'kanan'	=> { 'x' => '(1) right (2) senior' },
 'kancil'	=> { 'x' => 'mousedeer' },
 'kantung'	=> { 'x' => 'pouch',
		     '#' => '; purse' },
# 'kanun'	=> { 'x' => 'code of law' },
 'kapah'	=> { 'x' => 'gasp',
		     '#' => '; tremble' },
# 'kapai'	=> { 'x' => 'to flap the arms to stay afloat' },
 'kapal angkasa'	=> { 'x' => 'spaceship' },
 'kapal induk'	=> { 'x' => 'mothership' },
 'kapal korek'	=> { 'x' => 'dredge' },
 'kapal perang'	=> { 'x' => 'battleship' },
 'kapal selam'	=> { 'x' => 'submarine' },
 'kapal terbang'	=> { 'x' => 'aeroplane' },
 'kapas'	=> { 'x' => 'cotton' },
# 'kapuk'	=> { 'x' => 'a type of cotton' },
 'kapung'	=> { 'x' => 'afloat' },
 'karam'	=> { 'x' => 'sink (of ship)',
		     '#' => 'submerge' },
 'karau'	=> { 'x' => 'churn' },
 'kardus'	=> { 'x' => 'hardboard' },
 'kari'		=> { 'x' => 'curry' },
 'karib'	=> { 'x' => 'intimate' },
# 'karkas'	=> { 'x' => 'crabbed (of handwriting)' },
 'karung'	=> { 'x' => 'sack' },
 'kasa'		=> { 'x' => 'gauze' },
 'kasap'	=> { 'x' => 'craggy',
		     '#' => '; rugged' },
 'kasuari'	=> { 'x' => 'ostrich' },
 'kasut'	=> { 'x' => 'shoe' },
 'katak'	=> { 'x' => 'frog' },
 'katik'	=> { 'x' => 'small',
		     '#' => '; short; stunted' },
 'katuk'	=> { 'x' => 'knock',
		     '#' => '; to tap',
		     't' => 'v' },
# 'kau'		=> { 'x' => 'you (abbreviation of "engkau")' },
 'kaus'		=> { 'x' => 'hose' },
 'kaus kaki'	=> { 'x' => 'footwear' },
# 'kaut'		=> { 'x' => 'scoop up' },
 'kawah'	=> { 'x' => 'cauldron',
		     '#' => 'large pan; crater' },
 'kawasan'	=> { 'x' => 'area',
		     '#' => '; region' },
 'kawat'	=> { 'x' => 'cable',
		     '#' => '; wire' },
# 'kawat berduri'	=> { 'x' => 'barbed wire' },
 'kayangan'	=> { 'x' => 'fairyland',
		     '#' => 'very beautiful place' },
 'kayap'	=> { 'x' => 'shingles' },
 'keadaan'	=> { 'x' => 'condition',
		     '#' => '; situation; circumstances',
		     't' => 'n',
		     'df' => 'ada' },
 'kebanyakan'	=> { 'x' => 'most of',
		     '#' => '; majority of',
		     'df' => 'banyak' },
 'kecamuk'	=> { 'x' => 'causing to feel stunned or bewildered',
		     '#' => 'furious (of combat)' },
 'kecapi'	=> { 'x' => 'lute' },
 'kecundang'	=> { 'x' => 'defeated',
		     '#' => '; beaten' },
 'kecur'	=> { 'x' => 'mouth-watering' },
# 'kedal'	=> { 'x' => 'skin disease of hands and feet' },
# 'kedang'	=> { 'x' => 'outstretched (of limb)' },
 'kedekut'	=> { 'x' => 'stingy' },
 'kedip'	=> { 'x' => 'blink',
		     '#' => '; twinkle; flicker' },
 'kejora'	=> { 'x' => 'venus' },
 'keju'		=> { 'x' => 'cheese' },
 'kejur'	=> { 'x' => 'stiff' },
 'kekok'	=> { 'x' => 'clumsy' },
 'kekuda'	=> { 'x' => 'trestle' },
 'kelabu'	=> { 'x' => 'grey' },
 'keladak'	=> { 'x' => 'dregs',
		     '#' => '; sediment' },
 'keladi'	=> { 'x' => 'yam' },
# 'kelak'	=> { 'x' => 'soon after' },
 'kelalang'	=> { 'x' => 'earthenware pitcher',
		     '#' => 'flask' },
 'kelambu'	=> { 'x' => 'mosquito-net' },
 'kelangkang'	=> { 'x' => 'crotch',
		     '#' => '; groin' },
# 'kelapa sawit'	=> { 'x' => 'oil palm' },
 'kelar'	=> { 'x' => 'nick',
		     '#' => 'small cut (2) segment of centipede',
		     't' => 'n' },
 'kelasi'	=> { 'x' => 'sailor' },
# 'kelat'	=> { 'x' => 'bitterish in taste' },
# 'kelawar'	=> { 'x' => 'bat (animal)' },
 'keldai'	=> { 'x' => 'ass',
		     '#' => '; donkey' },
# 'keledek'	=> { 'x' => 'sweet potato' },
 'kelek-kelek'	=> { 'x' => 'armrest' },
 'kelemayar'	=> { 'x' => 'glow-worm' },
 'kelemayuh'	=> { 'x' => 'gangrene' },
 'kelemumur'	=> { 'x' => 'dandruff' },
# 'kelengkeng'	=> { 'x' => 'little finger' },
 'kelenjar'	=> { 'x' => 'gland' },
# 'kelentang'	=> { 'x' => 'clanking sound' },
# 'kelenting'	=> { 'x' => 'clanging noise' },
# 'kelentong'	=> { 'x' => '(1) to bluff (2) hawker\'s rattle' },
 'kelentit'	=> { 'x' => 'clitoris' },
 'kelepet'	=> { 'x' => 'lapel' },
 'keletah'	=> { 'x' => 'coquettish' },
# 'keli'		=> { 'x' => 'river catfish' },
 'keliar'	=> { 'x' => 'gallivant',
		     '#' => '; to prowl',
		     't' => 'v' },
# 'kelibat'	=> { 'x' => 'double-headed paddle' },
 'kelicap'	=> { 'x' => 'sun-bird' },
 'kelikir'	=> { 'x' => 'gravel',
		     '#' => 'rattan ring' },
 'kelim'	=> { 'x' => 'hem (of cloth)',
		     '#' => 'seam' },
 'kelinci'	=> { 'x' => 'hare' },
 'kelip-kelip'	=> { 'x' => 'firefly' },
# 'kelmarin'	=> { 'x' => 'day before yesterday' },
# 'kelompong'	=> { 'x' => 'part of telephone on which the receiver rests' },
 'kelonet'	=> { 'x' => 'measly',
		     '#' => '; meagre' },
# 'kelong'	=> { 'x' => 'fish tunnel net' },
# 'kelongsong'	=> { 'x' => 'leaf or paper cone used as container or wrapper' },
 'kelontong'	=> { 'x' => 'haberdashery' },
 'kelu'		=> { 'x' => 'speechless' },
# 'keluang'	=> { 'x' => 'flying fox' },
 'keluli'	=> { 'x' => 'steel' },
 'kelumit'	=> { 'x' => 'morsel',
		     '#' => 'very small amount' },
 'kemala'	=> { 'x' => 'bezoar' },
 'kemanakan'	=> { 'x' => 'nephew',
		     '#' => '; niece' },
 'kemarau'	=> { 'x' => 'drought' },
 'kemaruk'	=> { 'x' => 'rapacious',
		     '#' => 'ravenous; very hungry or greedy' },
# 'kematu'	=> { 'x' => 'corn (hardened area of skin)' },
 'kembar'	=> { 'x' => 'twin' },
 'kembiri'	=> { 'x' => 'castrate' },
 'kemboja'	=> { 'x' => 'frangipani' },
# 'kembu'	=> { 'x' => 'creel; angler\'s basket' },
 'kembung'	=> { 'x' => 'flatulent',
		     '#' => 'distended from pressure within' },
 'kemeja'	=> { 'x' => 'shirt' },
 'kemelut'	=> { 'x' => 'crucial or critical',
		     '#' => 'crisis; emergency' },
 'kemenyan'	=> { 'x' => 'incense' },
 'kemik'	=> { 'x' => 'dent',
		     '#' => '; dented' },
# 'kempas-kempis'	=> { 'x' => 'inflate and deflate' },
# 'kempunan'	=> { 'x' => 'longing for' },
 'kemuncak'	=> { 'x' => 'peak',
		     '#' => '; summit' },
# 'kemuncup'	=> { 'x' => 'love grass' },
 'kencang'	=> { 'x' => 'boisterous',
		     '#' => 'strong (of wind)' },
 'kencing'	=> { 'x' => 'urine' },
# 'kencing manis'	=> { 'x' => 'diabetes mellitus' },
 'kenderaan'	=> { 'x' => 'vehicle' },
# 'kendi'	=> { 'x' => '(1) cylindrical glass or earthenware jar (2) curlew' },
 'kenduri'	=> { 'x' => 'feast',
		     't' => 'n' },
# 'kengkang'	=> { 'x' => 'to walk with legs wide apart' },
 'kening'	=> { 'x' => 'eyebrow' },
 'kenit'	=> { 'x' => 'tiny',
		     '#' => '; midget; dwarf' },
# 'kental'	=> { 'x' => 'thick (of fluid)' },
 'kentang'	=> { 'x' => 'potato' },
 'kenyal'	=> { 'x' => 'pliable',
		     '#' => '; elastic' },
# 'kepada'	=> { 'x' => 'to (person)' },
 'kepah'	=> { 'x' => 'mussel' },
 'kepal'	=> { 'x' => 'lump' },
 'kepalan'	=> { 'x' => 'lump' },
 'kepalang'	=> { 'x' => 'little' },
 'keparat'	=> { 'x' => 'non-believer' },
 'kepialu'	=> { 'x' => 'typhoid' },
 'kepil'	=> { 'x' => 'attach' },
# 'kepiting'	=> { 'x' => 'soft-shelled crab' },
 'kepompong'	=> { 'x' => 'chrysalis',
		     '#' => '; pupa' },
# 'kepuk'	=> { 'x' => 'rice barn' },
 'kera'		=> { 'x' => 'monkey' },
 'kerabat'	=> { 'x' => 'kinship',
		     '#' => '; relatives' },
 'keraian'	=> { 'x' => 'festival',
		     '#' => '; entertainment' },
# 'kerak'	=> { 'x' => 'crust (e.g of bread)' },
 'kerakal'	=> { 'x' => 'pebble' },
# 'keramat'	=> { 'x' => 'one having supernatural powers' },
# 'kerambit'	=> { 'x' => 'small sickle with curved end' },
 'keran'	=> { 'x' => 'faucet',
		     '#' => '; tap' },
 'kerana'	=> { 'x' => 'because',
		     '#' => 'for the sake of' },
 'keranda'	=> { 'x' => 'coffin',
		     '#' => '; casket' },
 'kerang'	=> { 'x' => 'cockle',
		     '#' => '; shellfish' },
 'kerangka'	=> { 'x' => 'framework',
		     '#' => '; chassis; carcass; draft' },
 'kerani'	=> { 'x' => 'clerk' },
 'keranjang'	=> { 'x' => 'crate',
		     '#' => '; basket' },
 'kerawang'	=> { 'x' => 'fretwork' },
 'kerdil'	=> { 'x' => 'cretinous',
		     '#' => 'dwarfish (2) cretin; dwarf',
		     't' => 'a' },
 'kerdip'	=> { 'x' => 'twinkle',
		     '#' => '; wink' },
# 'kerek'	=> { 'x' => 'apparatus for hoisting things' },
 'kerekot'	=> { 'x' => 'twisted' },
 'kerenah'	=> { 'x' => 'whim',
		     '#' => '; caprice' },
# 'kerengga'	=> { 'x' => 'red ant' },
# 'kerepek'	=> { 'x' => 'fried chips of banana, tapioca, sweet potato, etc. ' },
# 'keretek'	=> { 'x' => 'a type of cigarette containing tobacco and cloves' },
# 'keria'	=> { 'x' => 'crane (bird)' },
 'kericau'	=> { 'x' => 'chirp' },
 'kerikil'	=> { 'x' => 'pebble' },
 'kerinting'	=> { 'x' => 'frizzy',
		     '#' => 'a perm or artificial wave in the hair' },
# 'kerip'	=> { 'x' => 'nip with the front teeth' },
# 'keris'	=> { 'x' => 'malay dagger' },
# 'kerisik'	=> { 'x' => '(1) dry old banana fronds (2) rustling of dry leaves' },
 'kerjaya'	=> { 'x' => 'career' },
# 'kerkah'	=> { 'x' => 'crunch noisily with the teeth' },
# 'kerkap'	=> { 'x' => 'a crunching sound' },
# 'kerlap'	=> { 'x' => 'a short nap' },
 'kernyih'	=> { 'x' => 'grin' },
 'kerongsang'	=> { 'x' => 'brooch' },
# 'keropok'	=> { 'x' => 'crackers or chips (usually made from shrimps)' },
 'kersang'	=> { 'x' => 'barren',
		     '#' => '; dry' },
 'kersik'	=> { 'x' => 'grit' },
# 'kertak'	=> { 'x' => 'gnash or grind (one\'s teeth)' },
 'kertas'	=> { 'x' => 'paper' },
 'kertau'	=> { 'x' => 'mulberry' },
 'keruan'	=> { 'x' => 'certain',
		     '#' => '; definite' },
 'kerubung'	=> { 'x' => 'swarm' },
 'kerudung'	=> { 'x' => 'cowl' },
 'keruping'	=> { 'x' => 'scab',
		     '#' => 'crust or clotted blood on a wound' },
# 'kerutu'	=> { 'x' => 'rough to the touch' },
 'kesah'	=> { 'x' => 'restless' },
 'kesahan'	=> { 'x' => 'authenticity',
		     '#' => '; legality; legitimacy' },
# 'kesak'	=> { 'x' => 'move on slowly' },
 'kesal'	=> { 'x' => 'regretable',
		     '#' => '; deplorable; regret' },
 'kesatria'	=> { 'x' => 'warrior' },
# 'ketak'	=> { 'x' => 'cackle (of hens)' },
 'ketap'	=> { 'x' => 'clench',
		     '#' => 'grit (2) plain; evident' },
 'ketar'	=> { 'x' => 'doddery',
		     '#' => '; trembling' },
 'ketara'	=> { 'x' => 'conspicuous',
		     '#' => '; obvious' },
 'ketemu'	=> { 'x' => 'meet' },
 'ketiak'	=> { 'x' => 'armpit' },
# 'ketik'	=> { 'x' => 'clack (short sharp sound)' },
# 'keting'	=> { 'x' => 'part of the leg just above the heel' },
 'ketingting'	=> { 'x' => 'hopscotch' },
 'ketip'	=> { 'x' => 'sting of a mosquito bite',
		     '#' => 'pinch' },
 'ketitir'	=> { 'x' => 'turtle-dove' },
 'ketuhar'	=> { 'x' => 'oven' },
 'ketumbar'	=> { 'x' => 'coriander' },
 'ketumbit'	=> { 'x' => 'stye' },
# 'ketupat'	=> { 'x' => 'cooked rice packed in palm leaves' },
 'khadam'	=> { 'x' => 'household servant',
		     '#' => 'subordinate assistant' },
# 'khalayak'	=> { 'x' => 'creature; mankind; god\'s creations' },
 'khalifah'	=> { 'x' => 'caliph' },
# 'khalwat'	=> { 'x' => 'state of an unmarried couple being together in seclusion' },
 'khas'		=> { 'x' => 'special' },
 'khat'		=> { 'x' => 'hand-writing' },
 'khatam'	=> { 'x' => 'end',
		     '#' => '; conclude; complete' },
# 'khatib'	=> { 'x' => 'preacher in mosque' },
 'khatulistiwa'	=> { 'x' => 'equator' },
 'khazanah'	=> { 'x' => 'treasury' },
 'khilaf'	=> { 'x' => 'blunder',
		     '#' => '; mistake' },
 'khuatir'	=> { 'x' => 'worried',
		     '#' => '; afraid' },
 'khunsa'	=> { 'x' => 'hermaphrodite' },
# 'khusyuk'	=> { 'x' => '(1) engrossed (2) humility' },
 'kiamat'	=> { 'x' => 'doomsday',
		     '#' => 'day of judgement' },
 'kiambang'	=> { 'x' => 'water-lily' },
# 'kiblat'	=> { 'x' => 'direction of mecca' },
 'kicap'	=> { 'x' => 'ketchup' },
 'kidal'	=> { 'x' => 'left-handed' },
 'kijang'	=> { 'x' => 'deer' },
# 'kikir'	=> { 'x' => '(1) stingy (2) a file (for smoothening things)' },
 'kili-kili'	=> { 'x' => 'spool' },
 'kimia'	=> { 'x' => 'chemistry' },
 'kini'		=> { 'x' => 'now' },
 'kirai'	=> { 'x' => 'shake out',
		     '#' => 'winnow (rice)' },
 'kiri'		=> { 'x' => 'left' },
 'kismis'	=> { 'x' => 'raisin' },
 'kita'		=> { 'x' => 'we',
		     '#' => '; us' },
 'kitab'	=> { 'x' => 'book' },
# 'kitaran'	=> { 'x' => 'cycle of events' },
 'kocek'	=> { 'x' => 'pocket' },
 'kocok'	=> { 'x' => 'shake',
		     '#' => '; to mix; to incite',
		     't' => 'v' },
# 'kodi'		=> { 'x' => 'a score (twenty)' },
 'kodok'	=> { 'x' => 'frog' },
 'kohong'	=> { 'x' => 'fetid',
		     '#' => '; stinking' },
# 'kolah'	=> { 'x' => 'square stone or cement water tank' },
 'kolam'	=> { 'x' => 'pond' },
 'kole'		=> { 'x' => 'mug' },
 'kolek'	=> { 'x' => 'canoe' },
 'kolot'	=> { 'x' => 'old-fashioned',
		     '#' => 'out-of-date' },
# 'kompang'	=> { 'x' => 'shallow drum' },
 'kongkong'	=> { 'x' => 'pillory' },
# 'konon'	=> { 'x' => 'it is said' },
 'kontang'	=> { 'x' => 'dry',
		     '#' => '; parched' },
 'kopi'		=> { 'x' => 'coffee' },
# 'kopiah'	=> { 'x' => 'malay cap' },
 'korok'	=> { 'x' => 'burrow',
		     't' => 'n' },
 'kotak'	=> { 'x' => 'box' },
# 'kuaci'	=> { 'x' => 'dried melon seed' },
 'kuah'		=> { 'x' => 'gravy' },
 'kuala'	=> { 'x' => 'estuary',
		     '#' => 'confluence of rivers' },
 'kuali'	=> { 'x' => 'frying-pan' },
 'kubah'	=> { 'x' => 'dome' },
 'kubis'	=> { 'x' => 'cabbage' },
 'kubu'		=> { 'x' => 'fortress' },
 'kubung'	=> { 'x' => 'lemur' },
# 'kucai'	=> { 'x' => 'chive (vegetable)' },
# 'kucar-kacir'	=> { 'x' => 'in complete confusion' },
 'kucing'	=> { 'x' => 'cat' },
 'kuda belang'	=> { 'x' => 'zebra' },
 'kuda-kuda'	=> { 'x' => 'trestle',
		     '#' => 'easel' },
# 'kudis'	=> { 'x' => 'skin sore' },
 'kudrat'	=> { 'x' => 'god\'s might' },
 'kudung'	=> { 'x' => 'maimed' },
 'kudup'	=> { 'x' => 'bud' },
 'kudus'	=> { 'x' => 'holy',
		     '#' => '; sacred; blessed' },
# 'kugiran'	=> { 'x' => 'musical group' },
 'kuih'		=> { 'x' => 'cake',
		     '#' => '; cookie' },
 'kuil'		=> { 'x' => 'temple' },
 'kuinin'	=> { 'x' => 'quinine' },
# 'kuit'		=> { 'x' => 'touch with the fingertips' },
 'kuku'		=> { 'x' => 'nail',
		     '#' => '; claw' },
 'kulapuk'	=> { 'x' => 'mildew' },
 'kulat'	=> { 'x' => 'fungus',
		     '#' => '; mushroom' },
 'kuliah'	=> { 'x' => 'lecture' },
 'kulup'	=> { 'x' => 'foreskin' },
 'kumai'	=> { 'x' => 'moulding' },
 'kuman'	=> { 'x' => 'germ' },
 'kumandang'	=> { 'x' => 'echo' },
 'kumbang'	=> { 'x' => 'beetle' },
 'kumis'	=> { 'x' => 'moustache' },
 'kumparan'	=> { 'x' => 'bobbin' },
 'kumuh'	=> { 'x' => 'excrete' },
 'kunang-kunang'	=> { 'x' => 'firefly' },
# 'kundang'	=> { 'x' => 'a page boy' },
 'kundur'	=> { 'x' => 'wax-gourd' },
 'kuno'		=> { 'x' => 'ancient',
		     '#' => 'old-fashioned' },
 'kunyit'	=> { 'x' => 'turmeric' },
# 'kupang'	=> { 'x' => 'an old type of coin' },
 'kuping'	=> { 'x' => 'ear',
		     '#' => '; scab' },
 'kupu-kupu'	=> { 'x' => 'butterfly' },
 'kura-kura'	=> { 'x' => 'tortoise' },
 'kurap'	=> { 'x' => 'ringworm' },
# 'kurma'	=> { 'x' => '(1) a date (fruit) (2) a spicy dish' },
 'kurun'	=> { 'x' => 'century' },
# 'kusam'	=> { 'x' => 'matt or dull (of a surface)' },
 'kusta'	=> { 'x' => 'leprosy' },
# 'kutak'	=> { 'x' => 'shake violently' },
 'kutang'	=> { 'x' => 'bodice',
		     '#' => '; brassiere' },
 'kutu'		=> { 'x' => 'louse',
		     '#' => '; flea' },
# 'kutub'	=> { 'x' => 'pole (of earth\'s axis or magnet)' },
 'kuyu'		=> { 'x' => 'dewy-eyed',
		     '#' => 'sad' },
 'kuyup'	=> { 'x' => 'drenched' },
 'laba'		=> { 'x' => 'profit' },
 'labah-labah'	=> { 'x' => 'spider' },
# 'labang'	=> { 'x' => 'hard of hearing' },
# 'labi-labi'	=> { 'x' => 'river turtle' },
 'labu'		=> { 'x' => 'gourd' },
 'labuci'	=> { 'x' => 'sequin',
		     '#' => '; spangle' },
# 'labuh'	=> { 'x' => '(1)hanging down',
#		     '#' => 'long (of dress) (2)to anchor' },
 'labur'	=> { 'x' => 'invest',
		     't' => 'v' },
 'laci'		=> { 'x' => 'drawer' },
 'lacur'	=> { 'x' => 'indecent',
		     '#' => '; obscene' },
 'lada'		=> { 'x' => 'chillies',
		     '#' => '; pepper' },
 'ladam'	=> { 'x' => 'horseshoe' },
 'ladang'	=> { 'x' => 'estate',
		     '#' => '; farm; plantation' },
 'laden'	=> { 'x' => 'serve',
		     '#' => 'to wait on',
		     't' => 'v' },
# 'lading'	=> { 'x' => '(1)a type of broad and curved chopper (2)a dug-out canoe' },
 'lafaz'	=> { 'x' => 'utterance' },
 'laga'		=> { 'x' => 'clash',
		     '#' => '; collide; fight' },
 'lagak'	=> { 'x' => 'manner',
		     '#' => '; conduct; behaviour; swank' },
# 'lagang'	=> { 'x' => 'to begin weaving' },
 'lagi'		=> { 'x' => 'again',
		     '#' => '; still; and; also; more; additional' },
# 'lagi-lagi'	=> { 'x' => 'again and again' },
 'lagipun'	=> { 'x' => 'moreover',
		     '#' => '; besides' },
 'lagu'		=> { 'x' => 'song' },
# 'lahad'	=> { 'x' => 'niche for the corpse in a muslim grave' },
 'lahap'	=> { 'x' => 'gluttonous',
		     '#' => 'greedy (2)to eat greedily' },
 'lahar'	=> { 'x' => 'lava' },
 'lahir'	=> { 'x' => 'born' },
 'laici'	=> { 'x' => 'lychee' },
# 'laidaun'	=> { 'x' => 'blade (e.g. of grass)' },
 'lain'		=> { 'x' => 'other',
		     '#' => '; different' },
 'lain-lainnya'	=> { 'x' => 'etcetera',
		     '#' => 'others' },
 'lajak'	=> { 'x' => 'fast',
		     '#' => '; outspoken' },
 'laju'		=> { 'x' => 'fast' },
# 'lajur'	=> { 'x' => 'column (e.g. of troops)' },
 'lakar'	=> { 'x' => 'sketch',
		     '#' => '; to outline',
		     't' => 'v' },
 'lakaran'	=> { 'x' => 'sketch',
		     't' => 'n' },
 'laki'		=> { 'x' => 'husband' },
 'laki-laki'	=> { 'x' => 'male' },
 'laknat'	=> { 'x' => 'damn',
		     '#' => 'to curse; a curse',
		     't' => 'v' },
# 'lakon'	=> { 'x' => 'to act (in a play or film)' },
 'lakonan'	=> { 'x' => 'act',
		     '#' => '; a play; a drama',
		     't' => 'n' },
# 'laksa'	=> { 'x' => 'a preparation of noodles' },
 'laksamana'	=> { 'x' => 'admiral' },
 'laksana'	=> { 'x' => 'perform',
		     '#' => '; to execute; to accomplish',
		     't' => 'v' },
 'lakur'	=> { 'x' => 'fuse',
		     '#' => '; blend' },
# 'lala'		=> { 'x' => 'a type of sea mollusc' },
 'lalah'	=> { 'x' => 'gobble',
		     't' => 'v' },
 'lalai'	=> { 'x' => 'careless',
		     '#' => '; negligent; indifferent' },
 'lalak'	=> { 'x' => 'yell',
		     't' => 'v' },
# 'lalang'	=> { 'x' => 'long-bladed grass' },
# 'lalat'	=> { 'x' => 'a fly (insect)' },
 'lali'		=> { 'x' => 'immune',
		     't' => 'a' },
 'lalu'		=> { 'x' => 'pass',
		     '#' => 'to make way; to elapse (of time)',
		     't' => 'v' },
 'lalu lintas'	=> { 'x' => 'traffic' },
# 'lalu-lalang'	=> { 'x' => 'passing back and forth' },
 'laluan'	=> { 'x' => 'passage' },
# 'lalut'	=> { 'x' => 'disjointed (of talk)' },
 'lama'		=> { 'x' => 'old',
		     '#' => 'a long time' },
 'lama-lama'	=> { 'x' => 'finally' },
# 'lama-lamaan'	=> { 'x' => 'in the long run' },
 'lamar'	=> { 'x' => 'propose',
		     '#' => 'put forward',
		     't' => 'v' },
 'lamaran'	=> { 'x' => 'proposal',
		     '#' => '; application' },
 'lambai'	=> { 'x' => 'wave',
		     't' => 'v' },
# 'lambak'	=> { 'x' => 'disorderly heap' },
 'lambang'	=> { 'x' => 'symbol',
		     '#' => 'emblem;' },
 'lambat'	=> { 'x' => 'slow',
		     '#' => '; late' },
# 'lambat-laun'	=> { 'x' => 'sooner or later' },
 'lambuk'	=> { 'x' => 'friable' },
 'lambung'	=> { 'x' => 'lob',
		     '#' => 'to toss up; to bounce up (2)bulwark',
		     't' => 'v' },
# 'lamin'	=> { 'x' => 'bridal dais' },
 'lampai'	=> { 'x' => 'lanky',
		     '#' => '; slim' },
# 'lampan'	=> { 'x' => 'tin mine' },
 'lampau'	=> { 'x' => 'abysmal',
		     '#' => '; extreme; excessive' },
 'lampin'	=> { 'x' => 'napkin',
		     '#' => '; diaper' },
 'lampir'	=> { 'x' => 'affix',
		     '#' => '; to attach; to enclose',
		     't' => 'v' },
 'lampiran'	=> { 'x' => 'attachment',
		     '#' => '; enclosure; appendix' },
 'lampu'	=> { 'x' => 'lamp' },
 'lampung'	=> { 'x' => 'float' },
# 'lamun'	=> { 'x' => 'to day-dream' },
# 'lamunan'	=> { 'x' => 'a day-dream' },
 'lanar'	=> { 'x' => 'alluvium' },
 'lanau'	=> { 'x' => 'silt' },
 'lanca'	=> { 'x' => 'rickshaw' },
 'lancang'	=> { 'x' => 'outspoken',
		     '#' => 'cheeky (2)a swift-sailing yacht',
		     't' => 'a' },
 'lancar'	=> { 'x' => 'fluent',
		     '#' => '; smooth' },
 'lancip'	=> { 'x' => 'tapered' },
# 'lancong'	=> { 'x' => 'to travel or tour' },
 'lancung'	=> { 'x' => 'phoney',
		     '#' => '; sham; false' },
# 'lancur'	=> { 'x' => 'to gush out' },
 'landa'	=> { 'x' => 'hit',
		     '#' => '; strike; enter forcefully',
		     't' => 'v' },
# 'landai'	=> { 'x' => 'gently sloping' },
 'landak'	=> { 'x' => 'porcupine',
		     '#' => '; hedgehog' },
 'landas'	=> { 'x' => 'base',
		     '#' => '; foundation' },
 'landasan'	=> { 'x' => 'rail' },
# 'langah'	=> { 'x' => 'to open widely' },
 'langak'	=> { 'x' => 'search',
		     't' => 'v' },
# 'langau'	=> { 'x' => 'bluebottle fly' },
# 'langgai'	=> { 'x' => 'the shell of leguminous seeds' },
 'langgan'	=> { 'x' => 'subscribe',
		     't' => 'v' },
 'langganan'	=> { 'x' => 'subscription' },
 'langgar'	=> { 'x' => 'collide',
		     't' => 'v' },
 'langit'	=> { 'x' => 'sky' },
 'langit-langit'	=> { 'x' => 'canopy' },
 'langkah'	=> { 'x' => 'step',
		     't' => 'n' },
 'langkan'	=> { 'x' => 'baluster' },
 'langkas'	=> { 'x' => 'fall of the fruit',
		     '#' => 'end of fruit season' },
# 'langkau'	=> { 'x' => 'to skip or omit' },
# 'langkup'	=> { 'x' => 'overturned or upside-down' },
# 'langsai'	=> { 'x' => 'to settle or clear (of debt)' },
 'langsing'	=> { 'x' => 'slender',
		     '#' => 'slim and graceful' },
 'langsir'	=> { 'x' => 'curtain' },
# 'langsuir'	=> { 'x' => 'a female vampire' },
 'langsung'	=> { 'x' => 'direct' },
 'lanjur'	=> { 'x' => 'expand',
		     't' => 'v' },
 'lanjut'	=> { 'x' => 'continuous' },
 'lanjutan'	=> { 'x' => 'continuation' },
 'lantai'	=> { 'x' => 'floor' },
 'lantak'	=> { 'x' => 'hammer' },
 'lantang'	=> { 'x' => 'clarion',
		     '#' => '; audible; loud' },
# 'lantar'	=> { 'x' => 'to put forward' },
 'lantas'	=> { 'x' => 'forthwith',
		     '#' => 'straight away' },
 'lantik'	=> { 'x' => 'appoint',
		     't' => 'v' },
 'lantikan'	=> { 'x' => 'appointment' },
 'lantun'	=> { 'x' => 'bounce',
		     '#' => '; to rebound',
		     't' => 'v' },
 'lantur'	=> { 'x' => 'digress',
		     '#' => '; to deviate',
		     't' => 'v' },
 'lanun'	=> { 'x' => 'pirate' },
 'lanyak'	=> { 'x' => 'trample',
		     't' => 'v' },
 'lap'		=> { 'x' => 'wipe',
		     '#' => '; to mop',
		     't' => 'v' },
 'lapah'	=> { 'x' => 'skin',
		     '#' => '; to devour',
		     't' => 'v' },
 'lapan'	=> { 'x' => 'eight' },
 'lapang'	=> { 'x' => 'spacious',
		     '#' => 'roomy; open and wide; free (of time)' },
# 'lapangan'	=> { 'x' => '(1)field (2)sphere of interest' },
 'lapangan terbang'	=> { 'x' => 'airfield' },
 'lapar'	=> { 'x' => 'hungry' },
 'lapik'	=> { 'x' => 'underlayer',
		     '#' => '; lining' },
 'lapis'	=> { 'x' => 'layered' },
 'lapisan'	=> { 'x' => 'layer',
		     '#' => '; class' },
 'lapor'	=> { 'x' => 'report',
		     't' => 'v' },
 'laporan'	=> { 'x' => 'report',
		     't' => 'n' },
 'lapuk'	=> { 'x' => 'mouldy',
		     '#' => '; stale' },
 'lara'		=> { 'x' => 'heartache',
		     '#' => '; sorrow' },
 'laram'	=> { 'x' => 'stylish',
		     '#' => '; showy' },
 'larang'	=> { 'x' => 'prohibit',
		     '#' => '; to forbid',
		     't' => 'v' },
 'larangan'	=> { 'x' => 'prohibition' },
# 'laras'	=> { 'x' => 'barrel (e.g. of gun)' },
 'larat'	=> { 'x' => 'able',
		     '#' => 'dragging on' },
 'lari'		=> { 'x' => 'run',
		     't' => 'v' },
 'larik'	=> { 'x' => 'carve',
		     '#' => 'smoothen with a lathe',
		     't' => 'v' },
 'laris'	=> { 'x' => 'in damand',
		     '#' => 'marketable' },
 'larut'	=> { 'x' => 'dissolving',
		     '#' => 'melting (2)late (of night)',
		     't' => 'a' },
 'lasak'	=> { 'x' => 'durable' },
 'lasam'	=> { 'x' => 'faded' },
 'lastik'	=> { 'x' => 'catapult' },
 'lata'		=> { 'x' => 'waterfall',
		     '#' => '(1)to creep (2)cascade' },
# 'latah'	=> { 'x' => 'to say or do something unconsciously out of shock or fright' },
 'latar'	=> { 'x' => 'setting' },
 'latar belakang'	=> { 'x' => 'background' },
 'latih'	=> { 'x' => 'train',
		     '#' => '; to practise',
		     't' => 'v' },
 'latihan'	=> { 'x' => 'training',
		     '#' => 'practice;' },
# 'latihan asas'	=> { 'x' => 'basic training' },
# 'latuk'	=> { 'x' => 'a type of large knife curved at the top' },
 'lau burung'	=> { 'x' => 'aviary' },
# 'lauk'		=> { 'x' => 'a cooked dish of fish, meat, etc' },
# 'lauk-pauk'	=> { 'x' => 'a variety of cooked dishes' },
 'laung'	=> { 'x' => 'shout',
		     '#' => 'to call loudly',
		     't' => 'v' },
 'laungan'	=> { 'x' => 'shout',
		     '#' => 'a loud cry',
		     't' => 'n' },
 'laut'		=> { 'x' => 'sea' },
 'lautan'	=> { 'x' => 'ocean' },
 'lawa'		=> { 'x' => 'pretty',
		     '#' => '; elegant' },
 'lawak'	=> { 'x' => 'comedy' },
 'lawan'	=> { 'x' => 'opponent',
		     '#' => '; opposite' },
 'lawan dalam'	=> { 'x' => 'infighting' },
 'lawat'	=> { 'x' => 'visit',
		     't' => 'v' },
 'lawatan'	=> { 'x' => 'visit',
		     't' => 'n' },
 'layak'	=> { 'x' => 'qualified',
		     '#' => '; fit; suitable; eligible; competent' },
 'layan'	=> { 'x' => 'serve',
		     '#' => '(food); to entertain',
		     't' => 'v' },
 'layanan'	=> { 'x' => 'hospitality',
		     '#' => '; service' },
 'layang-layang'	=> { 'x' => 'kite' },
 'layar'	=> { 'x' => 'sail',
		     '#' => 'noun and verb' },
 'layu'		=> { 'x' => 'wilted',
		     '#' => '; withered' },
 'layur'	=> { 'x' => 'parch',
		     't' => 'v' },
 'lazat'	=> { 'x' => 'delicious',
		     '#' => '; tasty' },
 'lazim'	=> { 'x' => 'habitual',
		     '#' => '; usual' },
 'lebah'	=> { 'x' => 'bee' },
 'lebam'	=> { 'x' => 'bruise' },
 'lebar'	=> { 'x' => 'wide',
		     '#' => '; broad' },
 'lebarnya'	=> { 'x' => 'width',
		     '#' => '; breadth' },
 'lebat'	=> { 'x' => 'dense (of foliage or hair)',
		     '#' => 'heavy (of rain)' },
 'lebih'	=> { 'x' => 'more',
		     '#' => '; extra' },
 'lebihan'	=> { 'x' => 'excess' },
 'lebih kurang'	=> { 'x' => 'approximately',
		     '#' => 'more or less' },
 'lebih-lebih lagi'	=> { 'x' => 'especially' },
 'lebuh'	=> { 'x' => 'avenue' },
 'lebuhraya'	=> { 'x' => 'highway' },
 'lebur'	=> { 'x' => 'molten' },
 'lecah'	=> { 'x' => 'muddy',
		     '#' => '; sloppy' },
 'leceh'	=> { 'x' => 'troublesome',
		     '#' => '; worthless' },
 'lecek'	=> { 'x' => 'mashed' },
 'lecet'	=> { 'x' => 'footsore' },
 'lecur'	=> { 'x' => 'blistered',
		     '#' => '; scalded' },
# 'ledak'	=> { 'x' => 'to blow up with explosives' },
 'ledakan'	=> { 'x' => 'explosion',
		     '#' => '; detonation' },
# 'lega'		=> { 'x' => 'relieved (e.g. from pain, anxiety, discomfort)' },
 'legam'	=> { 'x' => 'pitch',
		     '#' => 'dark; deep (of colour)' },
 'legap'	=> { 'x' => 'opaque' },
 'legar'	=> { 'x' => 'revolve',
		     't' => 'v' },
 'legeh'	=> { 'x' => 'watershed' },
 'legup-legap'	=> { 'x' => 'sound of heartbeat',
		     '#' => 'throbbing sound' },
 'leher'	=> { 'x' => 'neck' },
 'leka'		=> { 'x' => 'lax',
		     '#' => 'slack; not strict; absorbed; carried away' },
 'lekah'	=> { 'x' => 'crack',
		     '#' => 'groove; crevice (e.g. in wood)' },
 'lekang'	=> { 'x' => 'not adhering',
		     '#' => 'cracking (from heat)' },
 'lekap'	=> { 'x' => 'cuddle',
		     '#' => 'to sit or lie close to; to stick to',
		     't' => 'v' },
# 'lekar'	=> { 'x' => 'stand for cooking pots' },
 'lekas'	=> { 'x' => 'quickly',
		     '#' => '; fast' },
 'lekat'	=> { 'x' => 'adhere',
		     '#' => '; to stick',
		     't' => 'v' },
 'lekit'	=> { 'x' => 'sticky' },
 'lekuk'	=> { 'x' => 'hollow',
		     '#' => '; concavity; dent' },
 'lekuk-lekak'	=> { 'x' => 'bumpy' },
 'lekung'	=> { 'x' => 'sunken' },
 'lelabah'	=> { 'x' => 'spider' },
 'lelah'	=> { 'x' => 'tired',
		     '#' => 'exhausted (2)asthma; wheezing',
		     't' => 'a' },
# 'lelai'	=> { 'x' => 'droop (of branch, coconut leaf, etc)' },
 'lelaki'	=> { 'x' => 'male',
		     '#' => '; man' },
 'lelangit'	=> { 'x' => 'palate' },
 'lelap'	=> { 'x' => 'asleep' },
 'lelas'	=> { 'x' => 'abrasive' },
 'lelasan'	=> { 'x' => 'abrasion' },
 'leleh'	=> { 'x' => 'trickle',
		     '#' => '; to ooze',
		     't' => 'v' },
 'lelong'	=> { 'x' => 'auction' },
# 'lelopak'	=> { 'x' => 'chamber holding cartridges (in a gun) or slides (in a projector)' },
 'leluasa'	=> { 'x' => 'unlimited',
		     '#' => '; uncontrolled; unrestrained' },
 'lelucon'	=> { 'x' => 'humour' },
 'leluhur'	=> { 'x' => 'ancestor' },
 'lelurah'	=> { 'x' => 'gully' },
 'lemah'	=> { 'x' => 'weak',
		     '#' => '; feeble; frail' },
 'lemah gemalai'	=> { 'x' => 'graceful' },
 'lemah hati'	=> { 'x' => 'soft-hearted' },
 'lemah lembut'	=> { 'x' => 'gentle',
		     '#' => 'graceful' },
 'lemah semangat'	=> { 'x' => 'weak-willed' },
 'lemak'	=> { 'x' => 'fat',
		     '#' => '; fatty' },
# 'lemang'	=> { 'x' => 'glutinous rice and coconut milk cooked in bamboo' },
# 'lemas'	=> { 'x' => 'suffocation (in smoke, gas or by drowning)' },
 'lembaga'	=> { 'x' => 'board',
		     '#' => 'governing body (2)embryo; foetus',
		     't' => 'n' },
 'lembah'	=> { 'x' => 'valley' },
 'lembap'	=> { 'x' => 'moist',
		     '#' => '; humid; damp' },
 'lembar'	=> { 'x' => 'strand',
		     '#' => 'numeral coefficient for paper, thread',
		     't' => 'n' },
# 'lembaran'	=> { 'x' => 'sheet (of paper)' },
 'lembik'	=> { 'x' => 'flaccid' },
 'lembing'	=> { 'x' => 'javelin',
		     '#' => '; spear' },
 'lembu'	=> { 'x' => 'cow' },
 'lembung'	=> { 'x' => 'inflatable' },
 'lembur'	=> { 'x' => 'overtime' },
 'lembut'	=> { 'x' => 'soft',
		     '#' => '; gentle' },
 'lempang'	=> { 'x' => 'slap',
		     '#' => '; to smack; to hit',
		     't' => 'v' },
 'lempar'	=> { 'x' => 'hurl',
		     '#' => '; to fling',
		     't' => 'v' },
 'lempeng'	=> { 'x' => 'pancake',
		     '#' => 'a kind of cake',
		     't' => 'n' },
# 'lempuk'	=> { 'x' => 'a cake made from durian or jackfruit cooked with sugar' },
# 'lempung'	=> { 'x' => 'soft and light' },
# 'lena'		=> { 'x' => 'sound asleep' },
 'lencana'	=> { 'x' => 'badge' },
 'lencong'	=> { 'x' => 'divert',
		     '#' => '; to detour; to deviate',
		     't' => 'v' },
 'lencongan'	=> { 'x' => 'detour',
		     '#' => '; a diversion; a deviation',
		     't' => 'n' },
 'lendap'	=> { 'x' => 'clot',
		     't' => 'n' },
 'lendir'	=> { 'x' => 'mucus' },
 'lendung'	=> { 'x' => 'sag',
		     't' => 'v' },
 'lendut'	=> { 'x' => 'sagging' },
 'lengah'	=> { 'x' => 'dawdle',
		     '#' => 'to dilly-dally; to idle' },
 'lengan'	=> { 'x' => 'arm',
		     '#' => '; forearm' },
 'lengan baju'	=> { 'x' => 'sleeve' },
 'lengang'	=> { 'x' => 'desolate',
		     '#' => '; deserted; uninhabited' },
 'lengas'	=> { 'x' => 'moist',
		     '#' => '; humid; clammy' },
# 'lenggang'	=> { 'x' => 'to swing the arms',
#		     '#' => 'to sway the head and body' },
 'lenggok'	=> { 'x' => 'gait' },
 'lengkap'	=> { 'x' => 'complete',
		     '#' => '; equipped' },
 'lengkok'	=> { 'x' => 'curve',
		     '#' => '; bend; arc' },
# 'lengkuas'	=> { 'x' => 'a type of root resembling ginger' },
 'lengkung'	=> { 'x' => 'curve',
		     '#' => '; arc' },
 'lengkungan'	=> { 'x' => 'curvature' },
 'lenguh'	=> { 'x' => 'moo',
		     't' => 'v' },
 'lengung'	=> { 'x' => 'brood',
		     't' => 'v' },
# 'lentam-lentum'	=> { 'x' => 'loud sound like that of a cannon' },
# 'lentik'	=> { 'x' => 'somewhat curved' },
 'lenting'	=> { 'x' => 'rebound',
		     '#' => 'to spring back',
		     't' => 'v' },
# 'lentok'	=> { 'x' => 'to incline the head' },
 'lentuk'	=> { 'x' => 'bend',
		     't' => 'n' },
 'lentur'	=> { 'x' => 'flexible',
		     '#' => '; supple' },
# 'lenyak'	=> { 'x' => 'sound asleep' },
 'lenyap'	=> { 'x' => 'disappear',
		     '#' => '; to vanish',
		     't' => 'v' },
 'lepa'		=> { 'x' => 'plaster',
		     '#' => '; mortar' },
 'lepak'	=> { 'x' => 'fair',
		     '#' => 'very white, fair (2)to sit in a lazy way',
		     't' => 'a' },
# 'lepasan'	=> { 'x' => 'a graduate or school-leaver' },
# 'lepat'	=> { 'x' => 'a type of cake steamed in banana leaves' },
 'leper'	=> { 'x' => 'flat-surfaced' },
 'lepuh'	=> { 'x' => 'blister' },
# 'lepur'	=> { 'x' => 'to die through suffocation in mud' },
 'lerai'	=> { 'x' => 'disengage',
		     '#' => 'to break up',
		     't' => 'v' },
 'lereng'	=> { 'x' => 'slope',
		     't' => 'n' },
# 'leret'	=> { 'x' => 'too long and trailing' },
 'lesap'	=> { 'x' => 'disappear',
		     '#' => '; to vanish',
		     't' => 'v' },
# 'leset'	=> { 'x' => 'feeling depressed' },
# 'lesi'		=> { 'x' => 'looking drawn and sickly' },
 'lesu'		=> { 'x' => 'listless',
		     '#' => '; drawn' },
# 'lesung'	=> { 'x' => 'rice mortar' },
 'letak'	=> { 'x' => 'place',
		     '#' => '; to put; to lay',
		     't' => 'v' },
 'leter'	=> { 'x' => 'nag',
		     't' => 'v' },
 'leteran'	=> { 'x' => 'chatter' },
 'letih'	=> { 'x' => 'tired',
		     '#' => '; weary' },
 'letup'	=> { 'x' => 'explode',
		     't' => 'v' },
 'letupan'	=> { 'x' => 'explosion' },
 'letus'	=> { 'x' => 'erupt',
		     't' => 'v' },
 'lewat'	=> { 'x' => 'late' },
 'liang'	=> { 'x' => 'hole',
		     '#' => '; a burrow',
		     't' => 'n' },
 'liar'		=> { 'x' => 'wild',
		     '#' => '; uncivilized' },
 'liat'		=> { 'x' => 'hard',
		     '#' => '; firm' },
 'libat'	=> { 'x' => 'involve',
		     't' => 'v' },
 'libur'	=> { 'x' => 'holiday' },
 'licik'	=> { 'x' => 'cunning',
		     '#' => '; crafty; shrewd' },
 'licin'	=> { 'x' => 'smooth' },
 'lidah'	=> { 'x' => 'tongue' },
# 'lidas'	=> { 'x' => 'itchy (of tongue) after eating sour fruit' },
# 'lidi'		=> { 'x' => 'vein of coconut palm frond' },
# 'ligat'	=> { 'x' => 'spinning fast' },
# 'lihat'	=> { 'x' => 'to look at' },
# 'likat'	=> { 'x' => 'thick and sticky' },
# 'liku'		=> { 'x' => 'meandering or winding course' },
 'lilin'	=> { 'x' => 'candle',
		     '#' => '; wax' },
 'lilit'	=> { 'x' => 'entwine',
		     't' => 'v' },
 'lilitan'	=> { 'x' => 'circumference' },
 'limau'	=> { 'x' => 'orange',
		     '#' => '; lime; lemon' },
 'limau gedang'	=> { 'x' => 'grapefruit' },
 'limau nipis'	=> { 'x' => 'lime' },
# 'limbang'	=> { 'x' => 'to pan (in search of gold ore)' },
 'limbungan'	=> { 'x' => 'dockyard' },
 'limpa'	=> { 'x' => 'spleen' },
 'limpah'	=> { 'x' => 'overflow',
		     't' => 'v' },
# 'limpap'	=> { 'x' => '(1)in layers (2)excessive debt' },
# 'linang'	=> { 'x' => 'to flow (for tears or sweat)' },
 'lincah'	=> { 'x' => 'nimble' },
# 'lincir'	=> { 'x' => 'smooth (in moving)' },
# 'lindung'	=> { 'x' => 'to take refuge or shelter' },
 'lindungan'	=> { 'x' => 'haven',
		     '#' => '; refuge' },
 'lingga'	=> { 'x' => 'colossus' },
 'lingkar'	=> { 'x' => 'coil',
		     't' => 'n' },
 'lingkaran'	=> { 'x' => 'convolution',
		     '#' => '; a coil',
		     't' => 'n' },
 'lingkung'	=> { 'x' => 'surround',
		     '#' => '; to encircle',
		     't' => 'v' },
 'lingkungan'	=> { 'x' => 'encirclement',
		     '#' => '; enclosure; sphere' },
 'lingkup'	=> { 'x' => 'cover' },
 'lintah'	=> { 'x' => 'leech' },
 'lintang'	=> { 'x' => 'horizontal' },
 'lintang-pukang'	=> { 'x' => 'helter-skelter' },
 'lintas'	=> { 'x' => 'cross',
		     '#' => 'to pass by' },
 'lipan'	=> { 'x' => 'centipede' },
 'lipas'	=> { 'x' => 'cockroach' },
 'lipat'	=> { 'x' => 'fold',
		     't' => 'v' },
 'lipatan'	=> { 'x' => 'fold',
		     't' => 'n' },
# 'lipit'	=> { 'x' => 'narrow hem' },
 'lipur'	=> { 'x' => 'comfort',
		     '#' => '; to console',
		     't' => 'v' },
 'liput'	=> { 'x' => 'cover',
		     '#' => '; to comprise',
		     't' => 'v' },
 'liputan'	=> { 'x' => 'coverage',
		     '#' => '; inclusion' },
 'lisan'	=> { 'x' => 'oral',
		     '#' => '; verbal' },
 'lisut'	=> { 'x' => 'shrunken',
		     '#' => '; soft' },
 'litar'	=> { 'x' => 'circuit' },
# 'litup'	=> { 'x' => 'covered and concealed' },
 'liuk'		=> { 'x' => 'snake',
		     '#' => '; to sway',
		     't' => 'v' },
 'liwat'	=> { 'x' => 'sodomy' },
 'loba'		=> { 'x' => 'grasping',
		     '#' => 'greedy for money or possessions' },
 'lobak'	=> { 'x' => 'radish' },
 'lobak merah'	=> { 'x' => 'carrot' },
 'loceng'	=> { 'x' => 'bell' },
 'lodak'	=> { 'x' => 'sediment' },
# 'lodeh'	=> { 'x' => 'mixed vegetables cooked to pulp' },
 'logam'	=> { 'x' => 'metal' },
 'logamaya'	=> { 'x' => 'mirage' },
 'loghat'	=> { 'x' => 'dialect',
		     '#' => '; slang' },
 'lohong'	=> { 'x' => 'hole' },
 'loji'		=> { 'x' => 'industrial plant',
		     '#' => 'factory; industrial site' },
# 'lok'		=> { 'x' => 'curve of a kris' },
 'lokek'	=> { 'x' => 'mean',
		     '#' => '; miserly; stingy' },
 'lolong'	=> { 'x' => 'howl',
		     '#' => 'a loud cry',
		     't' => 'n' },
# 'lombong'	=> { 'x' => 'mine for extracting metal, coal, etc' },
# 'lombong bijih'	=> { 'x' => 'tin mine' },
 'lompang'	=> { 'x' => 'vacant',
		     '#' => 'empty; a vacuole; an air pocket' },
 'lompat'	=> { 'x' => 'jump',
		     '#' => '; to leap',
		     't' => 'v' },
 'lompatan'	=> { 'x' => 'jump',
		     '#' => '; a leap',
		     't' => 'n' },
# 'lompat bergalah'	=> { 'x' => 'pole vault' },
# 'lompat jauh'	=> { 'x' => 'long jump' },
 'lompat kijang'	=> { 'x' => 'triple jump',
		     '#' => 'hop, step and jump' },
# 'lompat tinggi'	=> { 'x' => 'high jump' },
 'loncat'	=> { 'x' => 'hop',
		     't' => 'v' },
 'loncatan'	=> { 'x' => 'hop',
		     't' => 'n' },
# 'londeh'	=> { 'x' => 'to slip off or drop (as for sarong)' },
# 'long'		=> { 'x' => 'a bottomless coffin' },
 'longgar'	=> { 'x' => 'loose',
		     '#' => '; diffuse' },
 'longgok'	=> { 'x' => 'pile',
		     '#' => 'a heap or mass',
		     't' => 'n' },
 'longgokan'	=> { 'x' => 'heap',
		     't' => 'n' },
# 'longkah'	=> { 'x' => 'easily peeled off (e.g. flesh from the seed)' },
 'longkang'	=> { 'x' => 'drain' },
 'longlai'	=> { 'x' => 'swaying of body',
		     '#' => 'weak' },
 'lonjak'	=> { 'x' => 'gambol',
		     '#' => 'to jump about playfully' },
# 'lonjakan'	=> { 'x' => 'gamboling movement' },
 'lonjong'	=> { 'x' => 'oval',
		     '#' => '; ovoid' },
 'lontar'	=> { 'x' => 'throw',
		     '#' => '; to hurl',
		     't' => 'v' },
# 'lontong'	=> { 'x' => 'a type of malay food made of rice and gravy' },
 'lopak'	=> { 'x' => 'puddle' },
 'lopong'	=> { 'x' => 'agape',
		     '#' => '; empty' },
 'lorek'	=> { 'x' => 'stripe',
		     '#' => '; band' },
 'lori'		=> { 'x' => 'truck',
		     '#' => '; lorry' },
 'lorong'	=> { 'x' => 'lane',
		     '#' => '; path' },
 'loteng'	=> { 'x' => 'attic' },
# 'lotong'	=> { 'x' => 'black long-tailed monkey' },
 'loya'		=> { 'x' => 'nausea' },
 'loyang'	=> { 'x' => 'brass' },
 'luah'		=> { 'x' => 'eject',
		     '#' => 'to spit out' },
# 'luak'		=> { 'x' => 'decreased in quantity' },
 'luang'	=> { 'x' => 'free' },
# 'luap'		=> { 'x' => 'to boil over' },
 'luar'		=> { 'x' => 'outside' },
 'luaran'	=> { 'x' => 'exterior' },
 'luar bandar'	=> { 'x' => 'rural' },
# 'luar batas'	=> { 'x' => 'off limit' },
 'luar biasa'	=> { 'x' => 'extraordinary' },
# 'luar dalam'	=> { 'x' => 'inside out' },
 'luar negara'	=> { 'x' => 'overseas',
		     '#' => 'abroad' },
# 'luar nikah'	=> { 'x' => 'out of wedlock' },
 'luas'		=> { 'x' => 'wide',
		     '#' => '; broad' },
 'luat'		=> { 'x' => 'despise',
		     '#' => 'to feel nauseated; to feel disgusted' },
 'lubang'	=> { 'x' => 'hole' },
 'lubuk'	=> { 'x' => 'gulf',
		     '#' => 'deep part of a river' },
 'lucah'	=> { 'x' => 'obscene',
		     '#' => '; lewd' },
 'lucu'		=> { 'x' => 'funny',
		     '#' => '; comical' },
 'lucut'	=> { 'x' => 'denude' },
 'ludah'	=> { 'x' => 'saliva' },
 'luhur'	=> { 'x' => 'majestic',
		     '#' => '; noble' },
 'luka'		=> { 'x' => 'wound',
		     '#' => '; injury' },
# 'lukah'	=> { 'x' => 'fish trap' },
 'lukis'	=> { 'x' => 'draw',
		     't' => 'v' },
 'lukisan'	=> { 'x' => 'drawing' },
# 'luluh'	=> { 'x' => 'crushed to powder' },
 'lulur'	=> { 'x' => 'gulp',
		     't' => 'v' },
 'lumang'	=> { 'x' => 'smear',
		     't' => 'v' },
 'lumas'	=> { 'x' => 'paint',
		     't' => 'v' },
# 'lumat'	=> { 'x' => 'fine (powdery)' },
 'lumayan'	=> { 'x' => 'handsome (of amount)',
		     '#' => 'sufficient' },
 'lumba'	=> { 'x' => 'race',
		     't' => 'v' },
 'lumba-lumba'	=> { 'x' => 'dolphin' },
 'lumpuh'	=> { 'x' => 'paralysis',
		     '#' => '; paralytic' },
 'lumpur'	=> { 'x' => 'mud' },
 'lumrah'	=> { 'x' => 'normal' },
# 'lumur'	=> { 'x' => 'to smear with fat during cooking' },
 'lumuran'	=> { 'x' => 'smear',
		     't' => 'n' },
 'lumut'	=> { 'x' => 'moss',
		     '#' => '; lichen' },
 'lunak'	=> { 'x' => 'mellow',
		     '#' => '; soft' },
 'lunas'	=> { 'x' => 'source',
		     '#' => 'main point (2)keel',
		     't' => 'n' },
 'luncur'	=> { 'x' => 'glide',
		     't' => 'v' },
 'lundi'	=> { 'x' => 'grub' },
# 'lungkup'	=> { 'x' => 'upside down' },
# 'lungsur'	=> { 'x' => 'to slide down' },
# 'lunjur'	=> { 'x' => 'to stretch out the legs' },
# 'luntur'	=> { 'x' => 'to discolour or fade' },
 'lupa'		=> { 'x' => 'forget',
		     't' => 'v' },
 'luput'	=> { 'x' => 'expiry',
		     '#' => 'termination of validity' },
 'lurah'	=> { 'x' => 'valley',
		     '#' => '; groove' },
 'luru'		=> { 'x' => 'dash',
		     't' => 'v' },
 'luruh'	=> { 'x' => 'drop',
		     't' => 'v' },
 'lurus'	=> { 'x' => 'honest',
		     '#' => '(1)straight (2)frank',
		     't' => 'a' },
 'lurut'	=> { 'x' => 'rub',
		     '#' => 'to smoothen with fingers',
		     't' => 'v' },
# 'lusa'		=> { 'x' => 'day after tomorrow' },
 'lusuh'	=> { 'x' => 'worn out',
		     '#' => 'faded' },
 'lut'		=> { 'x' => 'penetrative' },
 'lutcahaya'	=> { 'x' => 'translucent' },
 'lutsinar'	=> { 'x' => 'transparent' },
 'lutut'	=> { 'x' => 'knee' },
 'luyu'		=> { 'x' => 'sleepy' },

 'maaf'		=> { 'x' => 'forgiveness' },
 'maafkan saya'	=> { 'x' => 'excuse me',
		     '#' => 'forgive me' },
 'mabuk'	=> { 'x' => 'drunk' },
# 'mabuk asmara'	=> { 'x' => 'love sick' },
 'mabuk laut'	=> { 'x' => 'seasick' },
 'macam'	=> { 'x' => 'like',
		     '#' => '; kind; sort; type' },
 'macang'	=> { 'x' => 'horse-mango' },
 'madah'	=> { 'x' => 'eulogy' },
 'madat'	=> { 'x' => 'opium' },
# 'madrasah'	=> { 'x' => 'islamic school' },
# 'madu'		=> { 'x' => '(1)honey (2)woman sharing the same husband' },
 'maghrib'	=> { 'x' => 'sunset' },
 'maging'	=> { 'x' => 'carnivorous' },
 'maha'		=> { 'x' => 'great' },
 'mahaguru'	=> { 'x' => 'great teacher',
		     '#' => 'professor' },
 'maha kuasa'	=> { 'x' => 'almighty' },
 'mahal'	=> { 'x' => 'expensive' },
 'mahar'	=> { 'x' => 'dowry' },
 'maharaja'	=> { 'x' => 'emperor' },
 'maharani'	=> { 'x' => 'empress',
		     '#' => '; queen' },
# 'mahasiswa'	=> { 'x' => 'university student' },
 'maharajalela'	=> { 'x' => 'rampage',
		     't' => 'v' },
 'mahir'	=> { 'x' => 'skilful' },
# 'mahkamah'	=> { 'x' => 'court of law' },
# 'mahkota'	=> { 'x' => 'royal crown' },
 'mahligai'	=> { 'x' => 'palace' },
# 'mahsul'	=> { 'x' => 'products of a country' },
 'mahu'		=> { 'x' => 'want',
		     '#' => '; to desire',
		     't' => 'v' },
 'main'		=> { 'x' => 'play',
		     't' => 'v' },
 'mainan'	=> { 'x' => 'toy',
		     '#' => 'act of playing' },
# 'majal'	=> { 'x' => 'blunt (of knife)' },
 'majalah'	=> { 'x' => 'magazine' },
 'majikan'	=> { 'x' => 'employer' },
 'majlis'	=> { 'x' => 'council',
		     '#' => '; meeting; assembly' },
 'majmuk'	=> { 'x' => 'compound',
		     '#' => '; complex' },
 'maju'		=> { 'x' => 'developed' },
 'mak'		=> { 'x' => 'mother' },
# 'mak angkat'	=> { 'x' => 'adopted mother' },
 'makcik'	=> { 'x' => 'auntie' },
 'mak tiri'	=> { 'x' => 'stepmother' },
 'makam'	=> { 'x' => 'mausoleum',
		     '#' => '; tomb' },
 'makan'	=> { 'x' => 'eat',
		     't' => 'v' },
 'makanan'	=> { 'x' => 'food' },
 'makbul'	=> { 'x' => 'fulfilled',
		     '#' => 'answered (of prayers)' },
 'makhluk'	=> { 'x' => 'creature',
		     't' => 'n' },
 'maki'		=> { 'x' => 'abuse',
		     't' => 'v' },
 'makian'	=> { 'x' => 'curse',
		     '#' => 'act of hurling abuse',
		     't' => 'n' },
 'makin'	=> { 'x' => 'increasingly' },
 'maklum'	=> { 'x' => 'know',
		     't' => 'v' },
 'maklumat'	=> { 'x' => 'information' },
 'makmal'	=> { 'x' => 'laboratory' },
 'makmur'	=> { 'x' => 'prosperous',
		     '#' => 'to prosper' },
 'makna'	=> { 'x' => 'meaning' },
 'makruf'	=> { 'x' => 'famous' },
 'maksiat'	=> { 'x' => 'vice',
		     '#' => '; immorality' },
 'maksud'	=> { 'x' => 'meaning',
		     '#' => '; purpose; intention' },
 'maktab'	=> { 'x' => 'college' },
# 'maktub'	=> { 'x' => 'recorded in writing' },
 'malah'	=> { 'x' => 'on the contrary',
		     '#' => 'in fact; but' },
 'malahan'	=> { 'x' => 'on the contrary',
		     '#' => 'in fact; but' },
 'malaikat'	=> { 'x' => 'angel' },
 'malam'	=> { 'x' => 'night' },
# 'malam minggu'	=> { 'x' => 'saturday night' },
 'malang'	=> { 'x' => 'unfortunate',
		     '#' => '; unlucky' },
 'malangnya'	=> { 'x' => 'unfortunately' },
 'malap'	=> { 'x' => 'dim' },
 'malapetaka'	=> { 'x' => 'calamity',
		     '#' => '; disaster' },
 'malar'	=> { 'x' => 'constant',
		     '#' => '; continuous' },
 'malas'	=> { 'x' => 'lazy' },
 'malik'	=> { 'x' => 'lord' },
 'malim'	=> { 'x' => 'expert' },
 'malu'		=> { 'x' => 'shy',
		     '#' => '; ashamed; embarrassed' },
# 'malung'	=> { 'x' => 'large sea eel' },
 'mamah'	=> { 'x' => 'munch',
		     '#' => '; to chew',
		     't' => 'v' },
# 'mamak'	=> { 'x' => 'maternal uncle' },
 'mambang'	=> { 'x' => 'ghost',
		     '#' => '; spirit' },
 'mampat'	=> { 'x' => 'compress' },
 'mampu'	=> { 'x' => 'able to',
		     '#' => 'capable' },
# 'mampus'	=> { 'x' => 'to die (unrefined expression)' },
 'mancis'	=> { 'x' => 'matches' },
# 'mancung'	=> { 'x' => 'high and sharp' },
 'mancur'	=> { 'x' => 'spout',
		     '#' => '; to squirt',
		     't' => 'v' },
 'mandi'	=> { 'x' => 'bathe',
		     't' => 'v' },
# 'mandul'	=> { 'x' => 'barren or sterile (of female)' },
# 'mandur'	=> { 'x' => 'head of the labourers' },
 'manfaat'	=> { 'x' => 'benefit' },
# 'mangga'	=> { 'x' => '(1)mango (2)padlock' },
# 'manggar'	=> { 'x' => 'base of coconut palm frond' },
 'manggis'	=> { 'x' => 'mangosteen' },
# 'mangkat'	=> { 'x' => 'to die (of royalty)' },
 'mangkin'	=> { 'x' => 'catalyst' },
# 'mangku'	=> { 'x' => 'acting (of official post)' },
 'mangkuk'	=> { 'x' => 'bowl' },
 'mangsa'	=> { 'x' => 'victim',
		     '#' => '; prey; casualty' },
 'mangu'	=> { 'x' => 'amazed',
		     '#' => '; perplexed; bewildered' },
 'mani'		=> { 'x' => 'semen' },
 'manik'	=> { 'x' => 'bead' },
 'manikam'	=> { 'x' => 'gem' },
 'manis'	=> { 'x' => 'sweet' },
# 'manisan'	=> { 'x' => 'sweet dish' },
 'manja'	=> { 'x' => 'pampered',
		     '#' => '; indulgent' },
 'manjur'	=> { 'x' => 'potent',
		     '#' => '; effective' },
# 'mansit'	=> { 'x' => 'cuff (of sleeve)' },
 'mansuh'	=> { 'x' => 'vanish',
		     '#' => '; to disappear; to annul; to abolish',
		     't' => 'v' },
 'mantap'	=> { 'x' => 'established' },
 'mantera'	=> { 'x' => 'magical charm or spell',
		     '#' => 'incantation' },
# 'manusia'	=> { 'x' => 'human being' },
 'mara'		=> { 'x' => 'advance',
		     't' => 'v' },
 'marah'	=> { 'x' => 'angry' },
# 'marak'	=> { 'x' => 'to flare up' },
 'mari'		=> { 'x' => 'come',
		     't' => 'v' },
 'marikh'	=> { 'x' => 'mars' },
 'markah'	=> { 'x' => 'mark' },
 'markas'	=> { 'x' => 'headquarters' },
 'marmar'	=> { 'x' => 'marble' },
 'marmut'	=> { 'x' => 'marmot',
		     '#' => 'guinea-pig' },
# 'martabak'	=> { 'x' => 'a kind of bread with meat fillings' },
 'martabat'	=> { 'x' => 'prestige' },
 'maruah'	=> { 'x' => 'pride',
		     '#' => 'self-respect' },
 'masa'		=> { 'x' => 'time',
		     '#' => '; period; era' },
 'masa depan'	=> { 'x' => 'future' },
 'masa lalu'	=> { 'x' => 'past' },
 'masa silam'	=> { 'x' => 'past' },
# 'masak'	=> { 'x' => '(1)to cook (2)ripe' },
# 'masakan'	=> { 'x' => '(1)cookery (2)how could it be' },
 'masalah'	=> { 'x' => 'problem' },
 'masam'	=> { 'x' => 'sour' },
 'maserba'	=> { 'x' => 'omnivore' },
 'masih'	=> { 'x' => 'still' },
 'masin'	=> { 'x' => 'salty' },
 'masjid'	=> { 'x' => 'mosque' },
 'mastautin'	=> { 'x' => 'reside',
		     't' => 'v' },
 'masuk'	=> { 'x' => 'enter',
		     't' => 'v' },
 'masuk campur'	=> { 'x' => 'interfere' },
 'masyarakat'	=> { 'x' => 'society',
		     '#' => 'organized community' },
 'masyghul'	=> { 'x' => 'depressed',
		     '#' => '; sad' },
 'masyhur'	=> { 'x' => 'famous' },
 'mata'		=> { 'x' => 'eye' },
# 'mata air'	=> { 'x' => 'spring (water)' },
 'mata hitam'	=> { 'x' => 'iris' },
 'mata wang'	=> { 'x' => 'currency' },
 'matahari'	=> { 'x' => 'sun' },
 'mata-mata'	=> { 'x' => 'policeman' },
 'matang'	=> { 'x' => 'mature' },
 'matarah'	=> { 'x' => 'beacon' },
 'mati'		=> { 'x' => 'die',
		     't' => 'v' },
# 'mati-matian'	=> { 'x' => 'with full effort' },
 'matlamat'	=> { 'x' => 'aim',
		     '#' => '; objective; target' },
 'maujud'	=> { 'x' => 'existing' },
 'maun'		=> { 'x' => 'herbivorous' },
# 'maung'	=> { 'x' => 'unpleasant in smell or taste' },
 'maut'		=> { 'x' => 'death' },
 'mawar'	=> { 'x' => 'rose' },
 'maya'		=> { 'x' => 'illusion',
		     '#' => '; delusion' },
# 'mayam'	=> { 'x' => 'unit of weight for gold' },
 'mayang'	=> { 'x' => 'palm-blossom' },
 'mayat'	=> { 'x' => 'corpse' },
# 'mazhab'	=> { 'x' => 'religious sect or school of thought' },
 'mazmur'	=> { 'x' => 'hymn' },
 'medan'	=> { 'x' => 'field' },
 'medan perang'	=> { 'x' => 'battlefield' },
 'megah'	=> { 'x' => 'proud',
		     '#' => '; conceited' },
 'meja'		=> { 'x' => 'table' },
# 'mekar'	=> { 'x' => 'to blossom or bloom' },
# 'melaka'	=> { 'x' => 'a type of tree with edible fruit' },
 'melarat'	=> { 'x' => 'destitute',
		     '#' => '; needy' },
 'melati'	=> { 'x' => 'jasmine' },
 'melayu'	=> { 'x' => 'malay' },
 'meleset'	=> { 'x' => 'not precise',
		     '#' => 'not to the point; irrelevant; non-specific' },
# 'melukut'	=> { 'x' => 'broken rice grains' },
 'melulu'	=> { 'x' => 'hasty' },
 'melur'	=> { 'x' => 'jasmine' },
 'memang'	=> { 'x' => 'of course',
		     '#' => 'naturally' },
 'memar'	=> { 'x' => 'contusion',
		     '#' => '; bruise' },
 'membanyakkan'	=> { 'x' => 'increase',
		     't' => 'v',
		     'df' => 'banyak' },
 'memerang'	=> { 'x' => 'otter',
		     '#' => '; beaver' },
 'mempelai'	=> { 'x' => 'bridegroom',
		     '#' => '; bride' },
 'mempelam'	=> { 'x' => 'mango',
		     't' => 'n' },
 'menang'	=> { 'x' => 'win',
		     't' => 'v' },
 'menantu'	=> { 'x' => 'son-in-law',
		     '#' => 'daughter-in-law',
		     't' => 'n' },
 'menara'	=> { 'x' => 'tower',
		     '#' => '; minaret' },
 'mendak'	=> { 'x' => 'sediment' },
# 'mendap'	=> { 'x' => 'to settle as a sediment' },
 'mendapan'	=> { 'x' => 'sedimentation' },
# 'mendiang'	=> { 'x' => 'the late' },
 'mendung'	=> { 'x' => 'overcast',
		     '#' => '; cloudy' },
 'mengada-ngada'	=> { 'x' => 'boast',
			     '#' => '; to pretend',
			     't' => 'v',
			     'df' => 'ada' },
# 'mengada-ngadakan'	=> { 'x' => 'concoct an excuse',
#			     'df' => 'ada' },
 'mengadakan'	=> { 'x' => 'convene',
		     '#' => 'hold; conduct;',
		     't' => 'v',
		     'df' => 'ada' },
 'mengah'	=> { 'x' => 'breathless',
		     '#' => '; dyspneic' },
 'mengkal'	=> { 'x' => 'half-ripe' },
# 'mentadak'	=> { 'x' => 'praying mantis' },
 'mentah'	=> { 'x' => 'raw',
		     '#' => 'uncooked; unprocessed (2)immature; inexperienced',
		     't' => 'a' },
# 'mentang-mentang'	=> { 'x' => 'just because' },
 'mentega'	=> { 'x' => 'butter' },
 'menteri'	=> { 'x' => 'minister' },
 'mentimun'	=> { 'x' => 'cucumber' },
# 'mentua'	=> { 'x' => 'father or mother-in-law' },
 'mentul'	=> { 'x' => 'bulb' },
 'menung'	=> { 'x' => 'ponder',
		     '#' => '; to contemplate',
		     't' => 'v' },
 'merah'	=> { 'x' => 'red' },
 'merah jambu'	=> { 'x' => 'pink' },
 'merah lembayung'	=> { 'x' => 'magenta' },
 'merah manggis'	=> { 'x' => 'maroon' },
# 'merak'	=> { 'x' => 'peacock or peahen' },
 'merana'	=> { 'x' => 'languish',
		     '#' => 'to live miserably or in ill-health' },
 'merbah'	=> { 'x' => 'thrush' },
# 'merbuk'	=> { 'x' => 'turtle dove' },
 'mercu'	=> { 'x' => 'peak',
		     '#' => '; summit; climax' },
 'mercun'	=> { 'x' => 'fire-crackers' },
 'merdeka'	=> { 'x' => 'independent',
		     '#' => '; free' },
 'merdu'	=> { 'x' => 'melodious' },
 'mereka'	=> { 'x' => 'they',
		     '#' => '; them; their' },
# 'mergastua'	=> { 'x' => 'wild animals of the forest' },
 'meriah'	=> { 'x' => 'hilarious',
		     '#' => '; joyful; happy' },
 'meriam'	=> { 'x' => 'cannon' },
# 'merinyu'	=> { 'x' => 'inspector or supervisor' },
# 'merosot'	=> { 'x' => 'in deteriorated condition' },
 'merpati'	=> { 'x' => 'dove',
		     '#' => '; pigeon' },
 'mersik'	=> { 'x' => 'shrill',
		     '#' => 'piercing (of sound)' },
# 'mesir'	=> { 'x' => 'of egypt' },
 'mesra'	=> { 'x' => 'amicable',
		     '#' => '; hospitable; friendly; close' },
 'mesti'	=> { 'x' => 'must' },
 'mestika'	=> { 'x' => 'jewel',
		     '#' => '; bezoar' },
 'mesyuarat'	=> { 'x' => 'meeting' },
# 'meterai'	=> { 'x' => 'official seal' },
 'mewah'	=> { 'x' => 'luxurious' },
 'mi'		=> { 'x' => 'noodles' },
 'miang'	=> { 'x' => 'itchy' },
 'milik'	=> { 'x' => 'own',
		     '#' => '; to possess',
		     't' => 'v' },
 'mimbar'	=> { 'x' => 'rostrum',
		     '#' => '; pulpit' },
 'mimpi'	=> { 'x' => 'dream' },
 'minat'	=> { 'x' => 'interest',
		     '#' => '; enthusiasm; liking' },
 'minggu'	=> { 'x' => 'week' },
 'mingguan'	=> { 'x' => 'weekly' },
 'minta'	=> { 'x' => 'ask',
		     '#' => '; to beg; to request',
		     't' => 'v' },
 'minum'	=> { 'x' => 'drink',
		     't' => 'v' },
 'minuman'	=> { 'x' => 'drink',
		     't' => 'n' },
 'minuman keras'	=> { 'x' => 'liquor',
		     '#' => 'alcoholic drink' },
# 'minuman ringan'	=> { 'x' => 'soft drink' },
 'minyak'	=> { 'x' => 'oil',
		     '#' => '; fat; petroleum' },
 'minyak sapi'	=> { 'x' => 'ghee' },
 'minyak tanah'	=> { 'x' => 'kerosene' },
 'miring'	=> { 'x' => 'oblique',
		     '#' => 'slanting; to tilt' },
 'mirip'	=> { 'x' => 'resemble',
		     't' => 'v' },
 'misai'	=> { 'x' => 'moustache' },
 'misal'	=> { 'x' => 'example' },
 'miskin'	=> { 'x' => 'poor' },
 'modal'	=> { 'x' => 'capital' },
# 'moga-moga'	=> { 'x' => 'may it be' },
 'mogok'	=> { 'x' => 'strike',
		     't' => 'n' },
# 'mogok lapar'	=> { 'x' => 'hunger strike' },
 'mohon'	=> { 'x' => 'apply',
		     't' => 'v' },
# 'mohor'	=> { 'x' => 'official seal' },
 'molek'	=> { 'x' => 'pretty',
		     '#' => '; attractive; lovely' },
 'momok'	=> { 'x' => 'ghost',
		     '#' => 'evil spirit; something causing fear' },
 'mongel'	=> { 'x' => 'beautiful',
		     '#' => '; attractive' },
# 'montel'	=> { 'x' => 'plump and healthy' },
 'montok'	=> { 'x' => 'chubby',
		     '#' => '; plump' },
 'monyet'	=> { 'x' => 'monkey' },
 'moyang'	=> { 'x' => 'great-grandparent' },
 'muafakat'	=> { 'x' => 'agreement' },
 'muak'		=> { 'x' => 'nauseated',
		     '#' => '; sated' },
 'mual'		=> { 'x' => 'nausea' },
# 'mualim'	=> { 'x' => 'religious teacher' },
 'muara'	=> { 'x' => 'estuary' },
# 'muat'		=> { 'x' => 'having sufficient capacity' },
 'muatan'	=> { 'x' => 'cargo',
		     '#' => '; load' },
 'muazam'	=> { 'x' => 'majesty' },
# 'muazin'	=> { 'x' => 'summoner to prayer' },
 'mubaligh'	=> { 'x' => 'preacher',
		     '#' => '; missionary' },
 'muda'		=> { 'x' => 'young',
		     '#' => 'not ripe' },
 'mudah'	=> { 'x' => 'easy',
		     '#' => '; convenient' },
 'mudah-mudahan'	=> { 'x' => 'hopefully',
		     '#' => 'perhaps' },
 'mudarat'	=> { 'x' => 'harmful',
		     '#' => '; detrimental' },
# 'mudik'	=> { 'x' => 'to go upstream' },
 'muflis'	=> { 'x' => 'bankrupt' },
# 'mufti'	=> { 'x' => 'muslim religious expert' },
 'muhibah'	=> { 'x' => 'goodwill' },
 'mujarab'	=> { 'x' => 'efficacious',
		     '#' => 'effective (of medicine)' },
 'mujur'	=> { 'x' => 'luckily',
		     '#' => '; fortunately' },
 'muka'		=> { 'x' => 'face' },
# 'muka depan'	=> { 'x' => 'front page' },
 'muka-muka'	=> { 'x' => 'insincere' },
 'muka pintu'	=> { 'x' => 'doorway' },
# 'muka selamba'	=> { 'x' => 'poker face' },
 'muka surat'	=> { 'x' => 'page' },
 'muka tebal'	=> { 'x' => 'thick-skinned' },
 'mukah'	=> { 'x' => 'fornication' },
 'mukim'	=> { 'x' => 'district' },
 'mukjizat'	=> { 'x' => 'miracle' },
 'muktamad'	=> { 'x' => 'definitive',
		     '#' => '; final' },
 'muktamar'	=> { 'x' => 'conference',
		     '#' => '; congress' },
 'mula'		=> { 'x' => 'beginning',
		     '#' => 'to begin' },
 'mulai'	=> { 'x' => 'start',
		     't' => 'v' },
 'mula-mula'	=> { 'x' => 'at first',
		     '#' => 'first of all' },
 'mulas'	=> { 'x' => 'colic' },
 'mulia'	=> { 'x' => 'noble',
		     '#' => '; distinguished; honourable; respectable' },
 'mulur'	=> { 'x' => 'ductile' },
 'mulut'	=> { 'x' => 'mouth' },
 'mulut manis'	=> { 'x' => 'sweet-tongued' },
 'mulut murai'	=> { 'x' => 'chatterbox' },
# 'mumbang'	=> { 'x' => 'green unripe coconut' },
 'munafik'	=> { 'x' => 'hypocrite' },
 'munasabah'	=> { 'x' => 'credible',
		     '#' => '; reasonable; suitable' },
 'muncul'	=> { 'x' => 'emerge',
		     '#' => '; to appear',
		     't' => 'v' },
 'muncung'	=> { 'x' => 'muzzle',
		     '#' => '; snout; beak; spout' },
# 'mundar-mandir'	=> { 'x' => 'walk to and fro' },
 'mundur'	=> { 'x' => 'retreat',
		     '#' => 'to recede; backward or underdeveloped',
		     't' => 'v' },
# 'mungil'	=> { 'x' => 'small and cute' },
 'mungkar'	=> { 'x' => 'disobey',
		     '#' => 'to deny; sinful',
		     't' => 'v' },
 'mungkin'	=> { 'x' => 'possible',
		     '#' => '; maybe; perhaps' },
# 'mungkir'	=> { 'x' => 'to breach or default' },
# 'munsyi'	=> { 'x' => 'language teacher' },
 'muntah'	=> { 'x' => 'vomit',
		     't' => 'v' },
 'murah'	=> { 'x' => 'cheap' },
 'murah hati'	=> { 'x' => 'generous' },
 'murai'	=> { 'x' => 'magpie' },
 'muram'	=> { 'x' => 'gloomy',
		     '#' => '; dismal; glum' },
 'murid'	=> { 'x' => 'pupil',
		     '#' => '; student' },
 'murka'	=> { 'x' => 'wrathful',
		     '#' => '; angry' },
 'murni'	=> { 'x' => 'clean',
		     '#' => '; pure; genuine' },
 'murtad'	=> { 'x' => 'apostate' },
 'murung'	=> { 'x' => 'depressed' },
 'musafir'	=> { 'x' => 'traveller' },
 'musang'	=> { 'x' => 'civet-cat' },
 'musim'	=> { 'x' => 'season' },
 'muslihat'	=> { 'x' => 'trick',
		     '#' => '; stratagem' },
# 'muslim'	=> { 'x' => 'one who believes and follows the teachings of islam' },
# 'muslimat'	=> { 'x' => 'muslim women' },
 'musnah'	=> { 'x' => 'destroy',
		     '#' => 'destructible' },
 'mustahak'	=> { 'x' => 'important' },
 'mustahil'	=> { 'x' => 'impossible',
		     '#' => '; incredible' },
# 'mustajab'	=> { 'x' => 'effective (of medicine)' },
 'musuh'	=> { 'x' => 'enemy',
		     '#' => '; foe' },
 'musytari'	=> { 'x' => 'jupiter' },
 'mutakhir'	=> { 'x' => 'modern',
		     '#' => 'the latest' },
 'mutiara'	=> { 'x' => 'pearl' },
 'mutlak'	=> { 'x' => 'absolute',
		     '#' => '; complete; categorical' },
 'mutu'		=> { 'x' => 'quality' },
 'muzakarah'	=> { 'x' => 'discussion' },

 'nabi'		=> { 'x' => 'prophet' },
 'nada'		=> { 'x' => 'tone',
		     '#' => '; intonation' },
 'nadi'		=> { 'x' => 'pulse' },
 'nafkah'	=> { 'x' => 'maintenance',
		     '#' => 'livelihood; subsistence;  alimony' },
 'nafsu'	=> { 'x' => 'lust',
		     '#' => 'intense desire' },
 'naga'		=> { 'x' => 'dragon' },
 'nahas'	=> { 'x' => 'mishap',
		     '#' => '; misfortune; disaster' },
 'nahu'		=> { 'x' => 'grammar' },
 'naib'		=> { 'x' => 'deputy' },
 'najis'	=> { 'x' => 'excrement',
		     '#' => '; faeces; filth' },
 'nak'		=> { 'x' => 'want' },
 'nakhoda'	=> { 'x' => 'captain' },
 'naluri'	=> { 'x' => 'instinct' },
 'namun'	=> { 'x' => 'yet',
		     '#' => '; still' },
 'nanah'	=> { 'x' => 'pus' },
 'nanas'	=> { 'x' => 'pineapple' },
 'nangka'	=> { 'x' => 'jackfruit' },
# 'nasab'	=> { 'x' => 'lineage of ancestors or descendants' },
# 'nasi'		=> { 'x' => 'cooked rice' },
 'naskhah'	=> { 'x' => 'copy (of a book, etc)',
		     '#' => 'manuscript' },
 'nasrani'	=> { 'x' => 'christian',
		     '#' => '; eurasian' },
 'natijah'	=> { 'x' => 'result',
		     '#' => '; consequence; conclusion' },
 'nazak'	=> { 'x' => 'moribund' },
# 'nazir'	=> { 'x' => 'school inspector' },
 'nekad'	=> { 'x' => 'determined' },
 'nelayan'	=> { 'x' => 'fisherman' },
# 'neraca'	=> { 'x' => 'a kind of weighing apparatus with hanging pans' },
 'neraka'	=> { 'x' => 'hell' },
 'nescaya'	=> { 'x' => 'certainly' },
# 'ngiang'	=> { 'x' => 'buzzing sound (in the mind)' },
# 'ngilu'	=> { 'x' => 'gnawing pain' },
# 'nguak'	=> { 'x' => 'bray like a donkey' },
 'nila'		=> { 'x' => 'blue dye',
		     '#' => 'indigo' },
 'nilam'	=> { 'x' => 'sapphire' },
# 'nipah'	=> { 'x' => 'a type of palm' },
 'nipis'	=> { 'x' => 'thin' },
 'nirinsani'	=> { 'x' => 'dehumanize' },
# 'nirwana'	=> { 'x' => 'state of perfect bliss' },
 'nisan'	=> { 'x' => 'gravestone' },
 'nisbah'	=> { 'x' => 'ratio' },
 'niskala'	=> { 'x' => 'having no material or physical substance',
		     '#' => 'abstract' },
 'nista'	=> { 'x' => 'insult',
		     '#' => '; abuse' },
# 'nobat'	=> { 'x' => 'malay royal band' },
# 'noktah'	=> { 'x' => 'full stop' },
 'nota'		=> { 'x' => 'note' },
 'nujum'	=> { 'x' => 'prophet',
		     '#' => 'fortune-teller' },
 'nusa'		=> { 'x' => 'motherland',
		     '#' => '; fatherland' },
# 'nusantara'	=> { 'x' => 'malay archipelago' },
 'nyah'		=> { 'x' => 'go away!',
		     '#' => 'get away!' },
# 'nyahcas'	=> { 'x' => 'release the electric charge of' },
 'nyahjangkit'	=> { 'x' => 'disinfect' },
 'nyahpecutan'	=> { 'x' => 'deceleration' },
 'nyamuk'	=> { 'x' => 'mosquito' },
 'nyanyuk'	=> { 'x' => 'dotage',
		     '#' => 'senility with feeble mind' },
# 'nyaring'	=> { 'x' => 'piercing and shrill (of sound)' },
 'nyaris'	=> { 'x' => 'almost',
		     '#' => '; nearly' },
# 'nyenyak'	=> { 'x' => 'sound asleep' },
# 'nyiru'	=> { 'x' => 'triangular tray made from bamboo' },
 'nyiur'	=> { 'x' => 'coconut' },
# 'nyonya'	=> { 'x' => 'term used for married chinese lady' },
 'nyunyut'	=> { 'x' => 'suck' },
 'obor'		=> { 'x' => 'torch' },
 'ogah'		=> { 'x' => 'hookah' },
 'oktober'	=> { 'x' => 'october' },
 'olakan'	=> { 'x' => 'convection',
		     '#' => '; eddy' },
 'oleng'	=> { 'x' => 'sway',
		     '#' => '; rock' },
 'olok-olok'	=> { 'x' => 'jest',
		     '#' => 'joke; make fun' },
 'omong'	=> { 'x' => 'chatter',
		     '#' => 'empty talk' },
 'onar'		=> { 'x' => 'commotion',
		     '#' => '; uproar' },
# 'onde-onde'	=> { 'x' => 'sweet dumpling of flour and coconut' },
 'opah'		=> { 'x' => 'grandmother' },
 'oren'		=> { 'x' => 'orange' },
 'otot'		=> { 'x' => 'muscle' },
# 'pacak'	=> { 'x' => 'to erect a pointed pole in the ground' },
 'pacal'	=> { 'x' => 'i',
		     '#' => 'me (when addressing royalty)' },
# 'pacat'	=> { 'x' => 'land (or jungle) leech' },
# 'pacul'	=> { 'x' => '(1)hoe (2)to appear suddenly' },
 'padah'	=> { 'x' => 'omen',
		     '#' => '; warning' },
 'padam'	=> { 'x' => 'extinguish',
		     '#' => 'to put off; to switch off; to rub off' },
 'padan'	=> { 'x' => 'matched',
		     '#' => '; fitting; suited' },
 'padanan'	=> { 'x' => 'suitability' },
 'padang'	=> { 'x' => 'field' },
 'padang pasir'	=> { 'x' => 'desert' },
 'padat'	=> { 'x' => 'compact',
		     '#' => '; packed; dense' },
 'paderi'	=> { 'x' => 'priest' },
 'padi'		=> { 'x' => 'rice-plant',
		     '#' => 'rice-grain with its husk' },
# 'padu'		=> { 'x' => '(1)solid (2)united' },
 'paduka'	=> { 'x' => 'excellency',
		     '#' => '; majesty' },
 'pagar'	=> { 'x' => 'fence' },
 'pagi'		=> { 'x' => 'morning' },
# 'pagi-pagi'	=> { 'x' => 'early in the morning' },
# 'pagut'	=> { 'x' => 'to peck (of bird)' },
 'paha'		=> { 'x' => 'thigh' },
 'pahala'	=> { 'x' => 'reward',
		     '#' => '; merit' },
 'pahat'	=> { 'x' => 'chisel' },
 'pahit'	=> { 'x' => 'bitter' },
 'pahlawan'	=> { 'x' => 'hero',
		     '#' => '; warrior' },
 'pajak'	=> { 'x' => 'lease' },
 'pajak gadai'	=> { 'x' => 'pawnshop' },
 'pak'		=> { 'x' => 'father',
		     '#' => '; uncle' },
 'pakcik'	=> { 'x' => 'uncle' },
 'pakai'	=> { 'x' => 'wear',
		     '#' => '; to use',
		     't' => 'v' },
 'pakaian'	=> { 'x' => 'clothes' },
 'pakaian seragam'	=> { 'x' => 'uniform' },
 'pakal'	=> { 'x' => 'caulk',
		     't' => 'v' },
 'pakar'	=> { 'x' => 'expert',
		     '#' => '; specialist' },
 'pakar runding'	=> { 'x' => 'consultant' },
 'pakat'	=> { 'x' => 'agree',
		     '#' => '; to conspire',
		     't' => 'v' },
 'pakatan'	=> { 'x' => 'pact',
		     '#' => '; agreement; treaty; conspiracy' },
 'pakis'	=> { 'x' => 'fern' },
 'paksa'	=> { 'x' => 'force',
		     '#' => '; to compel',
		     't' => 'v' },
 'paksaan'	=> { 'x' => 'compulsion' },
 'paksi'	=> { 'x' => 'axis' },
 'paku'		=> { 'x' => 'nail',
		     '#' => '; ferns' },
 'pala'		=> { 'x' => 'nutmeg' },
# 'palam'	=> { 'x' => '(1)grout (2)plug' },
 'palang'	=> { 'x' => 'crossbar' },
 'palit'	=> { 'x' => 'smear',
		     '#' => '; to smudge',
		     't' => 'v' },
 'palsu'	=> { 'x' => 'false' },
 'palu'		=> { 'x' => 'hit',
		     '#' => '; to beat',
		     't' => 'v' },
 'paluan'	=> { 'x' => 'knock',
		     '#' => '; a blow',
		     't' => 'n' },
 'palung'	=> { 'x' => 'pool',
		     '#' => '; trough' },
 'palut'	=> { 'x' => 'wrapping',
		     '#' => '; covering' },
 'pamah'	=> { 'x' => 'lowlands' },
 'paman'	=> { 'x' => 'uncle' },
 'pamer'	=> { 'x' => 'exhibit',
		     't' => 'v' },
 'pameran'	=> { 'x' => 'exhibition' },
 'pampang'	=> { 'x' => 'spread out',
		     '#' => 'to stretch out' },
 'pampas'	=> { 'x' => 'compensation' },
 'pampasan'	=> { 'x' => 'compensation' },
# 'panah'	=> { 'x' => 'bow (for shooting arrows)' },
 'panahan'	=> { 'x' => 'archery' },
 'panas'	=> { 'x' => 'hot',
		     '#' => '; feverish' },
 'panas terik'	=> { 'x' => 'very hot',
		     '#' => 'blistering; scorching' },
 'panas-panas'	=> { 'x' => 'hot' },
# 'panau'	=> { 'x' => 'pityriasis versicolor (a type of skin disease)' },
# 'pancalogam'	=> { 'x' => 'an alloy of five metals' },
# 'pancaindera'	=> { 'x' => 'the five senses' },
# 'pancang'	=> { 'x' => 'pole or stake driven into the ground' },
 'pancar'	=> { 'x' => 'radiate',
		     '#' => 'to gush out; to broadcast; to emit' },
 'pancaran'	=> { 'x' => 'spout',
		     '#' => 'broadcast; emission; beam or ray' },
# 'pancaragam'	=> { 'x' => 'band or orchestra' },
 'pancing'	=> { 'x' => 'fishing hook',
		     '#' => 'to fish' },
 'pancit'	=> { 'x' => 'puncture',
		     't' => 'n' },
 'pancung'	=> { 'x' => 'behead',
		     't' => 'v' },
 'pancungan'	=> { 'x' => 'decapitation' },
 'pancur'	=> { 'x' => 'flow',
		     '#' => 'spurt out; to spout',
		     't' => 'v' },
 'pancut'	=> { 'x' => 'spurt',
		     '#' => 'to gush out',
		     't' => 'v' },
 'pancutan'	=> { 'x' => 'spurt',
		     '#' => '; an ejection',
		     't' => 'n' },
 'pandai'	=> { 'x' => 'clever',
		     '#' => '; intelligent' },
 'pandang'	=> { 'x' => 'look',
		     '#' => '; to consider',
		     't' => 'v' },
 'pandangan'	=> { 'x' => 'opinion',
		     '#' => '; view' },
# 'pandang-memandang'	=> { 'x' => 'to exchange looks or glances' },
 'pandir'	=> { 'x' => 'stupid' },
 'pandu'	=> { 'x' => 'guide',
		     '#' => '; to drive; to pilot',
		     't' => 'v' },
 'panduan'	=> { 'x' => 'guidance',
		     '#' => '; directory' },
# 'pandu puteri'	=> { 'x' => 'girl guide' },
 'panggang'	=> { 'x' => 'roast',
		     '#' => '(verb); to toast; roasted' },
 'panggil'	=> { 'x' => 'call',
		     't' => 'v' },
 'panggilan'	=> { 'x' => 'call',
		     '#' => 'a summon; name or title',
		     't' => 'n' },
 'panggung'	=> { 'x' => 'theatre',
		     '#' => '; stage' },
 'panggung wayang'	=> { 'x' => 'cinema' },
 'pangkah'	=> { 'x' => 'cross',
		     '#' => '(noun); to put a cross' },
 'pangkal'	=> { 'x' => 'beginning',
		     '#' => '; base' },
 'pangkalan'	=> { 'x' => 'base',
		     '#' => '; jetty' },
# 'pangkas'	=> { 'x' => 'to clip or cut' },
 'pangkat'	=> { 'x' => 'rank' },
 'pangkin'	=> { 'x' => 'bunk' },
# 'pangku'	=> { 'x' => '(1)to take on one\'s lap (2)to hold office in an acting capacity' },
# 'pangkuan'	=> { 'x' => 'the lap' },
 'panglima'	=> { 'x' => 'warrior',
		     '#' => '; commander' },
 'pangsa'	=> { 'x' => 'compartment',
		     '#' => 'section (of fruit)' },
 'pangsapuri'	=> { 'x' => 'apartment' },
 'panitia'	=> { 'x' => 'commission',
		     '#' => '; committee' },
 'panjang'	=> { 'x' => 'long' },
 'panjang akal'	=> { 'x' => 'resourceful',
		     '#' => 'intelligent' },
 'panjangnya'	=> { 'x' => 'length' },
 'panjat'	=> { 'x' => 'climb',
		     't' => 'v' },
 'panji-panji'	=> { 'x' => 'bunting',
		     '#' => 'streamer' },
 'pantai'	=> { 'x' => 'beach',
		     '#' => '; coast' },
 'pantang'	=> { 'x' => 'prohibition',
		     '#' => 'abstinence; to abstain' },
 'pantang larang'	=> { 'x' => 'prohibition',
		     '#' => 'taboo' },
 'pantas'	=> { 'x' => 'fast',
		     '#' => '; quick; swift' },
 'pantat'	=> { 'x' => 'posterior or bottom',
		     '#' => 'external genitalia' },
 'pantul'	=> { 'x' => 'bound',
		     '#' => 'bounce back; to spring',
		     't' => 'v' },
 'pantulan'	=> { 'x' => 'reflex',
		     '#' => '; rebound' },
 'pantun'	=> { 'x' => 'quatrain' },
# 'papa'		=> { 'x' => 'very poor' },
 'papa kedana'	=> { 'x' => 'destitute' },
 'papah'	=> { 'x' => 'supported',
		     '#' => 'to support' },
 'papan'	=> { 'x' => 'plank' },
 'papan catur'	=> { 'x' => 'chess-board' },
 'papan hitam'	=> { 'x' => 'blackboard' },
 'papan iklan'	=> { 'x' => 'billboard' },
 'papan kenyataan'	=> { 'x' => 'notice-board' },
 'papar'	=> { 'x' => 'flat' },
 'papas'	=> { 'x' => 'counteract',
		     '#' => '(1)to take off; to strip off',
		     't' => 'v' },
# 'para'		=> { 'x' => 'prefix denoting large numbers or large amount' },
 'para-para'	=> { 'x' => 'rack',
		     '#' => 'shelf' },
 'parah'	=> { 'x' => 'serious',
		     '#' => 'critical (of illness or injury)' },
 'parang'	=> { 'x' => 'chopping-knife' },
 'paras'	=> { 'x' => 'face',
		     '#' => '; level' },
# 'parau'	=> { 'x' => 'hoarse (of voice)' },
 'pari'		=> { 'x' => 'ray',
		     '#' => '; skate' },
 'pari-pari'	=> { 'x' => 'fairy' },
 'parit'	=> { 'x' => 'ditch',
		     '#' => '; drain' },
 'paru-paru'	=> { 'x' => 'lung' },
 'paruh'	=> { 'x' => 'bill',
		     '#' => 'beak (2)half',
		     't' => 'n' },
# 'parut'	=> { 'x' => '(1)scar (2)to grate or scrape' },
 'pasak'	=> { 'x' => 'pin',
		     '#' => '; peg; wedge' },
 'pasang'	=> { 'x' => 'pair',
		     '#' => 'set (2)to install; to affix; to fasten (3)to rise (of tide)' },
 'pasangan'	=> { 'x' => 'couple' },
# 'pasang badan'	=> { 'x' => 'to dress up' },
 'pasang telinga'	=> { 'x' => 'eavesdrop',
		     't' => 'v' },
 'pasar'	=> { 'x' => 'market' },
# 'pasar borong'	=> { 'x' => 'wholesale market' },
# 'pasar gelap'	=> { 'x' => 'black market' },
# 'pasar malam'	=> { 'x' => 'night market' },
 'pasaraya'	=> { 'x' => 'supermarket' },
 'pasir'	=> { 'x' => 'sand' },
 'pasti'	=> { 'x' => 'definite',
		     '#' => '; certain; sure' },
 'pasu'		=> { 'x' => 'flower-pot',
		     '#' => 'vase' },
# 'pasu-pasu'	=> { 'x' => 'cheek bones' },
 'pasukan'	=> { 'x' => 'team',
		     '#' => 'unit of troops' },
 'pasung'	=> { 'x' => 'pillory',
		     '#' => '; handcuffs' },
 'patah'	=> { 'x' => 'broken',
		     '#' => '(of long objects), fracture (2)numeral coefficient for words',
		     't' => 'a' },
 'patah hati'	=> { 'x' => 'broken-hearted' },
 'pateri'	=> { 'x' => 'solder' },
 'pati'		=> { 'x' => 'essence',
		     '#' => '; extract' },
 'patuh'	=> { 'x' => 'obedient' },
 'patuk'	=> { 'x' => 'peck',
		     '#' => 'to bite (of snake)',
		     't' => 'v' },
 'patung'	=> { 'x' => 'statue',
		     '#' => '; dummy; doll; idol' },
 'patung-patung'	=> { 'x' => 'dragon-fly' },
 'patut'	=> { 'x' => 'fair',
		     '#' => 'reasonable; right and proper; appropriate' },
 'paus'		=> { 'x' => 'whale' },
 'paut'		=> { 'x' => 'cling on',
		     '#' => 'hold on tightly',
		     't' => 'v' },
 'pawagam'	=> { 'x' => 'cinema',
		     '#' => '; theatre' },
# 'pawah'	=> { 'x' => 'sharing of profits between tenant and landlord' },
# 'pawang'	=> { 'x' => 'malay witch doctor' },
 'paya'		=> { 'x' => 'swamp' },
# 'paya bakau'	=> { 'x' => 'mangrove swamp' },
 'payah'	=> { 'x' => 'difficult' },
 'payau'	=> { 'x' => 'brackish' },
 'payung'	=> { 'x' => 'umbrella' },
 'pecah'	=> { 'x' => 'break',
		     't' => 'v' },
 'pecahan'	=> { 'x' => 'fraction' },
 'pecat'	=> { 'x' => 'dismiss',
		     't' => 'v' },
 'pecut'	=> { 'x' => 'accelerate',
		     't' => 'v' },
 'pedang'	=> { 'x' => 'sword' },
# 'pedap'	=> { 'x' => 'to imbibe or absorb' },
 'pedas'	=> { 'x' => 'hot (of chillies and curry)',
		     '#' => 'caustic' },
 'pedati'	=> { 'x' => 'caravan',
		     '#' => '; cart; carriage' },
 'pedih'	=> { 'x' => 'smarting',
		     '#' => '; sorrowful' },
 'pedoman'	=> { 'x' => 'compass',
		     '#' => '; guide' },
 'peduli'	=> { 'x' => 'mind',
		     '#' => '; bother about; to mind; to care' },
# 'pegaga'	=> { 'x' => 'a kind of creeping plant' },
 'pegang'	=> { 'x' => 'hold',
		     '#' => '; to control',
		     't' => 'v' },
 'pegangan'	=> { 'x' => 'hold',
		     '#' => 'something that is held',
		     't' => 'n' },
 'pegawai'	=> { 'x' => 'officer' },
 'peguam'	=> { 'x' => 'lawyer' },
 'peguambela'	=> { 'x' => 'advocate',
		     '#' => '; barrister' },
 'peguamcara'	=> { 'x' => 'solicitor' },
# 'pegun'	=> { 'x' => '(1)petrified (2)silent in meditation' },
 'pejal'	=> { 'x' => 'solid',
		     '#' => '; firm' },
 'pejalwapan'	=> { 'x' => 'condensation' },
# 'pejam'	=> { 'x' => 'to close or shut (of eyes)' },
 'peka'		=> { 'x' => 'sensitive' },
 'pekak'	=> { 'x' => 'deaf' },
 'pekan'	=> { 'x' => 'town',
		     '#' => '; marketplace' },
# 'pekap'	=> { 'x' => 'to cover (mouth or ears) with the hand' },
# 'pekasam'	=> { 'x' => 'fish or meat pickled in brine' },
# 'pekat'	=> { 'x' => 'thick or concentrated (of liquid)' },
 'pekerti'	=> { 'x' => 'character',
		     '#' => '; disposition' },
 'pekik'	=> { 'x' => 'scream',
		     't' => 'v' },
# 'pelamin'	=> { 'x' => 'bridal dais' },
 'pelampung'	=> { 'x' => 'float',
		     '#' => '; buoy' },
 'pelana'	=> { 'x' => 'saddle' },
 'pelanduk'	=> { 'x' => 'mouse-deer' },
 'pelangi'	=> { 'x' => 'rainbow' },
 'pelantar'	=> { 'x' => 'long bench',
		     '#' => 'landing on stairs' },
 'pelanting'	=> { 'x' => 'scatter',
		     't' => 'v' },
 'pelat'	=> { 'x' => 'faulty pronunciation',
		     '#' => 'dialect; accent' },
 'pelawa'	=> { 'x' => 'invite',
		     't' => 'v' },
 'pelawaan'	=> { 'x' => 'invitation' },
 'pelbagai'	=> { 'x' => 'assorted',
		     '#' => '; variety' },
 'pelecok'	=> { 'x' => 'sprain',
		     't' => 'v' },
 'pelekat'	=> { 'x' => 'gum',
		     '#' => '; glue' },
 'pelepah'	=> { 'x' => 'rib of palm leaf',
		     '#' => 'rib of feather; frond of palm tree' },
 'pelesir'	=> { 'x' => 'gallivant',
		     't' => 'v' },
 'pelihara'	=> { 'x' => 'rear',
		     '#' => 'to take care of',
		     't' => 'v' },
# 'peliharaan'	=> { 'x' => 'that which is being reared' },
 'pelik'	=> { 'x' => 'strange',
		     '#' => '; queer' },
 'pelita'	=> { 'x' => 'lamp' },
 'pelopor'	=> { 'x' => 'pioneer' },
 'pelosok'	=> { 'x' => 'corner',
		     '#' => 'nook (of country)' },
 'peluang'	=> { 'x' => 'chance',
		     '#' => '; opportunity' },
 'peluh'	=> { 'x' => 'sweat',
		     '#' => '; perspiration' },
 'peluk'	=> { 'x' => 'embrace',
		     '#' => '; to hug',
		     't' => 'v' },
 'pelukan'	=> { 'x' => 'hug',
		     't' => 'n' },
 'peluru'	=> { 'x' => 'bullet' },
 'pementerjemah'	=> { 'x' => 'translator',
			     't' => 'n',
			     'df' => 'terjemah?' },
 'pena'		=> { 'x' => 'pen',
		     '#' => '(writing device)',
		     't' => 'n' },
 'penat'	=> { 'x' => 'tired' },
 'penawar'	=> { 'x' => 'antidote' },
 'pencak'	=> { 'x' => 'self-defence',
		     '#' => 'to parry' },
 'pencil'	=> { 'x' => 'isolate',
		     't' => 'v' },
 'pendam'	=> { 'x' => 'hide',
		     '#' => 'conceal (of feelings, emotions, secrets)',
		     't' => 'v' },
# 'pendaman'	=> { 'x' => 'something that is concealed' },
 'pendek'	=> { 'x' => 'short' },
 'pendekar'	=> { 'x' => 'warrior',
		     '#' => 'expert in malay art of self-defence' },
# 'pendita'	=> { 'x' => 'great scholar' },
 'pengantin'	=> { 'x' => 'bride',
		     '#' => '; bridegroom' },
 'pengaruh'	=> { 'x' => 'influence',
		     '#' => '; authority' },
 'penggal'	=> { 'x' => 'term',
		     '#' => '(2)paragraph, chapter; volume (3)to behead',
		     't' => 'n' },
# 'penggawa'	=> { 'x' => 'village headman' },
# 'penghulu'	=> { 'x' => 'village headman' },
 'pengsan'	=> { 'x' => 'unconscious',
		     '#' => 'to faint' },
 'pening'	=> { 'x' => 'dizzy',
		     '#' => 'giddy; feeling confused' },
# 'pening-pening lalat'	=> { 'x' => 'slightly dizzy' },
# 'peniti'	=> { 'x' => 'safety pin' },
 'penjara'	=> { 'x' => 'jail',
		     '#' => '; prison' },
 'penjuru'	=> { 'x' => 'corner',
		     '#' => '; angle' },
 'pentas'	=> { 'x' => 'stage' },
 'penting'	=> { 'x' => 'important' },
 'penuh'	=> { 'x' => 'full' },
 'penyek'	=> { 'x' => 'flattened' },
 'penyu'	=> { 'x' => 'turtle' },
 'pepatah'	=> { 'x' => 'saying',
		     '#' => '; maxim; proverb' },
 'perabot'	=> { 'x' => 'furniture' },
 'perah'	=> { 'x' => 'wring',
		     '#' => '; to squeeze',
		     't' => 'v' },
 'perahan'	=> { 'x' => 'juice',
		     '#' => 'that which has been squeezed out' },
 'perahu'	=> { 'x' => 'boat' },
 'perajurit'	=> { 'x' => 'soldier' },
 'perak'	=> { 'x' => 'silver' },
# 'peraka'	=> { 'x' => 'a ship\'s hold' },
# 'peram'	=> { 'x' => 'to keep fruit till ripe' },
 'peran'	=> { 'x' => 'clown',
		     '#' => '; jester' },
 'peranan'	=> { 'x' => 'role' },
 'perancis'	=> { 'x' => 'french' },
# 'perang'	=> { 'x' => '(1)war (2)brown' },
 'peperangan'	=> { 'x' => 'war' },
 'perangai'	=> { 'x' => 'behaviour',
		     '#' => '; character; nature; disposition' },
 'perangkap'	=> { 'x' => 'trap' },
 'peranjat'	=> { 'x' => 'startled',
		     '#' => '; shocked; surprised' },
# 'perap'	=> { 'x' => '(1)to flap (wings) (2)to lock oneself up in the house' },
 'peras'	=> { 'x' => 'extort',
		     '#' => '; to extract',
		     't' => 'v' },
 'perasan'	=> { 'x' => 'aware of',
		     '#' => 'conscious of' },
 'perawan'	=> { 'x' => 'maiden',
		     '#' => 'virgin girl' },
 'perbahasaan'	=> { 'x' => 'speech',
		     '#' => '; customary etiquette',
		     't' => 'n',
		     'df' => 'bahasa' },
# 'perca'	=> { 'x' => 'remnants of cloth' },
 'percaya'	=> { 'x' => 'believe',
		     't' => 'v' },
 'percik'	=> { 'x' => 'sprinkle',
		     't' => 'v' },
# 'percuma'	=> { 'x' => '(1)free of charge (2)in vain (of time or effort)' },
 'perdana'	=> { 'x' => 'premier',
		     '#' => '; principal; prime' },
# 'perdu'	=> { 'x' => 'base of tree trunk' },
 'perempuan'	=> { 'x' => 'female',
		     '#' => '; woman; girl' },
# 'perencah'	=> { 'x' => 'something used to add taste to a dish' },
# 'perenggan'	=> { 'x' => '(1)boundary (2)paragraph' },
 'peri'		=> { 'x' => 'nature',
		     '#' => 'manner (of feelings, situations)' },
 'peri-peri'	=> { 'x' => 'fairy' },
# 'peria'	=> { 'x' => 'bitter gourd' },
 'peribadi'	=> { 'x' => 'private',
		     '#' => '; personal' },
 'peribahasa'	=> { 'x' => 'proverb' },
 'peribumi'	=> { 'x' => 'native' },
 'perigi'	=> { 'x' => 'well' },
# 'perigi buta'	=> { 'x' => 'disused well' },
 'perihal'	=> { 'x' => 'matters',
		     '#' => '; situation' },
 'perikemanusiaan'	=> { 'x' => 'humanity',
		     '#' => '; compassion' },
 'periksa'	=> { 'x' => 'examine',
		     '#' => '; to check; to investigate',
		     't' => 'v' },
# 'perinci'	=> { 'x' => 'to describe in great detail' },
 'peringkat'	=> { 'x' => 'grade',
		     '#' => '; stage' },
 'perintah'	=> { 'x' => 'command',
		     '#' => '; order' },
 'perisai'	=> { 'x' => 'shield',
		     't' => 'n' },
 'peristiwa'	=> { 'x' => 'incident',
		     '#' => '; event; happening' },
 'perisytiharan'	=> { 'x' => 'declaration',
			     't' => 'n' },
 'perit'	=> { 'x' => 'painful',
		     't' => 'a' },
 'periuk'	=> { 'x' => 'pot',
		     '#' => 'for cooking ',
		     't' => 'n' },
 'perkakas'	=> { 'x' => 'instrument',
		     '#' => 'tool; apparatus; equipment' },
 'perkara'	=> { 'x' => 'article',
		     '#' => 'matter',
		     't' => 'n' },
 'perkasa'	=> { 'x' => 'strong',
		     '#' => '; brave; powerful' },
 'perkosa'	=> { 'x' => 'brave',
		     '#' => 'strong (2)to force; to rape',
		     't' => 'a' },
# 'perkosaan'	=> { 'x' => 'the act of forcing or raping' },
 'perlahan'	=> { 'x' => 'slow',
		     't' => 'a' },
 'perli'	=> { 'x' => 'tease',
		     't' => 'v' },
# 'perlu'	=> { 'x' => 'necessary: must' },
 'permai'	=> { 'x' => 'beautiful',
		     '#' => '; magnificent; wonderful' },
 'permaidani'	=> { 'x' => 'carpet' },
 'permaisuri'	=> { 'x' => 'queen' },
 'permata'	=> { 'x' => 'jewel' },
# 'pernah'	=> { 'x' => 'to (ever) have' },
 'peroi'	=> { 'x' => 'friable' },
# 'peronyok'	=> { 'x' => 'to crumple (of paper)' },
# 'perosok'	=> { 'x' => 'to sink or slip into' },
 'persegi'	=> { 'x' => 'square' },
 'pertama'	=> { 'x' => 'first' },
 'perut'	=> { 'x' => 'stomach' },
 'perwira'	=> { 'x' => 'hero',
		     '#' => '; warrior' },
 'pesan'	=> { 'x' => 'message',
		     '#' => '; order' },
 'pesanan'	=> { 'x' => 'message',
		     '#' => '; order' },
 'pesat'	=> { 'x' => 'quick',
		     '#' => 'rapid (of development)' },
 'pesawat'	=> { 'x' => 'machine' },
 'pesisir'	=> { 'x' => 'beach',
		     '#' => '; shore' },
 'pesona'	=> { 'x' => 'spell',
		     '#' => 'or charm',
		     't' => 'n' },
# 'pesong'	=> { 'x' => 'to change direction or course' },
 'pesta'	=> { 'x' => 'festival' },
 'pesuruhjaya'	=> { 'x' => 'commissioner' },
 'peta'		=> { 'x' => 'map' },
 'petah'	=> { 'x' => 'eloquent',
		     '#' => '; fluent' },
# 'petai'	=> { 'x' => 'stinking edible green pod' },
 'petak'	=> { 'x' => 'compartment',
		     '#' => '; section' },
 'petala'	=> { 'x' => 'layer',
		     '#' => '; stratum; storey' },
# 'petaling'	=> { 'x' => 'small hardwood tree' },
 'petang'	=> { 'x' => 'afternoon',
		     '#' => '; evening' },
 'peti'		=> { 'x' => 'box',
		     '#' => '; casket; case' },
 'peti sejuk'	=> { 'x' => 'refrigerator' },
 'peti surat'	=> { 'x' => 'post-box' },
 'petik'	=> { 'x' => 'pluck',
		     '#' => '(2)to quote',
		     't' => 'v' },
 'petikan'	=> { 'x' => 'quotation' },
 'petola'	=> { 'x' => 'loofah' },
 'petir'	=> { 'x' => 'thunder' },
 'petua'	=> { 'x' => 'advice',
		     '#' => '; ruling' },
 'piagam'	=> { 'x' => 'charter',
		     '#' => '; constitution' },
 'piala'	=> { 'x' => 'cup' },
 'piat'		=> { 'x' => 'twist',
		     't' => 'v' },
 'piatu'	=> { 'x' => 'orphan' },
 'piawai'	=> { 'x' => 'correct',
		     '#' => '; precise; accurate; exact; standard' },
 'picagari'	=> { 'x' => 'syringe' },
 'picing'	=> { 'x' => 'blink',
		     '#' => 'to wink; to close the eyes',
		     't' => 'v' },
 'picit'	=> { 'x' => 'press',
		     '#' => '; to squeeze; to pinch',
		     't' => 'v' },
 'pidato'	=> { 'x' => 'speech',
		     '#' => '; lecture; talk' },
 'pihak'	=> { 'x' => 'side',
		     '#' => '; party' },
# 'pijak'	=> { 'x' => 'to step on' },
 'pijat'	=> { 'x' => 'bed-bug' },
 'pikat'	=> { 'x' => 'trap',
		     '#' => '; to tempt; to attract',
		     't' => 'v' },
# 'pikul'	=> { 'x' => '(1)a unit of weight (=133lbs.) (2)to carry on the shoulder' },
# 'pilin'	=> { 'x' => 'to twist or wind' },
 'pilih'	=> { 'x' => 'choose',
		     '#' => '; to select; to elect',
		     't' => 'v' },
 'pilihan'	=> { 'x' => 'choice',
		     '#' => '; selection' },
# 'pilihanraya'	=> { 'x' => 'general election' },
 'pilu'		=> { 'x' => 'sad',
		     '#' => '; sorrowful; mournful' },
 'pimpin'	=> { 'x' => 'lead',
		     '#' => '; to guide',
		     't' => 'v' },
 'pimpinan'	=> { 'x' => 'leadership' },
# 'pinang'	=> { 'x' => '(1)areca-nut (2)to propose (for marriage)' },
 'pinar'	=> { 'x' => 'glowing',
		     '#' => '; shimmering' },
# 'pincang'	=> { 'x' => '(1)lame (2)unbalanced (of music)' },
 'pinda'	=> { 'x' => 'alter',
		     '#' => '; to amend; to correct',
		     't' => 'v' },
 'pindaan'	=> { 'x' => 'amendment' },
# 'pindah'	=> { 'x' => 'to move or shift from one place to another' },
# 'pindah milik'	=> { 'x' => 'transfer of ownership' },
# 'pindah tangan'	=> { 'x' => 'change of hands' },
 'pindahan'	=> { 'x' => 'transfer',
		     't' => 'n' },
 'pinga'	=> { 'x' => 'astounded',
		     '#' => '; stunned' },
 'pingat'	=> { 'x' => 'medal' },
 'pinggan'	=> { 'x' => 'plate',
		     '#' => '; dish' },
 'pinggan mangkuk'	=> { 'x' => 'crockery' },
 'pinggang'	=> { 'x' => 'waist' },
 'pinggir'	=> { 'x' => 'edge' },
 'pinggir jalan'	=> { 'x' => 'roadside' },
 'pinggir kota'	=> { 'x' => 'suburbs' },
 'pinggir laut'	=> { 'x' => 'coast' },
 'pinggul'	=> { 'x' => 'buttocks',
		     '#' => '; hip' },
 'pinjam'	=> { 'x' => 'borrow',
		     't' => 'v' },
 'pinjaman'	=> { 'x' => 'loan' },
 'pinta'	=> { 'x' => 'request',
		     '#' => 'to ask for',
		     't' => 'v' },
 'pintal'	=> { 'x' => 'twist',
		     '#' => '; to spin',
		     't' => 'v' },
 'pintar'	=> { 'x' => 'cunning',
		     '#' => 'sharp-witted; smart; clever',
		     't' => 'a' },
 'pintas'	=> { 'x' => 'intercept',
		     '#' => 'to cut short; interrupt; to cut across',
		     't' => 'v' },
 'pintasan'	=> { 'x' => 'short-cut' },
 'pintu'	=> { 'x' => 'door' },
 'pipi'		=> { 'x' => 'cheek' },
# 'pipih'	=> { 'x' => 'thin and flat' },
# 'pipis'	=> { 'x' => 'to mash or grind' },
 'pipit'	=> { 'x' => 'sparrow' },
 'piring'	=> { 'x' => 'saucer' },
# 'piring hitam'	=> { 'x' => 'gramophone record' },
# 'pisah'	=> { 'x' => 'to be separated' },
 'pisang'	=> { 'x' => 'banana' },
 'pisau'	=> { 'x' => 'knife' },
 'pita'		=> { 'x' => 'ribbon',
		     '#' => '; tape' },
 'pitam'	=> { 'x' => 'dizziness' },
 'piutang'	=> { 'x' => 'credit',
		     '#' => 'monies receivable' },
# 'plumbum'	=> { 'x' => 'lead (metal)' },
 'pohon'	=> { 'x' => 'tree',
		     '#' => '(2)to apply, to beg; to request',
		     't' => 'n' },
 'pokok'	=> { 'x' => 'tree',
		     '#' => '(2)principle, capital',
		     't' => 'n' },
 'pondan'	=> { 'x' => 'transvestite' },
 'pondok'	=> { 'x' => 'hut',
		     '#' => '; booth; shed' },
 'ponteng'	=> { 'x' => 'cheat',
		     '#' => '(1)to play truant, to swindle',
		     't' => 'v' },
 'pontianak'	=> { 'x' => 'vampire',
		     '#' => 'female',
		     't' => 'n' },
 'porak-peranda'	=> { 'x' => 'chaotic',
		     '#' => 'in disorder',
			     't' => 'a' },
 'potong'	=> { 'x' => 'piece',
		     '#' => 'a slice; to cut',
		     't' => 'n' },
# 'potongan'	=> { 'x' => 'the cut (of clothes)' },
 'prakata'	=> { 'x' => 'foreword' },
 'pramugara'	=> { 'x' => 'air-steward' },
 'pramugari'	=> { 'x' => 'air-stewardess' },
 'prasangka'	=> { 'x' => 'prejudice',
		     '#' => '; suspicion' },
 'prasejarah'	=> { 'x' => 'prehistorical' },
 'prestasi'	=> { 'x' => 'performance' },
 'puak'		=> { 'x' => 'group',
		     '#' => '; tribe' },
# 'puaka'	=> { 'x' => 'evil spirit' },
 'puas'		=> { 'x' => 'satisfied',
		     '#' => '; contented' },
 'puasa'	=> { 'x' => 'fast' },
 'pucat'	=> { 'x' => 'pale' },
# 'pucuk'	=> { 'x' => '(1)a shoot or sprout (2)numeral coefficient for letter or gun' },
 'pudar'	=> { 'x' => 'dim (of light)',
		     '#' => 'faded' },
# 'puding'	=> { 'x' => 'an ornamental shrub' },
 'puisi'	=> { 'x' => 'poetry' },
 'puja'		=> { 'x' => 'worship',
		     '#' => '; to adore',
		     't' => 'v' },
 'pujangga'	=> { 'x' => 'author',
		     '#' => 'literary person' },
 'puji'		=> { 'x' => 'praise',
		     't' => 'v' },
 'pujian'	=> { 'x' => 'compliment',
		     '#' => 'or praise',
		     't' => 'n' },
 'pujuk'	=> { 'x' => 'coax',
		     '#' => 'to persuade; to entice',
		     't' => 'v' },
 'pujukan'	=> { 'x' => 'persuasion',
		     '#' => '; enticement' },
 'pukal'	=> { 'x' => 'lump',
		     '#' => '; block' },
 'pukang'	=> { 'x' => 'crotch' },
# 'pukat'	=> { 'x' => 'dragnet (for fishing)' },
# 'pukau'	=> { 'x' => 'charm used (by burglars) to make people fall asleep' },
# 'pukul'	=> { 'x' => '(1)to beat or hit (2)hour' },
 'pulang'	=> { 'x' => 'return',
		     '#' => 'to go back',
		     't' => 'v' },
# 'pulangan'	=> { 'x' => 'the act of returning' },
 'pulang kerahmatullah'	=> { 'x' => 'die',
		     't' => 'v' },
 'pulas'	=> { 'x' => 'twist',
		     '#' => '; to wring',
		     't' => 'v' },
# 'pulau'	=> { 'x' => '(1)island (2)to boycott' },
 'pulih'	=> { 'x' => 'recover',
		     '#' => '; to restore',
		     't' => 'v' },
# 'pulut'	=> { 'x' => 'glutinous rice' },
 'pun'		=> { 'x' => 'also' },
 'punah'	=> { 'x' => 'destroy',
		     't' => 'v' },
 'punai'	=> { 'x' => 'pigeon',
		     '#' => '; dove' },
# 'punat'	=> { 'x' => '(1)button (2)core of a boil' },
 'punca'	=> { 'x' => 'source',
		     '#' => '; origin' },
 'puncak'	=> { 'x' => 'peak',
		     '#' => '; summit; acme' },
 'pundi-pundi'	=> { 'x' => 'purse' },
# 'pundi-pundi kencing'	=> { 'x' => 'urinary bladder' },
 'punggah'	=> { 'x' => 'unload',
		     't' => 'v' },
# 'pungguk'	=> { 'x' => 'malayan hawk owl' },
 'punggung'	=> { 'x' => 'buttocks',
		     '#' => '; back; hips' },
 'pungut'	=> { 'x' => 'pick',
		     '#' => '; to collect; to harvest',
		     't' => 'v' },
 'pungutan'	=> { 'x' => 'collection' },
 'puntal'	=> { 'x' => 'coiled',
		     '#' => 'wound up' },
 'puntung'	=> { 'x' => 'butt (e.g. of cigarette)',
		     '#' => 'stump' },
 'punya'	=> { 'x' => 'have',
		     '#' => '; to possess; to own',
		     't' => 'v' },
# 'pupu'		=> { 'x' => 'degree of kinship' },
 'pupuk'	=> { 'x' => 'manure',
		     '#' => '; to nurture',
		     't' => 'v' },
 'pupus'	=> { 'x' => 'extinct' },
 'pura-pura'	=> { 'x' => 'pretending' },
 'purata'	=> { 'x' => 'average' },
 'purba'	=> { 'x' => 'ancient' },
# 'purbakala'	=> { 'x' => 'ancient times' },
 'purdah'	=> { 'x' => 'veil' },
 'puri'		=> { 'x' => 'castle',
		     '#' => '; palace; city' },
# 'purnama'	=> { 'x' => 'full moon' },
 'pusaka'	=> { 'x' => 'heirloom',
		     '#' => '; heritage' },
 'pusar'	=> { 'x' => 'revolve',
		     't' => 'v' },
 'pusaran'	=> { 'x' => 'rotation' },
 'pusara'	=> { 'x' => 'cemetary',
		     '#' => '; graveyard' },
 'pusat'	=> { 'x' => 'centre',
		     '#' => '; navel' },
 'pusing'	=> { 'x' => 'rotate',
		     '#' => '; to revolve',
		     't' => 'v' },
 'pusingan'	=> { 'x' => 'rotation',
		     '#' => 'a round' },
 'puspa'	=> { 'x' => 'flower' },
 'pustaka'	=> { 'x' => 'book' },
 'pustakawan'	=> { 'x' => 'librarian' },
 'putar'	=> { 'x' => 'rotate',
		     't' => 'v' },
 'putaran'	=> { 'x' => 'rotation' },
 'putera'	=> { 'x' => 'prince' },
 'puteri'	=> { 'x' => 'princess' },
 'putih'	=> { 'x' => 'white',
		     '#' => '; fair' },
 'putih kuning'	=> { 'x' => 'cream-coloured' },
 'putik'	=> { 'x' => 'newly-formed fruit',
		     '#' => 'pistil' },
 'puting'	=> { 'x' => 'nipple',
		     '#' => '; teat' },
 'puting beliung'	=> { 'x' => 'whirlwind',
		     '#' => 'tornado' },
 'putus'	=> { 'x' => 'finish',
		     '#' => 'to break off',
		     't' => 'v' },
 'puyu'		=> { 'x' => 'whirlwind' },
 'puyuh'	=> { 'x' => 'quail' },
# 'qada'		=> { 'x' => 'an action performed as a replacement' },
# 'qari'		=> { 'x' => 'a male koran reader' },
# 'qariah'	=> { 'x' => 'a female koran reader' },
# 'quran'	=> { 'x' => 'koran (sacred book of muslims)' },
 'raba'		=> { 'x' => 'grope',
		     '#' => '; to touch; to fondle',
		     't' => 'v' },
 'rabak'	=> { 'x' => 'large tear',
		     '#' => 'ragged; tattered' },
 'rabik'	=> { 'x' => 'torn',
		     '#' => '; tattered; ripped' },
# 'rabit'	=> { 'x' => 'torn at the edge' },
 'rabuk'	=> { 'x' => 'tinder' },
# 'rabun'	=> { 'x' => 'poor eyesight' },
 'rabun dekat'	=> { 'x' => 'long-sightedness' },
 'rabun jauh'	=> { 'x' => 'short-sightedness' },
# 'rabung'	=> { 'x' => 'ridge of a roof' },
# 'racik'	=> { 'x' => 'cut into thin slices' },
# 'racikan'	=> { 'x' => 'finely cut slices' },
 'racun'	=> { 'x' => 'poison' },
 'radak'	=> { 'x' => 'stab',
		     't' => 'v' },
# 'raden'	=> { 'x' => 'title of javanese nobility' },
# 'raga'		=> { 'x' => '(1) basket (2) a kind of rattan ball (3) to show off' },
 'ragam'	=> { 'x' => 'manner',
		     '#' => 'way (2) bad behaviour (3) melody; tune (4) united; faithful',
		     't' => 'n' },
 'ragi'		=> { 'x' => 'yeast' },
 'ragu-ragu'	=> { 'x' => 'doubtful',
		     '#' => 'dubious; suspicious' },
 'ragum'	=> { 'x' => 'pincer',
		     '#' => '; clamp' },
 'ragut'	=> { 'x' => 'grab',
		     '#' => '; to snatch',
		     't' => 'v' },
 'rahang'	=> { 'x' => 'jaw' },
# 'rahim'	=> { 'x' => '(1) womb (2) merciful (of god)' },
 'rahmat'	=> { 'x' => 'blessing',
		     '#' => 'mercy (bestowed by god)' },
 'rai'		=> { 'x' => 'entertain',
		     '#' => '; to celebrate',
		     't' => 'v' },
# 'raih'		=> { 'x' => 'to buy up for resale' },
 'raja'		=> { 'x' => 'king' },
# 'raja muda'	=> { 'x' => 'crown prince' },
 'raja sehari'	=> { 'x' => 'bridegroom' },
 'rajah'	=> { 'x' => 'diagram',
		     '#' => '; chart' },
# 'rajau'	=> { 'x' => 'unripe rice-stalks left at reaping' },
 'rajawali'	=> { 'x' => 'sparrow-hawk' },
 'rajin'	=> { 'x' => 'hardworking',
		     '#' => '; industrious; diligent' },
 'rajuk'	=> { 'x' => 'sulk',
		     '#' => '; to bicker',
		     't' => 'v' },
 'rakam'	=> { 'x' => 'record',
		     't' => 'v' },
 'rakaman'	=> { 'x' => 'recording',
		     't' => 'n' },
 'rakan'	=> { 'x' => 'friend',
		     '#' => '; companion; comrade' },
 'rakit'	=> { 'x' => 'raft' },
 'raksa'	=> { 'x' => 'mercury' },
 'raksasa'	=> { 'x' => 'giant',
		     '#' => 'demon' },
 'rakus'	=> { 'x' => 'greedy' },
 'rakyat'	=> { 'x' => 'people',
		     '#' => '; public; citizen' },
 'ralat'	=> { 'x' => 'mistake',
		     '#' => '; error' },
 'rama-rama'	=> { 'x' => 'butterfly' },
 'ramah'	=> { 'x' => 'friendly',
		     '#' => '; cordial; amiable' },
# 'ramai'	=> { 'x' => 'many (of people)' },
 'ramal'	=> { 'x' => 'predict',
		     '#' => '; to forecast',
		     't' => 'v' },
 'ramalan'	=> { 'x' => 'prediction' },
 'ramas'	=> { 'x' => 'knead',
		     't' => 'v' },
 'rambang'	=> { 'x' => 'random',
		     '#' => 'uncertain (of feelings, aim, etc.)' },
 'rambang mata'	=> { 'x' => 'flirtatious',
		     '#' => 'having a roving eye' },
 'rambu-rambu'	=> { 'x' => 'fringes',
		     '#' => 'tassels' },
 'rami'		=> { 'x' => 'jute',
		     '#' => '; hemp' },
 'rampai'	=> { 'x' => 'mixed',
		     '#' => '; various' },
 'rampas'	=> { 'x' => 'confiscate',
		     '#' => '; to seize; to capture; to hijack',
		     't' => 'v' },
 'ramping'	=> { 'x' => 'slim',
		     '#' => 'slender (of waist)' },
 'rampok'	=> { 'x' => 'burgle',
		     't' => 'v' },
# 'ramu'		=> { 'x' => 'to collect all sorts of material' },
 'ramuan'	=> { 'x' => 'ingredients' },
 'ranap'	=> { 'x' => 'flatten out',
		     '#' => 'to level to the ground',
		     't' => 'v' },
 'rancak'	=> { 'x' => 'lively' },
 'rancang'	=> { 'x' => 'plan',
		     '#' => '; to prepare',
		     't' => 'v' },
 'rancangan'	=> { 'x' => 'plan',
		     't' => 'n' },
 'randuk'	=> { 'x' => 'wade',
		     't' => 'v' },
 'rang'		=> { 'x' => 'draft',
		     '#' => 'a sketch (2) fallow (of land)',
		     't' => 'n' },
# 'rang undang-undang'	=> { 'x' => 'bill (in parliament)' },
 'rangka'	=> { 'x' => 'skeleton',
		     '#' => '; outline' },
 'rangkai'	=> { 'x' => 'bunch',
		     '#' => 'a bundle; a cluster (2) a unit of length',
		     't' => 'n' },
 'rangkak'	=> { 'x' => 'crawl',
		     't' => 'v' },
 'rangkap'	=> { 'x' => 'link lines of a verse',
		     '#' => 'two-fold' },
# 'rangking'	=> { 'x' => 'a type of large basket with lid' },
 'rangkul'	=> { 'x' => 'embrace',
		     't' => 'v' },
 'rangup'	=> { 'x' => 'brittle',
		     '#' => '; crisp' },
# 'ranjang'	=> { 'x' => 'iron bed-stead' },
 'ranjau'	=> { 'x' => 'mantrap',
		     '#' => 'booby-trap' },
 'rantai'	=> { 'x' => 'chain',
		     '#' => '; series; sequence' },
 'rantai leher'	=> { 'x' => 'necklace' },
 'rantai tangan'	=> { 'x' => 'bracelet' },
# 'rantaian'	=> { 'x' => 'connected series or sequence' },
 'rantau'	=> { 'x' => 'bay',
		     '#' => '; creek; region; colony' },
 'ranting'	=> { 'x' => 'twig' },
# 'ranum'	=> { 'x' => 'over-ripe (of fruit)' },
 'rapat'	=> { 'x' => 'close',
		     '#' => '; intimate; compact' },
 'rapi'		=> { 'x' => 'neat',
		     '#' => '; orderly' },
 'rapuh'	=> { 'x' => 'fragile',
		     '#' => '; brittle; friable' },
 'rasa'		=> { 'x' => 'feeling',
		     '#' => 'emotion (2) taste (3) opinion',
		     't' => 'n' },
 'rasi'		=> { 'x' => 'compatible',
		     '#' => '; suitable' },
 'rasmi'	=> { 'x' => 'official',
		     '#' => '; formal' },
 'rasuah'	=> { 'x' => 'bribe' },
 'rasuk'	=> { 'x' => 'possessed (by evil spirits)',
		     '#' => 'obsessed' },
 'rasul'	=> { 'x' => 'messenger of god',
		     '#' => 'prophet' },
 'rata'		=> { 'x' => 'flat',
		     '#' => '; level; even' },
 'ratap'	=> { 'x' => 'grieve',
		     '#' => '; to wail',
		     't' => 'v' },
 'ratapan'	=> { 'x' => 'grief' },
 'ratna'	=> { 'x' => 'jewel' },
 'ratu'		=> { 'x' => 'queen' },
# 'raung'	=> { 'x' => 'to wail or moan aloud' },
# 'raungan'	=> { 'x' => 'loud weeping or wailing' },
 'raup'		=> { 'x' => 'two handfuls',
		     '#' => 'to scoop up with both hands' },
 'raut'		=> { 'x' => 'pare',
		     't' => 'v' },
# 'rawak'	=> { 'x' => 'at random' },
# 'rawan'	=> { 'x' => '(1) anxious (2) numeral coefficient for articles made of cord' },
 'rawat'	=> { 'x' => 'nurse',
		     't' => 'v' },
 'rawatan'	=> { 'x' => 'treatment',
		     '#' => 'medical care' },
 'raya'		=> { 'x' => 'large',
		     '#' => '; main; principle; great' },
 'rayap'	=> { 'x' => 'creep',
		     '#' => '; to crawl',
		     't' => 'v' },
 'rayau'	=> { 'x' => 'roam',
		     '#' => '; to wander',
		     't' => 'v' },
 'rayu'		=> { 'x' => 'appeal',
		     '#' => '; to plead; to request',
		     't' => 'v' },
 'rayuan'	=> { 'x' => 'appeal',
		     '#' => '; a plea',
		     't' => 'n' },
 'rebah'	=> { 'x' => 'collapse',
		     't' => 'v' },
# 'rebak'	=> { 'x' => 'to spread (for fire, news, epidemic)' },
# 'reban'	=> { 'x' => 'a fowl\'s pen' },
 'rebas'	=> { 'x' => 'drizzle' },
# 'rebung'	=> { 'x' => 'bamboo shoot' },
 'rebus'	=> { 'x' => 'boiled' },
 'rebut'	=> { 'x' => 'snatch',
		     '#' => 'to seize; to grab; to scramble for something',
		     't' => 'v' },
 'recih'	=> { 'x' => 'remnants',
		     '#' => 'small change' },
 'recik'	=> { 'x' => 'sprinkle',
		     't' => 'v' },
 'reda'		=> { 'x' => 'subside',
		     '#' => '(2) willing (1) to decrease in intensity; consenting',
		     't' => 'v' },
# 'redah'	=> { 'x' => 'to take a direct way through (e.g. a forest, desert, flood, etc.)' },
 'redaksi'	=> { 'x' => 'editorial' },
 'redup'	=> { 'x' => 'obscured',
		     '#' => '; clouded; gloomy' },
 'regang'	=> { 'x' => 'taut',
		     '#' => '; tight; stretched' },
 'regu'		=> { 'x' => 'team',
		     '#' => '; gang; group; pair' },
 'rehat'	=> { 'x' => 'rest' },
 'reja'		=> { 'x' => 'scraps',
		     '#' => '; leftovers' },
# 'rejam'	=> { 'x' => 'to stone to death' },
 'reka'		=> { 'x' => 'invent',
		     '#' => '; to create; to design; to compose',
		     't' => 'v' },
# 'reka bentuk'	=> { 'x' => 'the design' },
 'rekaan'	=> { 'x' => 'invention' },
# 'rekah'	=> { 'x' => 'to split or crack' },
# 'rekahan'	=> { 'x' => 'a split, fissure or crack' },
# 'rekat'	=> { 'x' => 'to glue together' },
 'rela'		=> { 'x' => 'willing' },
 'relau'	=> { 'x' => 'furnace' },
 'remah'	=> { 'x' => 'crumb' },
 'remaja'	=> { 'x' => 'adolescent' },
# 'remang'	=> { 'x' => 'fine body hair' },
# 'rembat'	=> { 'x' => '(1) whip (2) trap' },
 'rembes'	=> { 'x' => 'secrete',
		     '#' => '; ooze' },
 'rembesan'	=> { 'x' => 'secretion' },
 'remeh-temeh'	=> { 'x' => 'unimportant',
		     '#' => 'trivial; petty' },
 'rempah'	=> { 'x' => 'spices' },
# 'rempak'	=> { 'x' => '(1) chipped (2) united' },
 'rempang-lempung'	=> { 'x' => 'injured',
		     '#' => 'tattered' },
 'rempuh'	=> { 'x' => 'stampede',
		     '#' => 'to storm at',
		     't' => 'v' },
 'rempuhan'	=> { 'x' => 'stampede',
		     't' => 'n' },
 'remuk'	=> { 'x' => 'smash',
		     '#' => '; to shatter',
		     't' => 'v' },
 'remuk hati'	=> { 'x' => 'broken-hearted' },
 'remuk-redam'	=> { 'x' => 'smashed',
		     '#' => 'crushed' },
 'renang'	=> { 'x' => 'swim',
		     't' => 'v' },
 'rencah'	=> { 'x' => 'seasoning',
		     '#' => '; condiment; flavouring' },
 'rencana'	=> { 'x' => 'article',
		     '#' => '; feature; story' },
 'rencat'	=> { 'x' => 'stunted',
		     '#' => '; retarded' },
 'renda'	=> { 'x' => 'lace' },
 'rendah'	=> { 'x' => 'low' },
 'rendam'	=> { 'x' => 'soak',
		     't' => 'v' },
# 'rendang'	=> { 'x' => 'food fried in coconut oil' },
# 'renek'	=> { 'x' => 'small and short' },
# 'renggang'	=> { 'x' => 'far apart' },
 'rengus'	=> { 'x' => 'grumpy',
		     '#' => '; sullen' },
 'renjis'	=> { 'x' => 'sprinkle',
		     '#' => '; scatter' },
 'rentak'	=> { 'x' => 'rhythm',
		     '#' => 'beat ' },
 'rentang'	=> { 'x' => 'stretch tight',
		     '#' => 'to spread along',
		     't' => 'v' },
 'rentap'	=> { 'x' => 'snatch',
		     '#' => 'to pull violently',
		     't' => 'v' },
# 'rentas'	=> { 'x' => 'to take a short cut' },
 'rentetan'	=> { 'x' => 'sequence',
		     '#' => '; series' },
 'renung'	=> { 'x' => 'stare',
		     '#' => '; to gaze; to ponder',
		     't' => 'v' },
 'renungan'	=> { 'x' => 'the act of staring or gazing',
		     '#' => 'contemplation' },
 'renyai'	=> { 'x' => 'drizzle' },
 'renyuk'	=> { 'x' => 'crumple',
		     't' => 'v' },
 'renyuk-renyik'	=> { 'x' => 'crumpled' },
# 'repek'	=> { 'x' => 'to talk nonsense' },
 'reput'	=> { 'x' => 'rotten',
		     '#' => '; decayed' },
 'resah'	=> { 'x' => 'fidgety',
		     '#' => '; restless; uneasy' },
 'resam'	=> { 'x' => 'custom',
		     '#' => '; tradition' },
# 'resap'	=> { 'x' => 'penetrate into',
#		     '#' => 'to seep into; to diffuse into' },
 'restu'	=> { 'x' => 'blessing' },
 'retak'	=> { 'x' => 'crack',
		     't' => 'v' },
 'retakan'	=> { 'x' => 'crack',
		     't' => 'n' },
# 'retas'	=> { 'x' => 'to rip open' },
 'rezeki'	=> { 'x' => 'livelihood',
		     '#' => '; luck' },
 'ria'		=> { 'x' => 'jovial',
		     '#' => '; joyful; cheerful' },
 'riadah'	=> { 'x' => 'exercise',
		     '#' => '; recreation' },
 'riak'		=> { 'x' => 'vain',
		     '#' => 'proud; (1) ripple on the water',
		     't' => 'a' },
 'riang'	=> { 'x' => 'happy',
		     '#' => '; cheerful; merry',
		     't' => 'a' },
# 'riba'		=> { 'x' => '(1) hold on one\'s lap (2) interest on money lent' },
 'ribut'	=> { 'x' => 'violent',
		     '#' => '; storm' },
# 'ridip'	=> { 'x' => 'dorsal fin of a fish' },
# 'rimas'	=> { 'x' => 'uneasy (because of heat, etc.)' },
 'rimba'	=> { 'x' => 'forest',
		     '#' => '; jungle',
		     't' => 'n' },
 'rimbun'	=> { 'x' => 'dense',
		     '#' => 'thick (of hair, foliage, etc.)',
		     't' => 'a' },
# 'rinci'	=> { 'x' => 'specify in details' },
 'rindu'	=> { 'x' => 'long for',
		     '#' => 'to yearn for',
		     't' => 'v' },
# 'rindu dendam'	=> { 'x' => 'passionate longing' },
# 'ringan'	=> { 'x' => 'light (in weight)' },
 'ringan mulut'	=> { 'x' => 'friendly' },
# 'ringan tangan'	=> { 'x' => 'helpful person' },
 'ringan tulang'	=> { 'x' => 'hardworking' },
# 'ringgit malaysia'	=> { 'x' => 'malaysian currency' },
 'ringkas'	=> { 'x' => 'brief',
		     '#' => '; concise' },
 'ringkasan'	=> { 'x' => 'summary' },
 'ringkasnya'	=> { 'x' => 'briefly',
		     '#' => 'in short' },
 'ringkuk'	=> { 'x' => 'crouch',
		     '#' => 'to bend or stoop',
		     't' => 'v' },
# 'rintang'	=> { 'x' => 'to block with a barricade' },
 'rintangan'	=> { 'x' => 'barricade',
		     '#' => '; obstacle' },
 'rintih'	=> { 'x' => 'moan',
		     '#' => 'to groan (in pain)',
		     't' => 'v' },
 'rintihan'	=> { 'x' => 'groan',
		     '#' => 'or moan',
		     't' => 'n' },
 'rintik'	=> { 'x' => 'speckle',
		     '#' => '; spot' },
 'rintik-rintik'	=> { 'x' => 'drizzle' },
 'rintis'	=> { 'x' => 'pioneer',
		     '#' => 'to clear a way; to open up',
		     't' => 'v' },
 'risalah'	=> { 'x' => 'pamphlet' },
 'risau'	=> { 'x' => 'worried' },
# 'risik'	=> { 'x' => 'to make discreet inquiries' },
 'riuh'		=> { 'x' => 'noisy' },
 'riwayat'	=> { 'x' => 'story',
		     '#' => '; tale' },
 'riwayat hidup'	=> { 'x' => 'biography' },
# 'robek'	=> { 'x' => 'to tear or rip' },
 'roboh'	=> { 'x' => 'collapse',
		     't' => 'v' },
 'roda'		=> { 'x' => 'wheel' },
 'rodok'	=> { 'x' => 'stab',
		     't' => 'v' },
 'rogol'	=> { 'x' => 'rape',
		     't' => 'v' },
 'roh'		=> { 'x' => 'spirit',
		     '#' => '; soul' },
 'rohani'	=> { 'x' => 'spirituality' },
 'rohaniah'	=> { 'x' => 'spiritual' },
# 'rojak'	=> { 'x' => 'salad of mixed vegetables taken with sauce' },
 'rokok'	=> { 'x' => 'cigarette' },
# 'roma'		=> { 'x' => 'fine body hair' },
# 'roman'	=> { 'x' => 'a person\'s looks or appearance' },
 'rombak'	=> { 'x' => 'demolish',
		     '#' => '; to reshuffle',
		     't' => 'v' },
 'rombakan'	=> { 'x' => 'reshuffle',
		     't' => 'n' },
# 'rombong'	=> { 'x' => '(1) large basket made of palm leaves (2) to form a group' },
# 'rombongan'	=> { 'x' => 'a group (of travellers)' },
 'rompak'	=> { 'x' => 'rob',
		     't' => 'v' },
 'rompakan'	=> { 'x' => 'robbery' },
 'rompong'	=> { 'x' => 'damaged at the tip',
		     '#' => 'mutilated (of ear, nose, etc.)' },
 'ronda'	=> { 'x' => 'patrol',
		     't' => 'v' },
# 'rongak'	=> { 'x' => 'gap (in teeth, fence)' },
 'rongga'	=> { 'x' => 'cavity',
		     '#' => 'hollow space' },
# 'ronggeng'	=> { 'x' => 'a dance (for couples)' },
 'rongkong'	=> { 'x' => 'throat' },
 'ronta'	=> { 'x' => 'struggle',
		     '#' => '; to resist',
		     't' => 'v' },
 'rosak'	=> { 'x' => 'damaged',
		     '#' => '; spoilt' },
 'rosot'	=> { 'x' => 'decline',
		     '#' => '; deteriorate; diminish' },
 'rotan'	=> { 'x' => 'rattan',
		     '#' => '; cane' },
 'roti'		=> { 'x' => 'bread' },
 'ruam'		=> { 'x' => 'rash' },
# 'ruam panas'	=> { 'x' => 'prickly heat' },
 'ruam saraf'	=> { 'x' => 'shingles' },
 'ruang'	=> { 'x' => 'space',
		     '#' => '; a room',
		     't' => 'n' },
 'ruangan'	=> { 'x' => 'column' },
 'ruang makan'	=> { 'x' => 'dining-room' },
# 'ruang waktu'	=> { 'x' => 'time frame' },
 'ruap'		=> { 'x' => 'evaporate',
		     '#' => 'to boil over; to bubble or foam over',
		     't' => 'v' },
 'ruas'		=> { 'x' => 'the section between two joints',
		     '#' => 'internode' },
# 'rugi'		=> { 'x' => 'to suffer a loss' },
 'ruji'		=> { 'x' => 'staple food',
		     '#' => 'basic; main' },
 'rujuk'	=> { 'x' => 'refer',
		     't' => 'v' },
 'rujukan'	=> { 'x' => 'reference' },
 'rukun'	=> { 'x' => 'pillar',
		     '#' => 'basic principle' },
 'rumah'	=> { 'x' => 'house' },
 'rumah tangga'	=> { 'x' => 'household' },
 'rumbia'	=> { 'x' => 'sago-palm' },
 'rumi'		=> { 'x' => 'roman' },
 'rumit'	=> { 'x' => 'difficult' },
 'rumpai'	=> { 'x' => 'weed' },
# 'rumpair'	=> { 'x' => 'a kind of sea plant',
#		     '#' => 'alga' },
 'rumpun'	=> { 'x' => 'clump',
		     '#' => '; a cluster',
		     't' => 'n' },
 'rumput'	=> { 'x' => 'grass' },
 'rumus'	=> { 'x' => 'formula' },
 'runcing'	=> { 'x' => 'tapered',
		     '#' => '; pointed; sharp' },
 'runcit'	=> { 'x' => 'retail' },
 'runding'	=> { 'x' => 'discuss',
		     '#' => '; to negotiate',
		     't' => 'v' },
 'rundingan'	=> { 'x' => 'discussion',
		     '#' => '; negotiation' },
 'rungut'	=> { 'x' => 'grumble',
		     '#' => '; to complain',
		     't' => 'v' },
 'rungutan'	=> { 'x' => 'complaint',
		     't' => 'n' },
 'runsing'	=> { 'x' => 'worried' },
 'runtuh'	=> { 'x' => 'collapse',
		     't' => 'v' },
 'runtun'	=> { 'x' => 'drag',
		     '#' => 'to pull violently',
		     't' => 'v' },
 'runtunan'	=> { 'x' => 'series' },
 'rupa'		=> { 'x' => 'appearance',
		     '#' => '; form' },
 'rupa kata'	=> { 'x' => 'adverb' },
 'rupa nama'	=> { 'x' => 'adjective' },
 'rupanya'	=> { 'x' => 'apparently' },
 'rupawan'	=> { 'x' => 'beautiful' },
 'rusa'		=> { 'x' => 'deer' },
 'rusa senggerik'	=> { 'x' => 'unicorn' },
# 'rusuh'	=> { 'x' => 'to create trouble' },
 'rusuhan'	=> { 'x' => 'riot',
		     '#' => '; a rebellion',
		     't' => 'n' },
 'rusuk'	=> { 'x' => 'side',
		     '#' => 'flank; edge (2)rib',
		     't' => 'n' },
 'saat'		=> { 'x' => 'second (time)',
		     '#' => 'moment' },
 'sabar'	=> { 'x' => 'patient',
		     '#' => '; calm' },
 'sabda'	=> { 'x' => 'saying',
		     '#' => 'verbal expression' },
 'sabit'	=> { 'x' => 'sickle' },
 'sabun'	=> { 'x' => 'soap' },
# 'sabung'	=> { 'x' => 'to fight (of cocks)' },
 'sabungan'	=> { 'x' => 'cock-fighting' },
# 'sabung-menyabung'	=> { 'x' => 'flashing (of lighting)' },
 'sabut'	=> { 'x' => 'husk' },
 'sadai'	=> { 'x' => 'stranded',
		     '#' => 'beached (of boat)' },
# 'sadap'	=> { 'x' => 'to tap a palm tree for its juice' },
 'saderi'	=> { 'x' => 'celery' },
# 'sadur'	=> { 'x' => 'metallic plating or coating' },
# 'saga'		=> { 'x' => 'a type of red seed' },
 'sagat'	=> { 'x' => 'grate',
		     '#' => '; to scrape',
		     't' => 'v' },
 'sagu'		=> { 'x' => 'sago' },
 'sah'		=> { 'x' => 'authentic',
		     '#' => '; genuine; legal' },
 'sahabat'	=> { 'x' => 'friend' },
 'sahaja'	=> { 'x' => 'only',
		     '#' => '; merely; just' },
 'saham'	=> { 'x' => 'share',
		     't' => 'n' },
 'sahih'	=> { 'x' => 'true',
		     '#' => '; valid; sure; certain' },
 'sahsiah'	=> { 'x' => 'personality' },
# 'sahur'	=> { 'x' => 'pre-dawn meal in the muslim fasting month' },
# 'sahut'	=> { 'x' => 'to answer a call' },
 'sahutan'	=> { 'x' => 'answer',
		     '#' => '; a response',
		     't' => 'n' },
 'saing'	=> { 'x' => 'compete',
		     't' => 'v' },
 'saingan'	=> { 'x' => 'competitor' },
 'sajak'	=> { 'x' => 'poem' },
# 'saji'		=> { 'x' => 'to serve (food)' },
 'sajian'	=> { 'x' => 'dish',
		     't' => 'n' },
 'sakat'	=> { 'x' => 'tease',
		     '#' => 'to make fun of',
		     't' => 'v' },
 'saki-baki'	=> { 'x' => 'remainder',
		     '#' => 'balance' },
 'sakit'	=> { 'x' => 'ill',
		     '#' => '; pain; painful' },
 'sakit hati'	=> { 'x' => 'annoyed' },
 'saksama'	=> { 'x' => 'just',
		     '#' => '; impartial; fair' },
 'saksi'	=> { 'x' => 'witness' },
# 'sakti'	=> { 'x' => 'supernatural power' },
 'saku'		=> { 'x' => 'pocket' },
 'salah'	=> { 'x' => 'wrong (2)guilty',
		     '#' => 'at fault',
		     't' => 'a' },
 'salai'	=> { 'x' => 'roast',
		     '#' => 'to dry over a fire',
		     't' => 'v' },
 'salak'	=> { 'x' => 'bark',
		     't' => 'v' },
 'salam'	=> { 'x' => 'peace',
		     '#' => '; greetings' },
# 'salang'	=> { 'x' => 'a method of execution' },
# 'salangkan'	=> { 'x' => 'even if' },
 'salasilah'	=> { 'x' => 'genealogy',
		     '#' => '; pedigree' },
# 'salib'	=> { 'x' => 'cross for crucifixion' },
 'salih'	=> { 'x' => 'pious',
		     '#' => '; virtuous' },
# 'salin'	=> { 'x' => '(1)to change clothes (2)to give birth' },
 'salinan'	=> { 'x' => 'copy',
		     't' => 'n' },
 'saling'	=> { 'x' => 'mutual' },
# 'salir'	=> { 'x' => 'to flow off',
#		     '#' => 'to drain away' },
 'saliran'	=> { 'x' => 'drainage' },
 'salji'	=> { 'x' => 'snow' },
# 'salur'	=> { 'x' => 'to lead or channel into' },
 'saluran'	=> { 'x' => 'channel',
		     't' => 'n' },
# 'salur darah'	=> { 'x' => 'blood vessel' },
 'salur kencing'	=> { 'x' => 'urethra' },
# 'salur mani'	=> { 'x' => 'vas deferens' },
 'salur nadi'	=> { 'x' => 'artery' },
 'salut'	=> { 'x' => 'coat',
		     '#' => '; to enwrap',
		     't' => 'v' },
 'salut bunga'	=> { 'x' => 'calyx' },
 'sama'		=> { 'x' => 'same',
		     '#' => '; together' },
 'samak'	=> { 'x' => 'tannin' },
 'samar'	=> { 'x' => 'dim',
		     '#' => '; vague; obscure' },
# 'sambal'	=> { 'x' => 'spicy condiment' },
 'sambar'	=> { 'x' => 'snatch',
		     '#' => 'to swoop down and seize',
		     't' => 'v' },
 'sambil'	=> { 'x' => 'while',
		     '#' => '; simultaneously' },
 'sambilan'	=> { 'x' => 'part-time',
		     '#' => 'subsidiary' },
 'sambil lalu'	=> { 'x' => 'incidentally',
		     '#' => 'by the way' },
 'sambung'	=> { 'x' => 'continue',
		     '#' => 'to fasten or join together',
		     't' => 'v' },
 'sambungan'	=> { 'x' => 'continuation',
		     '#' => '; connection; extension' },
 'sambut'	=> { 'x' => 'welcome',
		     '#' => 'to receive; to celebrate or observe',
		     't' => 'v' },
 'sambutan'	=> { 'x' => 'reception',
		     '#' => '; welcome; response; celebration' },
# 'sami'		=> { 'x' => 'buddhist monk' },
 'sampah'	=> { 'x' => 'rubbish',
		     '#' => '; garbage; litter' },
# 'sampah sarap'	=> { 'x' => 'garbage of all sorts' },
# 'sampai hati'	=> { 'x' => 'to have the heart to do something' },
# 'sampan'	=> { 'x' => 'small boat' },
 'samping'	=> { 'x' => 'side',
		     '#' => '; flank' },
# 'sampingan'	=> { 'x' => 'a by product' },
 'sampuk'	=> { 'x' => 'interfere',
		     '#' => '; to interrupt; to intervene',
		     't' => 'v' },
 'sampul'	=> { 'x' => 'envelope',
		     '#' => '; wrapper; cover' },
 'samseng'	=> { 'x' => 'gangster',
		     '#' => '; hooligan' },
 'samudera'	=> { 'x' => 'ocean',
		     '#' => '; sea' },
 'samun'	=> { 'x' => 'rob',
		     't' => 'v' },
 'sana'		=> { 'x' => 'there' },
 'sanak saudara'	=> { 'x' => 'relatives' },
 'sandang'	=> { 'x' => 'shoulder-strap' },
 'sandar'	=> { 'x' => 'lean on',
		     '#' => 'to rely on; to depend on',
		     't' => 'v' },
# 'sandar-menyandar'	=> { 'x' => 'to depend on one another' },
 'sandaran'	=> { 'x' => 'prop',
		     '#' => '; support; maintenance' },
 'sanding'	=> { 'x' => 'near',
		     '#' => '; close; adjacent' },
 'sandiwara'	=> { 'x' => 'stageplay',
		     '#' => '; concert' },
# 'sang'		=> { 'x' => 'honorific epithet' },
 'sangga'	=> { 'x' => 'support',
		     't' => 'v' },
 'sanggah-menyanggah'	=> { 'x' => 'oppose',
		     '#' => 'to protest against',
			     't' => 'v' },
 'sanggama'	=> { 'x' => 'union',
		     '#' => '; confederation' },
 'sanggul'	=> { 'x' => 'coiffure',
		     '#' => 'knot of hair' },
 'sanggup'	=> { 'x' => 'willing',
		     '#' => '; ready; able; capable' },
 'sangka'	=> { 'x' => 'presume',
		     '#' => '; to expect; to guess',
		     't' => 'v' },
 'sangkaan'	=> { 'x' => 'presumption',
		     '#' => '; conjecture; guess; imagination; expectation' },
 'sangkak'	=> { 'x' => 'hinder',
		     '#' => '; to obstruct; to impede',
		     't' => 'v' },
# 'sangkal'	=> { 'x' => '(1)to deny (2)handle (of hammer)' },
 'sangkalan'	=> { 'x' => 'denial' },
 'sangkar'	=> { 'x' => 'cage' },
 'sangkut'	=> { 'x' => 'stuck',
		     '#' => '; attached' },
 'sangkut-paut'	=> { 'x' => 'involved',
		     '#' => 'implicated' },
 'sangsi'	=> { 'x' => 'doubt',
		     '#' => 'to be suspicious',
		     't' => 'v' },
 'sanjung'	=> { 'x' => 'praise',
		     '#' => '; to flatter; to adulate',
		     't' => 'v' },
 'sanjungan'	=> { 'x' => 'flattery',
		     '#' => '; adulation' },
 'santai'	=> { 'x' => 'relaxation' },
# 'santan'	=> { 'x' => 'coconut milk' },
 'santap'	=> { 'x' => 'dine',
		     '#' => 'to eat and drink (of royalty)',
		     't' => 'v' },
 'santapan'	=> { 'x' => 'food',
		     '#' => '; dishes; meal' },
 'santun'	=> { 'x' => 'well-mannered' },
 'sanubari'	=> { 'x' => 'heart',
		     '#' => '; emotions' },
 'sapa'		=> { 'x' => 'greet',
		     '#' => 'to speak to; to address',
		     't' => 'v' },
 'sapaan'	=> { 'x' => 'greeting',
		     '#' => '; salutation' },
# 'sapi'		=> { 'x' => 'cow or bull' },
 'sapu'		=> { 'x' => 'wipe',
		     '#' => 'to sweep; to rub gently',
		     't' => 'v' },
 'sapu tangan'	=> { 'x' => 'handkerchief' },
 'sara'		=> { 'x' => 'pension',
		     '#' => '; allowance' },
 'sara hidup'	=> { 'x' => 'livelihood' },
 'saraf'	=> { 'x' => 'nerve' },
 'saran'	=> { 'x' => 'suggest',
		     '#' => '; to propose',
		     't' => 'v' },
 'saranan'	=> { 'x' => 'suggestion',
		     '#' => '; proposal; propaganda' },
 'sarang'	=> { 'x' => 'nest',
		     '#' => '; web' },
# 'sarap'	=> { 'x' => 'to have breakfast' },
 'sarapan'	=> { 'x' => 'breakfast' },
# 'sarat'	=> { 'x' => 'heavily loaded' },
 'saribunga'	=> { 'x' => 'corolla',
		     '#' => '; petals' },
 'saring'	=> { 'x' => 'filter',
		     '#' => '; to refine; to sift; to sieve; to purify',
		     't' => 'v' },
 'saringan'	=> { 'x' => 'refinement',
		     '#' => 'preliminary rounds of contest' },
 'sarjana'	=> { 'x' => 'scholar' },
 'sarjana muda'	=> { 'x' => 'bachelor\'s degree' },
 'sarung'	=> { 'x' => 'sarong',
		     '#' => '; sheath; cover; wrapper' },
 'sasa'		=> { 'x' => 'strong',
		     '#' => '; sturdy' },
 'sasar'	=> { 'x' => 'eccentric',
		     '#' => '; odd; confused; crazy' },
 'sasaran'	=> { 'x' => 'target' },
 'sastera'	=> { 'x' => 'literature' },
# 'sasterawan'	=> { 'x' => 'male scholar' },
# 'sasterawati'	=> { 'x' => 'female scholar' },
 'sasul'	=> { 'x' => 'overshot',
		     '#' => 'gone too far' },
 'satah'	=> { 'x' => 'plane',
		     '#' => '; flat; level' },
 'satu'		=> { 'x' => 'one' },
# 'satu-satu'	=> { 'x' => 'one by one' },
# 'satu-satunya'	=> { 'x' => 'the only one' },
 'saudagar'	=> { 'x' => 'merchant',
		     '#' => '; trader' },
 'saudara'	=> { 'x' => 'brother or sister',
		     '#' => 'relative; comrade' },
# 'saudara-mara'	=> { 'x' => 'relatives in general' },
# 'saudari'	=> { 'x' => 'female relative or friend' },
 'sauh'		=> { 'x' => 'anchor' },
 'saujana'	=> { 'x' => 'spacious',
		     '#' => '; extensive' },
 'sauk'		=> { 'x' => 'scoop',
		     't' => 'n' },
 'sawah'	=> { 'x' => 'rice-field' },
 'sawan'	=> { 'x' => 'fits',
		     '#' => '; epilepsy' },
 'sawang'	=> { 'x' => 'cobweb' },
 'sawat'	=> { 'x' => 'belt' },
 'saya'		=> { 'x' => 'i',
		     '#' => '; my; me' },
 'sayang'	=> { 'x' => 'love',
		     '#' => '; affection' },
 'sayap'	=> { 'x' => 'wing' },
 'sayat'	=> { 'x' => 'slice',
		     't' => 'v' },
 'sayu'		=> { 'x' => 'sad',
		     '#' => '; melancholic' },
# 'sayup'	=> { 'x' => 'very faintly visible or audible' },
 'sayup-sayup'	=> { 'x' => 'vague',
		     '#' => 'indistinct' },
 'sayur'	=> { 'x' => 'vegetable' },
# 'sayur-sayuran'	=> { 'x' => 'variety of vegetables' },
# 'sayur-mayur'	=> { 'x' => 'variety of vegetables' },
 'se'		=> { 'x' => 'one',
		     '#' => '; same; a; an' },
 'sebab'	=> { 'x' => 'reason',
		     '#' => '; cause; because' },
 'sebab-musabab'	=> { 'x' => 'reason' },
 'sebak'	=> { 'x' => 'choked',
		     '#' => 'to shed tears' },
 'sebal'	=> { 'x' => 'resentful',
		     '#' => '; disillusioned; dissatisfied' },
 'sebar'	=> { 'x' => 'spread',
		     '#' => '; to distribute; to disseminate',
		     't' => 'v' },
 'sebaran'	=> { 'x' => 'seed' },
 'sebat'	=> { 'x' => 'whip',
		     '#' => '; to cane; to steal',
		     't' => 'v' },
 'sebatan'	=> { 'x' => 'whipping',
		     '#' => '; caning' },
# 'sebaya'	=> { 'x' => 'similar (of age, looks)' },
 'seberang'	=> { 'x' => 'opposite side (of river, road)',
		     '#' => 'across' },
 'sebu'		=> { 'x' => 'choked (of nose)',
		     '#' => 'full (of stomach)' },
 'sebut'	=> { 'x' => 'utter',
		     '#' => '; to mention; to say; to pronounce',
		     't' => 'v' },
 'sebutan'	=> { 'x' => 'expression',
		     '#' => '; utterance; pronunciation' },
 'sedak'	=> { 'x' => 'choke',
		     '#' => '; to hiccup',
		     't' => 'v' },
 'sedap'	=> { 'x' => 'pleasant (of taste, smell)',
		     '#' => 'nice (of voice); tasty; delicious' },
 'sedar'	=> { 'x' => 'conscious',
		     '#' => '; aware' },
 'sedekah'	=> { 'x' => 'alms' },
 'sederhana'	=> { 'x' => 'moderate',
		     '#' => '; average; medium; simple' },
 'sedia'	=> { 'x' => 'ready',
		     '#' => '; prepared; willing' },
 'sediakala'	=> { 'x' => 'immemorial',
		     '#' => 'old; of long past' },
 'sedih'	=> { 'x' => 'sad',
		     '#' => '; sorrowful' },
 'sedu'		=> { 'x' => 'sobbing' },
 'sedu-sedan'	=> { 'x' => 'sobbing' },
 'sedut'	=> { 'x' => 'inhale',
		     '#' => 'to suck up',
		     't' => 'v' },
 'sedutan'	=> { 'x' => 'inhalation',
		     '#' => '; suction' },
 'segak'	=> { 'x' => 'smart-looking',
		     '#' => 'chic; elegant; stylish' },
 'segan'	=> { 'x' => 'shy',
		     '#' => '; bashful' },
 'segan-silu'	=> { 'x' => 'bashful' },
 'segar'	=> { 'x' => 'fresh' },
 'segar-bugar'	=> { 'x' => 'fit',
		     '#' => 'like new' },
 'segera'	=> { 'x' => 'without delay',
		     '#' => 'urgent; quick' },
 'segi'		=> { 'x' => 'aspect',
		     '#' => '; angle; view; side; facet' },
 'segi empat'	=> { 'x' => 'square' },
 'segi tiga'	=> { 'x' => 'triangle' },
# 'segi tiga sama kaki'	=> { 'x' => 'isosceles triangle' },
# 'segi tiga sama sisi'	=> { 'x' => 'equilateral triangle' },
 'sejahtera'	=> { 'x' => 'peaceful' },
 'sejarah'	=> { 'x' => 'history' },
 'sejat'	=> { 'x' => 'evaporate',
		     't' => 'v' },
 'sejuk'	=> { 'x' => 'cool',
		     '#' => '; cold' },
 'sekam'	=> { 'x' => 'grain husk',
		     '#' => 'chaff' },
 'sekarang'	=> { 'x' => 'now' },
 'sekat'	=> { 'x' => 'block',
		     '#' => '; to obstruct',
		     't' => 'v' },
 'sekatan'	=> { 'x' => 'obstruction' },
 'sekerap'	=> { 'x' => 'scrap' },
 'sekoi'	=> { 'x' => 'millet' },
 'sekolah'	=> { 'x' => 'school' },
 'sekongkol'	=> { 'x' => 'conspiracy' },
 'seksa'	=> { 'x' => 'torture',
		     't' => 'v' },
 'seksaan'	=> { 'x' => 'suffering',
		     '#' => '; torture' },
 'sekutu'	=> { 'x' => 'partner',
		     '#' => '; ally' },
 'sela'		=> { 'x' => 'interval',
		     '#' => '; gap; opening' },
# 'seladang'	=> { 'x' => 'wild ox' },
# 'selak'	=> { 'x' => '(1)a bolt (2)to pull out a garment' },
 'selam'	=> { 'x' => 'dive',
		     't' => 'v' },
 'selamat'	=> { 'x' => 'safe' },
 'selamat datang'	=> { 'x' => 'welcome' },
 'selamat jalan'	=> { 'x' => 'goodbye',
		     '#' => 'farewell' },
 'selamat malam'	=> { 'x' => 'goodnight' },
# 'selamat pagi'	=> { 'x' => 'good morning' },
 'selamba'	=> { 'x' => 'poker-faced',
		     '#' => 'shameless' },
 'selang'	=> { 'x' => 'interval',
		     '#' => '; pause' },
 'selaput'	=> { 'x' => 'membrane' },
 'selaput mata'	=> { 'x' => 'cataract' },
# 'selar'	=> { 'x' => 'branding iron' },
# 'selasih'	=> { 'x' => 'a type of plant' },
 'selat'	=> { 'x' => 'straits' },
 'selatan'	=> { 'x' => 'south' },
# 'selawat'	=> { 'x' => 'prayer for peace and prosperity' },
 'selekeh'	=> { 'x' => 'stain',
		     '#' => '; smudge' },
 'selekoh'	=> { 'x' => 'curve',
		     '#' => '; bend; twist' },
 'selempang'	=> { 'x' => 'sash' },
 'selendang'	=> { 'x' => 'shawl' },
 'selenggara'	=> { 'x' => 'maintain',
		     '#' => 'to look after; to keep in good condition',
		     't' => 'v' },
 'selera'	=> { 'x' => 'appetite',
		     '#' => '; zest' },
 'selerak'	=> { 'x' => 'scattered' },
 'selesa'	=> { 'x' => 'comfortable',
		     '#' => '; leisure' },
 'selesai'	=> { 'x' => 'finished',
		     '#' => '; settled; completed' },
 'seleweng'	=> { 'x' => 'divert',
		     '#' => '; to deviate',
		     't' => 'v' },
 'selia'	=> { 'x' => 'inspect',
		     't' => 'v' },
 'selidik'	=> { 'x' => 'investigate',
		     '#' => 'to study; to do research',
		     't' => 'v' },
 'selimut'	=> { 'x' => 'blanket' },
# 'selinap'	=> { 'x' => 'to sneak away' },
 'selindung'	=> { 'x' => 'hide',
		     '#' => 'to conceal; to take cover',
		     't' => 'v' },
 'seling'	=> { 'x' => 'alternate' },
 'selingan'	=> { 'x' => 'interlude' },
 'selirat'	=> { 'x' => 'confused' },
 'selisih'	=> { 'x' => 'difference',
		     '#' => '; dispute; disagreement' },
 'selit'	=> { 'x' => 'insert',
		     't' => 'v' },
 'seliuh'	=> { 'x' => 'sprained' },
 'selok'	=> { 'x' => 'intricacy' },
 'selok-belok'	=> { 'x' => 'intricacy' },
 'selongkar'	=> { 'x' => 'ransack',
		     '#' => '; to rummage',
		     't' => 'v' },
 'seloroh'	=> { 'x' => 'comical',
		     '#' => '; joking; humorous' },
# 'selsema'	=> { 'x' => 'a cold (medical)' },
 'seluar'	=> { 'x' => 'trousers',
		     '#' => '; pants' },
 'seluar dalam'	=> { 'x' => 'underpants' },
 'selubung'	=> { 'x' => 'cover',
		     '#' => '; veil' },
 'seludup'	=> { 'x' => 'smuggle',
		     't' => 'v' },
# 'seluk'	=> { 'x' => 'to put the hand in the pocket' },
# 'selumbar'	=> { 'x' => 'wooden splinter' },
 'seluruh'	=> { 'x' => 'entire',
		     '#' => '; whole' },
 'selusup'	=> { 'x' => 'penetrate',
		     '#' => '; to infiltrate',
		     't' => 'v' },
 'selut'	=> { 'x' => 'mud' },
# 'semadi'	=> { 'x' => '(1)concentration (2)to bury' },
 'semai'	=> { 'x' => 'sow',
		     '#' => 'to plant seedlings',
		     't' => 'v' },
 'semaian'	=> { 'x' => 'nursery',
		     '#' => '; seedlings' },
 'semak'	=> { 'x' => 'bush',
		     '#' => 'undergrowth (2)to check (3)to revise',
		     't' => 'v' },
# 'semak-samun'	=> { 'x' => 'undergrowth of all kinds' },
 'semangat'	=> { 'x' => 'spirit',
		     '#' => '; zest; enthusiasm; soul; vigour' },
 'semangka'	=> { 'x' => 'watermelon' },
 'semarak'	=> { 'x' => 'splendour',
		     '#' => '; excellence' },
 'semat'	=> { 'x' => 'pin',
		     't' => 'n' },
 'sembah'	=> { 'x' => 'worship',
		     '#' => '; to idolize',
		     't' => 'v' },
# 'sembah salam'	=> { 'x' => 'good wishes' },
 'sembahyang'	=> { 'x' => 'worship',
		     '#' => '; to pray',
		     't' => 'v' },
# 'sembam'	=> { 'x' => 'to fall in a prone position or on one\'s face' },
 'sembang'	=> { 'x' => 'chatter' },
 'sembap'	=> { 'x' => 'swell',
		     't' => 'v' },
 'sembarang'	=> { 'x' => 'arbitrary' },
# 'sembarangan'	=> { 'x' => 'at random' },
 'sembelih'	=> { 'x' => 'slaughter',
		     't' => 'v' },
 'sembelihan'	=> { 'x' => 'slaughter',
		     '#' => '; bloodshed' },
 'sembelit'	=> { 'x' => 'constipation',
		     '#' => '; constipated' },
 'semboyan'	=> { 'x' => 'signal',
		     '#' => '; alarm' },
# 'sembuh'	=> { 'x' => 'to recover from ill-health' },
 'sembul'	=> { 'x' => 'protrude',
		     't' => 'v' },
 'sembunyi'	=> { 'x' => 'hide',
		     '#' => '; to conceal',
		     't' => 'v' },
 'sembur'	=> { 'x' => 'spout',
		     '#' => '; to spray; to sprinkle',
		     't' => 'v' },
 'semenanjung'	=> { 'x' => 'peninsula' },
 'semenjak'	=> { 'x' => 'since' },
# 'semenjak itu'	=> { 'x' => 'ever since' },
 'sementara'	=> { 'x' => 'temporary',
		     '#' => '; while' },
 'sementara itu'	=> { 'x' => 'meanwhile' },
 'semerbak'	=> { 'x' => 'fragrant' },
# 'semesta alam'	=> { 'x' => 'the whole universe' },
 'sempadan'	=> { 'x' => 'boundary' },
 'sempang'	=> { 'x' => 'hyphen' },
 'sempat'	=> { 'x' => 'having the time',
		     '#' => 'early' },
 'sempit'	=> { 'x' => 'narrow' },
 'sempurna'	=> { 'x' => 'complete',
		     '#' => '; perfect' },
 'semut'	=> { 'x' => 'ant' },
 'sen'		=> { 'x' => 'cent' },
 'senak'	=> { 'x' => 'tight',
		     '#' => 'feeling stuffed' },
 'senak perut'	=> { 'x' => 'indigestion',
		     '#' => 'feeling of fullness in abdomen' },
# 'senam'	=> { 'x' => 'to do physical exercise' },
# 'senaman'	=> { 'x' => 'physical exercise' },
 'senang'	=> { 'x' => 'easy',
		     '#' => 'comfortable; free (from care)' },
 'senapang'	=> { 'x' => 'gun' },
 'senarai'	=> { 'x' => 'list' },
 'senda'	=> { 'x' => 'joke' },
 'sendat'	=> { 'x' => 'tight',
		     '#' => 'close-fitting' },
 'sendawa'	=> { 'x' => 'belch',
		     '#' => '; to burp',
		     't' => 'v' },
 'sendeng'	=> { 'x' => 'slanting',
		     '#' => '; sloping; leaning; askew' },
 'sendi'	=> { 'x' => 'joint' },
 'senduk'	=> { 'x' => 'ladle' },
 'sengaja'	=> { 'x' => 'purposely',
		     '#' => '; intentionally' },
 'sengal'	=> { 'x' => 'pain in the joints',
		     '#' => 'rheumatism' },
 'sengat'	=> { 'x' => 'sting',
		     't' => 'n' },
# 'sengau'	=> { 'x' => 'nasal (of voice)' },
 'senget'	=> { 'x' => 'slanting',
		     '#' => '; inclining' },
 'senggugut'	=> { 'x' => 'dysmenorrhoea' },
 'sengguk'	=> { 'x' => 'nod',
		     't' => 'v' },
 'sengih'	=> { 'x' => 'grin',
		     't' => 'v' },
 'sengihan'	=> { 'x' => 'grin',
		     't' => 'n' },
 'sengit'	=> { 'x' => 'violent' },
 'sengkang'	=> { 'x' => 'dash',
		     't' => 'n' },
 'sengketa'	=> { 'x' => 'dispute',
		     't' => 'n' },
 'sengsara'	=> { 'x' => 'suffering',
		     '#' => '; agony' },
 'seni'		=> { 'x' => 'art',
		     '#' => 'skill (2)fine',
		     't' => 'n' },
# 'seni bahasa'	=> { 'x' => 'fine language' },
 'seni bina'	=> { 'x' => 'architecture' },
# 'seni lukis'	=> { 'x' => 'art of painting or drawing' },
 'seni ukir'	=> { 'x' => 'sculpture' },
# 'seniman'	=> { 'x' => 'male actor' },
 'seniwati'	=> { 'x' => 'actress' },
 'senja'	=> { 'x' => 'dusk',
		     '#' => '; twilight' },
 'senjakala'	=> { 'x' => 'evening' },
 'senjata'	=> { 'x' => 'weapon',
		     '#' => '; arms' },
 'senjata api'	=> { 'x' => 'firearms' },
 'senjata berat'	=> { 'x' => 'artillery' },
 'senonoh'	=> { 'x' => 'proper',
		     '#' => 'decent; well-behaved' },
 'sentak'	=> { 'x' => 'jerk',
		     '#' => 'to pull suddenly',
		     't' => 'v' },
 'sental'	=> { 'x' => 'rub',
		     '#' => '; to scrub; to erase',
		     't' => 'v' },
 'sentap'	=> { 'x' => 'tug',
		     '#' => 'to pull sharply',
		     't' => 'v' },
# 'senteng'	=> { 'x' => 'short or scanty (of clothes)' },
 'sentosa'	=> { 'x' => 'peaceful',
		     '#' => '; tranquil' },
 'sentuh'	=> { 'x' => 'touch',
		     't' => 'v' },
 'sentuhan'	=> { 'x' => 'contact' },
 'senyap'	=> { 'x' => 'quiet',
		     '#' => '; silent' },
# 'senyap-senyap'	=> { 'x' => 'quietly; without anybody\'s knowledge' },
 'senyum'	=> { 'x' => 'smile',
		     't' => 'v' },
 'senyuman'	=> { 'x' => 'smile',
		     't' => 'n' },
# 'sepah'	=> { 'x' => '(1)to chew (of betel leaf) (2)scattered' },
 'sepak'	=> { 'x' => 'slap',
		     '#' => '(2)to kick',
		     't' => 'v' },
 'sepanduk'	=> { 'x' => 'banner',
		     '#' => '; placard' },
# 'separa'	=> { 'x' => 'a section only' },
 'separuh'	=> { 'x' => 'half',
		     '#' => '; semi' },
 'sepatu'	=> { 'x' => 'shoe' },
 'sepatu besi'	=> { 'x' => 'horse-shoe' },
 'seperti'	=> { 'x' => 'like',
		     '#' => 'such as' },
 'sepi'		=> { 'x' => 'quiet',
		     '#' => '; desolate; deserted' },
 'sepit'	=> { 'x' => 'tweezers',
		     '#' => '; pincers; chopsticks' },
 'sepoi-sepoi'	=> { 'x' => 'gentle',
		     '#' => 'mild' },
# 'sepoi-sepoi bahasa'	=> { 'x' => 'soft breeze' },
 'sepuh'	=> { 'x' => 'gilt' },
 'serabut'	=> { 'x' => 'fibre' },
 'serah'	=> { 'x' => 'surrender',
		     't' => 'v' },
# 'serahan'	=> { 'x' => 'something that is submitted' },
 'serai'	=> { 'x' => 'lemon-grass' },
# 'serak'	=> { 'x' => 'hoarse (of voice)' },
 'seram'	=> { 'x' => 'terrifying',
		     '#' => '; frightful' },
 'serambi'	=> { 'x' => 'verandah',
		     '#' => '; porch' },
 'serampang'	=> { 'x' => 'harpoon',
		     't' => 'n' },
 'serang'	=> { 'x' => 'boatswain' },
 'serangan'	=> { 'x' => 'attack',
		     '#' => '; an assault',
		     't' => 'n' },
 'serangga'	=> { 'x' => 'insect' },
 'serani'	=> { 'x' => 'eurasian' },
 'serap'	=> { 'x' => 'absorb',
		     't' => 'v' },
 'serapan'	=> { 'x' => 'absorption' },
 'serapah'	=> { 'x' => 'curse',
		     't' => 'n' },
 'serban'	=> { 'x' => 'turban' },
 'serbu'	=> { 'x' => 'invade',
		     '#' => '; to attack',
		     't' => 'v' },
 'serbuan'	=> { 'x' => 'raid',
		     '#' => '; an attack',
		     't' => 'n' },
 'serbuk'	=> { 'x' => 'powder' },
# 'serempak'	=> { 'x' => 'coming suddenly and unexpectedly' },
 'serentak'	=> { 'x' => 'simultaneously' },
 'seret'	=> { 'x' => 'drag',
		     't' => 'v' },
 'sergah'	=> { 'x' => 'startling' },
 'sergahan'	=> { 'x' => 'snarl',
		     '#' => 'act of startling',
		     't' => 'n' },
 'sergam'	=> { 'x' => 'conspicuous' },
 'seri'		=> { 'x' => 'splendour',
		     '#' => 'brightness (2)royal honorific (3)a draw or tie (of a game)',
		     't' => 'n' },
 'serigala'	=> { 'x' => 'wolf',
		     '#' => '; jackal',
		     't' => 'n' },
 'serik'	=> { 'x' => 'discourage',
		     't' => 'v' },
 'seringai'	=> { 'x' => 'grin',
		     't' => 'n' },
# 'serkap'	=> { 'x' => 'conical fish-trap' },
# 'serkup'	=> { 'x' => 'conical coop' },
 'serlah'	=> { 'x' => 'gleaming white against dark background',
		     '#' => 'exposed' },
 'serong'	=> { 'x' => 'askew',
		     '#' => '; crooked; unfaithful; insincere' },
 'seronok'	=> { 'x' => 'enjoyable',
		     '#' => '; pleasant' },
 'serpih'	=> { 'x' => 'chip',
		     '#' => '; a fragment; a splinter',
		     't' => 'n' },
 'serpihan'	=> { 'x' => 'chip',
		     '#' => '; a fragment; a splinter',
		     't' => 'n' },
 'serta-merta'	=> { 'x' => 'immediately' },
 'seru'		=> { 'x' => 'exclaim',
		     '#' => 'to cry aloud; to call',
		     't' => 'v' },
 'seruling'	=> { 'x' => 'flute' },
# 'sesah'	=> { 'x' => 'beat with a cane' },
 'sesak'	=> { 'x' => 'congested',
		     '#' => '; tight; crowded; packed' },
 'sesal'	=> { 'x' => 'regretful',
		     '#' => '; repentant' },
 'sesalan'	=> { 'x' => 'repentance' },
 'sesat'	=> { 'x' => 'lost',
		     '#' => 'gone astray' },
 'sesuai'	=> { 'x' => 'suitable',
		     '#' => '; appropriate' },
 'sesungut'	=> { 'x' => 'feeler',
		     '#' => '; antenna' },
# 'seterika'	=> { 'x' => 'iron (for clothes)' },
 'seteru'	=> { 'x' => 'enemy',
		     '#' => '; foe' },
 'setia'	=> { 'x' => 'loyal',
		     '#' => '; faithful' },
 'setiausaha'	=> { 'x' => 'secretary' },
 'setinggan'	=> { 'x' => 'squatter' },
 'sewa'		=> { 'x' => 'rent',
		     '#' => '; lease' },
 'sewaan'	=> { 'x' => 'rental' },
# 'sewa beli'	=> { 'x' => 'hire purchase' },
 'sfera'	=> { 'x' => 'sphere' },
 'sia-sia'	=> { 'x' => 'useless',
		     '#' => 'futile; in vain' },
# 'siak'		=> { 'x' => 'mosque caretaker' },
 'sial'		=> { 'x' => 'unlucky',
		     '#' => '; unfortunate' },
 'siamang'	=> { 'x' => 'gibbon',
		     't' => 'n' },
# 'siang'	=> { 'x' => '(1)daytime (2)to cut up and clean (meat or fish)' },
 'siang hari'	=> { 'x' => 'daytime' },
 'siang-siang'	=> { 'x' => 'early' },
 'siap'		=> { 'x' => 'ready',
		     '#' => '; prepared; finished; completed' },
 'siap sedia'	=> { 'x' => 'ready',
		     '#' => 'well-prepared' },
 'siapa'	=> { 'x' => 'who',
		     '#' => '; whose' },
 'siar'		=> { 'x' => 'stroll',
		     't' => 'v' },
 'siaran'	=> { 'x' => 'broadcast',
		     't' => 'n' },
 'siasat'	=> { 'x' => 'investigate',
		     't' => 'v' },
 'siasatan'	=> { 'x' => 'investigative',
		     '#' => '; investigation' },
 'siat'		=> { 'x' => 'shred',
		     '#' => 'to tear into small pieces',
		     't' => 'v' },
 'sibuk'	=> { 'x' => 'busy' },
 'sibur-sibur'	=> { 'x' => 'dragon-fly' },
# 'sidai'	=> { 'x' => 'to hang out (clothes)' },
 'sidang'	=> { 'x' => 'council',
		     '#' => '; board; meeting' },
 'sifar'	=> { 'x' => 'zero' },
 'sifat'	=> { 'x' => 'characteristic',
		     '#' => '; feature; quality' },
# 'sifir'	=> { 'x' => 'an arithmetical table' },
 'sihat'	=> { 'x' => 'healthy' },
 'sihir'	=> { 'x' => 'magic',
		     '#' => '; sorcery' },
 'sijil'	=> { 'x' => 'certificate' },
 'sikap'	=> { 'x' => 'demeanour',
		     '#' => '; attitude' },
# 'sikat'	=> { 'x' => '(1)a comb (2)a bunch (of bananas)' },
 'siku'		=> { 'x' => 'elbow' },
# 'siku-siku'	=> { 'x' => 'a set-square' },
# 'sila'		=> { 'x' => '(1)please (2)to sit cross-legged' },
# 'silam'	=> { 'x' => 'the past' },
 'silang'	=> { 'x' => 'cross',
		     't' => 'n' },
 'silap'	=> { 'x' => 'wrong',
		     '#' => '; mistaken' },
 'silau'	=> { 'x' => 'glitter',
		     '#' => '; dazzle' },
 'silih'	=> { 'x' => 'alternate' },
 'silu'		=> { 'x' => 'shy',
		     '#' => '; bashful; timid' },
 'simbah'	=> { 'x' => 'soaked',
		     '#' => '; wet' },
 'simpan'	=> { 'x' => 'keep',
		     '#' => 'to store; to save (money)',
		     't' => 'v' },
 'simpanan'	=> { 'x' => 'savings' },
 'simpang'	=> { 'x' => 'junction' },
 'simpangan'	=> { 'x' => 'cross-roads' },
 'simpang-siur'	=> { 'x' => 'criss-crossing' },
 'simpul'	=> { 'x' => 'knot',
		     't' => 'n' },
 'simpulan'	=> { 'x' => 'knot',
		     '#' => '; a bond',
		     't' => 'n' },
# 'simpulan bahasa'	=> { 'x' => 'an idiom' },
 'sinar'	=> { 'x' => 'ray',
		     '#' => 'a beam (of light)',
		     't' => 'n' },
 'sinaran'	=> { 'x' => 'ray',
		     '#' => 'a glow; a gleam; a glitter; illumination',
		     't' => 'n' },
 'sindir'	=> { 'x' => 'hint',
		     '#' => '; to insinuate; to tease; to mock',
		     't' => 'v' },
 'sindiran'	=> { 'x' => 'insinuation',
		     't' => 'n' },
 'singa'	=> { 'x' => 'lion',
		     't' => 'n' },
# 'singgah'	=> { 'x' => 'to stop by on the way' },
 'singgahsana'	=> { 'x' => 'throne',
		     't' => 'n' },
 'singgung'	=> { 'x' => 'insult',
		     '#' => '; to offend',
		     't' => 'v' },
 'singkap'	=> { 'x' => 'reveal',
		     '#' => 'to expose; to lay open; to lift (skirt)',
		     't' => 'v' },
 'singkat'	=> { 'x' => 'short',
		     '#' => '; brief',
		     't' => 'a' },
 'singkatan'	=> { 'x' => 'abbreviation' },
 'singkir'	=> { 'x' => 'expel',
		     '#' => 'dismiss',
		     't' => 'v' },
# 'singsing'	=> { 'x' => 'roll up',
#		     '#' => '(sleeves, trousers)',
#		     't' => 'v' },
 'sinis'	=> { 'x' => 'cynical' },
# 'sipi'		=> { 'x' => 'off target' },
 'sipu'		=> { 'x' => 'shy',
		     '#' => '; bashful' },
 'siput'	=> { 'x' => 'snail' },
 'siram'	=> { 'x' => 'water',
		     't' => 'v' },
# 'sirap'	=> { 'x' => 'slightly raised' },
 'sirat'	=> { 'x' => 'netting',
		     '#' => '; mesh' },
# 'sirih'	=> { 'x' => 'betel leaf' },
 'sirip'	=> { 'x' => 'fin' },
 'sisa'		=> { 'x' => 'remainder',
		     '#' => '; leftovers' },
 'sisi'		=> { 'x' => 'side',
		     '#' => '; edge' },
# 'sisih'	=> { 'x' => 'to stay apart' },
# 'sisik'	=> { 'x' => 'scale (of fish)' },
 'sisip'	=> { 'x' => 'insert',
		     't' => 'v' },
 'sisipan'	=> { 'x' => 'insertion' },
# 'sisir'	=> { 'x' => '(1)to comb (2)a comb (of bananas)' },
 'siswa'	=> { 'x' => 'undergraduate' },
 'sita'		=> { 'x' => 'forfeited',
		     '#' => '; confiscated' },
 'sitaan'	=> { 'x' => 'confiscation',
		     '#' => 'confiscated goods' },
 'situ'		=> { 'x' => 'there' },
 'siul'		=> { 'x' => 'whistle',
		     't' => 'v' },
 'siulan'	=> { 'x' => 'whistling' },
 'siuman'	=> { 'x' => 'recovered consciousness',
		     '#' => 'sane' },
 'soal'		=> { 'x' => 'question',
		     't' => 'v' },
 'soalan'	=> { 'x' => 'question',
		     't' => 'n' },
 'soal selidik'	=> { 'x' => 'questionaire' },
 'sodok'	=> { 'x' => 'shovel',
		     't' => 'v' },
 'sogok'	=> { 'x' => 'bribe',
		     't' => 'n' },
 'sokong'	=> { 'x' => 'support',
		     '#' => 'to back up',
		     't' => 'v' },
 'sokongan'	=> { 'x' => 'support',
		     '#' => '; backing' },
 'solek'	=> { 'x' => 'make-up' },
 'sombong'	=> { 'x' => 'proud',
		     '#' => '; conceited; snobbish' },
 'sompek'	=> { 'x' => 'chipped' },
# 'sondol'	=> { 'x' => 'to butt with lowered head' },
# 'songkok'	=> { 'x' => 'malay male head-dress' },
 'songsang'	=> { 'x' => 'upside down',
		     '#' => 'inverted' },
 'sopan'	=> { 'x' => 'respectful',
		     '#' => '; courteous; polite' },
 'sopan santun'	=> { 'x' => 'courtesy',
		     '#' => 'politeness' },
 'sorak-sorai'	=> { 'x' => 'applause',
		     '#' => 'cheering' },
 'sorakan'	=> { 'x' => 'applause',
		     '#' => '; cheers' },
 'sore'		=> { 'x' => 'afternoon',
		     '#' => 'early evening' },
 'sorok'	=> { 'x' => 'hide',
		     '#' => '; to conceal',
		     't' => 'v' },
 'sorong'	=> { 'x' => 'shove',
		     '#' => 'to push forward; to urge',
		     't' => 'v' },
 'sorot'	=> { 'x' => 'ray',
		     '#' => 'beam (2)to review',
		     't' => 'n' },
 'sorotan'	=> { 'x' => 'glow',
		     '#' => 'noun or verb?; radiation (2)reflection; review' },
 'sotong'	=> { 'x' => 'cuttlefish' },
 'sua'		=> { 'x' => 'meet',
		     '#' => '; to encounter; to join',
		     't' => 'v' },
 'suai'		=> { 'x' => 'suitable',
		     '#' => '; fit; appropriate' },
 'suai kenal'	=> { 'x' => 'orientation' },
 'suam'		=> { 'x' => 'lukewarm',
		     '#' => '; feverish' },
 'suami'	=> { 'x' => 'husband' },
 'suap'		=> { 'x' => 'feed',
		     '#' => '(2)to bribe',
		     't' => 'v' },
 'suara'	=> { 'x' => 'voice' },
 'suara hati'	=> { 'x' => 'conscience' },
# 'suara ramai'	=> { 'x' => 'opinion of the majority' },
 'suasana'	=> { 'x' => 'mood',
		     '#' => '; atmosphere; situation; circumstances' },
 'suatu'	=> { 'x' => 'one',
		     '#' => '; a' },
 'subahat'	=> { 'x' => 'accomplice' },
 'subang'	=> { 'x' => 'ear-ring',
		     '#' => 'ear-stud' },
 'subuh'	=> { 'x' => 'dawn' },
 'subur'	=> { 'x' => 'flourishing',
		     '#' => '; healthy; fertile' },
 'suci'		=> { 'x' => 'chaste',
		     '#' => '; pure; virtuous; holy' },
 'sudah'	=> { 'x' => 'already',
		     '#' => '; finished' },
 'sudahlah'	=> { 'x' => 'that\'s enough' },
 'sudahnya'	=> { 'x' => 'finally' },
 'sudah-sudah'	=> { 'x' => 'past',
		     '#' => 'bygone' },
 'sudi'		=> { 'x' => 'willing' },
# 'sudip'	=> { 'x' => 'wooden ladle' },
 'sudu'		=> { 'x' => 'spoon' },
 'sudut'	=> { 'x' => 'corner',
		     '#' => 'angle; aspect; point of view' },
 'sugul'	=> { 'x' => 'sadness',
		     '#' => '; grief; sorrow' },
 'suhu'		=> { 'x' => 'temperature' },
# 'sujud'	=> { 'x' => 'prostrate (in prayer)' },
 'suka'		=> { 'x' => 'like',
		     '#' => '; enjoy' },
 'suka hati'	=> { 'x' => 'delighted',
		     '#' => 'happy' },
 'suka ria'	=> { 'x' => 'gay',
		     '#' => 'happy' },
 'sukacita'	=> { 'x' => 'glad',
		     '#' => '; happy; cheerful' },
 'sukan'	=> { 'x' => 'sport' },
 'sukar'	=> { 'x' => 'difficult',
		     '#' => '; hard' },
 'sukarela'	=> { 'x' => 'voluntary' },
 'sukarelawan'	=> { 'x' => 'volunteer' },
 'sukat'	=> { 'x' => 'quantity',
		     '#' => '; capacity' },
 'sukatan'	=> { 'x' => 'measurement',
		     '#' => '; assessment' },
 'suku'		=> { 'x' => 'quarter',
		     't' => 'n' },
 'suku kata'	=> { 'x' => 'syllable',
		     't' => 'n' },
 'suku bangsa'	=> { 'x' => 'tribe' },
 'suku-sakat'	=> { 'x' => 'family',
		     '#' => 'clan' },
 'sula'		=> { 'x' => 'impale',
		     't' => 'v' },
 'sulah'	=> { 'x' => 'bald' },
 'sulam'	=> { 'x' => 'embroider',
		     't' => 'v' },
 'sulaman'	=> { 'x' => 'embroidery' },
 'suling'	=> { 'x' => 'distilled' },
 'sulit'	=> { 'x' => 'secret',
		     '#' => 'confidential (2)difficult',
		     't' => 'a' },
# 'sultan'	=> { 'x' => 'muslim ruler' },
# 'sultanah'	=> { 'x' => 'muslim ruler\'s consort' },
 'suluh'	=> { 'x' => 'torch',
		     't' => 'n' },
 'sulung'	=> { 'x' => 'the first',
		     '#' => 'the eldest' },
 'sulur'	=> { 'x' => 'tendril',
		     't' => 'n' },
 'sumbang'	=> { 'x' => 'donate',
		     '#' => 'to contribute (2)indecent; immoral',
		     't' => 'v' },
 'sumbangan'	=> { 'x' => 'contribution',
		     't' => 'n' },
 'sumbangsih'	=> { 'x' => 'contribution',
		     '#' => '; aid; alms',
		     't' => 'n' },
 'sumbat'	=> { 'x' => 'cork',
		     '#' => 'stopper (2)tight (hole)',
		     't' => 'n' },
 'sumber'	=> { 'x' => 'source',
		     '#' => '; resource',
		     't' => 'n' },
 'sumbing'	=> { 'x' => 'torn',
		     '#' => '; split',
		     't' => 'a' },
# 'sumbu'	=> { 'x' => 'horn of a rhinoceros' },
 'sumpah'	=> { 'x' => 'oath',
		     '#' => 'solemn promise',
		     't' => 'n' },
 'sumpahan'	=> { 'x' => 'curse' },
 'sumpah-sumpah'	=> { 'x' => 'chameleon' },
# 'sumpit'	=> { 'x' => 'shoot with a blow-pipe' },
 'sumpitan'	=> { 'x' => 'blow-pipe' },
# 'sumsum'	=> { 'x' => 'bone marrow' },
 'sumur'	=> { 'x' => 'well',
		     't' => 'n' },
 'sunat'	=> { 'x' => 'circumcision' },
 'sungai'	=> { 'x' => 'river' },
 'sungguh'	=> { 'x' => 'true',
		     '#' => '; real; indeed' },
 'sungguh-sungguh'	=> { 'x' => 'truly',
		     '#' => 'really; indeed; ernestly' },
 'sungguhpun'	=> { 'x' => 'although' },
# 'sungkur'	=> { 'x' => '(1)to lower one\'s head (2)a shovel' },
 'sungut'	=> { 'x' => 'feeler',
		     '#' => '; antenna' },
 'sungut-sungut'	=> { 'x' => 'feeler',
		     '#' => 'antenna' },
# 'sunti'	=> { 'x' => 'a female child' },
 'suntik'	=> { 'x' => 'inject',
		     '#' => '; to inoculate; to vaccinate',
		     't' => 'v' },
 'suntikan'	=> { 'x' => 'injection',
		     '#' => '; inoculation; vaccination' },
# 'sunting'	=> { 'x' => 'an ornament worn in the hair' },
 'suntuk'	=> { 'x' => 'overdue',
		     '#' => 'short of time',
		     't' => 'a' },
 'sunyi'	=> { 'x' => 'quiet',
		     '#' => '; lonely',
		     't' => 'a' },
# 'surah'	=> { 'x' => 'a chapter of the koran' },
# 'surai'	=> { 'x' => '(1)to disperse (2)tress; horse\'s mane' },
 'suram'	=> { 'x' => 'gloomy',
		     '#' => '; hazy; dim',
		     't' => 'a' },
 'surat'	=> { 'x' => 'letter',
		     't' => 'n' },
 'suratkhabar'	=> { 'x' => 'newspaper',
		     't' => 'n' },
# 'surau'	=> { 'x' => 'muslim prayer house' },
 'suri'		=> { 'x' => 'queen',
		     't' => 'n' },
 'suri rumahtangga'	=> { 'x' => 'housewife' },
# 'suria'	=> { 'x' => 'the sun' },
# 'suruh'	=> { 'x' => 'to order or instruct' },
 'suruhan'	=> { 'x' => 'order',
		     't' => 'n' },
 'suruhanjaya'	=> { 'x' => 'commission' },
 'surut'	=> { 'x' => 'subside',
		     '#' => '; to ebb; to decrease',
		     't' => 'v' },
 'susah'	=> { 'x' => 'difficult',
		     '#' => '(2)misery, worry',
		     't' => 'a' },
 'susah hati'	=> { 'x' => 'worried',
		     '#' => 'troubled' },
 'susah-susah'	=> { 'x' => 'bother',
		     '#' => 'to take the trouble',
		     't' => 'v' },
 'susila'	=> { 'x' => 'ethical' },
 'susu'		=> { 'x' => 'milk' },
# 'susuh'	=> { 'x' => 'a spur (of cock)' },
 'susuk'	=> { 'x' => 'figure',
		     '#' => '; shape' },
# 'susuk badan'	=> { 'x' => 'bodily shape or figure' },
 'susul'	=> { 'x' => 'follow',
		     't' => 'v' },
 'susulan'	=> { 'x' => 'follow-up' },
 'susun'	=> { 'x' => 'pile',
		     '#' => '; layer' },
 'susunan'	=> { 'x' => 'arrangement' },
 'susup'	=> { 'x' => 'infiltrate',
		     '#' => 'to enter secretly',
		     't' => 'v' },
 'susur'	=> { 'x' => 'edge',
		     '#' => '; fringe; margin; border',
		     't' => 'n' },
 'susut'	=> { 'x' => 'decrease',
		     '#' => '; to shrink',
		     't' => 'v' },
 'sutera'	=> { 'x' => 'silk' },
# 'sutradara'	=> { 'x' => 'director of a play or film' },
# 'swasta'	=> { 'x' => 'private (not public)' },
 'syabas'	=> { 'x' => 'good',
		     '#' => 'well done' },
 'syah'		=> { 'x' => 'ruler' },
 'syahbandar'	=> { 'x' => 'harbour-master' },
 'syahid'	=> { 'x' => 'martyr' },
 'syair'	=> { 'x' => 'poem' },
 'syaitan'	=> { 'x' => 'satan',
		     '#' => 'the devil' },
 'syak'		=> { 'x' => 'suspicion' },
 'syarah'	=> { 'x' => 'lecture',
		     't' => 'v' },
 'syarahan'	=> { 'x' => 'lecture',
		     't' => 'n' },
 'syarat'	=> { 'x' => 'condition',
		     '#' => '; requirement; prerequisite' },
# 'syariah'	=> { 'x' => 'islamic law' },
 'syarikat'	=> { 'x' => 'company',
		     '#' => '; corporation' },
 'syirik'	=> { 'x' => 'polytheism' },
 'syok'		=> { 'x' => 'attractive',
		     '#' => '; appealing; pleasant' },
 'syor'		=> { 'x' => 'suggestion',
		     '#' => '; recommendation' },
 'syukur'	=> { 'x' => 'thanks',
		     '#' => '; gratitude' },
 'syurga'	=> { 'x' => 'heaven' },
 'taat'		=> { 'x' => 'obedient',
		     '#' => '; faithful; loyal' },
 'tabah'	=> { 'x' => 'determined',
		     '#' => '; persevering' },
 'tabal'	=> { 'x' => 'install',
		     '#' => '; to inaugurate',
		     't' => 'v' },
 'tabiat'	=> { 'x' => 'habit',
		     '#' => '; behaviour' },
 'tabii'	=> { 'x' => 'natural',
		     '#' => '; inborn' },
               
 'tabik'	=> { 'x' => 'salute',
		     't' => 'n' },
 'tabir'	=> { 'x' => 'curtain',
		     '#' => '; screen' },
# 'tabuh'	=> { 'x' => 'a mosque drum' },
 'tabung'	=> { 'x' => 'money-box',
		     '#' => 'fund; tube' },
 'tabungan'	=> { 'x' => 'savings' },
# 'tabung uji'	=> { 'x' => 'test tube' },
 'tabur'	=> { 'x' => 'scatter',
		     '#' => '; to disseminate',
		     't' => 'v' },
# 'tadah'	=> { 'x' => 'to receive with both palms' },
 'tadahan'	=> { 'x' => 'catchment' },
 'tadbir'	=> { 'x' => 'administrative' },
# 'tadi'		=> { 'x' => 'just now' },
 'tadika'	=> { 'x' => 'kindergarten' },
 'tafakur'	=> { 'x' => 'meditation' },
 'tafsir'	=> { 'x' => 'interpretation' },
 'tagak'	=> { 'x' => 'durable',
		     '#' => 'lasting (2)to hesitate; to dilly-dally; to defer',
		     't' => 'a' },
 'tagih'	=> { 'x' => 'addictive',
		     '#' => 'to crave for',
		     't' => 'a' },
 'tahan'	=> { 'x' => 'endure',
		     '#' => '; to last; to tolerate',
		     't' => 'v' },
 'tahan api'	=> { 'x' => 'fireproof' },
 'tahan lasak'	=> { 'x' => 'hardy' },
# 'tahan uji'	=> { 'x' => 'endurance test' },
 'tahanan'	=> { 'x' => 'detention' },
 'tahap'	=> { 'x' => 'level',
		     '#' => '; stage' },
 'tahi'		=> { 'x' => 'dung' },
# 'tahi arak'	=> { 'x' => 'an alcoholic' },
 'tahi judi'	=> { 'x' => 'gambler',
		     't' => 'n' },
# 'tahi mata'	=> { 'x' => 'eye discharge' },
# 'tahi telinga'	=> { 'x' => 'ear wax' },
 'tahniah'	=> { 'x' => 'congratulations' },
# 'tahu'		=> { 'x' => '(1)to know (2)soya' },
# 'tahu-tahu'	=> { 'x' => 'without being aware of' },
 'tahun'	=> { 'x' => 'year' },
 'tahunan'	=> { 'x' => 'annual' },
 'tahyul'	=> { 'x' => 'superstition' },
 'taja'		=> { 'x' => 'sponsor',
		     't' => 'v' },
 'tajaan'	=> { 'x' => 'sponsorship' },
 'tajak'	=> { 'x' => 'hoe',
		     't' => 'n' },
 'tajam'	=> { 'x' => 'sharp' },
 'tajuk'	=> { 'x' => 'title' },
 'tak'		=> { 'x' => 'no',
		     '#' => 'not (abbreviation of tidak)' },
 'takabur'	=> { 'x' => 'proud',
		     '#' => '; arrogant' },
 'takal'	=> { 'x' => 'pulley' },
# 'takar'	=> { 'x' => 'glass or porcelain jar' },
# 'takat'	=> { 'x' => 'extreme degree or limit' },
 'takdir'	=> { 'x' => 'destiny',
		     '#' => '; fate' },
 'takhta'	=> { 'x' => 'throne' },
 'takik'	=> { 'x' => 'notch',
		     '#' => '; indentation' },
 'takjub'	=> { 'x' => 'astonished',
		     '#' => '; amazed' },
# 'takkan'	=> { 'x' => 'impossible; can\'t; won\'t' },
 'taklimat'	=> { 'x' => 'briefing' },
 'takluk'	=> { 'x' => 'subject',
		     '#' => '; to subdue; to subjugate',
		     't' => 'v' },
 'takrif'	=> { 'x' => 'definition',
		     '#' => '; description' },
 'taksir'	=> { 'x' => 'assess',
		     '#' => '; to evaluate; to appraise',
		     't' => 'v' },
 'taksiran'	=> { 'x' => 'assessment',
		     '#' => '; estimate; evaluation' },
 'takung'	=> { 'x' => 'stagnant' },
 'takungan'	=> { 'x' => 'reservoir' },
 'takut'	=> { 'x' => 'afraid' },
 'takwim'	=> { 'x' => 'almanac',
		     '#' => '; calendar' },
 'takziah'	=> { 'x' => 'condolence' },
# 'takzim'	=> { 'x' => 'high respect' },
 'tala'		=> { 'x' => 'tune',
		     '#' => 'pitch (in music) (2)padlock',
		     't' => 'n' },
 'talak'	=> { 'x' => 'divorce' },
 'talam'	=> { 'x' => 'tray' },
 'tali'		=> { 'x' => 'rope' },
# 'talian'	=> { 'x' => 'a line (of telephone)' },
 'talu'		=> { 'x' => 'flog',
		     '#' => '; to wallop',
		     't' => 'v' },
 'tamadun'	=> { 'x' => 'civilization',
		     '#' => '; civilized' },
 'tamak'	=> { 'x' => 'greedy' },
 'taman'	=> { 'x' => 'park',
		     '#' => '; garden' },
# 'tamar'	=> { 'x' => 'date (fruit)' },
 'tamat'	=> { 'x' => 'finished',
		     '#' => '; ended; terminated' },
 'tambah'	=> { 'x' => 'add',
		     '#' => '; to increase',
		     't' => 'v' },
 'tambahan'	=> { 'x' => 'addition',
		     '#' => 'an increase; additional' },
 'tambak'	=> { 'x' => 'embankment',
		     '#' => '; dyke' },
# 'tambang'	=> { 'x' => 'fare (for transport)' },
 'tambat'	=> { 'x' => 'moor',
		     '#' => 'to tie up',
		     't' => 'v' },
 'tambatan'	=> { 'x' => 'connection',
		     '#' => 'mooring buoy' },
 'tampak'	=> { 'x' => 'visible' },
 'tampaknya'	=> { 'x' => 'apparently',
		     '#' => '; obviously' },
 'tampal'	=> { 'x' => 'patch',
		     '#' => '; to plaster',
		     't' => 'v' },
 'tampalan'	=> { 'x' => 'patch',
		     '#' => '; a plaster; a poultice',
		     't' => 'n' },
 'tampan'	=> { 'x' => 'handsome',
		     '#' => 'smart-looking (2)to stop something moving',
		     't' => 'a' },
 'tampar'	=> { 'x' => 'slap',
		     't' => 'v' },
 'tamparan'	=> { 'x' => 'slap',
		     't' => 'n' },
# 'tampi'	=> { 'x' => 'to winnow or sift' },
 'tampil'	=> { 'x' => 'appear',
		     '#' => 'to come forward',
		     't' => 'v' },
 'tampuk'	=> { 'x' => 'calyx' },
 'tampung'	=> { 'x' => 'bear',
		     '#' => 'to endure; a patch',
		     't' => 'v' },
 'tamsil'	=> { 'x' => 'parable',
		     '#' => '; analogy' },
 'tamsilan'	=> { 'x' => 'comparison' },
 'tamu'		=> { 'x' => 'guest' },
 'tanah'	=> { 'x' => 'soil',
		     '#' => '; land; ground' },
 'tanahair'	=> { 'x' => 'motherland' },
 'tanah gambut'	=> { 'x' => 'peat' },
 'tanah gembur'	=> { 'x' => 'loam' },
 'tanah jajahan'	=> { 'x' => 'colony' },
 'tanah liat'	=> { 'x' => 'clay' },
 'tanah pamah'	=> { 'x' => 'plains' },
 'tanah tumpah darah'	=> { 'x' => 'motherland' },
# 'tanak'	=> { 'x' => 'to cook rice' },
 'tanam'	=> { 'x' => 'plant',
		     't' => 'v' },
 'tanaman'	=> { 'x' => 'plants' },
# 'tanam-tanaman'	=> { 'x' => 'all kinds of plants' },
 'tanda'	=> { 'x' => 'sign',
		     '#' => '; mark; symbol' },
 'tandan'	=> { 'x' => 'bunch',
		     '#' => 'cluster (of bananas, etc.)' },
 'tandang'	=> { 'x' => 'visit' },
 'tandas'	=> { 'x' => 'toilet',
		     '#' => '; latrine' },
 'tandatangan'	=> { 'x' => 'signature' },
 'tanding'	=> { 'x' => 'compete',
		     't' => 'v' },
 'tandu'	=> { 'x' => 'stretcher' },
 'tanduan'	=> { 'x' => 'palanquin' },
 'tanduk'	=> { 'x' => 'horn' },
 'tangan'	=> { 'x' => 'hand' },
 'tangga'	=> { 'x' => 'ladder',
		     '#' => 'stairs; a scale' },
 'tanggal'	=> { 'x' => 'drop off',
		     '#' => 'to take off (2)date (of calendar)',
		     't' => 'v' },
# 'tanggap'	=> { 'x' => 'to listen carefully' },
 'tanggapan'	=> { 'x' => 'response',
		     '#' => '; reaction; notion; idea' },
 'tangguh'	=> { 'x' => 'postpone' },
# 'tangguk'	=> { 'x' => 'a small fishing net' },
 'tanggung'	=> { 'x' => 'bear',
		     '#' => 'to be responsible (2)inadequate',
		     't' => 'v' },
 'tanggungan'	=> { 'x' => 'responsibility',
		     '#' => '; obligation; surety' },
 'tanggungjawab'	=> { 'x' => 'responsibility' },
 'tangis'	=> { 'x' => 'weep',
		     't' => 'v' },
 'tangisan'	=> { 'x' => 'weeping',
		     '#' => '; crying' },
 'tangkai'	=> { 'x' => 'stalk',
		     '#' => '; a handle; a stem',
		     't' => 'n' },
 'tangkai jering'	=> { 'x' => 'stingy' },
 'tangkal'	=> { 'x' => 'amulet',
		     '#' => '; a talisman',
		     't' => 'n' },
 'tangkap'	=> { 'x' => 'catch',
		     't' => 'v' },
 'tangkapan'	=> { 'x' => 'catch',
		     '#' => 'the capture',
		     't' => 'n' },
 'tangkas'	=> { 'x' => 'nimble',
		     '#' => '; agile' },
 'tangkis'	=> { 'x' => 'repulse',
		     '#' => 'to ward off; to repel',
		     't' => 'v' },
 'tanglung'	=> { 'x' => 'lantern' },
 'tangsi'	=> { 'x' => 'barracks' },
 'tani'		=> { 'x' => 'farming' },
# 'tanjak'	=> { 'x' => '(1)head-dress (2)going obliquely upwards' },
# 'tanjung'	=> { 'x' => 'cape (land jutting out into the sea)' },
 'tanpa'	=> { 'x' => 'without' },
 'tanya'	=> { 'x' => 'ask',
		     '#' => '; to enquire',
		     't' => 'v' },
 'tapa'		=> { 'x' => 'hermitage' },
 'tapak'	=> { 'x' => 'palm',
		     '#' => '(of the hand), sole of the foot; base; site',
		     't' => 'n' },
 'tapis'	=> { 'x' => 'filter',
		     '#' => '; to sieve; to censor',
		     't' => 'v' },
 'tapisan'	=> { 'x' => 'filtrate',
		     't' => 'v' },
 'tara'		=> { 'x' => 'equal',
		     '#' => '; par; even',
		     't' => 'a' },
 'taraf'	=> { 'x' => 'standard',
		     '#' => '; status; level',
		     't' => 'n' },
 'tarah'	=> { 'x' => 'plane',
		     '#' => '(wood)',
		     't' => 'v' },
 'tari'		=> { 'x' => 'dance',
		     't' => 'v' },
 'tarian'	=> { 'x' => 'dance',
		     't' => 'n' },
 'tarik'	=> { 'x' => 'pull',
		     't' => 'v' },
 'tarikh'	=> { 'x' => 'date',
		     '#' => '(of the calendar)',
		     't' => 'n' },
 'taring'	=> { 'x' => 'tusk',
		     '#' => '; fang',
		     't' => 'n' },
 'taruh'	=> { 'x' => 'stake',
		     '#' => 'bet (2)to put; to place',
		     't' => 'v' },
 'tarung'	=> { 'x' => 'clash',
		     '#' => '; to dispute; to quarrel',
		     't' => 'v' },
 'tasik'	=> { 'x' => 'lake' },
 'tata'		=> { 'x' => 'system',
		     '#' => '; order' },
 'tataacara'	=> { 'x' => 'agenda' },
 'tatabahasa'	=> { 'x' => 'grammar' },
 'tatacara'	=> { 'x' => 'procedure' },
# 'tatahukum'	=> { 'x' => 'legal system' },
# 'tatasusila'	=> { 'x' => 'code of ethics' },
 'tatatertib'	=> { 'x' => 'discipline' },
# 'tatah'	=> { 'x' => 'inlaid work' },
 'tatahan'	=> { 'x' => 'inlay' },
# 'tatang'	=> { 'x' => 'to carry in the palm of the hand' },
 'tatap'	=> { 'x' => 'scrutinize',
		     '#' => 'to observe intently',
		     't' => 'v' },
 'tatapan'	=> { 'x' => 'scrutiny' },
 'tatih'	=> { 'x' => 'unsteady',
		     '#' => 'wobbly; to toddle' },
 'tatkala'	=> { 'x' => 'when' },
 'taubat'	=> { 'x' => 'repentance',
		     '#' => '; penitence' },
 'taufan'	=> { 'x' => 'typhoon' },
# 'tauge'	=> { 'x' => 'bean sprout' },
# 'tauhu'	=> { 'x' => 'soyabean curd' },
# 'tauke'	=> { 'x' => 'chinese business proprietor' },
 'taulan'	=> { 'x' => 'friend',
		     't' => 'n' },
 'tauliah'	=> { 'x' => 'commission',
		     '#' => 'letter of appointment',
		     't' => 'n' },
 'taun'		=> { 'x' => 'cholera',
		     't' => 'n' },
# 'taurat'	=> { 'x' => 'old testament' },
 'taup'		=> { 'x' => 'united',
		     '#' => 'connected; joined together',
		     't' => 'a' },
 'taut'		=> { 'x' => 'united',
		     '#' => '(of wound), joined together',
		     't' => 'a' },
 'tawa'		=> { 'x' => 'laugh',
		     't' => 'v' },
 'tawan'	=> { 'x' => 'capture',
		     '#' => '; to captivate; to conquer',
		     't' => 'v' },
 'tawanan'	=> { 'x' => 'prisoner',
		     '#' => '; a captive',
		     't' => 'n' },
# 'tawar'	=> { 'x' => '(1)tasteless (2)to bargain' },
 'tawaran'	=> { 'x' => 'offer',
		     't' => 'n' },
 'tawar hati'	=> { 'x' => 'disheartened',
		     't' => 'a' },
 'tawar hambar'	=> { 'x' => 'tasteless',
		     't' => 'a' },
 'tawar-menawar'	=> { 'x' => 'bargain',
		     '#' => 'to haggle',
			     't' => 'v' },
 'tawarikh'	=> { 'x' => 'history',
		     '#' => '; annals' },
 'tayang'	=> { 'x' => 'show',
		     '#' => 'to display; to screen (a film)',
		     't' => 'v' },
 'tayangan'	=> { 'x' => 'show',
		     '#' => '; a display; a screening',
		     't' => 'n' },
 'tebal'	=> { 'x' => 'thick',
		     '#' => 'dense (of growth)' },
 'tebang'	=> { 'x' => 'fell',
		     '#' => '(a tree), to cut down',
		     't' => 'v' },
 'tebar'	=> { 'x' => 'scattered',
		     '#' => 'to scatter (seeds); to cast (a net)' },
# 'tebas'	=> { 'x' => 'to clear the undergrowth' },
# 'tebing'	=> { 'x' => 'bank (of river)' },
 'tebu'		=> { 'x' => 'sugar-cane' },
 'tebuan'	=> { 'x' => 'hornet' },
 'tebuk'	=> { 'x' => 'pierce',
		     '#' => '; to drill; to perforate',
		     't' => 'v' },
# 'tebus'	=> { 'x' => 'to recover or redeem by payment' },
 'tebusan'	=> { 'x' => 'ransom',
		     '#' => '; redemption' },
# 'teduh'	=> { 'x' => 'protection or shelter' },
 'tedung'	=> { 'x' => 'cobra' },
 'tegah'	=> { 'x' => 'forbid',
		     '#' => '; to prohibit',
		     't' => 'v' },
 'tegahan'	=> { 'x' => 'prohibition' },
 'tegak'	=> { 'x' => 'upright',
		     '#' => '; erect' },
 'tegang'	=> { 'x' => 'taut',
		     '#' => '; tight; tense' },
 'tegap'	=> { 'x' => 'well-built',
		     '#' => 'sturdy; firm' },
 'tegar'	=> { 'x' => 'stubborn',
		     '#' => '; obstinate' },
 'tegas'	=> { 'x' => 'firm',
		     '#' => 'well-defined; precise' },
 'tegasan'	=> { 'x' => 'clarification' },
 'teguh'	=> { 'x' => 'firm',
		     '#' => '; secure; steady' },
 'teguk'	=> { 'x' => 'gulp',
		     't' => 'n' },
# 'tegun'	=> { 'x' => 'to stop suddenly' },
 'tegur'	=> { 'x' => 'greet',
		     '#' => '; to accost; to criticize',
		     't' => 'v' },
 'teguran'	=> { 'x' => 'criticism',
		     '#' => '; greeting' },
 'teh'		=> { 'x' => 'tea' },
 'teka'		=> { 'x' => 'guess',
		     't' => 'v' },
 'teka-teki'	=> { 'x' => 'riddle',
		     't' => 'n' },
 'tekaan'	=> { 'x' => 'guess',
		     't' => 'n' },
 'tekad'	=> { 'x' => 'will-power',
		     '#' => 'determination' },
 'tekak'	=> { 'x' => 'throat' },
 'tekan'	=> { 'x' => 'press',
		     '#' => '(2)to oppress, to ill-treat',
		     't' => 'v' },
 'tekanan'	=> { 'x' => 'pressure',
		     '#' => '; stress' },
 'tekap'	=> { 'x' => 'trace',
		     '#' => '(2)to cover',
		     't' => 'v' },
 'tekat'	=> { 'x' => 'embroidery' },
 'teko'		=> { 'x' => 'teapot' },
# 'tekong'	=> { 'x' => 'anchorman (in sports)' },
# 'tekukur'	=> { 'x' => 'large cuckoo-dove' },
 'tekun'	=> { 'x' => 'diligent',
		     '#' => '; hardworking; industrious' },
 'telaah'	=> { 'x' => 'study',
		     '#' => '; to examine',
		     't' => 'v' },
 'teladan'	=> { 'x' => 'example' },
 'telaga'	=> { 'x' => 'well' },
 'telagah'	=> { 'x' => 'quarrel',
		     '#' => '; to disagree',
		     't' => 'v' },
 'telahan'	=> { 'x' => 'prediction' },
 'telan'	=> { 'x' => 'swallow',
		     't' => 'v' },
 'telangkup'	=> { 'x' => 'upside-down',
		     't' => 'a' },
 'telanjang'	=> { 'x' => 'nude',
		     '#' => '; naked',
		     't' => 'a' },
 'telap'	=> { 'x' => 'permeable',
		     't' => 'n' },
 'telapak'	=> { 'x' => 'palm',
		     '#' => '(of hand), sole of foot',
		     't' => 'n' },
 'telatah'	=> { 'x' => 'behaviour' },
# 'telekung'	=> { 'x' => 'a white praying veil used by muslim women' },
 'telentang'	=> { 'x' => 'supine' },
 'telinga'	=> { 'x' => 'ear',
		     't' => 'n' },
 'telingkah'	=> { 'x' => 'argue',
		     '#' => '; to dispute; to quarrel',
		     't' => 'v' },
 'teliti'	=> { 'x' => 'care',
		     '#' => 'close attention; accuracy; precision' },
 'teluk'	=> { 'x' => 'bay' },
# 'telungkup'	=> { 'x' => 'to lie prone' },
# 'telunjuk'	=> { 'x' => 'index finger' },
 'telur'	=> { 'x' => 'egg' },
 'telur dadar'	=> { 'x' => 'omelette' },
# 'telur masin'	=> { 'x' => 'salted egg' },
 'telut'	=> { 'x' => 'kneel',
		     't' => 'v' },
 'teman'	=> { 'x' => 'companion',
		     '#' => '; friend' },
# 'temasya'	=> { 'x' => 'a show or event (cultural, musical)' },
# 'tembaga'	=> { 'x' => 'copper: brass' },
 'tembaga merah'	=> { 'x' => 'copper' },
 'tembaga kuning'	=> { 'x' => 'brass' },
 'tembaga perunggu'	=> { 'x' => 'bronze' },
 'tembaga putih'	=> { 'x' => 'pewter' },
 'tembak'	=> { 'x' => 'shoot',
		     't' => 'v' },
# 'tembak-menembak'	=> { 'x' => 'a shoot-out' },
 'tembakan'	=> { 'x' => 'shooting' },
 'tembakau'	=> { 'x' => 'tobacco' },
 'tembam'	=> { 'x' => 'plump' },
# 'tembelang'	=> { 'x' => 'addled (of eggs)' },
 'temberang'	=> { 'x' => 'brag',
		     '#' => 'to tell a lie',
		     't' => 'v' },
 'tembikai'	=> { 'x' => 'watermelon' },
 'tembikar'	=> { 'x' => 'porcelain',
		     '#' => '; earthenware' },
 'tembok'	=> { 'x' => 'wall',
		     '#' => '; embankment' },
# 'tembolok'	=> { 'x' => 'crop, gizzard (of birds)' },
 'tembung'	=> { 'x' => 'meet',
		     '#' => '; encounter' },
 'tembuni'	=> { 'x' => 'placenta',
		     '#' => '; afterbirth' },
 'tembus'	=> { 'x' => 'perforated',
		     '#' => '; penetrable' },
 'tempa'	=> { 'x' => 'weld',
		     '#' => 'to forge (metals)',
		     't' => 'v' },
 'tempah'	=> { 'x' => 'reserve',
		     '#' => '; to book',
		     't' => 'v' },
 'tempahan'	=> { 'x' => 'booking' },
 'tempang'	=> { 'x' => 'lame',
		     '#' => '; crippled' },
 'tempat'	=> { 'x' => 'place',
		     '#' => '; location' },
 'tempatan'	=> { 'x' => 'local' },
# 'tempayan'	=> { 'x' => 'large earthen water-barrel' },
 'tempel'	=> { 'x' => 'stick',
		     '#' => '; to paste; to glue',
		     't' => 'v' },
 'tempelak'	=> { 'x' => 'rebuke',
		     '#' => '; to reproach; to censure',
		     't' => 'v' },
# 'tempeleng'	=> { 'x' => 'to slap on the face' },
 'tempiar'	=> { 'x' => 'scattered' },
# 'tempik'	=> { 'x' => 'a short loud cheer' },
# 'tempikan'	=> { 'x' => 'loud shouting' },
 'tempik-sorak'	=> { 'x' => 'cheering' },
# 'tempoh'	=> { 'x' => 'period of time' },
# 'tempoyak'	=> { 'x' => 'preserved durian' },
# 'tempua'	=> { 'x' => 'weaver bird' },
# 'tempuh'	=> { 'x' => 'to go or pass through' },
 'tempuling'	=> { 'x' => 'harpoon' },
 'tempur'	=> { 'x' => 'clash',
		     't' => 'v' },
# 'tempurung'	=> { 'x' => 'coconut shell' },
 'temu'		=> { 'x' => 'meet',
		     '#' => '; to find',
		     't' => 'v' },
# 'temu duga'	=> { 'x' => 'an interview' },
# 'temu ramah'	=> { 'x' => 'an interview' },
 'tenaga'	=> { 'x' => 'energy',
		     '#' => '; power; strength' },
 'tenang'	=> { 'x' => 'calm',
		     '#' => '; quiet; still; composed' },
 'tenat'	=> { 'x' => 'exhausted',
		     '#' => 'critically ill',
		     't' => 'a' },
 'tendang'	=> { 'x' => 'kick',
		     't' => 'v' },
 'tendangan'	=> { 'x' => 'kick',
		     't' => 'n' },
# 'tengadah'	=> { 'x' => 'to look up' },
 'tengah'	=> { 'x' => 'middle',
		     '#' => '; centre' },
 'tengah hari'	=> { 'x' => 'midday' },
 'tenggala'	=> { 'x' => 'plough',
		     't' => 'n' },
 'tenggara'	=> { 'x' => 'south-east' },
 'tenggek'	=> { 'x' => 'squat',
		     '#' => '; to crouch; to perch',
		     't' => 'v' },
 'tenggelam'	=> { 'x' => 'sink',
		     '#' => 'to set (of sun)' },
 'tengger'	=> { 'x' => 'perch',
		     't' => 'v' },
 'tenggiling'	=> { 'x' => 'armadillo' },
# 'tengik'	=> { 'x' => 'rancid (of oil)' },
 'tengkar'	=> { 'x' => 'quarrel',
		     't' => 'v' },
 'tengking'	=> { 'x' => 'snarl',
		     't' => 'v' },
 'tengkingan'	=> { 'x' => 'snarl',
		     't' => 'n' },
 'tengkolok'	=> { 'x' => 'head-dress' },
 'tengkorak'	=> { 'x' => 'skull' },
# 'tengku'	=> { 'x' => 'a malay prince or princess' },
# 'tengkuk'	=> { 'x' => 'nape of neck' },
 'tengok'	=> { 'x' => 'see',
		     '#' => '; to consider',
		     't' => 'v' },
 'tentang'	=> { 'x' => 'about',
		     '#' => '; regarding' },
 'tentangan'	=> { 'x' => 'objection',
		     '#' => '; opposition; resistance' },
 'tentera'	=> { 'x' => 'army',
		     '#' => '; military; troops' },
 'tenteram'	=> { 'x' => 'calm',
		     '#' => '; peaceful; tranquil; quiet' },
 'tentu'	=> { 'x' => 'sure',
		     '#' => '; certain; definite' },
 'tenun'	=> { 'x' => 'weave',
		     't' => 'v' },
# 'tenung'	=> { 'x' => '(1)to forecast (2)to gaze fixedly' },
 'tenungan'	=> { 'x' => 'prediction' },
 'tenusu'	=> { 'x' => 'dairy' },
# 'tepak'	=> { 'x' => 'a metal box' },
 'tepat'	=> { 'x' => 'exact',
		     '#' => '; precise' },
 'tepi'		=> { 'x' => 'side',
		     '#' => '; edge' },
# 'tepis'	=> { 'x' => 'to push aside' },
 'tepu'		=> { 'x' => 'brimful',
		     '#' => '; full' },
 'tepuk'	=> { 'x' => 'clap',
		     't' => 'v' },
# 'tepukan gemuruh'	=> { 'x' => 'loud applause' },
 'tepung'	=> { 'x' => 'flour' },
 'tera'		=> { 'x' => 'stamp',
		     '#' => 'official seal' },
# 'terajang'	=> { 'x' => 'to kick and trample' },
# 'teraju'	=> { 'x' => 'weighing scales' },
 'terang'	=> { 'x' => 'bright',
		     '#' => '; clear' },
# 'terang-benderang'	=> { 'x' => 'very bright' },
 'terang-terang'	=> { 'x' => 'clearly',
		     '#' => 'frankly' },
# 'terap'	=> { 'x' => '(1)to apply (2)mould (for cakes)' },
 'teras'	=> { 'x' => 'core',
		     '#' => '; essence' },
 'teratai'	=> { 'x' => 'lotus' },
# 'teratai kecil'	=> { 'x' => 'blue water-lily' },
# 'teratak'	=> { 'x' => 'a small hut' },
 'terbang'	=> { 'x' => 'fly',
		     't' => 'v' },
 'terbit'	=> { 'x' => 'rise',
		     '#' => '; to emerge; to appear',
		     't' => 'v' },
 'terbitan'	=> { 'x' => 'publication',
		     '#' => '; issue; edition' },
# 'teriak'	=> { 'x' => 'a loud cry or shout' },
 'terik'	=> { 'x' => 'tight',
		     '#' => '; excessive; unbearable' },
 'terima'	=> { 'x' => 'receive',
		     '#' => '; to accept',
		     't' => 'v' },
# 'terima salah'	=> { 'x' => 'plead guilty' },
 'terjemah'	=> { 'x' => 'translate',
		     't' => 'v' },
 'terjemahan'	=> { 'x' => 'translation' },
 'terjun'	=> { 'x' => 'dive',
		     '#' => 'to jump down',
		     't' => 'v' },
# 'terkam'	=> { 'x' => 'to pounce on' },
 'ternak'	=> { 'x' => 'livestock' },
 'ternakan'	=> { 'x' => 'breeding',
		     '#' => '; rearing' },
# 'teroka'	=> { 'x' => 'to open new land' },
# 'terompah'	=> { 'x' => 'clogs (wooden footwear)' },
 'teropong'	=> { 'x' => 'telescope' },
 'terowong'	=> { 'x' => 'tunnel' },
 'terpa'	=> { 'x' => 'leap',
		     '#' => 'to spring forward; to pounce',
		     't' => 'v' },
 'tertib'	=> { 'x' => 'order',
		     '#' => '; discipline; system' },
# 'tertib nikah'	=> { 'x' => 'marriage rites' },
# 'tertib sopan'	=> { 'x' => 'tradition of politeness' },
 'terubuk'	=> { 'x' => 'herring',
		     't' => 'n' },
 'teruk'	=> { 'x' => 'serious',
		     '#' => 'very bad; severe',
		     't' => 'a' },
 'teruna'	=> { 'x' => 'youthful',
		     '#' => '(male), young man',
		     't' => 'a' },
 'terung'	=> { 'x' => 'brinjal' },
 'terus'	=> { 'x' => 'straight',
		     '#' => '; direct',
		     't' => 'a' },
 'terusan'	=> { 'x' => 'canal',
		     't' => 'n' },
 'terus-menerus'	=> { 'x' => 'continuously',
		     '#' => 'non-stop' },
 'tetak'	=> { 'x' => 'chop',
		     '#' => '; to slash',
		     't' => 'v' },
 'tetakan'	=> { 'x' => 'slash',
		     't' => 'n' },
 'tetamu'	=> { 'x' => 'guest',
		     't' => 'n' },
 'tetangga'	=> { 'x' => 'neighbour',
		     't' => 'n' },
 'tetap'	=> { 'x' => 'specific',
		     '#' => '; unambiguous; fixed; permanent',
		     't' => 'a' },
 'tetas'	=> { 'x' => 'hatch',
		     '#' => 'to slit open',
		     't' => 'v' },
 'tetek'	=> { 'x' => 'breast' },
# 'tetes'	=> { 'x' => 'drop (of fluid)' },
# 'tetesan'	=> { 'x' => 'drops (of fluid)' },
 'tewas'	=> { 'x' => 'defeated' },
 'tiang'	=> { 'x' => 'pillar',
		     '#' => '; post' },
# 'tiarap'	=> { 'x' => 'to lie prone' },
 'tiba'		=> { 'x' => 'arrive',
		     '#' => '; to reach',
		     't' => 'v' },
 'tiba-tiba'	=> { 'x' => 'suddenly' },
 'tidak apa-apa'	=> { 'x' => 'nothing' },
 'tidur'	=> { 'x' => 'sleep',
		     't' => 'v' },
# 'tidur ayam'	=> { 'x' => 'to sleep lightly' },
# 'tidur mati'	=> { 'x' => 'to sleep soundly' },
 'tikai'	=> { 'x' => 'quarrel' },
 'tikam'	=> { 'x' => 'stab',
		     '#' => '(2)to bet',
		     't' => 'v' },
 'tikaman'	=> { 'x' => 'stab',
		     't' => 'n' },
 'tikam dadu'	=> { 'x' => 'gamble' },
 'tikar'	=> { 'x' => 'mat',
		     '#' => '; rug',
		     't' => 'n' },
 'tikus'	=> { 'x' => 'rat',
		     't' => 'n' },
 'tilam'	=> { 'x' => 'mattress',
		     't' => 'n' },
 'tilik'	=> { 'x' => 'foretell',
		     '#' => '(1)to observe carefully, to gaze fixedly',
		     't' => 'v' },
 'tilikan'	=> { 'x' => 'prediction',
		     '#' => '; observation',
		     't' => 'n' },
 'tilik nasib'	=> { 'x' => 'fortune-telling',
		     't' => 'n' },
 'timah'	=> { 'x' => 'tin' },
 'timang'	=> { 'x' => 'dandle',
		     '#' => 'to caress; to rock (child)',
		     't' => 'v' },
 'timangan'	=> { 'x' => 'darling',
		     '#' => '; pet; nickname' },
 'timba'	=> { 'x' => 'pail',
		     '#' => '; bucket',
		     't' => 'n' },
 'timbal'	=> { 'x' => 'balanced',
		     '#' => '; equable' },
 'timbalan'	=> { 'x' => 'vice',
		     '#' => '; deputy' },
 'timbang'	=> { 'x' => 'weigh',
		     '#' => '(2)to consider, to contemplate',
		     't' => 'v' },
 'timbang rasa'	=> { 'x' => 'sympathy' },
 'timbul'	=> { 'x' => 'emerge',
		     '#' => 'to appear; to float up',
		     't' => 'v' },
 'timbun'	=> { 'x' => 'heap',
		     '#' => '; pile; mass',
		     't' => 'n' },
 'timbus'	=> { 'x' => 'bury',
		     '#' => 'to fill up (a hole)',
		     't' => 'v' },
# 'timpa'	=> { 'x' => 'to strike or hit (of falling object)' },
 'timpaan'	=> { 'x' => 'obstacle' },
 'timpal'	=> { 'x' => 'balanced',
		     '#' => '; proportionate' },
 'timun'	=> { 'x' => 'cucumber' },
 'timur'	=> { 'x' => 'east' },
# 'tindak'	=> { 'x' => 'to take action' },
 'tindakan'	=> { 'x' => 'action' },
 'tindak balas'	=> { 'x' => 'reaction' },
 'tindak tanduk'	=> { 'x' => 'behaviour',
		     '#' => 'character; nature' },
 'tindas'	=> { 'x' => 'oppress',
		     '#' => '; to suppress; to intimidate; to bully',
		     't' => 'v' },
 'tindasan'	=> { 'x' => 'oppression',
		     't' => 'n' },
 'tindih'	=> { 'x' => 'oppress',
		     '#' => 'to press upon',
		     't' => 'n' },
# 'tindik'	=> { 'x' => 'to pierce (ear)' },
# 'tinggal'	=> { 'x' => '(1)to live (2)to leave (3)to stay behind (4)to be left' },
 'tinggi'	=> { 'x' => 'high',
		     '#' => '; tall' },
 'tingkah'	=> { 'x' => 'behaviour' },
# 'tingkahan'	=> { 'x' => 'musical accompaniment' },
 'tingkap'	=> { 'x' => 'window' },
 'tingkat'	=> { 'x' => 'storey',
		     '#' => '; floor' },
# 'tinkatan'	=> { 'x' => 'form or grade (in school)' },
 'tinjau'	=> { 'x' => 'observe',
		     '#' => '; to watch',
		     't' => 'v' },
 'tinjauan'	=> { 'x' => 'observation',
		     '#' => '; survey; review' },
 'tinju'	=> { 'x' => 'boxing' },
 'tinta'	=> { 'x' => 'ink' },
 'tionghua'	=> { 'x' => 'chinese' },
 'tiongkok'	=> { 'x' => 'china' },
 'tipis'	=> { 'x' => 'thin',
		     '#' => 'slim; fine (of thread); sheer (of material)' },
 'tipu'		=> { 'x' => 'deceit',
		     '#' => '; cheat; fraud' },
 'tirai'	=> { 'x' => 'curtain' },
 'tiram'	=> { 'x' => 'oyster' },
 'tiri'		=> { 'x' => 'step-' },
# 'tiris'	=> { 'x' => 'to leak through' },
 'tiru'		=> { 'x' => 'copy',
		     '#' => '; to imitate',
		     't' => 'v' },
 'tiruan'	=> { 'x' => 'imitation',
		     '#' => 'counterfeit; a copy' },
 'tirus'	=> { 'x' => 'tapering' },
 'titah'	=> { 'x' => 'royal command',
		     '#' => 'formal address or speech (royal)',
		     't' => 'n' },
 'titi'		=> { 'x' => 'bridge',
		     '#' => '(wooden)',
		     't' => 'n' },
# 'titian'	=> { 'x' => 'wooden crossing' },
 'titik'	=> { 'x' => 'dot',
		     '#' => '(1)a drop of liquid (2)a full-stop; a point',
		     't' => 'n' },
 'titikberat'	=> { 'x' => 'emphasize',
		     '#' => 'emphasise',
		     't' => 'v' },
# 'titik dua'	=> { 'x' => 'a colon (:)' },
 'titis'	=> { 'x' => 'drop',
		     't' => 'n' },
 'titisan'	=> { 'x' => 'droplets',
		     '#' => '; trickle' },
 'tiup'		=> { 'x' => 'blow',
		     't' => 'v' },
# 'tiupan'	=> { 'x' => 'a gust (of air)' },
 'tocang'	=> { 'x' => 'plait',
		     '#' => 'braid (of hair)' },
 'todak'	=> { 'x' => 'sword-fish' },
 'togel'	=> { 'x' => 'bald',
		     '#' => '; tailless' },
 'tohor'	=> { 'x' => 'shallow' },
 'tok'		=> { 'x' => 'grandfather' },
 'toko'		=> { 'x' => 'shop' },
 'tokoh'	=> { 'x' => 'figure',
		     '#' => '; a personality',
		     't' => 'n' },
 'tokok'	=> { 'x' => 'addition' },
# 'tokong'	=> { 'x' => 'a chinese or buddhist temple' },
 'tolak'	=> { 'x' => 'push',
		     '#' => '(2)to subtract (3)to reject',
		     't' => 'v' },
 'tolakan'	=> { 'x' => 'shove',
		     '#' => 'a push; rejection',
		     't' => 'n' },
# 'tolak ansur'	=> { 'x' => 'to give and take' },
# 'tolak bala'	=> { 'x' => 'to avert evil' },
# 'toleh'	=> { 'x' => 'to look back' },
 'tolok'	=> { 'x' => 'equal',
		     '#' => '; matching' },
 'tolol'	=> { 'x' => 'stupid' },
 'tolong'	=> { 'x' => 'assistance',
		     '#' => 'to help; please' },
# 'tolong-menolong'	=> { 'x' => 'to help one another' },
 'tombak'	=> { 'x' => 'spear',
		     '#' => '; lance; javelin' },
# 'tombol'	=> { 'x' => '(1)knob (2)knot (in wood)' },
 'tompok'	=> { 'x' => 'spot',
		     '#' => 'mark; blotch (2)heap; pile',
		     't' => 'n' },
 'tong'		=> { 'x' => 'barrel',
		     '#' => '; bin' },
# 'tonggek'	=> { 'x' => 'protruding (of buttocks)' },
 'tongkang'	=> { 'x' => 'lighter',
		     '#' => 'flat-bottomed boat or barge' },
 'tongkat'	=> { 'x' => 'walking-stick' },
 'tongkol'	=> { 'x' => 'chunk',
		     '#' => 'cob (of maize); nugget',
		     't' => 'n' },
 'tonjol'	=> { 'x' => 'protrude',
		     '#' => 'a hump or protrusion',
		     't' => 'v' },
 'tonton'	=> { 'x' => 'watch',
		     '#' => '(as a spectator)',
		     't' => 'v' },
 'tontonan'	=> { 'x' => 'show',
		     '#' => 'or display',
		     't' => 'n' },
# 'tonyoh'	=> { 'x' => 'to scrub thoroughly',
#		     't' => 'v' },
 'topang'	=> { 'x' => 'support',
		     '#' => '; prop',
		     't' => 'v' },
 'topeng'	=> { 'x' => 'mask',
		     't' => 'n' },
 'topi'		=> { 'x' => 'hat',
		     't' => 'n' },
 'toreh'	=> { 'x' => 'tap',
		     '#' => 'e.g. rubber',
		     't' => 'v' },
 'torehan'	=> { 'x' => 'incision',
		     't' => 'n' },
# 'toyol'	=> { 'x' => 'a type of evil spirit or ghost' },
 'trengkas'	=> { 'x' => 'shorthand' },
 'tua'		=> { 'x' => 'old',
		     '#' => 'ripe (2)dark (of colour)' },
 'tua-tua'	=> { 'x' => 'old',
		     '#' => 'ripe; mature' },
 'tuah'		=> { 'x' => 'luck',
		     '#' => '; fortune' },
 'tuai'		=> { 'x' => 'harvest',
		     '#' => 'harvesting knife',
		     't' => 'v' },
 'tuak'		=> { 'x' => 'toddy',
		     '#' => 'palm-wine' },
 'tuala'	=> { 'x' => 'towel' },
 'tuan'		=> { 'x' => 'sir',
		     '#' => '; master' },
 'tuan rumah'	=> { 'x' => 'landlord' },
# 'tuang'	=> { 'x' => '(1)to pour (2)to be absent' },
 'tuas'		=> { 'x' => 'lever' },
# 'tuba'		=> { 'x' => 'poisonous root used in fishing' },
 'tubi'		=> { 'x' => 'persistently',
		     '#' => '; repeatedly' },
 'tubuh'	=> { 'x' => 'body' },
# 'tubuh badan'	=> { 'x' => 'the whole body' },
 'tuduh'	=> { 'x' => 'accuse',
		     't' => 'v' },
 'tuduhan'	=> { 'x' => 'accusation' },
 'tuding'	=> { 'x' => 'index finger',
		     '#' => 'to point at',
		     't' => 'n' },
 'tudung'	=> { 'x' => 'cover',
		     '#' => '; lid; veil' },
 'tugas'	=> { 'x' => 'duty',
		     '#' => '; task' },
 'tugasan'	=> { 'x' => 'assignment' },
 'tugu'		=> { 'x' => 'monument' },
 'tuhan'	=> { 'x' => 'god' },
 'tujah'	=> { 'x' => 'stab',
		     '#' => '; to pierce',
		     't' => 'v' },
 'tuju'		=> { 'x' => 'direction' },
 'tujuan'	=> { 'x' => 'intention',
		     '#' => '; purpose; aim' },
# 'tukang'	=> { 'x' => 'skilled workman' },
 'tukar'	=> { 'x' => 'change',
		     '#' => '; to exchange',
		     't' => 'v' },
 'tukaran'	=> { 'x' => 'replacement' },
 'tukar ganti'	=> { 'x' => 'substitute',
		     't' => 'v' },
 'tukul'	=> { 'x' => 'hammer',
		     't' => 'n' },
 'tulang'	=> { 'x' => 'bone' },
 'tular'	=> { 'x' => 'contagious',
		     '#' => 'infectious; to spread (disease)' },
# 'tulat'	=> { 'x' => 'third day after today' },
 'tulen'	=> { 'x' => 'pure',
		     '#' => '; genuine' },
 'tuli'		=> { 'x' => 'deaf' },
 'tulis'	=> { 'x' => 'write',
		     't' => 'v' },
 'tulisan'	=> { 'x' => 'writing' },
 'tulus'	=> { 'x' => 'honest',
		     '#' => '; sincere; heartfelt; straightforward' },
 'tumbang'	=> { 'x' => 'collapse',
		     '#' => '; fall' },
# 'tumbesar'	=> { 'x' => 'growth (of plants, etc.)' },
 'tumbuh'	=> { 'x' => 'develop',
		     '#' => '; to grow',
		     't' => 'v' },
 'tumbuhan'	=> { 'x' => 'growth' },
 'tumbuh-tumbuhan'	=> { 'x' => 'plants' },
 'tumbuk'	=> { 'x' => 'punch',
		     '#' => '(2)to pound',
		     't' => 'v' },
 'tumis'	=> { 'x' => 'fry',
		     't' => 'v' },
# 'tumit'	=> { 'x' => 'heel (of foot)' },
 'tumpah'	=> { 'x' => 'spill',
		     't' => 'v' },
 'tumpahan'	=> { 'x' => 'spillage' },
 'tumpah darah'	=> { 'x' => 'motherland' },
# 'tumpang'	=> { 'x' => '(1)to reside (2)to take a lift or ride' },
 'tumpangan'	=> { 'x' => 'lodging' },
 'tumpas'	=> { 'x' => 'annihilate',
		     '#' => '; to destroy',
		     't' => 'v' },
 'tumpat'	=> { 'x' => 'compact',
		     '#' => '; packed; crowded; full' },
 'tumpu'	=> { 'x' => 'focus',
		     '#' => 'to concentrate (2)to support',
		     't' => 'v' },
 'tumpuan'	=> { 'x' => 'focus',
		     '#' => '; support' },
 'tumpul'	=> { 'x' => 'blunt' },
# 'tun'		=> { 'x' => 'an honourable title' },
# 'tunai'	=> { 'x' => '(1)cash (2)accomplished' },
 'tunang'	=> { 'x' => 'fianc&#233',
		     '#' => 'or fiancee' },
 'tunas'	=> { 'x' => 'bud',
		     '#' => '; a sprout',
		     't' => 'n' },
 'tunda'	=> { 'x' => 'tow',
		     '#' => '(2)to postpone',
		     't' => 'v' },
 'tunduk'	=> { 'x' => 'bow',
		     '#' => '; to submit',
		     't' => 'v' },
# 'tunggak'	=> { 'x' => '(1)to be in arrears (2)tree stump' },
 'tunggakan'	=> { 'x' => 'arrears' },
 'tunggal'	=> { 'x' => 'sole',
		     '#' => '; solitary; single' },
# 'tunggang'	=> { 'x' => '(1)upside-down (2)to ride' },
 'tunggu'	=> { 'x' => 'wait',
		     't' => 'v' },
# 'tunggul'	=> { 'x' => 'tree stump' },
 'tungku'	=> { 'x' => 'trivet',
		     '#' => '; brazier' },
 'tungkus lumus'	=> { 'x' => 'overworked' },
 'tunjal'	=> { 'x' => 'poke',
		     '#' => '; to thrust',
		     't' => 'v' },
 'tunjam'	=> { 'x' => 'dive',
		     '#' => '; to plunge',
		     't' => 'v' },
 'tunjuk'	=> { 'x' => 'show',
		     '#' => '; to point',
		     't' => 'v' },
 'tunjuk ajar'	=> { 'x' => 'guidance' },
 'tunjuk perasaan'	=> { 'x' => 'demonstration' },
 'tuntun'	=> { 'x' => 'guide',
		     '#' => 'to lead by the hand',
		     't' => 'v' },
 'tuntut'	=> { 'x' => 'claim',
		     '#' => '(2)to study',
		     't' => 'v' },
 'tuntutan'	=> { 'x' => 'claim',
		     '#' => '; a demand',
		     't' => 'n' },
 'tupai'	=> { 'x' => 'squirrel' },
 'turas'	=> { 'x' => 'filter',
		     't' => 'v' },
 'turun'	=> { 'x' => 'descend',
		     '#' => 'to disembark; to come down',
		     't' => 'v' },
 'turunan'	=> { 'x' => 'descent',
		     '#' => 'genealogy ' },
 'turun-temurun'	=> { 'x' => 'hereditary',
		     '#' => 'from generation to generation' },
# 'turus'	=> { 'x' => 'main post or pillar' },
 'turut'	=> { 'x' => 'follow',
		     '#' => 'to go along',
		     't' => 'v' },
 'turutan'	=> { 'x' => 'sequence' },
 'tusuk'	=> { 'x' => 'skewer',
		     '#' => 'pin ' },
 'tut'		=> { 'x' => 'graft',
		     't' => 'n' },
 'tutup'	=> { 'x' => 'shut',
		     '#' => '; to close',
		     't' => 'v' },
 'tutur'	=> { 'x' => 'speak',
		     '#' => '; to talk; to converse',
		     't' => 'v' },
 'ubi'		=> { 'x' => 'parsnip',
		     '#' => 'tapioca ' },
 'ubin'		=> { 'x' => 'tile' },
 'ubur-ubur'	=> { 'x' => 'jellyfish' },
 'udang'	=> { 'x' => 'prawn' },
 'udik'		=> { 'x' => 'upstream' },
 'ufuk'		=> { 'x' => 'horizon',
		     '#' => 'limit of knowledge or interests' },
# 'ulam'		=> { 'x' => 'raw vegetable to be eaten with rice' },
# 'ulama'	=> { 'x' => 'muslim scholar' },
 'ular'		=> { 'x' => 'snake' },
 'ulat'		=> { 'x' => 'maggot',
		     '#' => '; caterpillar; larva; worm' },
 'ulung'	=> { 'x' => 'first-born',
		     '#' => 'eldest; superior' },
 'umang-umang'	=> { 'x' => 'hermit-crab' },
 'umat'		=> { 'x' => 'humanity',
		     '#' => 'religious sect or community; follower (of religion)' },
 'umbi'		=> { 'x' => 'tuber',
		     '#' => 'corm (underground stem)',
		     't' => 'n' },
# 'umbut'	=> { 'x' => 'edible palm pith' },
 'umpil'	=> { 'x' => 'lever' },
 'undan'	=> { 'x' => 'swan',
		     '#' => 'pelican ' },
 'unggas'	=> { 'x' => 'birds' },
 'unggis'	=> { 'x' => 'gnaw',
		     '#' => 'nibble ' },
# 'unggun'	=> { 'x' => 'stack or pile (of wood)' },
 'ungka'	=> { 'x' => 'gibbon' },
 'ungu'		=> { 'x' => 'purple' },
 'unta'		=> { 'x' => 'camel' },
 'untai'	=> { 'x' => 'chain',
		     '#' => 'numeral coefficient for necklace,etc.',
		     't' => 'n' },
 'untut'	=> { 'x' => 'elephantiasis' },
 'upacara'	=> { 'x' => 'ceremony' },
# 'urat'		=> { 'x' => 'vein or nerve' },
 'uri'		=> { 'x' => 'placenta' },
 'usang'	=> { 'x' => 'decrepit',
		     '#' => '; dilapidated; obsolete' },
 'usus'		=> { 'x' => 'intestine' },
 'utas'		=> { 'x' => 'string',
		     '#' => 'chain ',
		     't' => 'n' },
 'vaksin'	=> { 'x' => 'vaccine',
		     't' => 'n' },
 'van'		=> { 'x' => 'van' },
 'vanila'	=> { 'x' => 'vanilla',
		     '#' => 'noun or adj?' },
 'video'	=> { 'x' => 'video',
		     '#' => 'noun or adj?' },
 'virus'	=> { 'x' => 'virus',
		     't' => 'n' },
 'visa'		=> { 'x' => 'visa',
		     't' => 'n' },
 'vitamin'	=> { 'x' => 'vitamin',
		     't' => 'n' },
 'wabak'	=> { 'x' => 'epidemic',
		     't' => 'n' },
 'wacana'	=> { 'x' => 'discourse',
		     '#' => 'speech; lecture ',
		     't' => 'n' },
 'wafat'	=> { 'x' => 'pass away',
		     't' => 'v' },
 'waham'	=> { 'x' => 'suspicion',
		     '#' => 'doubt ' },
# 'wahyu'	=> { 'x' => 'revelation through a dream' },
 'waja'		=> { 'x' => 'steel' },
# 'wajah'	=> { 'x' => 'facial features' },
# 'wajik'	=> { 'x' => 'sweet sticky rice cake' },
 'wali'		=> { 'x' => 'sponsor',
		     '#' => '; godparent; guardian' },
 'warak'	=> { 'x' => 'devout',
		     '#' => 'pious ' },
# 'wargakota'	=> { 'x' => 'inhabitant of a city' },
 'warkah'	=> { 'x' => 'epistle',
		     '#' => 'letter ' },
 'warung'	=> { 'x' => 'stall' },
 'wasangka'	=> { 'x' => 'suspicion' },
 'waswas'	=> { 'x' => 'indecision',
		     '#' => '; hesitation; doubt' },
# 'watan'	=> { 'x' => 'native land' },
# 'watikah'	=> { 'x' => 'letter of authority' },
 'wau'		=> { 'x' => 'kite' },
 'wawancara'	=> { 'x' => 'interview',
		     't' => 'n' },
 'wawasan'	=> { 'x' => 'vision' },
# 'wayang'	=> { 'x' => 'performance on a screen' },
 'wayang gambar'	=> { 'x' => 'cinema',
		     '#' => 'movie ' },
# 'wayang kulit'	=> { 'x' => 'traditional malay shadow play' },
 'wenang'	=> { 'x' => 'power' },
 'wibawa'	=> { 'x' => 'authority' },
 'wilayah'	=> { 'x' => 'province',
		     '#' => 'administrative territory',
		     't' => 'n' },
 'wisma'	=> { 'x' => 'house' },
 'x-ray'	=> { 'x' => 'x-ray' },
 'yahudi'	=> { 'x' => 'jew' },
 'yang teramat mulia'	=> { 'x' => 'highness' },
 'yatim'	=> { 'x' => 'orphan' },
# 'yayasan'	=> { 'x' => 'foundation (institution or fund)' },
 'yu'		=> { 'x' => 'shark' },
 'yuran'	=> { 'x' => 'fee' },
 'zahid'	=> { 'x' => 'ascetic',
		     '#' => 'recluse ' },
 'zaitun'	=> { 'x' => 'olive' },
 'zakar'	=> { 'x' => 'penis' },
 'zakat'	=> { 'x' => 'tithe' },
 'zaman'	=> { 'x' => 'epoch',
		     '#' => 'particular period or age inhistory; era' },
 'zamrud'	=> { 'x' => 'emerald' },
# 'zapin'	=> { 'x' => 'a song and dance of arab origin' },
 'zarah'	=> { 'x' => 'particle',
		     '#' => 'atom ' },
# 'zat'		=> { 'x' => 'nutritional value' },
 'zirafah'	=> { 'x' => 'giraffe' },
 'zuhal'	=> { 'x' => 'saturn' },
 'zuhrah'	=> { 'x' => 'venus' },
 'zuhur'	=> { 'x' => 'noon' },
# 'zuriat'	=> { 'x' => 'descent: genealogy' },
);
}

1;

